@@ -10,7 +10,7 @@
 #include <fcntl.h>
 #include <ctype.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
@@ -484,9 +484,9 @@ _slave_mode_help(Evas_Object *edje EINA_UNUSED, char *args EINA_UNUSED)
         "\t     * STRING_SET <set length> \"string1\" \"string2\" ...\n"
         "\t     * INT_SET <set length> integer1 integer2 integer3 ...\n"
         "\t     * FLOAT_SET <set length> float1 float2 float3 ...\n"
-        "\t     * STRING_INT \"message\" interger\n"
+        "\t     * STRING_INT \"message\" integer\n"
         "\t     * STRING_FLOAT \"message\" float\n"
-        "\t     * STRING_INT_SET \"string\" <set length> interger1 ...\n"
+        "\t     * STRING_INT_SET \"string\" <set length> integer1 ...\n"
         "\t     * STRING_FLOAT_SET \"string\" <set length> float1 float2 ...\n"
         "\tinfo <part>\n"
         "\t   Print part geometry: <x>,<y>,<w>,<h>\n"
@@ -590,6 +590,7 @@ _slave_mode(void *data, Ecore_Fd_Handler *fd_handler)
 
    return ECORE_CALLBACK_RENEW;
 }
+
 #endif
 
 static void
@@ -835,6 +836,27 @@ _edje_reload(void *data EINA_UNUSED, Evas_Object *obj, const char *emission EINA
    _edje_load_or_show_error(obj, file, group);
 }
 
+static void
+_edje_circul(void *data, Evas_Object *obj EINA_UNUSED, void *event_info)
+{
+   char buf[1024] = "";
+   Eina_List *parts = event_info;
+   Eina_List *l;
+   char *part_name;
+   char *group = data;
+
+   part_name = eina_list_data_get(eina_list_last(parts));
+   strncat(buf, part_name, strlen(part_name));
+   EINA_LIST_FOREACH(parts, l, part_name)
+     {
+        strncat(buf, " -> ", strlen(" -> "));
+        strncat(buf, part_name, strlen(part_name));
+     }
+
+   fprintf(stderr, "Group '%s' have a circul dependency between parts: %s\n",
+           group, buf);
+}
+
 static Eina_Bool
 _edje_load_or_show_error(Evas_Object *edje, const char *file, const char *group)
 {
@@ -930,6 +952,7 @@ _create_edje(Evas *evas, const struct opts *opts)
              edje_file_collection_list_free(groups);
           }
      }
+   evas_object_smart_callback_add(edje, "circular,dependency", _edje_circul, opts->group);
 
    edje_object_size_max_get(edje, &maxw, &maxh);
    edje_object_size_min_get(edje, &minw, &minh);
@@ -1102,9 +1125,9 @@ main(int argc, char **argv)
    f = eina_file_open(opts.file, EINA_FALSE);
    if (edje_mmap_3d_has(f, group))
      {
-        Eina_List* engine_list, *n;
+        Eina_List *engine_list, *n;
         Eina_Bool opengl_x11_has = EINA_FALSE, wayland_egl_has = EINA_FALSE;
-        const char* engine;
+        const char *engine;
         engine_list = ecore_evas_engines_get();
         EINA_LIST_FOREACH(engine_list, n, engine)
           {
