@@ -197,7 +197,9 @@ _dispatch(Client *src, void *buffer)
                   hdr->cid = SWAP_32(src->cid);
                   hdr->size = SWAP_32(hdr->size);
                   hdr->opcode = SWAP_32(hdr->opcode);
-                  efl_io_writer_write(dest->client, &s, NULL);
+                  if (efl_io_writer_write(dest->client, &s, NULL) !=
+                      EINA_ERROR_NO_ERROR)
+                    ERR("Cannot write to client [%s:%i]", dest->app_name, (int)dest->pid);
                   INF("Transfer of %d bytes from %s(%d) to %s(%d): operation %s\n",
                         hdr->size,
                         src->app_name, src->pid,
@@ -567,7 +569,7 @@ _local_server_create(void)
    snprintf(path, sizeof(path) - 1, "%s/%s/%s/%i", socket_path,
          LOCAL_SERVER_PATH, LOCAL_SERVER_NAME, LOCAL_SERVER_PORT);
 
-   loop = ecore_main_loop_get();
+   loop = efl_main_loop_get();
 
 #ifdef EFL_NET_SERVER_UNIX_CLASS
    _local_server = efl_add(EFL_NET_SERVER_SIMPLE_CLASS, loop,
@@ -590,7 +592,6 @@ _local_server_create(void)
 #ifdef EFL_NET_SERVER_UNIX_CLASS
    {
       Eo *inner_server = efl_net_server_simple_inner_server_get(_local_server);
-      efl_net_server_unix_unlink_before_bind_set(inner_server, EINA_TRUE);
       efl_net_server_unix_leading_directories_create_set(inner_server, EINA_TRUE, 0700);
    }
 #endif
@@ -622,7 +623,7 @@ _remote_server_create(void)
    Eina_Bool ret = EINA_FALSE;
    char address[256];
 
-   loop = ecore_main_loop_get();
+   loop = efl_main_loop_get();
 
    _remote_server = efl_add(EFL_NET_SERVER_SIMPLE_CLASS, loop,
                     efl_net_server_simple_inner_class_set(efl_added, EFL_NET_SERVER_TCP_CLASS));
