@@ -17,6 +17,7 @@ void test_bg_plain(void *data, Evas_Object *obj, void *event_info);
 void test_bg_image(void *data, Evas_Object *obj, void *event_info);
 void test_bg_options(void *data, Evas_Object *obj, void *event_info);
 void test_bg_window(void *data, Evas_Object *obj, void *event_info);
+void test_bg_scale_type(void *data, Evas_Object *obj, void *event_info);
 void test_icon(void *data, Evas_Object *obj, void *event_info);
 void test_icon_transparent(void *data, Evas_Object *obj, void *event_info);
 void test_icon_standard(void *data, Evas_Object *obj, void *event_info);
@@ -30,6 +31,7 @@ void test_box_align(void *data, Evas_Object *obj, void *event_info);
 void test_box_stack(void *data, Evas_Object *obj, void *event_info);
 void test_ui_box(void *data, Evas_Object *obj, void *event_info);
 void test_button(void *data, Evas_Object *obj, void *event_info);
+void test_ui_button(void *data, Evas_Object *obj, void *event_info);
 void test_cnp(void *data, Evas_Object *obj, void *event_info);
 void test_events(void *data, Evas_Object *obj, void *event_info);
 void test_transit(void *data, Evas_Object *obj, void *event_info);
@@ -108,6 +110,8 @@ void test_inwin3(void *data, Evas_Object *obj, void *event_info);
 void test_scaling(void *data, Evas_Object *obj, void *event_info);
 void test_scaling2(void *data, Evas_Object *obj, void *event_info);
 void test_slider(void *data, Evas_Object *obj, void *event_info);
+void test_slider_interval(void *data, Evas_Object *obj, void *event_info);
+void test_ui_slider(void *data, Evas_Object *obj, void *event_info);
 void test_actionslider(void *data, Evas_Object *obj, void *event_info);
 void test_genlist(void *data, Evas_Object *obj, void *event_info);
 void test_genlist2(void *data, Evas_Object *obj, void *event_info);
@@ -137,6 +141,7 @@ void test_genlist_filter(void *data, Evas_Object *obj, void *event_info);
 void test_genlist_show_bring(void *data, Evas_Object *obj, void *event_info);
 void test_genlist_cache(void *data, Evas_Object *obj, void *event_info);
 void test_genlist_reusable(void *data, Evas_Object *obj, void *event_info);
+void test_genlist_item_show(void *data, Evas_Object *obj, void *event_info);
 void test_gesture_layer(void *data, Evas_Object *obj, void *event_info);
 void test_gesture_layer2(void *data, Evas_Object *obj, void *event_info);
 void test_gesture_layer3(void *data, Evas_Object *obj, void *event_info);
@@ -148,8 +153,8 @@ void test_table5(void *data, Evas_Object *obj, void *event_info);
 void test_table6(void *data, Evas_Object *obj, void *event_info);
 void test_table7(void *data, Evas_Object *obj, void *event_info);
 void test_table8(void *data, Evas_Object *obj, void *event_info);
-void test_ui_grid(void *data, Evas_Object *obj, void *event_info);
-void test_ui_grid_linear(void *data, Evas_Object *obj, void *event_info);
+void test_ui_table(void *data, Evas_Object *obj, void *event_info);
+void test_ui_table_linear(void *data, Evas_Object *obj, void *event_info);
 void test_gengrid(void *data, Evas_Object *obj, void *event_info);
 void test_gengrid2(void *data, Evas_Object *obj, void *event_info);
 void test_gengrid3(void *data, Evas_Object *obj, void *event_info);
@@ -166,6 +171,7 @@ void test_win_state2(void *data, Evas_Object *obj, void *event_info);
 void test_win_stack(void *data, Evas_Object *obj, void *event_info);
 void test_progressbar(void *data, Evas_Object *obj, void *event_info);
 void test_progressbar2(void *data, Evas_Object *obj, void *event_info);
+void test_ui_progressbar(void *data, Evas_Object *obj, void *event_info);
 void test_fileselector(void *data, Evas_Object *obj, void *event_info);
 void test_separator(void *data, Evas_Object *obj, void *event_info);
 void test_scroller(void *data, Evas_Object *obj, void *event_info);
@@ -173,7 +179,14 @@ void test_scroller2(void *data, Evas_Object *obj, void *event_info);
 void test_scroller3(void *data, Evas_Object *obj, void *event_info);
 void test_scroller4(void *data, Evas_Object *obj, void *event_info);
 void test_scroller5(void *data, Evas_Object *obj, void *event_info);
+void test_efl_ui_scroller(void *data, Evas_Object *obj, void *event_info);
+void test_efl_ui_scroller2(void *data, Evas_Object *obj, void *event_info);
 void test_spinner(void *data, Evas_Object *obj, void *event_info);
+void test_ui_spin(void *data, Evas_Object *obj, void *event_info);
+void test_ui_spin_button(void *data, Evas_Object *obj, void *event_info);
+void test_ui_datepicker(void *data, Evas_Object *obj, void *event_info);
+void test_ui_timepicker(void *data, Evas_Object *obj, void *event_info);
+void test_ui_tags(void *data, Evas_Object *obj, void *event_info);
 void test_index(void *data, Evas_Object *obj, void *event_info);
 void test_index2(void *data, Evas_Object *obj, void *event_info);
 void test_index3(void *data, Evas_Object *obj, void *event_info);
@@ -194,9 +207,11 @@ void test_menu2(void *data, Evas_Object *obj, void *event_info);
 void test_panel(void *data, Evas_Object *obj, void *event_info);
 void test_panel2(void *data, Evas_Object *obj, void *event_info);
 void test_panes(void *data, Evas_Object *obj, void *event_info);
+void test_panes_minsize(void *data, Evas_Object *obj, void *event_info);
 void test_calendar(void *data, Evas_Object *obj, void *event_info);
 void test_calendar2(void *data, Evas_Object *obj, void *event_info);
 void test_calendar3(void *data, Evas_Object *obj, void *event_info);
+void test_efl_ui_calendar(void *data, Evas_Object *obj, void *event_info);
 void test_map(void *data, Evas_Object *obj, void *event_info);
 void test_weather(void *data, Evas_Object *obj, void *event_info);
 void test_flip(void *data, Evas_Object *obj, void *event_info);
@@ -239,6 +254,8 @@ void test_focus3(void *data, Evas_Object *obj, void *event_info);
 void test_focus_object_style(void *data, Evas_Object *obj, void *event_info);
 void test_focus_object_policy(void *data, Evas_Object *obj, void *event_info);
 void test_focus4(void *data, Evas_Object *obj, void *event_info);
+void test_focus5(void *data, Evas_Object *obj, void *event_info);
+void test_focus6(void *data, Evas_Object *obj, void *event_info);
 void test_flipselector(void *data, Evas_Object *obj, void *event_info);
 void test_diskselector(void *data, Evas_Object *obj, void *event_info);
 void test_colorselector(void *data, Evas_Object *obj, void *event_info);
@@ -254,7 +271,7 @@ void test_win_socket(void *data, Evas_Object *obj, void *event_info);
 void test_win_plug(void *data, Evas_Object *obj, void *event_info);
 void test_win_wm_rotation(void *data, Evas_Object *obj, void *event_info);
 void test_grid(void *data, Evas_Object *obj, void *event_info);
-void test_grid_static(void *data, Evas_Object *obj, void *event_info);
+void test_ui_table_static(void *data, Evas_Object *obj, void *event_info);
 void test_glview_simple(void *data, Evas_Object *obj, void *event_info);
 void test_glview(void *data, Evas_Object *obj, void *event_info);
 void test_glview_manygears(void *data, Evas_Object *obj, void *event_info);
@@ -264,13 +281,21 @@ void test_naviframe(void *data, Evas_Object *obj, void *event_info);
 void test_naviframe2(void *data, Evas_Object *obj, void *event_info);
 void test_naviframe3(void *data, Evas_Object *obj, void *event_info);
 void test_naviframe_complex(void *data, Evas_Object *obj, void *event_info);
+void test_ui_stack(void *data, Evas_Object *obj, void *event_info);
 //void test_factory(void *data, Evas_Object *obj, void *event_info);
 void test_datetime(void *data, Evas_Object *obj, void *event_info);
 void test_ui_clock(void *data, Evas_Object *obj, void *event_info);
 void test_popup(void *data, Evas_Object *obj, void *event_info);
+void test_ui_popup(void *data, Evas_Object *obj, void *event_info);
+void test_ui_popup_alert(void *data, Evas_Object *obj, void *event_info);
+void test_ui_popup_alert_scroll(void *data, Evas_Object *obj, void *event_info);
+void test_ui_popup_alert_text(void *data, Evas_Object *obj, void *event_info);
+void test_ui_popup_anchor(void *data, Evas_Object *obj, void *event_info);
 void test_dayselector(void *data, Evas_Object *obj, void *event_info);
 void test_image(void *data, Evas_Object *obj, void *event_info);
+void test_image_scale_type(void *data, Evas_Object *obj, void *event_info);
 void test_image_swallow_align(void *data, Evas_Object *obj, void *event_info);
+void test_image_prescale(void *data, Evas_Object *obj, void *event_info);
 void test_remote_image(void *data, Evas_Object *obj, void *event_info);
 void test_click_image(void *data, Evas_Object *obj, void *event_info);
 void test_load_image(void *data, Evas_Object *obj, void *event_info);
@@ -294,15 +319,20 @@ void test_dnd_multi_features(void *data, Evas_Object *obj, void *event_info);
 void test_dnd_types(void *data, Evas_Object *obj, void *event_info);
 void test_task_switcher(void *data, Evas_Object *obj, void *event_info);
 void test_win_dialog(void *data, Evas_Object *obj, void *event_info);
+void test_win_indicator(void *data, Evas_Object *obj, void *event_info);
+void test_win_modal(void *data, Evas_Object *obj, void *event_info);
 void test_win_modal(void *data, Evas_Object *obj, void *event_info);
 void test_box_disable(void *data, Evas_Object *obj, void *event_info);
 void test_layout_disable(void *data, Evas_Object *obj, void *event_info);
+void test_part_background(void *data, Evas_Object *obj, void *event_info);
+void test_part_shadow(void *data, Evas_Object *obj, void *event_info);
 
 void test_colorclass(void *data, Evas_Object *obj, void *event_info);
 
 void test_code_welcome(void *data, Evas_Object *obj, void *event_info);
 void test_code_editor(void *data, Evas_Object *obj, void *event_info);
 void test_code_syntax(void *data, Evas_Object *obj, void *event_info);
+void test_code_syntax_tabbed(void *data, Evas_Object *obj, void *event_info);
 void test_code_mirror(void *data, Evas_Object *obj, void *event_info);
 void test_code_log(void *data, Evas_Object *obj, void *event_info);
 void test_code_diff(void *data, Evas_Object *obj, void *event_info);
@@ -310,15 +340,43 @@ void test_code_diff_inline(void *data, Evas_Object *obj, void *event_info);
 
 void test_efl_ui_text(void *data, Evas_Object *obj, void *event_info);
 void test_efl_ui_text_label(void *data, Evas_Object *obj, void *event_info);
+void test_efl_ui_text_async(void *data, Evas_Object *obj, void *event_info);
+void test_ui_text_item_factory(void *data, Evas_Object *obj, void *event_info);
 void test_evas_mask(void *data, Edje_Object *obj, void *event_info);
 void test_gfx_filters(void *data, Evas_Object *obj, void *event_info);
 void test_evas_snapshot(void *data, Evas_Object *obj, void *event_info);
 void test_evas_map(void *data, Edje_Object *obj, void *event_info);
 void test_efl_gfx_map(void *data, Edje_Object *obj, void *event_info);
+void test_ui_textpath(void *data, Edje_Object *obj, void *event_info);
 
-Evas_Object *win, *tbx; // TODO: refactoring
-void *tt;
-Eina_List *tests;
+void test_efl_anim_alpha(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_rotate(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_rotate_relative(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_rotate_absolute(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_scale(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_scale_relative(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_scale_absolute(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_translate(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_translate_absolute(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_group_parallel(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_group_sequential(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_event_anim(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_pause(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_repeat(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_start_delay(void *data, Evas_Object *obj, void *event_info);
+void test_efl_anim_interpolator(void *data, Evas_Object *obj, void *event_info);
+
+void test_gesture_framework(void *data, Evas_Object *obj, void *event_info);
+
+void test_ui_tab_pager(void *data, Evas_Object *obj, void *event_info);
+
+static void _list_udpate(void);
+
+static Evas_Object *win, *tbx, *entry; // TODO: refactoring
+static void *tt;
+static Eina_List *tests;
+static Eina_Bool hide_legacy = EINA_FALSE;
+static Eina_Bool hide_beta = EINA_FALSE;
 
 struct elm_test
 {
@@ -330,6 +388,8 @@ struct elm_test
    Evas_Object *btn;
 
    void (*cb)(void *, Evas_Object *, void *);
+
+   Eina_Bool is_eo;
 };
 
 static int
@@ -342,20 +402,21 @@ _elm_test_sort(const void *pa, const void *pb)
 }
 
 static void
-_elm_test_add(Eina_List **p_list, const char *icon, const char *category, const char *name, void (*cb)(void *, Evas_Object *, void *))
+_elm_test_add(Eina_List **p_list, const char *icon, const char *category, const char *name, void (*cb)(void *, Evas_Object *, void *), Eina_Bool is_eo)
 {
    struct elm_test *t = calloc(1, sizeof(struct elm_test));
    t->icon = icon;
    t->category = category;
    t->name = name;
    t->cb = cb;
+   t->is_eo = is_eo;
    *p_list = eina_list_sorted_insert(*p_list, _elm_test_sort, t);
 }
 
 void
 my_win_del(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
-   elm_exit(); /* exit the program's main loop that runs in elm_run() */
+   efl_exit(0); /* exit the program's main loop that runs in elm_run() */
 }
 
 static void
@@ -365,6 +426,20 @@ _ui_tg_changed(void *data, Evas_Object *obj, void *event_info)
    elm_config_mirrored_set(elm_check_state_get(obj));
 }
 
+static void
+_legacy_chk_changed(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
+{
+   hide_legacy = elm_check_state_get(obj);
+   _list_udpate();
+}
+
+static void
+_beta_chk_changed(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
+{
+   hide_beta = elm_check_state_get(obj);
+   _list_udpate();
+}
+
 static void
 _frame_clicked(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
@@ -404,6 +479,10 @@ _menu_create(const char *option_str)
    _clear_menu();
    EINA_LIST_FOREACH(tests, l, t)
      {
+        if (hide_legacy && !t->is_eo)
+          continue;
+        if (hide_beta && t->is_eo)
+          continue;
         if (option_str &&
             !(strcasestr(t->name, option_str) || strcasestr(t->category, option_str)))
           continue;
@@ -454,6 +533,12 @@ _menu_create(const char *option_str)
                   elm_object_part_content_set(bt, "icon", ic);
                   evas_object_show(ic);
                }
+             else if (t->is_eo)
+               {
+                  ic = efl_add(EFL_UI_IMAGE_CLASS, win,
+                               efl_ui_image_icon_set(efl_added, "user-bookmarks"));
+                  elm_object_part_content_set(bt, "icon", ic);
+               }
              elm_box_pack_end(tbx2, bt);
              evas_object_show(bt);
              evas_object_smart_callback_add(bt, "clicked", t->cb, win);
@@ -474,6 +559,14 @@ _entry_changed_cb(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EIN
    _menu_create(str);
 }
 
+static void
+_list_udpate(void)
+{
+   const char *str = elm_entry_entry_get(entry);
+   if (!str) return;
+   _menu_create(str);
+}
+
 static void
 _entry_activated_cb(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
@@ -522,7 +615,7 @@ _space_removed_string_get(const char *name)
 static void
 my_win_main(const char *autorun, Eina_Bool test_win_only)
 {
-   Evas_Object *bg = NULL, *bx0 = NULL, *bx1 = NULL, *lb = NULL;
+   Evas_Object *bg = NULL, *bx0 = NULL, *bx1 = NULL, *lb = NULL, *chk = NULL;
    Evas_Object *fr = NULL, *tg = NULL, *sc = NULL, *en = NULL;
    Eina_List *l = NULL;
    struct elm_test *t = NULL;
@@ -545,7 +638,11 @@ my_win_main(const char *autorun, Eina_Bool test_win_only)
     * You can also set the title of the window at the same time.
     *   ex) win = elm_win_util_standard_add("main", "Elementary Tests"); */
    win = elm_win_add(NULL, "main", ELM_WIN_BASIC);
-   if (!win) exit(1);
+   if (!win)
+     {
+        efl_exit(1);
+        return ;
+     }
 
    explode_win_enable(win);
    /* Set the title of the window - This is in the titlebar. */
@@ -636,6 +733,21 @@ my_win_main(const char *autorun, Eina_Bool test_win_only)
    elm_box_pack_end(bx1, en);
    evas_object_show(en);
    elm_object_focus_set(en, EINA_TRUE);
+   entry = en;
+
+   chk = elm_check_add(win); // Check for hiding beta api
+   elm_object_text_set(chk, "Hide beta");
+   elm_check_state_set(chk, hide_beta);
+   evas_object_smart_callback_add(chk, "changed", _beta_chk_changed, NULL);
+   elm_box_pack_end(bx1, chk);
+   evas_object_show(chk);
+
+   chk = elm_check_add(win); // Check for hiding legacy api
+   elm_object_text_set(chk, "Hide Legacy");
+   elm_check_state_set(chk, hide_legacy);
+   evas_object_smart_callback_add(chk, "changed", _legacy_chk_changed, NULL);
+   elm_box_pack_end(bx1, chk);
+   evas_object_show(chk);
 
    sc = elm_scroller_add(win);
    elm_scroller_bounce_set(sc, EINA_FALSE, EINA_TRUE);
@@ -652,13 +764,13 @@ my_win_main(const char *autorun, Eina_Bool test_win_only)
 
 add_tests:
    tests = NULL;
-#define ADD_TEST(icon_, cat_, name_, cb_) _elm_test_add(&tests, icon_, cat_, name_, cb_)
+#define ADD_TEST(icon_, cat_, name_, cb_) _elm_test_add(&tests, icon_, cat_, name_, cb_, EINA_FALSE)
+#define ADD_TEST_EO(icon_, cat_, name_, cb_) _elm_test_add(&tests, icon_, cat_, name_, cb_, EINA_TRUE)
 
    //------------------------------//
    ADD_TEST(NULL, "Window / Background", "Bg Plain", test_bg_plain);
    ADD_TEST(NULL, "Window / Background", "Bg Image", test_bg_image);
    ADD_TEST(NULL, "Window / Background", "Bg Options", test_bg_options);
-   ADD_TEST(NULL, "Window / Background", "Bg EOAPI (Efl.Ui.Win)", test_bg_window);
    ADD_TEST(NULL, "Window / Background", "Window States", test_win_state);
    ADD_TEST(NULL, "Window / Background", "Window States 2", test_win_state2);
    ADD_TEST(NULL, "Window / Background", "Inwin", test_inwin);
@@ -672,6 +784,9 @@ add_tests:
    ADD_TEST(NULL, "Window / Background", "Window Keygrab Set", test_win_keygrab);
    ADD_TEST(NULL, "Window / Background", "Window Modal", test_win_modal);
    ADD_TEST(NULL, "Window / Background", "Window Stack", test_win_stack);
+   ADD_TEST(NULL, "Window / Background", "Window Indicator", test_win_indicator);
+   ADD_TEST_EO(NULL, "Window / Background", "Efl.Ui.Win (Bg part)", test_bg_window);
+   ADD_TEST_EO(NULL, "Window / Background", "Efl.Ui.Bg", test_bg_scale_type);
 
    //------------------------------//
    ADD_TEST(NULL, "Images", "Icon", test_icon);
@@ -685,10 +800,12 @@ add_tests:
    ADD_TEST(NULL, "Images", "Photo", test_photo);
    ADD_TEST(NULL, "Images", "Thumb", test_thumb);
    ADD_TEST(NULL, "Images", "Image", test_image);
+   ADD_TEST(NULL, "Images", "Image Scale Type", test_image_scale_type);
    ADD_TEST(NULL, "Images", "Image Align", test_image_swallow_align);
    ADD_TEST(NULL, "Images", "Image Remote", test_remote_image);
    ADD_TEST(NULL, "Images", "Image Click", test_click_image);
    ADD_TEST(NULL, "Images", "Image Async Load", test_load_image);
+   ADD_TEST(NULL, "Images", "Image Prescale", test_image_prescale);
    ADD_TEST(NULL, "Images", "Slideshow", test_slideshow);
    ADD_TEST(NULL, "Images", "Video", test_video);
 
@@ -714,13 +831,13 @@ add_tests:
    ADD_TEST(NULL, "Containers", "Grid", test_grid);
 
    //------------------------------//
-   ADD_TEST(NULL, "New Containers", "Ui.Box", test_ui_box);
-   ADD_TEST(NULL, "New Containers", "Ui.Grid", test_ui_grid);
-   ADD_TEST(NULL, "New Containers", "Ui.Grid Linear", test_ui_grid_linear);
-   ADD_TEST(NULL, "New Containers", "Ui.Grid.Static", test_grid_static);
+   ADD_TEST_EO(NULL, "Containers", "Efl.Ui.Box", test_ui_box);
+   ADD_TEST_EO(NULL, "Containers", "Efl.Ui.Table", test_ui_table);
+   ADD_TEST_EO(NULL, "Containers", "Efl.Ui.Table (Linear API)", test_ui_table_linear);
+   ADD_TEST_EO(NULL, "Containers", "Efl.Ui.Table_Static", test_ui_table_static);
 
    //------------------------------//
-   ADD_TEST(NULL, "New Events", "Event Refeed", test_events);
+   ADD_TEST_EO(NULL, "Events", "Event Refeed", test_events);
 
    //------------------------------//
    ADD_TEST(NULL, "Entries", "Entry", test_entry);
@@ -742,13 +859,17 @@ add_tests:
    ADD_TEST(NULL, "Entries", "Entry Anchor2", test_entry_anchor2);
    ADD_TEST(NULL, "Entries", "Entry Emoticon", test_entry_emoticon);
    ADD_TEST(NULL, "Entries", "Entry Password", test_entry_password);
-   ADD_TEST(NULL, "Entries", "Efl UI Text", test_efl_ui_text);
-   ADD_TEST(NULL, "Entries", "Efl UI Text Label", test_efl_ui_text_label);
+   ADD_TEST_EO(NULL, "Entries", "Efl.Ui.Text", test_efl_ui_text);
+   ADD_TEST_EO(NULL, "Entries", "Efl.Ui.Text Label", test_efl_ui_text_label);
+   ADD_TEST_EO(NULL, "Entries", "Efl.Ui.Text.Async", test_efl_ui_text_async);
+   ADD_TEST_EO(NULL, "Entries", "Ui.Text Item Factory", test_ui_text_item_factory);
+   ADD_TEST_EO(NULL, "Entries", "Efl.Ui.Tags", test_ui_tags);
 
    //------------------------------//
    ADD_TEST(NULL, "Advanced Entries", "Code Entry Markup", test_code_welcome);
    ADD_TEST(NULL, "Advanced Entries", "Code Editor", test_code_editor);
    ADD_TEST(NULL, "Advanced Entries", "Code Syntax", test_code_syntax);
+   ADD_TEST(NULL, "Advanced Entries", "Code Syntax (Tabbed)", test_code_syntax_tabbed);
    ADD_TEST(NULL, "Advanced Entries", "Mirrored Editor", test_code_mirror);
    ADD_TEST(NULL, "Advanced Entries", "Logger", test_code_log);
    ADD_TEST(NULL, "Advanced Entries", "Diff Comparison", test_code_diff);
@@ -756,6 +877,7 @@ add_tests:
 
    //------------------------------//
    ADD_TEST(NULL, "Buttons", "Button", test_button);
+   ADD_TEST_EO(NULL, "Buttons", "Efl.Ui.Button", test_ui_button);
 
    //------------------------------//
    ADD_TEST(NULL, "Prefs", "Prefs", test_prefs);
@@ -767,8 +889,7 @@ add_tests:
    ADD_TEST(NULL, "Effects", "Transit Zoom", test_transit_zoom);
    ADD_TEST(NULL, "Effects", "Transit Blend", test_transit_blend);
    ADD_TEST(NULL, "Effects", "Transit Fade", test_transit_fade);
-   ADD_TEST(NULL, "Effects", "Transit Resizable Flip",
-            test_transit_resizable_flip);
+   ADD_TEST(NULL, "Effects", "Transit Resizable Flip", test_transit_resizable_flip);
    ADD_TEST(NULL, "Effects", "Transit Custom", test_transit_custom);
    ADD_TEST(NULL, "Effects", "Transit Chain", test_transit_chain);
    ADD_TEST(NULL, "Effects", "Transit Tween", test_transit_tween);
@@ -779,8 +900,24 @@ add_tests:
    ADD_TEST(NULL, "Effects", "Flip Interactive", test_flip_interactive);
    ADD_TEST(NULL, "Effects", "Flip To", test_flip_to);
    ADD_TEST(NULL, "Effects", "Flip Page", test_flip_page);
-   ADD_TEST(NULL, "Effects", "Flip Page (EO API)", test_flip_page_eo);
    ADD_TEST(NULL, "Effects", "Animation", test_anim);
+   ADD_TEST_EO(NULL, "Effects", "Flip Page", test_flip_page_eo);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Alpha", test_efl_anim_alpha);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Rotate", test_efl_anim_rotate);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Rotate Relative", test_efl_anim_rotate_relative);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Rotate Absolute", test_efl_anim_rotate_absolute);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Scale", test_efl_anim_scale);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Scale Relative", test_efl_anim_scale_relative);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Scale Absolute", test_efl_anim_scale_absolute);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Translate", test_efl_anim_translate);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Translate Absolute", test_efl_anim_translate_absolute);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Group Parallel", test_efl_anim_group_parallel);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Group Sequential", test_efl_anim_group_sequential);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Event Animation", test_efl_anim_event_anim);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Pause", test_efl_anim_pause);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Repeat", test_efl_anim_repeat);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Start Delay", test_efl_anim_start_delay);
+   ADD_TEST_EO(NULL, "Effects", "Efl.Animation.Interpolator", test_efl_anim_interpolator);
 
    //------------------------------//
    ADD_TEST(NULL, "Edje External", "ExtButton", test_external_button);
@@ -850,6 +987,7 @@ add_tests:
    ADD_TEST(NULL, "Lists - Genlist", "Genlist Show/Bring", test_genlist_show_bring);
    ADD_TEST(NULL, "Lists - Genlist", "Genlist Cache", test_genlist_cache);
    ADD_TEST(NULL, "Lists - Genlist", "Genlist Reusable Contents", test_genlist_reusable);
+   ADD_TEST(NULL, "Lists - Genlist", "Genlist Item Show", test_genlist_item_show);
 
    //------------------------------//
 
@@ -885,6 +1023,7 @@ add_tests:
    ADD_TEST(NULL, "Input", "Gesture Layer 2", test_gesture_layer2);
    ADD_TEST(NULL, "Input", "Gesture Layer 3", test_gesture_layer3);
    ADD_TEST(NULL, "Input", "Multi Touch", test_multi);
+   ADD_TEST_EO(NULL, "Input", "Gesture", test_gesture_framework);
 
    //------------------------------//
    ADD_TEST(NULL, "Selectors", "Index", test_index);
@@ -921,6 +1060,7 @@ add_tests:
    ADD_TEST(NULL, "Scroller", "Scroller 3", test_scroller3);
    ADD_TEST(NULL, "Scroller", "Page Scroller", test_scroller4);
    ADD_TEST(NULL, "Scroller", "Scroller on Popup", test_scroller5);
+   ADD_TEST_EO(NULL, "Scroller", "Efl.Ui.Scroller", test_efl_ui_scroller);
 
    //------------------------------//
    // FIXME: add frame test
@@ -929,16 +1069,22 @@ add_tests:
 
    //------------------------------//
    ADD_TEST(NULL, "Range Values", "Spinner", test_spinner);
+   ADD_TEST_EO(NULL, "Range Values", "Efl.Ui.Spin", test_ui_spin);
+   ADD_TEST_EO(NULL, "Range Values", "Efl.Ui.Spin.Button", test_ui_spin_button);
    ADD_TEST(NULL, "Range Values", "Slider", test_slider);
    ADD_TEST(NULL, "Range Values", "Progressbar", test_progressbar);
    ADD_TEST(NULL, "Range Values", "Progressbar 2", test_progressbar2);
+   ADD_TEST_EO(NULL, "Range Values", "Efl.Ui.Progressbar", test_ui_progressbar);
+   ADD_TEST_EO(NULL, "Range Values", "Efl.Ui.Nstate", test_nstate);
+   ADD_TEST_EO(NULL, "Range Values", "Efl.Ui.Slider", test_ui_slider);
+   ADD_TEST_EO(NULL, "Range Values", "Efl.Ui.Slider_Interval", test_slider_interval);
 
    //------------------------------//
    ADD_TEST(NULL, "Booleans", "Check", test_check);
    ADD_TEST(NULL, "Booleans", "Check Toggle", test_check_toggle);
 
    //------------------------------//
-   ADD_TEST(NULL, "Range Values", "Nstate", test_nstate);
+   ADD_TEST_EO(NULL, "Tab Pager", "Efl.Ui.Tab_Pager", test_ui_tab_pager);
 
    //------------------------------//
    ADD_TEST(NULL, "Popups", "Ctxpopup", test_ctxpopup);
@@ -951,6 +1097,11 @@ add_tests:
    ADD_TEST(NULL, "Popups", "Tooltip 3", test_tooltip3);
    ADD_TEST(NULL, "Popups", "Tooltip 4", test_tooltip4);
    ADD_TEST(NULL, "Popups", "Popup", test_popup);
+   ADD_TEST_EO(NULL, "Popups", "Efl.Ui.Popup", test_ui_popup);
+   ADD_TEST_EO(NULL, "Popups", "Efl.Ui.Popup.Alert", test_ui_popup_alert);
+   ADD_TEST_EO(NULL, "Popups", "Efl.Ui.Popup.Alert.Scroll", test_ui_popup_alert_scroll);
+   ADD_TEST_EO(NULL, "Popups", "Efl.Ui.Popup.Alert.Text", test_ui_popup_alert_text);
+   ADD_TEST_EO(NULL, "Popups", "Efl.Ui.Popup.Anchor", test_ui_popup_anchor);
 
    //------------------------------//
    ADD_TEST(NULL, "Times & Dates", "Calendar", test_calendar);
@@ -961,7 +1112,10 @@ add_tests:
    ADD_TEST(NULL, "Times & Dates", "Clock Edit 2", test_clock_edit2);
    ADD_TEST(NULL, "Times & Dates", "Clock Pause", test_clock_pause);
    ADD_TEST(NULL, "Times & Dates", "Datetime", test_datetime);
-   ADD_TEST(NULL, "Times & Dates", "Ui.Clock", test_ui_clock);
+   ADD_TEST_EO(NULL, "Times & Dates", "Efl.Ui.Calendar", test_efl_ui_calendar);
+   ADD_TEST_EO(NULL, "Times & Dates", "Efl.Ui.Clock", test_ui_clock);
+   ADD_TEST_EO(NULL, "Times & Dates", "Efl.Ui.Datepicker", test_ui_datepicker);
+   ADD_TEST_EO(NULL, "Times & Dates", "Efl.Ui.Timepicker", test_ui_timepicker);
 
    //------------------------------//
    ADD_TEST(NULL, "Text", "Label", test_label);
@@ -969,6 +1123,7 @@ add_tests:
    ADD_TEST(NULL, "Text", "Label Wrap", test_label_wrap);
    ADD_TEST(NULL, "Text", "Label Ellipsis", test_label_ellipsis);
    ADD_TEST(NULL, "Text", "Label Emoji", test_label_emoji);
+   ADD_TEST_EO(NULL, "Text", "Efl.Ui.Textpath", test_ui_textpath);
 
    //------------------------------//
    ADD_TEST(NULL, "Stored Surface Buffer", "Launcher", test_launcher);
@@ -986,12 +1141,15 @@ add_tests:
    ADD_TEST(NULL, "Focus", "Focus Object Style", test_focus_object_style);
    ADD_TEST(NULL, "Focus", "Focus Object Policy", test_focus_object_policy);
    ADD_TEST(NULL, "Focus", "Focus 4", test_focus4);
+   ADD_TEST(NULL, "Focus", "Focus 5", test_focus5);
+   ADD_TEST(NULL, "Focus", "Focus 6", test_focus6);
 
    //------------------------------//
    ADD_TEST(NULL, "Naviframe", "Naviframe", test_naviframe);
    ADD_TEST(NULL, "Naviframe", "Naviframe 2", test_naviframe2);
    ADD_TEST(NULL, "Naviframe", "Naviframe 3", test_naviframe3);
    ADD_TEST(NULL, "Naviframe", "Naviframe: Complex", test_naviframe_complex);
+   ADD_TEST_EO(NULL, "Naviframe", "Efl.Ui.Stack", test_ui_stack);
 
    //------------------------------//
    ADD_TEST(NULL, "Geographic", "Map", test_map);
@@ -1000,6 +1158,7 @@ add_tests:
    ADD_TEST(NULL, "Dividers", "Panel", test_panel);
    ADD_TEST(NULL, "Dividers", "Panel Scrollable", test_panel2);
    ADD_TEST(NULL, "Dividers", "Panes", test_panes);
+   ADD_TEST_EO(NULL, "Dividers", "Efl.Ui.Panes", test_panes_minsize);
 
    //------------------------------//
    ADD_TEST(NULL, "Standardization", "Conformant", test_conformant);
@@ -1037,11 +1196,15 @@ add_tests:
    ADD_TEST(NULL, "Evas", "Gfx Filters", test_gfx_filters);
    ADD_TEST(NULL, "Evas", "Snapshot", test_evas_snapshot);
    ADD_TEST(NULL, "Evas", "Map", test_evas_map);
-   ADD_TEST(NULL, "Evas", "Gfx Map", test_efl_gfx_map);
+   ADD_TEST_EO(NULL, "Evas", "Efl.Gfx.Map", test_efl_gfx_map);
 
    //------------------------------//
    ADD_TEST(NULL, "Widgets Disable/Enable", "Box", test_box_disable);
    ADD_TEST(NULL, "Widgets Disable/Enable", "Layout", test_layout_disable);
+
+   //------------------------------//
+   ADD_TEST_EO(NULL, "Widgets Part", "Part Background", test_part_background);
+   ADD_TEST_EO(NULL, "Widgets Part", "Part Shadow", test_part_shadow);
 #undef ADD_TEST
 
    if (autorun)
@@ -1075,7 +1238,7 @@ add_tests:
           free(t);
 
         if (!l)
-          elm_exit();
+          efl_exit(0);
 
         return;
      }
@@ -1168,30 +1331,32 @@ efl_main(void *data EINA_UNUSED,
    /* if called with a single argument try to autorun a test with
     * the same name as the given param
     * ex:  elementary_test "Box Vert 2" */
-   if (eina_array_count(arge->argv) == 1)
+   if (eina_array_count(arge->argv) == 2)
      {
-        if (!strcmp(eina_array_data_get(arge->argv, 0), "--help"))
+        if ((!strcmp(eina_array_data_get(arge->argv, 1), "--help")) ||
+            (!strcmp(eina_array_data_get(arge->argv, 1), "-help")) ||
+            (!strcmp(eina_array_data_get(arge->argv, 1), "-h")))
           {
-             printf("Usages:\n"
-                    "$ elementary_test\n"
-                    "$ elementary_test --test-win-only [TEST_NAME]\n"
-                    "$ elementary_test -to [TEST_NAME]\n\n"
-                    "Examples:\n"
-                    "$ elementary_test -to Button\n\n");
-             efl_loop_quit(ev->object, 1);
+             efl_loop_quit(ev->object,
+                           eina_value_string_init("Usages:\n"
+                                                  "$ elementary_test\n"
+                                                  "$ elementary_test --test-win-only [TEST_NAME]\n"
+                                                  "$ elementary_test -to [TEST_NAME]\n\n"
+                                                  "Examples:\n"
+                                                  "$ elementary_test -to Button\n\n"));
              return ;
           }
-        autorun = eina_array_data_get(arge->argv, 0);
+        autorun = eina_array_data_get(arge->argv, 1);
      }
-   else if (eina_array_count(arge->argv) == 2)
+   else if (eina_array_count(arge->argv) == 3)
      {
         /* Just a workaround to make the shot module more
          * useful with elementary test. */
-        if ((!strcmp(eina_array_data_get(arge->argv, 0), "--test-win-only")) ||
-            (!strcmp(eina_array_data_get(arge->argv, 0), "-to")))
+        if ((!strcmp(eina_array_data_get(arge->argv, 1), "--test-win-only")) ||
+            (!strcmp(eina_array_data_get(arge->argv, 1), "-to")))
           {
              test_win_only = EINA_TRUE;
-             autorun = eina_array_data_get(arge->argv, 1);
+             autorun = eina_array_data_get(arge->argv, 2);
           }
      }
 
