@@ -563,7 +563,9 @@ _focus_layout_part(void *data, Evas_Object *o EINA_UNUSED, void *event_info EINA
 {
    Evas_Object *ed = elm_layout_edje_get(data);
 
+   edje_object_freeze(ed);
    Evas_Object *newfocus = (Evas_Object *)edje_object_part_object_get(ed, "sky");
+   edje_object_thaw(ed);
    const char *type = evas_object_type_get(newfocus);
    printf("evas_object_focus_set(%p, EINA_TRUE) %s\n", newfocus, type);
    evas_object_focus_set(newfocus, EINA_TRUE);;
@@ -900,6 +902,8 @@ test_focus3(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    evas_object_show(win);
 }
 
+/**** focus 4 ****/
+
 static void
 btn_clicked(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
@@ -926,7 +930,7 @@ test_focus4(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    Evas_Object *win, *box, *sc, *btn, *ly, *btn2;
    char buf[PATH_MAX];
 
-   win = elm_win_util_standard_add("focus4", "Focus 5");
+   win = elm_win_util_standard_add("focus4", "Focus 4");
    elm_win_autodel_set(win, EINA_TRUE);
 
    box = elm_box_add(win);
@@ -965,3 +969,258 @@ test_focus4(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_in
    evas_object_show(win);
 }
 
+/**** focus 5 ****/
+
+struct _focus5_obj {
+   const char *name;
+   Evas_Coord x, y, w, h;
+};
+
+struct _focus5_obj _focus5_layout_data1[] = {
+   {"top",    40,  0, 20, 10},
+   {"bottom", 40, 90, 20, 10},
+   {"left",    0, 45, 20, 10},
+   {"right",  80, 45, 20, 10},
+   {NULL, 0, 0, 0, 0} /* sentinel */
+};
+
+struct _focus5_obj _focus5_layout_data2[] = {
+   {"top L",   0,  0, 20, 10},
+   {"top R",  80,  0, 20, 10},
+   {"bot L",   0, 90, 20, 10},
+   {"bot R",  80, 90, 20, 10},
+   {"center", 40, 40, 20, 10},
+   {NULL, 0, 0, 0, 0} /* sentinel */
+};
+
+struct _focus5_obj _focus5_layout_data3[] = {
+   {"top",    40,  0, 20, 10},
+   {"bottom", 40, 90, 20, 10},
+   {"left",    0, 45, 20, 10},
+   {"right",  80, 45, 20, 10},
+   {"top L",   0,  0, 20, 10},
+   {"top R",  80,  0, 20, 10},
+   {"bot L",   0, 90, 20, 10},
+   {"bot R",  80, 90, 20, 10},
+   {"center", 40, 45, 20, 10},
+   {NULL, 0, 0, 0, 0} /* sentinel */
+};
+
+void
+_focus5_layout(Evas_Object *grid, struct _focus5_obj *layout)
+{
+   Evas_Object *obj;
+
+   evas_object_data_set(grid, "layout", layout);
+   elm_grid_clear(grid, EINA_TRUE);
+
+   while(layout->name) {
+      printf("button: %s\n", layout->name);
+      obj = elm_button_add(grid);
+      efl_name_set(obj, layout->name);
+      elm_object_text_set(obj, layout->name);
+      elm_grid_pack(grid, obj, layout->x, layout->y, layout->w, layout->h);
+      evas_object_show(obj);
+      layout++;
+   }
+}
+
+static void
+_focus5_btn_clicked(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *grid = data;
+   struct _focus5_obj *layout = evas_object_data_get(grid, "layout");
+
+   // brrr...a really naive looping 
+   if (layout == _focus5_layout_data1)
+      _focus5_layout(grid, _focus5_layout_data2);
+   else if (layout == _focus5_layout_data2)
+      _focus5_layout(grid, _focus5_layout_data3);
+   // else if (layout == _focus5_layout_data3)
+   //    _focus5_layout(grid, _focus5_layout_data4);
+   else
+      _focus5_layout(grid, _focus5_layout_data1);
+
+}
+
+void
+test_focus5(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win, *box, *sep, *btn, *grid;
+
+   win = elm_win_util_standard_add("focus5", "Focus 5");
+   elm_win_autodel_set(win, EINA_TRUE);
+
+   box = elm_box_add(win);
+   evas_object_size_hint_weight_set(box, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, box);
+   evas_object_show(box);
+
+   grid = elm_grid_add(box);
+   elm_grid_size_set(grid, 100, 100);
+   evas_object_size_hint_align_set(grid, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   evas_object_size_hint_weight_set(grid, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_box_pack_end(box, grid);
+   evas_object_show(grid);
+   _focus5_layout(grid, _focus5_layout_data1);
+
+   sep = elm_separator_add(box);
+   elm_separator_horizontal_set(sep, EINA_TRUE);
+   elm_box_pack_end(box, sep);
+   evas_object_show(sep);
+
+   btn = elm_button_add(box);
+   elm_object_focus_allow_set(btn, EINA_FALSE);
+   elm_box_pack_end(box, btn);
+   elm_object_text_set(btn, "Show next layout  (this btn is NOT focusable)");
+   evas_object_smart_callback_add(btn, "clicked", _focus5_btn_clicked, grid);
+   evas_object_show(btn);
+
+   evas_object_resize(win, 400, 400);
+   evas_object_show(win);
+}
+
+/**** focus 6 ****/
+static char *
+_focus6_gl_text_get(void *data, Evas_Object *obj EINA_UNUSED,
+                    const char *part EINA_UNUSED)
+{
+   char buf[32];
+   snprintf(buf, sizeof(buf), "Focus item %d", (int)(uintptr_t)data);
+   return strdup(buf);
+}
+
+static void
+_focus6_btn_clicked(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
+{
+   Evas_Object *ly = data;
+   Elm_Focus_Direction dir = (uintptr_t)evas_object_data_get(obj, "direction");
+
+   elm_object_focus_next(ly, dir);
+}
+
+void
+test_focus6(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win, *box, *box2, *sep, *ly, *lb, *btn, *gl;
+   Elm_Genlist_Item_Class *itc;
+   Elm_Object_Item *it;
+   char buf[PATH_MAX];
+   int i;
+
+   win = elm_win_util_standard_add("focus6", "Focus 6");
+   elm_win_autodel_set(win, EINA_TRUE);
+   elm_win_focus_highlight_enabled_set(win, EINA_TRUE);
+
+   // main vertical box
+   box = elm_box_add(win);
+   evas_object_size_hint_weight_set(box, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, box);
+   evas_object_show(box);
+
+   // main layout
+   ly = elm_layout_add(win);
+   snprintf(buf, sizeof(buf), "%s/objects/test.edj", elm_app_data_dir_get());
+   elm_layout_file_set(ly, buf, "focus_test_6");
+   evas_object_size_hint_weight_set(ly, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_align_set(ly, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   elm_box_pack_end(box, ly);
+   evas_object_show(ly);
+
+   lb = elm_label_add(ly);
+   elm_object_text_set(lb, "The game is to reach the buttons and the list items"
+                           " using only the keyboard");
+   elm_layout_content_set(ly, "label_swallow", lb);
+
+   // genlist in a swallow
+   gl = elm_genlist_add(ly);
+   evas_object_size_hint_weight_set(gl, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_align_set(gl, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   elm_genlist_select_mode_set(gl, ELM_OBJECT_SELECT_MODE_ALWAYS);
+   elm_layout_content_set(ly, "list_swallow", gl);
+
+   itc = elm_genlist_item_class_new();
+   itc->item_style = "default";
+   itc->func.text_get = _focus6_gl_text_get;
+   for (i = 0; i < 3; i++)
+     {
+        it = elm_genlist_item_append(gl, itc, (void*)(uintptr_t)i, NULL,
+                                     ELM_GENLIST_ITEM_NONE, NULL, NULL);
+        
+        if (i == 1)
+          {
+             elm_genlist_item_selected_set(it, EINA_TRUE);
+
+             /* focus should start from second item */
+             elm_object_item_focus_set(it, EINA_TRUE);
+          }
+     }
+   elm_genlist_item_class_free(itc);
+
+   // 3 buttons in an edje box
+   for (i = 0; i < 3; i++)
+     {
+        btn = elm_button_add(ly);
+        elm_object_text_set(btn, "btn");
+        elm_layout_box_append(ly, "box", btn);
+        evas_object_show(btn);
+        /* focus should start from second button */
+        // if (i == 1)
+          // elm_object_focus_set(btn, EINA_TRUE);
+     }
+
+   // 4 buttons (not focusable) to test focus move by API
+   sep = elm_separator_add(win);
+   elm_separator_horizontal_set(sep, EINA_TRUE);
+   elm_box_pack_end(box, sep);
+   evas_object_show(sep);
+
+   box2 = elm_box_add(win);
+   elm_box_horizontal_set(box2, EINA_TRUE);
+   evas_object_size_hint_weight_set(box2, EVAS_HINT_EXPAND, 0.0);
+   evas_object_size_hint_align_set(box2, EVAS_HINT_FILL, 0.0);
+   elm_box_pack_end(box, box2);
+   evas_object_show(box2);
+
+   lb = elm_label_add(ly);
+   evas_object_size_hint_weight_set(lb, EVAS_HINT_EXPAND, 0.0);
+   elm_object_text_set(lb, "Move the focus using elm_object_focus_next()");
+   elm_box_pack_end(box2, lb);
+   evas_object_show(lb);
+   
+   btn = elm_button_add(win);
+   elm_object_text_set(btn, "LEFT");
+   elm_object_focus_allow_set(btn, EINA_FALSE);
+   evas_object_data_set(btn, "direction", (void *)(uintptr_t)ELM_FOCUS_LEFT);
+   evas_object_smart_callback_add(btn, "clicked", _focus6_btn_clicked, ly);
+   elm_box_pack_end(box2, btn);
+   evas_object_show(btn);
+
+   btn = elm_button_add(win);
+   elm_object_text_set(btn, "UP");
+   elm_object_focus_allow_set(btn, EINA_FALSE);
+   evas_object_data_set(btn, "direction", (void *)(uintptr_t)ELM_FOCUS_UP);
+   evas_object_smart_callback_add(btn, "clicked", _focus6_btn_clicked, ly);
+   elm_box_pack_end(box2, btn);
+   evas_object_show(btn);
+
+   btn = elm_button_add(win);
+   elm_object_text_set(btn, "DOWN");
+   elm_object_focus_allow_set(btn, EINA_FALSE);
+   evas_object_data_set(btn, "direction", (void *)(uintptr_t)ELM_FOCUS_DOWN);
+   evas_object_smart_callback_add(btn, "clicked", _focus6_btn_clicked, ly);
+   elm_box_pack_end(box2, btn);
+   evas_object_show(btn);
+
+   btn = elm_button_add(win);
+   elm_object_text_set(btn, "RIGHT");
+   elm_object_focus_allow_set(btn, EINA_FALSE);
+   evas_object_data_set(btn, "direction", (void *)(uintptr_t)ELM_FOCUS_RIGHT);
+   evas_object_smart_callback_add(btn, "clicked", _focus6_btn_clicked, ly);
+   elm_box_pack_end(box2, btn);
+   evas_object_show(btn);
+
+   // size and show the window
+   evas_object_resize(win, 400, 400);
+   evas_object_show(win);
+}
