@@ -1,9 +1,11 @@
 #ifdef HAVE_CONFIG_H
 # include "elementary_config.h"
 #endif
-#include <Elementary.h>
 
-const int default_font_size = 48;
+#include <Elementary.h>
+#include "elm_colorselector.eo.h"
+
+static const int default_font_size = 48;
 
 typedef struct _Filter_Image
 {
@@ -150,7 +152,7 @@ _spinner_fill(Eo *obj)
      }
    elm_spinner_editable_set(obj, EINA_FALSE);
    elm_spinner_min_max_set(obj, 0, k - 1);
-   elm_obj_spinner_wrap_set(obj, 1);
+   elm_spinner_wrap_set(obj, 1);
 }
 
 static void
@@ -166,7 +168,7 @@ _filter_apply(Eo *win, const char *code, const char *name)
 }
 
 static void
-_spinner_cb(void *data, const Efl_Event *ev EINA_UNUSED)
+_spinner_cb(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
 {
    Eo *win = data;
    Eo *text, *code, *spinner, *tb;
@@ -197,8 +199,9 @@ _spinner_cb(void *data, const Efl_Event *ev EINA_UNUSED)
      }
 }
 
-static void
-_code_changed(void *data, const Efl_Event *ev EINA_UNUSED)
+static Eina_Value
+_code_changed(void *data, const Eina_Value v,
+              const Eina_Future *dead EINA_UNUSED)
 {
    Eo *win = data;
    Eo *code, *spinner;
@@ -225,22 +228,27 @@ _code_changed(void *data, const Efl_Event *ev EINA_UNUSED)
    elm_spinner_value_set(spinner, 0);
    _filter_apply(win, source, elm_spinner_special_value_get(spinner, 0));
    eina_strbuf_free(buf);
+
+   return v;
 }
 
 static void
 _code_changed_hack(void *data, const Efl_Event *ev EINA_UNUSED)
 {
-   Efl_Future *p = efl_loop_job(efl_loop_get(data), NULL);
-   efl_future_then(p, _code_changed, NULL, NULL, data);
+   Eina_Future *f;
+
+   f = eina_future_then(efl_loop_job(efl_loop_get(data)),
+                        _code_changed, data);
+   efl_future_Eina_FutureXXX_then(data, f);
 }
 
 static void
 _text_resize(void *data EINA_UNUSED, const Efl_Event *ev)
 {
-   int w = 0, h = 0;
+   Eina_Size2D sz;
 
-   efl_gfx_size_get(ev->object, &w, &h);
-   efl_gfx_size_hint_min_set(ev->object, w, h);
+   sz = efl_gfx_entity_size_get(ev->object);
+   efl_gfx_size_hint_min_set(ev->object, sz);
 }
 
 static void
@@ -250,7 +258,7 @@ _textblock_resize(void *data EINA_UNUSED, const Efl_Event *ev)
 
    evas_object_textblock_size_native_get(ev->object, &w, &h);
    evas_object_textblock_style_insets_get(ev->object, &l, &r, &t, &b);
-   efl_gfx_size_hint_min_set(ev->object, w + l + r, h + t + b);
+   efl_gfx_size_hint_min_set(ev->object, EINA_SIZE2D(w + l + r, h + t + b));
 }
 
 static void
@@ -288,8 +296,8 @@ _font_size_change(void *data, const Efl_Event *ev)
    const char *font;
 
    text = efl_key_wref_get(win, "text");
-   efl_text_properties_font_get(text, &font, NULL);
-   efl_text_properties_font_set(text, font, elm_spinner_value_get(ev->object));
+   efl_text_font_get(text, &font, NULL);
+   efl_text_font_set(text, font, elm_spinner_value_get(ev->object));
 }
 
 static void
@@ -303,10 +311,10 @@ _flip_click(void *data, const Efl_Event *ev EINA_UNUSED)
 }
 
 static void
-_colsel_cb(void *data, const Efl_Event *ev)
+_colsel_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
    Eo *win = data;
-   Eo *colsel = ev->object;
+   Eo *colsel = obj;
    Eo *text, *tb;
    int r = 0, g = 0, b = 0, a = 255;
    char buf[64];
@@ -325,61 +333,56 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
 {
    Eo *win, *box, *box2, *o, *text = NULL, *spinner, *code, *split, *flip, *tb;
 
-   win = efl_add(EFL_UI_WIN_CLASS, NULL,
+   win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
                  efl_text_set(efl_added, "Gfx Filter Editor"),
                  efl_ui_win_autodel_set(efl_added, 1));
 
    box = efl_add(EFL_UI_BOX_CLASS, win,
-                 efl_orientation_set(efl_added, EFL_ORIENT_DOWN),
-                 efl_gfx_size_hint_weight_set(efl_added, 1.0, 1.0));
+                 efl_ui_direction_set(efl_added, EFL_UI_DIR_VERTICAL));
 
    efl_content_set(win, box);
 
    {
       box2 = efl_add(EFL_UI_BOX_CLASS, win,
-                     efl_orientation_set(efl_added, EFL_ORIENT_HORIZONTAL),
+                     efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
                      efl_gfx_size_hint_weight_set(efl_added, 1.0, 0.0),
-                     efl_gfx_size_hint_align_set(efl_added, -1.0, 0.0),
-                     efl_gfx_visible_set(efl_added, 1));
+                     efl_gfx_size_hint_align_set(efl_added, -1.0, 0.0));
       efl_pack(box, box2);
 
       /* FIXME: Efl.Ui.Text doesn't work as expected. */
       o = efl_add(EFL_UI_TEXT_CLASS, win,
                   efl_gfx_size_hint_weight_set(efl_added, 0.0, 1.0),
-                  efl_gfx_size_hint_align_set(efl_added, 1.0, 0.5),
-                  efl_gfx_visible_set(efl_added, 1));
+                  efl_gfx_size_hint_align_set(efl_added, 1.0, 0.5));
       efl_text_set(o, "Filter:");
       efl_pack(box2, o);
 
-      o = spinner = efl_add(ELM_SPINNER_CLASS, win,
-                            efl_gfx_size_hint_weight_set(efl_added, 1.0, 1.0),
-                            efl_gfx_size_hint_align_set(efl_added, -1.0, 0.5),
-                            efl_gfx_visible_set(efl_added, 1));
+      o = spinner = elm_spinner_add(win);
+      efl_gfx_size_hint_weight_set(o, 1.0, 1.0);
+      efl_gfx_size_hint_align_set(o, -1.0, 0.5);
       _spinner_fill(o);
       efl_pack(box2, o);
-      spinner = o;
+      evas_object_show(o);
 
-      o = efl_add(ELM_SPINNER_CLASS, win,
-                  efl_gfx_size_hint_weight_set(efl_added, 0.0, 1.0),
-                  efl_gfx_size_hint_align_set(efl_added, -1.0, 0.5),
-                  elm_spinner_min_max_set(efl_added, 6, 120),
-                  elm_spinner_value_set(efl_added, default_font_size),
-                  efl_event_callback_add(efl_added, ELM_SPINNER_EVENT_DELAY_CHANGED, _font_size_change, win),
-                  efl_gfx_visible_set(efl_added, 1));
+      o = elm_spinner_add(win);
+      efl_gfx_size_hint_weight_set(o, 0.0, 1.0);
+      efl_gfx_size_hint_align_set(o, -1.0, 0.5);
+      elm_spinner_min_max_set(o, 6, 120);
+      elm_spinner_value_set(o, default_font_size);
+      efl_event_callback_add(o, ELM_SPINNER_EVENT_DELAY_CHANGED, _font_size_change, win);
       efl_pack(box2, o);
+      evas_object_show(o);
 
       o = efl_add(EFL_UI_BUTTON_CLASS, win,
                   efl_text_set(efl_added, "Flip"),
                   efl_gfx_size_hint_weight_set(efl_added, 0.0, 1.0),
                   efl_gfx_size_hint_align_set(efl_added, -1.0, 0.5),
-                  efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _flip_click, win),
-                  efl_gfx_visible_set(efl_added, 1));
+                  efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _flip_click, win));
       efl_pack(box2, o);
    }
 
    {
       box2 = efl_add(EFL_UI_BOX_CLASS, win,
-                     efl_orientation_set(efl_added, EFL_ORIENT_HORIZONTAL),
+                     efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
                      efl_gfx_size_hint_weight_set(efl_added, 1.0, 0.0),
                      efl_gfx_size_hint_align_set(efl_added, -1.0, 0.5),
                      efl_pack_padding_set(efl_added, 5, 5, 1),
@@ -389,6 +392,7 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
 
       for (size_t k = 0; k < EINA_C_ARRAY_LENGTH(images); k++)
         {
+           Eina_Size2D size = { ELM_SCALE_SIZE(48), ELM_SCALE_SIZE(48) };
            char buf[PATH_MAX];
 
            if (!images[k].path) break;
@@ -396,18 +400,18 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
            o = efl_add(EFL_UI_IMAGE_CLASS, win,
                        efl_gfx_size_hint_weight_set(efl_added, 0.0, 0.0),
                        efl_gfx_size_hint_align_set(efl_added, 0.5, 0.5),
-                       efl_gfx_size_hint_max_set(efl_added, ELM_SCALE_SIZE(48), ELM_SCALE_SIZE(48)),
-                       efl_gfx_size_hint_min_set(efl_added, ELM_SCALE_SIZE(48), ELM_SCALE_SIZE(48)),
+                       efl_gfx_size_hint_max_set(efl_added, size),
+                       efl_gfx_size_hint_min_set(efl_added, size),
                        efl_file_set(efl_added, buf, NULL),
                        efl_name_set(efl_added, images[k].src_name),
-                       elm_object_tooltip_text_set(efl_added, images[k].src_name),
-                       efl_gfx_visible_set(efl_added, 1));
+                       elm_object_tooltip_text_set(efl_added, images[k].src_name));
            if (efl_player_playable_get(o))
              efl_player_play_set(o, 1);
            efl_event_callback_add(o, EFL_UI_EVENT_CLICKED, _img_click, win);
            efl_pack(box2, o);
         }
 
+      Eina_Size2D maxsz = { -1, ELM_SCALE_SIZE(48 * 2) };
       const struct { int r, g, b, a; } colors[] = {
       { 255, 255, 255, 255 },
       { 0, 0, 0, 255 },
@@ -423,55 +427,47 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
       { 0, 0, 0, 0 }
       };
 
-      o = efl_add(ELM_COLORSELECTOR_CLASS, win,
-                  efl_gfx_size_hint_weight_set(efl_added, 1.0, 0),
-                  efl_gfx_size_hint_align_set(efl_added, -1.0, 0),
-                  elm_colorselector_mode_set(efl_added, ELM_COLORSELECTOR_PALETTE),
-                  efl_gfx_size_hint_max_set(efl_added, -1, ELM_SCALE_SIZE(48 * 2)),
-                  efl_name_set(efl_added, "myColor"),
-                  elm_object_tooltip_text_set(efl_added, "Pick a color to use as variable 'myColor'"),
-                  efl_event_callback_add(efl_added, ELM_COLORSELECTOR_EVENT_CHANGED, _colsel_cb, win),
-                  efl_gfx_visible_set(efl_added, 1));
+      o = elm_colorselector_add(win);
+      efl_gfx_size_hint_weight_set(o, 1.0, 0);
+      efl_gfx_size_hint_align_set(o, -1.0, 0);
+      elm_colorselector_mode_set(o, ELM_COLORSELECTOR_PALETTE);
+      efl_gfx_size_hint_max_set(o, maxsz);
+      efl_name_set(o, "myColor");
+      elm_object_tooltip_text_set(o, "Pick a color to use as variable 'myColor'");
+      evas_object_smart_callback_add(o, "changed", _colsel_cb, win);
       efl_pack(box2, o);
+      evas_object_show(o);
 
       for (size_t k = 0; k < EINA_C_ARRAY_LENGTH(colors); k++)
         elm_colorselector_palette_color_add(o, colors[k].r, colors[k].g, colors[k].b, colors[k].a);
-
-      efl_gfx_visible_set(box2, 1);
    }
 
-   /* FIXME: No panes in EO APIs. */
-   o = split = efl_add(ELM_PANES_CLASS, win,
-                       efl_gfx_size_hint_weight_set(efl_added, 1.0, 1.0),
-                       efl_gfx_size_hint_align_set(efl_added, -1.0, -1.0),
-                       efl_orientation_set(efl_added, EFL_ORIENT_HORIZONTAL),
-                       efl_gfx_visible_set(efl_added, 1));
+   o = split = efl_add(EFL_UI_PANES_CLASS, win,
+                       efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL));
    efl_pack(box, split);
 
    {
-      flip = efl_add(EFL_UI_FLIP_CLASS, win,
-                     efl_gfx_size_hint_weight_set(efl_added, 1.0, 0.0),
-                     efl_gfx_size_hint_align_set(efl_added, -1.0, -1.0),
-                     efl_gfx_visible_set(efl_added, 1));
-      efl_content_set(efl_part(split, "top"), flip);
+      flip = efl_add(EFL_UI_FLIP_CLASS, win);
+      efl_content_set(efl_part(split, "first"), flip);
 
       box2 = efl_add(EFL_UI_BOX_STACK_CLASS, win,
+                     efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
                      efl_gfx_size_hint_weight_set(efl_added, 1.0, 0.0),
                      efl_gfx_size_hint_align_set(efl_added, -1.0, -1.0),
-                     efl_pack_align_set(efl_added, 0.5, 0.5),
-                     efl_gfx_visible_set(efl_added, 1));
+                     efl_pack_align_set(efl_added, 0.5, 0.5));
       efl_pack(flip, box2);
 
       // Note: No TEXT object with EO APIs
       o = text = evas_object_text_add(evas_object_evas_get(win));
-      efl_event_callback_add(o, EFL_GFX_EVENT_RESIZE, _text_resize, NULL);
-      efl_text_properties_font_set(o, "Sans:style=Bold", default_font_size);
-      efl_canvas_object_scale_set(text, elm_config_scale_get());
+      efl_event_callback_add(o, EFL_GFX_ENTITY_EVENT_RESIZE, _text_resize, NULL);
+      efl_text_font_set(o, "Sans:style=Bold", default_font_size);
+      efl_gfx_entity_scale_set(text, elm_config_scale_get());
       efl_text_set(o, "EFL");
-      efl_gfx_visible_set(o, 1);
+      efl_gfx_entity_visible_set(o, 1);
       efl_pack(box2, o);
 
       o = box2 = efl_add(EFL_UI_BOX_STACK_CLASS, win,
+                         efl_ui_direction_set(efl_added, EFL_UI_DIR_HORIZONTAL),
                          efl_gfx_size_hint_weight_set(efl_added, 1.0, 0.0),
                          efl_gfx_size_hint_align_set(efl_added, -1.0, -1.0),
                          efl_pack_align_set(efl_added, 0.5, 0.5));
@@ -495,7 +491,7 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
       // Experimental textblock support
       o = tb = evas_object_textblock_add(evas_object_evas_get(win));
       efl_event_callback_add(o, EFL_CANVAS_TEXT_EVENT_STYLE_INSETS_CHANGED, _textblock_resize, NULL);
-      efl_event_callback_add(o, EFL_GFX_EVENT_RESIZE, _textblock_resize, NULL);
+      efl_event_callback_add(o, EFL_GFX_ENTITY_EVENT_RESIZE, _textblock_resize, NULL);
       Evas_Textblock_Style *st = evas_textblock_style_new();
       evas_textblock_style_set(st, "DEFAULT='font=Sans font_size=20 color=#FFF wrap=word'");
       for (size_t k = 0; k < EINA_C_ARRAY_LENGTH(programs); k++)
@@ -504,10 +500,9 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
         efl_gfx_filter_data_set(o, prg_data[k].name, prg_data[k].value, prg_data[k].exec);
       evas_object_textblock_style_set(o, st);
       evas_object_textblock_text_markup_set(o, tbtxt);
-      efl_canvas_object_scale_set(o, elm_config_scale_get());
+      efl_gfx_entity_scale_set(o, elm_config_scale_get());
       efl_pack(box2, o);
       evas_object_resize(o, 1, 1);
-      efl_gfx_visible_set(o, 1);
    }
 
    {
@@ -519,21 +514,15 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
             "blend { color = 'lime' }";
 
       o = code = efl_add(EFL_UI_TEXT_EDITABLE_CLASS, win,
-                         efl_gfx_size_hint_weight_set(efl_added, 1.0, 1.0),
-                         efl_gfx_size_hint_align_set(efl_added, -1.0, -1.0),
                          efl_ui_text_scrollable_set(efl_added, 1),
                          efl_text_multiline_set(efl_added, 1));
-      efl_event_callback_add(o, EFL_UI_TEXT_EVENT_CHANGED_USER, _code_changed, win);
+      efl_event_callback_add(o, EFL_UI_TEXT_EVENT_CHANGED_USER, _code_changed_hack, win);
 
       // Insert filter code inside style string: DEFAULT='blah blah <here>'
       efl_gfx_filter_program_set(o, code_filter, "code");
       efl_text_gfx_filter_set(o, "code");
 
-      // FIXME FIXME FIXME FIXME FIXME FIXME FIXME FIXME FIXME FIXME
-      // Efl.Ui.Text doesn't seem to trigger the proper events during edit
-      efl_event_callback_add(o, EFL_EVENT_KEY_DOWN, _code_changed_hack, win);
-
-      efl_content_set(efl_part(split, "bottom"), code);
+      efl_content_set(efl_part(split, "second"), code);
    }
 
    efl_key_wref_set(win, "text", text);
@@ -541,10 +530,9 @@ test_gfx_filters(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *eve
    efl_key_wref_set(win, "code", code);
    efl_key_wref_set(win, "flip", flip);
    efl_key_wref_set(win, "spinner", spinner);
-   efl_event_callback_add(spinner, ELM_SPINNER_EVENT_CHANGED, _spinner_cb, win);
+   evas_object_smart_callback_add(spinner, "changed", _spinner_cb, win);
    elm_spinner_value_set(spinner, 1.0);
-   _spinner_cb(win, NULL);
+   _spinner_cb(win, spinner, NULL);
 
-   efl_gfx_size_set(win, 500, 600);
-   efl_gfx_visible_set(win, 1);
+   efl_gfx_entity_size_set(win, EINA_SIZE2D(500,  600));
 }
