@@ -98,6 +98,81 @@ im_align_cb(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUS
    printf("align %.3f %.3f\n", h, v);
 }
 
+static const struct {
+   Efl_Gfx_Image_Scale_Type scale_type;
+   const char *name;
+} images_scale_type[] = {
+  { EFL_GFX_IMAGE_SCALE_TYPE_NONE, "None" },
+  { EFL_GFX_IMAGE_SCALE_TYPE_FILL, "Fill" },
+  { EFL_GFX_IMAGE_SCALE_TYPE_FIT_INSIDE, "Fit Inside" },
+  { EFL_GFX_IMAGE_SCALE_TYPE_FIT_OUTSIDE, "Fit Outside" },
+  { EFL_GFX_IMAGE_SCALE_TYPE_TILE, "Tile" },
+  { 0, NULL }
+};
+
+static void
+my_im_scale_ch(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win = data;
+   Evas_Object *im = evas_object_data_get(win, "im");
+   Evas_Object *rdg = evas_object_data_get(win, "rdg");
+   int v = elm_radio_value_get(rdg);
+
+   efl_gfx_image_scale_type_set(im, images_scale_type[v].scale_type);
+   fprintf(stderr, "Set %d[%s] and got %d\n",
+   images_scale_type[v].scale_type, images_scale_type[v].name, efl_gfx_image_scale_type_get(im));
+}
+
+void
+test_image_scale_type(void *data EINA_UNUSED, Evas_Object *obj  EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win, *box, *im, *rd, *rdg = NULL;
+   int i;
+
+   win = elm_win_util_standard_add("image test scale type", "Image Test Scale Type");
+   elm_win_autodel_set(win, EINA_TRUE);
+
+   box = elm_box_add(win);
+   evas_object_size_hint_weight_set(box, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, box);
+   evas_object_show(box);
+
+   im = efl_add(EFL_UI_IMAGE_CLASS, win);
+   char buf[PATH_MAX];
+   snprintf(buf, sizeof(buf), "%s/images/logo.png", elm_app_data_dir_get());
+   elm_image_file_set(im, buf, NULL);
+   evas_object_size_hint_weight_set(im, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_align_set(im, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   elm_box_pack_end(box, im);
+   evas_object_show(im);
+
+   evas_object_data_set(win, "im", im);
+
+   for (i = 0; images_scale_type[i].name; ++i)
+     {
+        rd = elm_radio_add(win);
+        evas_object_size_hint_align_set(rd, EVAS_HINT_FILL, EVAS_HINT_FILL);
+        evas_object_size_hint_weight_set(rd, EVAS_HINT_EXPAND, 0.0);
+        elm_radio_state_value_set(rd, i);
+        elm_object_text_set(rd, images_scale_type[i].name);
+        elm_box_pack_end(box, rd);
+        evas_object_show(rd);
+        evas_object_smart_callback_add(rd, "changed", my_im_scale_ch, win);
+        if (!rdg)
+          {
+             rdg = rd;
+             evas_object_data_set(win, "rdg", rdg);
+          }
+        else
+          {
+             elm_radio_group_add(rd, rdg);
+          }
+     }
+
+   evas_object_resize(win, 320, 480);
+   evas_object_show(win);
+}
+
 void
 test_image_swallow_align(void *data EINA_UNUSED, Evas_Object *obj  EINA_UNUSED, void *event_info EINA_UNUSED)
 {
@@ -304,7 +379,8 @@ test_remote_image(void *data EINA_UNUSED, Evas_Object *obj  EINA_UNUSED, void *e
    elm_entry_single_line_set(o, 1);
    evas_object_size_hint_weight_set(o, EVAS_HINT_EXPAND, 0);
    evas_object_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
-   elm_object_text_set(o, "http://41.media.tumblr.com/29f1ecd4f98aaff73fb21f479b450d4c/tumblr_mqsxdciQmB1rrju89o1_1280.jpg");
+   //elm_object_text_set(o, "http://41.media.tumblr.com/29f1ecd4f98aaff73fb21f479b450d4c/tumblr_mqsxdciQmB1rrju89o1_1280.jpg");
+   elm_object_text_set(o, "http://68.media.tumblr.com/d14765b2cc4ec25d1e7d640f3ec77a40/tumblr_ohtpjtRNlm1rrju89o1_500.jpg");
    evas_object_smart_callback_add(o, "activated", _url_activate_cb, win);
    elm_box_pack_end(box2, o);
    evas_object_show(o);
@@ -315,33 +391,14 @@ test_remote_image(void *data EINA_UNUSED, Evas_Object *obj  EINA_UNUSED, void *e
    // set file now
    _url_activate_cb(win, o, NULL);
 
-   evas_object_resize(win, 320, 480);
    evas_object_show(win);
+   evas_object_resize(win, 320, 480);
 }
 
 static void
-_img_clicked_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
+_img_clicked_cb(void *data EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-   Elm_Transit *trans;
-   static int degree = 0;
-
    fprintf(stderr, "%p - clicked\n", obj);
-
-   trans = elm_transit_add();
-   elm_transit_object_add(trans, data);
-   if (degree == 0)
-     {
-        elm_transit_effect_rotation_add(trans, 0, 180);
-        degree = 180;
-     }
-   else
-     {
-        elm_transit_effect_rotation_add(trans, 180, 360);
-        degree = 0;
-     }
-   elm_transit_duration_set(trans, 3.0);
-   elm_transit_objects_final_state_keep_set(trans, EINA_TRUE);
-   elm_transit_go(trans);
 }
 
 void
@@ -582,3 +639,78 @@ test_load_image(void *data EINA_UNUSED, Evas_Object *obj  EINA_UNUSED, void *eve
    evas_object_resize(win, 320, 480);
    evas_object_show(win);
 }
+
+static void
+_cb_prescale_radio_changed(void *data, Evas_Object *obj, void *event EINA_UNUSED)
+{
+   Evas_Object *o_bg = data;
+   int size;
+   size = elm_radio_value_get((Evas_Object *)obj);
+   elm_image_prescale_set(o_bg, size);
+}
+
+void
+test_image_prescale(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Evas_Object *win, *im;
+   Evas_Object *box, *hbox;
+   Evas_Object *rd, *rdg;
+   char buf[PATH_MAX];
+
+
+   win = elm_win_util_standard_add("image-prescale", "Image Prescale Test");
+   elm_win_autodel_set(win, EINA_TRUE);
+
+   box = elm_box_add(win);
+   evas_object_size_hint_weight_set(box, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   elm_win_resize_object_add(win, box);
+   evas_object_show(box);
+
+   im = elm_image_add(win);
+   snprintf(buf, sizeof(buf), "%s/images/plant_01.jpg", elm_app_data_dir_get());
+   elm_image_file_set(im, buf, NULL);
+   evas_object_size_hint_weight_set(im, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   evas_object_size_hint_align_set(im, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   elm_box_pack_end(box, im);
+   evas_object_show(im);
+
+   hbox = elm_box_add(win);
+   elm_box_horizontal_set(hbox, EINA_TRUE);
+   evas_object_size_hint_weight_set(hbox, EVAS_HINT_EXPAND, EVAS_HINT_FILL);
+   evas_object_size_hint_align_set(hbox, EVAS_HINT_FILL, EVAS_HINT_FILL);
+
+   rd = elm_radio_add(win);
+   elm_radio_state_value_set(rd, 50);
+   elm_object_text_set(rd, "50");
+   evas_object_size_hint_weight_set(rd, EVAS_HINT_EXPAND, EVAS_HINT_FILL);
+   evas_object_smart_callback_add(rd, "changed", _cb_prescale_radio_changed, im);
+   elm_box_pack_end(hbox, rd);
+   evas_object_show(rd);
+   rdg = rd;
+
+   rd = elm_radio_add(win);
+   elm_radio_state_value_set(rd, 100);
+   elm_radio_group_add(rd, rdg);
+   elm_object_text_set(rd, "100");
+   evas_object_size_hint_weight_set(rd, EVAS_HINT_EXPAND, EVAS_HINT_FILL);
+   evas_object_smart_callback_add(rd, "changed", _cb_prescale_radio_changed, im);
+   elm_box_pack_end(hbox, rd);
+   evas_object_show(rd);
+
+   rd = elm_radio_add(win);
+   elm_radio_state_value_set(rd, 200);
+   elm_radio_group_add(rd, rdg);
+   elm_object_text_set(rd, "200");
+   evas_object_size_hint_weight_set(rd, EVAS_HINT_EXPAND, EVAS_HINT_FILL);
+   evas_object_smart_callback_add(rd, "changed", _cb_prescale_radio_changed, im);
+   elm_box_pack_end(hbox, rd);
+   evas_object_show(rd);
+
+   elm_radio_value_set(rdg, 200);
+
+   elm_box_pack_end(box, hbox);
+   evas_object_show(hbox);
+
+   evas_object_resize(win, 320, 320);
+   evas_object_show(win);
+}
