@@ -653,7 +653,7 @@ static const struct {
 static void
 _radio_changed_cb(void *data, Evas_Object *obj, void *event_info EINA_UNUSED)
 {
-   unsigned char index = efl_ui_radio_value_get(obj);
+   unsigned char index = efl_ui_nstate_value_get(obj);
    efl_ui_image_icon_set(data, photocam_icons[index].name);
    printf("icon is %s\n", efl_ui_image_icon_get(data));
 }
@@ -763,12 +763,11 @@ _zoomable_clicked_cb(void *data EINA_UNUSED, const Efl_Event *ev)
 static void
 _zoomable_move_resize_cb(void *data, const Efl_Event *ev)
 {
-   int x, y, w, h;
+   Eina_Rect r;
 
-   efl_gfx_geometry_get(ev->object, &x, &y, &w, &h);
-
-   efl_gfx_size_set(data, w, h);
-   efl_gfx_position_set(data, x, y);
+   r = efl_gfx_entity_geometry_get(ev->object);
+   efl_gfx_entity_size_set(data, EINA_SIZE2D(r.w,  r.h));
+   efl_gfx_entity_position_set(data, r.pos);
 }
 
 static void
@@ -778,7 +777,7 @@ _zoomable_mouse_wheel_cb(void *data, const Efl_Event *e)
    Efl_Input_Pointer *ev = e->info;
    int zoom, _zoom, delta, val;
 
-   zoom = efl_ui_zoom_get(zoomable);
+   zoom = efl_ui_zoom_level_get(zoomable);
    delta = efl_input_pointer_wheel_delta_get(ev);
    if ((delta > 0) && (zoom == 1)) return;
 
@@ -796,7 +795,7 @@ _zoomable_mouse_wheel_cb(void *data, const Efl_Event *e)
      }
 
    efl_ui_zoom_mode_set(zoomable, EFL_UI_ZOOM_MODE_MANUAL);
-   if (zoom >= 1) efl_ui_zoom_set(zoomable, zoom);
+   if (zoom >= 1) efl_ui_zoom_level_set(zoomable, zoom);
 }
 
 void
@@ -805,32 +804,26 @@ test_image_zoomable_animated(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSE
    Eo *win, *bx, *zoomable, *rect;
    char buf[PATH_MAX];
 
-   win = efl_add(EFL_UI_WIN_CLASS, NULL,
+   win = efl_add_ref(EFL_UI_WIN_CLASS, NULL,
                  efl_ui_win_type_set(efl_added, EFL_UI_WIN_BASIC),
-                 efl_text_set(efl_added, "Efl.Ui.Image.Zoomable animation"),
+                 efl_text_set(efl_added, "Efl.Ui.Image_Zoomable animation"),
                  efl_ui_win_autodel_set(efl_added, EINA_TRUE));
 
    bx = efl_add(EFL_UI_BOX_CLASS, win,
-                efl_orientation_set(efl_added, EFL_ORIENT_DOWN),
-                efl_gfx_size_hint_weight_set(efl_added, EFL_GFX_SIZE_HINT_EXPAND, EFL_GFX_SIZE_HINT_EXPAND),
-                efl_content_set(win, efl_added),
-                efl_gfx_visible_set(efl_added, EINA_TRUE)
-               );
+                efl_ui_direction_set(efl_added, EFL_UI_DIR_DOWN),
+                efl_content_set(win, efl_added));
 
    efl_add(EFL_UI_TEXT_CLASS, bx,
            efl_text_set(efl_added, "Clicking the image will play/pause animation."),
-           efl_ui_text_interactive_editable_set(efl_added, EINA_FALSE),
+           efl_text_interactive_editable_set(efl_added, EINA_FALSE),
+           efl_gfx_size_hint_weight_set(efl_added, 1, 0),
            efl_canvas_text_style_set(efl_added, NULL, "DEFAULT='align=center font=Sans font_size=10 color=#fff wrap=word'"),
-           efl_gfx_visible_set(efl_added, EINA_TRUE),
            efl_pack(bx, efl_added)
           );
 
    snprintf(buf, sizeof(buf), "%s/images/animated_logo.gif", elm_app_data_dir_get());
    zoomable = efl_add(EFL_UI_IMAGE_ZOOMABLE_CLASS, win,
                       efl_file_set(efl_added, buf, NULL),
-                      efl_gfx_size_hint_weight_set(efl_added, EFL_GFX_SIZE_HINT_EXPAND, EFL_GFX_SIZE_HINT_EXPAND),
-                      efl_gfx_size_hint_align_set(efl_added, EFL_GFX_SIZE_HINT_FILL, EFL_GFX_SIZE_HINT_FILL),
-                      efl_gfx_visible_set(efl_added, EINA_TRUE),
                       efl_pack(bx, efl_added),
                       efl_event_callback_add(efl_added, EFL_UI_EVENT_CLICKED, _zoomable_clicked_cb, NULL)
                      );
@@ -843,16 +836,14 @@ test_image_zoomable_animated(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSE
 
    rect = efl_add(EFL_CANVAS_RECTANGLE_CLASS, win,
                   efl_gfx_color_set(efl_added, 0, 0, 0, 0),
-                  efl_gfx_visible_set(efl_added, EINA_TRUE),
                   efl_gfx_stack_raise(efl_added),
                   efl_canvas_object_repeat_events_set(efl_added, EINA_TRUE),
                   efl_event_callback_add(efl_added, EFL_EVENT_POINTER_WHEEL, _zoomable_mouse_wheel_cb, zoomable)
                  );
 
    // add move/resize callbacks to resize rect manually
-   efl_event_callback_add(zoomable, EFL_GFX_EVENT_RESIZE, _zoomable_move_resize_cb, rect);
-   efl_event_callback_add(zoomable, EFL_GFX_EVENT_MOVE, _zoomable_move_resize_cb, rect);
+   efl_event_callback_add(zoomable, EFL_GFX_ENTITY_EVENT_RESIZE, _zoomable_move_resize_cb, rect);
+   efl_event_callback_add(zoomable, EFL_GFX_ENTITY_EVENT_MOVE, _zoomable_move_resize_cb, rect);
 
-   efl_gfx_size_set(win, 300, 320);
-   efl_gfx_visible_set(win, EINA_TRUE);
+   efl_gfx_entity_size_set(win, EINA_SIZE2D(300,  320));
 }
