@@ -73,8 +73,8 @@ _final_type_and_type_type_get(Eolian_Type const* tp_in, Eolian_Type const*& tp_o
            !eolian_typedecl_is_extern(tpd))
          {
             auto btp = eolian_typedecl_aliased_base_get(tpd);
-            if (btp && eolian_type_full_name_get(btp) &&
-                strcmp(eolian_type_full_name_get(btp), "__undefined_type") != 0)
+            if (btp && eolian_type_name_get(btp) &&
+                strcmp(eolian_type_name_get(btp), "__undefined_type") != 0)
               {
                  _final_type_and_type_type_get(btp, tp_out, tpt_out);
               }
@@ -195,12 +195,11 @@ _eolian_type_cpp_type_named_get(const Eolian_Type *tp, std::string const& caller
           {"list", "Eina_List"},
           {"string", "const char*"},
           {"void_ptr", "void *"},
-          {"stringshare", "Eina_Stringshare*"},
-          {"future", "Efl_Future*"}
+          {"stringshare", "Eina_Stringshare*"}
 
         };
 
-        std::string type_name = eolian_type_name_get(tp);
+        std::string type_name = eolian_type_short_name_get(tp);
         auto it = type_map.find(type_name);
         if (it != end(type_map))
           type_name = it->second;
@@ -311,9 +310,9 @@ _function_return_is_missing(Eolian_Function const* func, Eolian_Function_Type fu
 }
 
 bool
-_type_is_generatable(const Eolian_Type *tp, bool add_pointer)
+_type_is_generatable(const Eolian_Type *tp, bool add_pointer, Eolian_C_Type_Type c_type_type)
 {
-   std::string c_type = eolian_type_c_type_get(tp);
+   std::string c_type = eolian_type_c_type_get(tp, c_type_type);
 
    if (add_pointer)
        c_type += " *";
@@ -325,7 +324,7 @@ bool
 _function_belongs_to(const Eolian_Function *function, std::string klass)
 {
    const Eolian_Class *cl = eolian_function_class_get(function);
-   const std::string name = cl ? eolian_class_full_name_get(cl) : "";
+   const std::string name = cl ? eolian_class_name_get(cl) : "";
    return name.find(klass) == 0;
 }
 
@@ -343,7 +342,7 @@ _function_is_generatable(const Eolian_Function *function, Eolian_Function_Type f
      {
         auto tp = ::eolian_parameter_type_get(parameter);
         bool add_pointer = eolian_parameter_direction_get(parameter) != EOLIAN_IN_PARAM;
-        if (!_type_is_generatable(tp, add_pointer))
+        if (!_type_is_generatable(tp, add_pointer, EOLIAN_C_TYPE_PARAM))
           return false;
 
         if (eolian_type_is_ptr(tp) && _function_belongs_to(function, "Efl.Object"))
@@ -352,7 +351,7 @@ _function_is_generatable(const Eolian_Function *function, Eolian_Function_Type f
 
    auto rtp = ::eolian_function_return_type_get(function, ftp);
 
-   return rtp ? _type_is_generatable(rtp, false) : true;
+   return rtp ? _type_is_generatable(rtp, false, EOLIAN_C_TYPE_RETURN) : true;
 }
 
 bool
@@ -489,18 +488,18 @@ int main(int argc, char** argv)
 
    // Add include paths to eolian library
    for(auto src : include_paths)
-     if (!::eolian_directory_scan(src.c_str()))
+     if (!::eolian_state_directory_add(src.c_str()))
        {
          EINA_CXX_DOM_LOG_WARN(eolian::js::domain)
            << "Couldn't load eolian from '" << src << "'.";
        }
-   if (!::eolian_all_eot_files_parse())
+   if (!::eolian_state_all_eot_files_parse())
      {
        EINA_CXX_DOM_LOG_WARN(eolian::js::domain)
          << "Eolian failed parsing eot files";
        assert(false && "Error parsing eot files");
      }
-   if (!::eolian_file_parse(in_file.c_str()))
+   if (!::eolian_state_file_parse(in_file.c_str()))
      {
        EINA_CXX_DOM_LOG_WARN(eolian::js::domain)
          << "Failed parsing: " << in_file << ".";
@@ -690,8 +689,8 @@ int main(int argc, char** argv)
         if (!tpd || ::eolian_typedecl_type_get(tpd) == EOLIAN_TYPEDECL_STRUCT_OPAQUE)
           continue;
 
-        auto struct_name = ::eolian_typedecl_name_get(tpd);
-        auto struct_type_full_name = ::eolian_typedecl_full_name_get(tpd);
+        auto struct_name = ::eolian_typedecl_short_name_get(tpd);
+        auto struct_type_full_name = ::eolian_typedecl_name_get(tpd);
         if (!struct_name || !struct_type_full_name)
           {
              EINA_CXX_DOM_LOG_ERR(eolian::js::domain) << "Could not get struct type name";
@@ -1015,7 +1014,7 @@ int main(int argc, char** argv)
                else
                  {
                         EINA_CXX_DOM_LOG_ERR(eolian::js::domain) << "Duplicate member function found in class: " <<
-                            eolian_class_full_name_get(klass) << ": '" << member_name << "'";
+                            eolian_class_name_get(klass) << ": '" << member_name << "'";
                  }
              }
            catch(eolian::js::incomplete_complex_type_error const& e)
@@ -1157,7 +1156,7 @@ int main(int argc, char** argv)
         auto tpd = &*first;
         if (::eolian_typedecl_is_extern(tpd))
           continue;
-        std::string enum_name = ::eolian_typedecl_name_get(tpd);
+        std::string enum_name = ::eolian_typedecl_short_name_get(tpd);
         os << "  {\n";
         os << "    auto to_export = ::efl::eo::js::get_namespace({";
         bool comma = false;
