@@ -23,13 +23,12 @@ static Eina_Prefix *pfx = NULL;
 
 struct ext_loader_s
 {
-   unsigned int length;
    const char *extension;
    const char *loader;
 };
 
 #define MATCHING(Ext, Module)                   \
-  { sizeof (Ext), Ext, Module }
+  { Ext, Module }
 
 /* The following list comes from evas_image_load.c
  * TODO: Don't duplicate, reuse common functions
