@@ -1,14 +1,10 @@
-#define EFL_BETA_API_SUPPORT 1
-#define EFL_EO_API_SUPPORT 1
 #ifdef HAVE_SYS_SOCKET_H
  #include <sys/socket.h>
 #endif
-#include <Ecore.h>
-#include <Ecore_Con.h>
+#include <Efl_Net.h>
 #include <Ecore_Getopt.h>
 #include <ctype.h>
 
-static int retval = EXIT_SUCCESS;
 static Eina_Bool monitoring = EINA_TRUE;
 
 static const char *
@@ -109,11 +105,11 @@ _access_point_print(Eo *ap)
           "INFO:  - remembered=%hhu\n"
           "INFO:  - immutable=%hhu\n"
           "INFO:  - security=%#x %s\n",
-          efl_net_control_access_point_name_get(ap),
+          efl_net_control_access_point_ssid_get(ap),
           _access_point_state_to_str(efl_net_control_access_point_state_get(ap)),
           _access_point_error_to_str(efl_net_control_access_point_error_get(ap)),
           efl_net_control_access_point_priority_get(ap),
-          efl_net_control_technology_name_get(efl_net_control_access_point_technology_get(ap)),
+          efl_name_get(efl_net_control_access_point_technology_get(ap)),
           efl_net_control_access_point_strength_get(ap),
           efl_net_control_access_point_roaming_get(ap),
           efl_net_control_access_point_auto_connect_get(ap),
@@ -299,8 +295,8 @@ _ctl_access_point_del(void *data EINA_UNUSED, const Efl_Event *event)
    Eo *ap = event->info;
    if (!monitoring) return;
    printf("INFO: Access Point Removed: %s [%s]\n",
-          efl_net_control_access_point_name_get(ap),
-          efl_net_control_technology_name_get(efl_net_control_access_point_technology_get(ap)));
+          efl_net_control_access_point_ssid_get(ap),
+          efl_name_get(efl_net_control_access_point_technology_get(ap)));
 }
 
 static void
@@ -320,12 +316,12 @@ _access_points_list(Eina_Iterator *it)
 
         printf("INFO: %4u | %-18.18s | %c%c%c   | %-13.13s | %s\n",
                efl_net_control_access_point_priority_get(ap),
-               efl_net_control_access_point_name_get(ap),
+               efl_net_control_access_point_ssid_get(ap),
                efl_net_control_access_point_remembered_get(ap) ? 'R' : '.',
                efl_net_control_access_point_immutable_get(ap) ? 'I' : '.',
                efl_net_control_access_point_auto_connect_get(ap) ? 'A' : '.',
                _access_point_state_to_str(efl_net_control_access_point_state_get(ap)),
-               efl_net_control_technology_name_get(efl_net_control_access_point_technology_get(ap)));
+               efl_name_get(efl_net_control_access_point_technology_get(ap)));
      }
 
    if (!first)
@@ -340,7 +336,7 @@ static void
 _ctl_access_points_changed(void *data EINA_UNUSED, const Efl_Event *event)
 {
    if (!monitoring) return;
-   _access_points_list(efl_net_control_access_points_get(event->object));
+   _access_points_list(efl_net_control_manager_access_points_get(event->object));
 }
 
 static const char *
@@ -377,7 +373,7 @@ _technology_print(Eo *tech)
           "INFO:  - connected=%hhu\n"
           "INFO:  - tethering=%hhu (id='%s', passphrase='%s')\n"
           "INFO:  - type=%s\n",
-          efl_net_control_technology_name_get(tech),
+          efl_name_get(tech),
           efl_net_control_technology_powered_get(tech),
           efl_net_control_technology_connected_get(tech),
           tethering, teth_id, teth_pass,
@@ -409,7 +405,7 @@ _ctl_technology_del(void *data EINA_UNUSED, const Efl_Event *event)
    Eo *tech = event->info;
    if (!monitoring) return;
    printf("INFO: Technology Removed: %s [%s]\n",
-          efl_net_control_technology_name_get(tech),
+          efl_name_get(tech),
           _technology_type_str(efl_net_control_technology_type_get(tech)));
 }
 
@@ -417,14 +413,14 @@ static void
 _ctl_radios_offline_changed(void *data EINA_UNUSED, const Efl_Event *event)
 {
    if (!monitoring) return;
-   printf("INFO: radios_offline=%hhu\n", efl_net_control_radios_offline_get(event->object));
+   printf("INFO: radios_offline=%hhu\n", efl_net_control_manager_radios_offline_get(event->object));
 }
 
 static void
 _ctl_state_changed(void *data EINA_UNUSED, const Efl_Event *event)
 {
    const char *str = "???";
-   Efl_Net_Control_State state = efl_net_control_state_get(event->object);
+   Efl_Net_Control_State state = efl_net_control_manager_state_get(event->object);
    switch (state)
      {
       case EFL_NET_CONTROL_STATE_OFFLINE: str = "offline"; break;
@@ -448,7 +444,7 @@ _ctl_agent_error(void *data EINA_UNUSED, const Efl_Event *event)
    printf("INFO: Agent Error:\n"
           "INFO:  - Access Point: %s\n"
           "INFO:  - Message: %s\n",
-          efl_net_control_access_point_name_get(e->access_point),
+          efl_net_control_access_point_ssid_get(e->access_point),
           e->message);
 }
 
@@ -459,7 +455,7 @@ _ctl_agent_browser_url(void *data EINA_UNUSED, const Efl_Event *event)
    printf("INFO: Agent requested to open browser:\n"
           "INFO:  - Access Point: %s\n"
           "INFO:  - URL: %s\n",
-          efl_net_control_access_point_name_get(e->access_point),
+          efl_net_control_access_point_ssid_get(e->access_point),
           e->url);
 }
 
@@ -587,7 +583,7 @@ _ctl_agent_request_input(void *data EINA_UNUSED, const Efl_Event *event)
           }
      }
 
-   efl_net_control_agent_reply(ctl,
+   efl_net_control_manager_agent_reply(ctl,
                                name,
                                ssid ? &ssid_slice : NULL,
                                username,
@@ -604,7 +600,7 @@ _ctl_agent_request_input(void *data EINA_UNUSED, const Efl_Event *event)
 static void
 _cmd_technologies_list(Eo *ctl, size_t argc EINA_UNUSED, char **argv EINA_UNUSED)
 {
-   Eina_Iterator *it = efl_net_control_technologies_get(ctl);
+   Eina_Iterator *it = efl_net_control_manager_technologies_get(ctl);
    Eo *tech;
    Eina_Bool first = EINA_TRUE;
 
@@ -618,7 +614,7 @@ _cmd_technologies_list(Eo *ctl, size_t argc EINA_UNUSED, char **argv EINA_UNUSED
           }
 
         printf("INFO:  %-18.18s | %c  | %c    | %s\n",
-               efl_net_control_technology_name_get(tech),
+               efl_name_get(tech),
                efl_net_control_technology_powered_get(tech) ? 'X' : ' ',
                efl_net_control_technology_connected_get(tech) ? 'X' : ' ',
                _technology_type_str(efl_net_control_technology_type_get(tech)));
@@ -674,10 +670,10 @@ _technology_find(Eo *ctl, const char *name)
         return NULL;
      }
 
-   it = efl_net_control_technologies_get(ctl);
+   it = efl_net_control_manager_technologies_get(ctl);
    EINA_ITERATOR_FOREACH(it, child)
      {
-        const char *tn = efl_net_control_technology_name_get(child);
+        const char *tn = efl_name_get(child);
         if (strcasecmp(name, tn) == 0)
           {
              eina_iterator_free(it);
@@ -698,22 +694,28 @@ _cmd_technology_show(Eo *ctl, size_t argc EINA_UNUSED, char **argv)
    _technology_print(tech);
 }
 
-static void
-_technology_scan_done(void *data, const Efl_Event *event EINA_UNUSED)
+static Eina_Value
+_technology_scan_done(void *data, const Eina_Value v,
+                      const Eina_Future *dead EINA_UNUSED)
 {
    Eo *tech = data;
-   printf("INFO: technology '%s' finished scan.\n",
-          efl_net_control_technology_name_get(tech));
-}
 
-static void
-_technology_scan_error(void *data, const Efl_Event *event)
-{
-   Eo *tech = data;
-   Efl_Future_Event_Failure *f = event->info;
-   printf("INFO: technology '%s' could not scan: %s\n",
-          efl_net_control_technology_name_get(tech),
-          eina_error_msg_get(f->error));
+   if (v.type == EINA_VALUE_TYPE_ERROR)
+     {
+        Eina_Error err = 0;
+
+        eina_value_error_get(&v, &err);
+        printf("INFO: technology '%s' could not scan: %s\n",
+               efl_name_get(tech),
+               eina_error_msg_get(err));
+     }
+   else
+     {
+        printf("INFO: technology '%s' finished scan.\n",
+               efl_name_get(tech));
+     }
+
+   return v;
 }
 
 static void
@@ -722,11 +724,8 @@ _cmd_technology_scan(Eo *ctl, size_t argc EINA_UNUSED, char **argv)
    Eo *tech = _technology_find(ctl, argv[1]);
    if (!tech) return;
    printf("INFO: started scan on technology '%s'\n", argv[1]);
-   efl_future_then(efl_net_control_technology_scan(tech),
-                   _technology_scan_done,
-                   _technology_scan_error,
-                   NULL,
-                   tech);
+   eina_future_then(efl_net_control_technology_scan(tech),
+                    _technology_scan_done, tech);
 }
 
 static void
@@ -738,7 +737,7 @@ _cmd_technology_powered(Eo *ctl, size_t argc, char **argv)
 
    if (!tech) return;
 
-   name = efl_net_control_technology_name_get(tech);
+   name = efl_name_get(tech);
    if (argc <= 2)
      {
         printf("INFO: technology '%s' powered %s\n",
@@ -765,7 +764,7 @@ _cmd_technology_tethering(Eo *ctl, size_t argc, char **argv)
 
    if (!tech) return;
 
-   name = efl_net_control_technology_name_get(tech);
+   name = efl_name_get(tech);
    if (argc <= 2)
      {
         efl_net_control_technology_tethering_get(tech, &enabled, &id, &pass);
@@ -790,7 +789,7 @@ _cmd_technology_tethering(Eo *ctl, size_t argc, char **argv)
 static void
 _cmd_access_points_list(Eo *ctl, size_t argc EINA_UNUSED, char **argv EINA_UNUSED)
 {
-   _access_points_list(efl_net_control_access_points_get(ctl));
+   _access_points_list(efl_net_control_manager_access_points_get(ctl));
 }
 
 static Eo *
@@ -809,12 +808,12 @@ _access_point_find(Eo *ctl, const char *name)
    if (name[0] == '#')
      prio = strtoul(name + 1, NULL, 10);
 
-   it = efl_net_control_access_points_get(ctl);
+   it = efl_net_control_manager_access_points_get(ctl);
    EINA_ITERATOR_FOREACH(it, child)
      {
         if (prio == UINT32_MAX)
           {
-             const char *n = efl_net_control_access_point_name_get(child);
+             const char *n = efl_net_control_access_point_ssid_get(child);
              if (strcasecmp(name, n) == 0)
                {
                   eina_iterator_free(it);
@@ -849,22 +848,28 @@ _cmd_access_point_show(Eo *ctl, size_t argc EINA_UNUSED, char **argv)
    _access_point_print(ap);
 }
 
-static void
-_access_point_connect_done(void *data, const Efl_Event *event EINA_UNUSED)
+static Eina_Value
+_access_point_connect(void *data, const Eina_Value v,
+                      const Eina_Future *dead EINA_UNUSED)
 {
    Eo *ap = data;
-   printf("INFO: access point '%s' finished connect.\n",
-          efl_net_control_access_point_name_get(ap));
-}
 
-static void
-_access_point_connect_error(void *data, const Efl_Event *event)
-{
-   Eo *ap = data;
-   Efl_Future_Event_Failure *f = event->info;
-   printf("INFO: access point '%s' could not connect: %s\n",
-          efl_net_control_access_point_name_get(ap),
-          eina_error_msg_get(f->error));
+   if (v.type == EINA_VALUE_TYPE_ERROR)
+     {
+        Eina_Error err = 0;
+
+        eina_value_error_get(&v, &err);
+        printf("INFO: access point '%s' could not connect: %s\n",
+               efl_net_control_access_point_ssid_get(ap),
+               eina_error_msg_get(err));
+     }
+   else
+     {
+        printf("INFO: access point '%s' finished connect.\n",
+               efl_net_control_access_point_ssid_get(ap));
+     }
+
+   return v;
 }
 
 static void
@@ -873,11 +878,8 @@ _cmd_access_point_connect(Eo *ctl, size_t argc EINA_UNUSED, char **argv)
    Eo *ap = _access_point_find(ctl, argv[1]);
    if (!ap) return;
    printf("INFO: connecting point '%s'\n", argv[1]);
-   efl_future_then(efl_net_control_access_point_connect(ap),
-                   _access_point_connect_done,
-                   _access_point_connect_error,
-                   NULL,
-                   ap);
+   eina_future_then(efl_net_control_access_point_connect(ap),
+                    _access_point_connect, ap);
 }
 
 static void
@@ -931,7 +933,7 @@ _cmd_access_point_auto_connect(Eo *ctl, size_t argc EINA_UNUSED, char **argv)
 
    if (!ap) return;
 
-   name = efl_net_control_access_point_name_get(ap);
+   name = efl_net_control_access_point_ssid_get(ap);
    if (argc <= 2)
      {
         printf("INFO: access_point '%s' auto connect %s\n",
@@ -1006,14 +1008,14 @@ _cmd_agent_set(Eo *ctl, size_t argc, char **argv)
 
    if (argc == 1)
      {
-        printf("INFO: agent is %s\n", _fmt_bool(efl_net_control_agent_enabled_get(ctl)));
+        printf("INFO: agent is %s\n", _fmt_bool(efl_net_control_manager_agent_enabled_get(ctl)));
         return;
      }
 
    if (!_parse_bool(argv[0], argv[1], &enabled))
      return;
 
-   efl_net_control_agent_enabled_set(ctl, enabled);
+   efl_net_control_manager_agent_enabled_set(ctl, enabled);
    printf("INFO: agent is now %s\n", _fmt_bool(enabled));
 }
 
@@ -1035,7 +1037,7 @@ _cmd_access_point_configure_ipv4(Eo *ctl, size_t argc, char **argv)
         return;
      }
 
-   name = efl_net_control_access_point_name_get(ap);
+   name = efl_net_control_access_point_ssid_get(ap);
 
    if (strcmp(argv[2], "off") == 0)
      ipv4_method = EFL_NET_CONTROL_ACCESS_POINT_IPV4_METHOD_OFF;
@@ -1077,7 +1079,7 @@ _cmd_access_point_configure_ipv6(Eo *ctl, size_t argc, char **argv)
         return;
      }
 
-   name = efl_net_control_access_point_name_get(ap);
+   name = efl_net_control_access_point_ssid_get(ap);
 
    if (strcmp(argv[2], "off") == 0)
      ipv6_method = EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_OFF;
@@ -1132,7 +1134,7 @@ _cmd_access_point_configure_proxy(Eo *ctl, size_t argc, char **argv)
         return;
      }
 
-   name = efl_net_control_access_point_name_get(ap);
+   name = efl_net_control_access_point_ssid_get(ap);
 
    if (strcmp(argv[2], "off") == 0)
      proxy_method = EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_OFF;
@@ -1178,10 +1180,10 @@ _cmd_access_point_configure_proxy(Eo *ctl, size_t argc, char **argv)
 }
 
 static void
-_cmd_quit(Eo *ctl EINA_UNUSED, size_t argc EINA_UNUSED, char **argv EINA_UNUSED)
+_cmd_quit(Eo *ctl, size_t argc EINA_UNUSED, char **argv EINA_UNUSED)
 {
    printf("INFO: bye!\n");
-   ecore_main_loop_quit();
+   efl_loop_quit(efl_loop_get(ctl), EINA_VALUE_EMPTY);
 }
 
 static void
@@ -1394,40 +1396,59 @@ _cmd_line(void *data, const Efl_Event *event)
 }
 
 EFL_CALLBACKS_ARRAY_DEFINE(ctl_events_cbs,
-                           { EFL_NET_CONTROL_EVENT_ACCESS_POINT_ADD, _ctl_access_point_add },
-                           { EFL_NET_CONTROL_EVENT_ACCESS_POINT_DEL, _ctl_access_point_del },
-                           { EFL_NET_CONTROL_EVENT_ACCESS_POINTS_CHANGED, _ctl_access_points_changed },
-                           { EFL_NET_CONTROL_EVENT_TECHNOLOGY_ADD, _ctl_technology_add },
-                           { EFL_NET_CONTROL_EVENT_TECHNOLOGY_DEL, _ctl_technology_del },
-                           { EFL_NET_CONTROL_EVENT_RADIOS_OFFLINE_CHANGED, _ctl_radios_offline_changed },
-                           { EFL_NET_CONTROL_EVENT_STATE_CHANGED, _ctl_state_changed },
-                           { EFL_NET_CONTROL_EVENT_AGENT_RELEASED, _ctl_agent_released },
-                           { EFL_NET_CONTROL_EVENT_AGENT_ERROR, _ctl_agent_error },
-                           { EFL_NET_CONTROL_EVENT_AGENT_BROWSER_URL, _ctl_agent_browser_url },
-                           { EFL_NET_CONTROL_EVENT_AGENT_REQUEST_INPUT, _ctl_agent_request_input });
+                           { EFL_NET_CONTROL_MANAGER_EVENT_ACCESS_POINT_ADD, _ctl_access_point_add },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_ACCESS_POINT_DEL, _ctl_access_point_del },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_ACCESS_POINTS_CHANGED, _ctl_access_points_changed },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_TECHNOLOGY_ADD, _ctl_technology_add },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_TECHNOLOGY_DEL, _ctl_technology_del },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_RADIOS_OFFLINE_CHANGED, _ctl_radios_offline_changed },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_STATE_CHANGED, _ctl_state_changed },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_AGENT_RELEASED, _ctl_agent_released },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_AGENT_ERROR, _ctl_agent_error },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_AGENT_BROWSER_URL, _ctl_agent_browser_url },
+                           { EFL_NET_CONTROL_MANAGER_EVENT_AGENT_REQUEST_INPUT, _ctl_agent_request_input });
 
-int
-main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
+static Eo *copier = NULL;
+
+
+EAPI_MAIN void
+efl_pause(void *data EINA_UNUSED,
+          const Efl_Event *ev EINA_UNUSED)
+{
+}
+
+EAPI_MAIN void
+efl_resume(void *data EINA_UNUSED,
+           const Efl_Event *ev EINA_UNUSED)
+{
+}
+
+EAPI_MAIN void
+efl_terminate(void *data EINA_UNUSED,
+              const Efl_Event *ev EINA_UNUSED)
+{
+   efl_del(copier);
+   copier = NULL;
+}
+
+EAPI_MAIN void
+efl_main(void *data EINA_UNUSED,
+         const Efl_Event *ev)
 {
    Eo *ctl;
    Eo *input;
-   Eo *copier;
    Eina_Slice line_delimiter = EINA_SLICE_STR("\n");
 
-   ecore_init();
-   ecore_con_init();
-
-   ctl = efl_add(EFL_NET_CONTROL_CLASS, ecore_main_loop_get(),
+   ctl = efl_add(EFL_NET_CONTROL_MANAGER_CLASS, ev->object,
                  efl_event_callback_array_add(efl_added, ctl_events_cbs(), NULL));
    if (!ctl)
      {
         fputs("ERROR: Could not create Efl.Net.Control object.\n", stderr);
-        retval = EXIT_FAILURE;
         goto end;
      }
 
-   input = efl_add(EFL_IO_STDIN_CLASS, ecore_main_loop_get());
-   copier = efl_add(EFL_IO_COPIER_CLASS, ecore_main_loop_get(),
+   input = efl_add(EFL_IO_STDIN_CLASS, ev->object);
+   copier = efl_add(EFL_IO_COPIER_CLASS, ev->object,
                     efl_io_copier_source_set(efl_added, input),
                     efl_io_copier_line_delimiter_set(efl_added, line_delimiter),
                     efl_io_copier_buffer_limit_set(efl_added, 8192),
@@ -1437,15 +1458,10 @@ main(int argc EINA_UNUSED, char **argv EINA_UNUSED)
    printf("INFO: monitoring is on, disable with 'monitor off'. See 'help'.\n");
    printf("INFO: type commands, if unsure try: 'help'\n");
 
-   ecore_main_loop_begin();
-
-   efl_del(copier);
-   efl_del(input);
-   efl_del(ctl);
+   return ;
 
  end:
-   ecore_con_shutdown();
-   ecore_shutdown();
-
-   return retval;
+   efl_loop_quit(efl_loop_get(ev->object), eina_value_int_init(EXIT_FAILURE));
 }
+
+EFL_MAIN_EX();
