@@ -1,8 +1,3 @@
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#include "elementary_config.h"
-#endif
-
 #include <Elementary.hh>
 
 EAPI_MAIN int
@@ -10,11 +5,13 @@ elm_main (int argc EINA_UNUSED, char **argv EINA_UNUSED)
 {
    elm_policy_set(ELM_POLICY_QUIT, ELM_POLICY_QUIT_LAST_WINDOW_HIDDEN);
 
-   efl::ui::Win win;
+   using efl::eo::instantiate;
+
+   efl::ui::Win win(instantiate);
    //win.title_set("Icon");
    win.autohide_set(true);
 
-   efl::ui::Image icon(win);
+   efl::ui::Image icon(instantiate, win);
    icon.icon_set("home");
 
    efl::eina::string_view path, group;
@@ -23,18 +20,13 @@ elm_main (int argc EINA_UNUSED, char **argv EINA_UNUSED)
 
    std::cout << ", name = " << icon.icon_get() << std::endl;
 
-   icon.scale_type_set(EFL_UI_IMAGE_SCALE_TYPE_NONE);
+   icon.scale_type_set(EFL_GFX_IMAGE_SCALE_TYPE_NONE);
    //icon.resizable_set(false, true);
    //icon.smooth_set(false);
    //icon.fill_outside_set(true);
 
-   // icon.size_hint_weight_set(EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
-   //win.resize_object_add(icon);
-   icon.eo_cxx::efl::Gfx::size_set(320,320);
-   icon.visible_set(true);
-
-   win.eo_cxx::efl::Gfx::size_set(320, 320);
-   win.visible_set(true);
+   win.content_set(icon);
+   win.size_set({320, 320});
 
    elm_run();
    return 0;
