@@ -15,7 +15,7 @@
 # include <langinfo.h>
 #endif
 
-#if defined(HAVE_SYS_MMAN_H) || defined(HAVE_EVIL)
+#if defined(HAVE_SYS_MMAN_H) || defined(_WIN32)
 # include <sys/mman.h>
 #endif
 
@@ -23,14 +23,16 @@
 # include <systemd/sd-daemon.h>
 #endif
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 #include <Eina.h>
 #include <Efl.h>
 
 #include "Ecore.h"
+#include "Efl_Core.h"
 #include "ecore_private.h"
+#include "../../static_libs/buildsystem/buildsystem.h"
 
 #if defined(HAVE_MALLINFO) || defined(HAVE_MALLOC_INFO)
 #include <malloc.h>
@@ -43,6 +45,8 @@
 static Ecore_Version _version = { VMAJ, VMIN, VMIC, VREV };
 EAPI Ecore_Version *ecore_version = &_version;
 
+EAPI double _efl_startup_time = 0;
+
 #if defined(HAVE_MALLINFO) || defined(HAVE_MALLOC_INFO)
 #define KEEP_MAX(Global, Local) \
   if (Global < (Local))         \
@@ -65,6 +69,8 @@ static int _ecore_init_count_threshold = 0;
 int _ecore_log_dom = -1;
 int _ecore_fps_debug = 0;
 
+extern void _ecore_thread_join();
+
 typedef struct _Ecore_Safe_Call Ecore_Safe_Call;
 struct _Ecore_Safe_Call
 {
@@ -84,10 +90,6 @@ struct _Ecore_Safe_Call
    Eina_Bool      suspend : 1;
 };
 
-#ifdef HAVE_SYSTEMD
-static Eina_Bool _systemd_watchdog_cb(void *data);
-#endif
-
 static void _ecore_main_loop_thread_safe_call(Ecore_Safe_Call *order);
 static void _thread_safe_cleanup(void *data);
 static void _thread_callback(void        *data,
@@ -104,6 +106,8 @@ static Eina_Condition _thread_cond;
 static Eina_Lock _thread_feedback_mutex;
 static Eina_Condition _thread_feedback_cond;
 
+Eina_Lock _environ_lock;
+
 static Eina_Lock _thread_id_lock;
 static int _thread_id = -1;
 static int _thread_id_max = 0;
@@ -113,10 +117,10 @@ static Ecore_Power_State _ecore_power_state = ECORE_POWER_STATE_MAINS;
 static Ecore_Memory_State _ecore_memory_state = ECORE_MEMORY_STATE_NORMAL;
 
 #ifdef HAVE_SYSTEMD
-static Ecore_Timer *_systemd_watchdog = NULL;
-#endif
+static void _systemd_watchdog_cb(void *data, const Efl_Event *event);
 
-static Efl_Vpath *vpath = NULL;
+static Efl_Loop_Timer *_systemd_watchdog = NULL;
+#endif
 
 Eina_Lock _ecore_main_loop_lock;
 int _ecore_main_lock_count;
@@ -161,9 +165,7 @@ ecore_system_modules_load(void)
                   const char **itr;
                   for (itr = built_modules; *itr != NULL; itr++)
                     {
-                       snprintf(buf, sizeof(buf),
-                                "%s/src/modules/ecore/system/%s/.libs",
-                                PACKAGE_BUILD_DIR, *itr);
+                       bs_mod_get(buf, sizeof(buf), "ecore/system", "system");
                        module_list = eina_module_list_get(module_list, buf,
                                                           EINA_FALSE, NULL, NULL);
                     }
@@ -199,6 +201,24 @@ ecore_system_modules_unload(void)
      }
 }
 
+static void
+_efl_first_loop_iterate(void *data, const Efl_Event *event)
+{
+   double end = ecore_time_unix_get();
+   char *first = data;
+
+   switch (*first)
+     {
+      case 'A': abort();
+      case 'E':
+      case 'D': exit(-1);
+      case 'T': fprintf(stderr, "Loop started: '%f' - '%f' = '%f' sec\n", end, _efl_startup_time, end - _efl_startup_time);
+         break;
+     }
+   efl_event_callback_del(event->object, EFL_APP_EVENT_RESUME,
+                          _efl_first_loop_iterate, data);
+}
+
 EAPI void
 ecore_app_no_system_modules(void)
 {
@@ -221,7 +241,7 @@ ecore_init(void)
         WRN("Not a utf8 locale!");
       }
     */
-#ifdef HAVE_EVIL
+#ifdef _WIN32
    if (!evil_init())
      return --_ecore_init_count;
 #endif
@@ -246,17 +266,15 @@ ecore_init(void)
         goto shutdown_log_dom;
      }
 
+   eina_lock_new(&_environ_lock);
+
    efl_object_init();
 
    if (getenv("ECORE_FPS_DEBUG")) _ecore_fps_debug = 1;
    if (_ecore_fps_debug) _ecore_fps_debug_init();
    if (!ecore_mempool_init()) goto shutdown_mempool;
    _ecore_main_loop_init();
-
-   vpath = efl_add(EFL_VPATH_CORE_CLASS, NULL);
-   if (vpath) efl_vpath_manager_register(EFL_VPATH_MANAGER_CLASS, 0, vpath);
-
-   _mainloop_singleton = efl_add(EFL_LOOP_CLASS, NULL);
+   if (!_ecore_event_init()) goto shutdown_event;
 
    _ecore_signal_init();
 #ifndef HAVE_EXOTIC
@@ -291,7 +309,7 @@ ecore_init(void)
        _ecore_memory_statistic_file = fopen(tmp, "wb");
 #endif
         _ecore_memory_pid = getpid();
-        ecore_animator_add(_ecore_memory_statistic, NULL);
+        ecore_poller_add(ECORE_POLLER_CORE, 1, _ecore_memory_statistic, NULL);
         _ecore_memory_statistic(NULL);
      }
 #endif
@@ -303,12 +321,17 @@ ecore_init(void)
 
         sec = ((double) atoi(getenv("WATCHDOG_USEC"))) / 1000 / 1000;
 
-        _systemd_watchdog = ecore_timer_add(sec / 2, _systemd_watchdog_cb, NULL);
+        _systemd_watchdog =
+           efl_add(EFL_LOOP_TIMER_CLASS, efl_main_loop_get(),
+                   efl_loop_timer_interval_set(efl_added, sec / 2),
+                   efl_event_callback_add(efl_added,
+                                          EFL_LOOP_TIMER_EVENT_TICK,
+                                          _systemd_watchdog_cb, NULL));
         unsetenv("WATCHDOG_USEC");
 
         INF("Setup systemd watchdog to : %f", sec);
 
-        _systemd_watchdog_cb(NULL);
+        _systemd_watchdog_cb(NULL, NULL);
      }
 #endif
 
@@ -321,7 +344,11 @@ ecore_init(void)
 
    if (!_no_system_modules)
      ecore_system_modules_load();
-
+   if (getenv("EFL_FIRST_LOOP"))
+     efl_event_callback_add(efl_main_loop_get(),
+                            EFL_APP_EVENT_RESUME,
+                            _efl_first_loop_iterate,
+                            getenv("EFL_FIRST_LOOP"));
    _ecore_init_count_threshold = _ecore_init_count;
 
    eina_log_timing(_ecore_log_dom,
@@ -330,13 +357,16 @@ ecore_init(void)
 
    return _ecore_init_count;
 
+shutdown_event:
+   _ecore_event_shutdown();
+   _ecore_main_shutdown();
 shutdown_mempool:
    ecore_mempool_shutdown();
    efl_object_shutdown();
 shutdown_log_dom:
    eina_shutdown();
 shutdown_evil:
-#ifdef HAVE_EVIL
+#ifdef _WIN32
    evil_shutdown();
 #endif
 
@@ -357,6 +387,7 @@ ecore_shutdown(void)
        }
      if (_ecore_init_count-- != _ecore_init_count_threshold)
        goto end;
+     efl_event_callback_call(efl_main_loop_get(), EFL_APP_EVENT_TERMINATE, NULL);
 
      ecore_system_modules_unload();
 
@@ -367,14 +398,11 @@ ecore_shutdown(void)
 #ifdef HAVE_SYSTEMD
      if (_systemd_watchdog)
        {
-          ecore_timer_del(_systemd_watchdog);
+          efl_del(_systemd_watchdog);
           _systemd_watchdog = NULL;
        }
 #endif
 
-     efl_del(_mainloop_singleton);
-     _mainloop_singleton = NULL;
-
      if (_ecore_fps_debug) _ecore_fps_debug_shutdown();
      _ecore_poller_shutdown();
      _ecore_animator_shutdown();
@@ -396,9 +424,10 @@ ecore_shutdown(void)
     * It should be fine now as we do wait for thread to shutdown before
     * we try to destroy the pipe.
     */
+     _ecore_pipe_wait(_thread_call, 1, 0);
      p = _thread_call;
      _thread_call = NULL;
-     _ecore_pipe_wait(p, 1, 0.1);
+     _ecore_pipe_wait(p, 1, 0);
      _ecore_pipe_del(p);
      eina_lock_free(&_thread_safety);
      eina_condition_free(&_thread_cond);
@@ -407,21 +436,13 @@ ecore_shutdown(void)
      eina_lock_free(&_thread_feedback_mutex);
      eina_lock_free(&_thread_id_lock);
 
-
 #ifndef HAVE_EXOTIC
      _ecore_exe_shutdown();
 #endif
-     _efl_loop_timer_shutdown();
      _ecore_event_shutdown();
      _ecore_main_shutdown();
      _ecore_signal_shutdown();
 
-   if (vpath)
-     {
-        efl_del(vpath);
-        vpath = NULL;
-     }
-
      _ecore_main_loop_shutdown();
 
 #if defined(HAVE_MALLINFO) || defined(HAVE_MALLOC_INFO)
@@ -450,9 +471,11 @@ ecore_shutdown(void)
 
      efl_object_shutdown();
 
+     eina_lock_free(&_environ_lock);
+
      eina_evlog("<RUN", NULL, 0.0, NULL);
      eina_shutdown();
-#ifdef HAVE_EVIL
+#ifdef _WIN32
      evil_shutdown();
 #endif
 
@@ -460,6 +483,31 @@ ecore_shutdown(void)
      return _ecore_init_count;
 }
 
+static unsigned int _ecore_init_ex = 0;
+
+EAPI unsigned int
+ecore_init_ex(int argc, char **argv)
+{
+   if (_ecore_init_ex++ != 0) return _ecore_init_ex;
+
+   ecore_init();
+   ecore_loop_arguments_send(argc,
+                             (argc > 0) ? ((const char **)argv) : NULL);
+   ecore_app_args_set(argc, (const char**) argv);
+
+   return _ecore_init_ex;
+}
+
+EAPI unsigned int
+ecore_shutdown_ex(void)
+{
+   if (--_ecore_init_ex != 0) return _ecore_init_ex;
+
+   ecore_shutdown();
+
+   return _ecore_init_ex;
+}
+
 struct _Ecore_Fork_Cb
 {
    Ecore_Cb func;
@@ -514,19 +562,32 @@ ecore_fork_reset(void)
 {
    Eina_List *l, *ln;
    Ecore_Fork_Cb *fcb;
-   
+
+   eina_debug_fork_reset();
+
    eina_main_loop_define();
    eina_lock_take(&_thread_safety);
 
    ecore_pipe_del(_thread_call);
    _thread_call = ecore_pipe_add(_thread_callback, NULL);
    /* If there was something in the pipe, trigger a wakeup again */
-   if (_thread_cb) ecore_pipe_write(_thread_call, &wakeup, sizeof (int));
+   if (_thread_cb)
+     {
+        Ecore_Safe_Call *call;
+
+        EINA_LIST_FOREACH_SAFE(_thread_cb, l, ln, call)
+          {
+             if (call->suspend || call->sync) continue;
+             if (call->cb.async != (Ecore_Cb)&_ecore_thread_join) continue;
+             _thread_cb = eina_list_remove_list(_thread_cb, l);
+             free(call);
+          }
+        if (_thread_cb) ecore_pipe_write(_thread_call, &wakeup, sizeof (int));
+     }
 
    eina_lock_release(&_thread_safety);
 
    // should this be done withing the eina lock stuff?
-   
    fork_cbs_walking++;
    EINA_LIST_FOREACH(fork_cbs, l, fcb)
      {
@@ -733,22 +794,18 @@ _ecore_magic_fail(const void *d,
                   Ecore_Magic req_m,
                   const char *fname EINA_UNUSED)
 {
-   ERR("\n"
-       "*** ECORE ERROR: Ecore Magic Check Failed!!!\n"
-       "*** IN FUNCTION: %s()", fname);
+   ERR("*** ECORE ERROR: Ecore Magic Check Failed!!! in: %s()", fname);
    if (!d)
-     ERR("  Input handle pointer is NULL!");
+     ERR("    Input handle pointer is NULL!");
    else if (m == ECORE_MAGIC_NONE)
-     ERR("  Input handle has already been freed!");
+     ERR("    Input handle has already been freed!");
    else if (m != req_m)
-     ERR("  Input handle is wrong type\n"
-         "    Expected: %08x - %s\n"
-         "    Supplied: %08x - %s",
+     ERR("    Input handle is wrong type\n"
+         "      Expected: %08x - %s\n"
+         "      Supplied: %08x - %s",
          (unsigned int)req_m, _ecore_magic_string_get(req_m),
          (unsigned int)m, _ecore_magic_string_get(m));
-   ERR("*** NAUGHTY PROGRAMMER!!!\n"
-       "*** SPANK SPANK SPANK!!!\n"
-       "*** Now go fix your code. Tut tut tut!");
+
    if (getenv("ECORE_ERROR_ABORT")) abort();
 }
 
@@ -879,7 +936,7 @@ _ecore_fps_debug_shutdown(void)
         unlink(buf);
         if (_ecore_fps_runtime_mmap)
           {
-             munmap(_ecore_fps_runtime_mmap, sizeof(int));
+             munmap(_ecore_fps_runtime_mmap, sizeof(unsigned int));
              _ecore_fps_runtime_mmap = NULL;
           }
         close(_ecore_fps_debug_fd);
@@ -907,11 +964,10 @@ _ecore_fps_debug_runtime_add(double t)
 }
 
 #ifdef HAVE_SYSTEMD
-static Eina_Bool
-_systemd_watchdog_cb(EINA_UNUSED void *data)
+static void
+_systemd_watchdog_cb(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
 {
    sd_notify(0, "WATCHDOG=1");
-   return ECORE_CALLBACK_RENEW;
 }
 #endif
 
