@@ -5,11 +5,7 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#ifdef _MSC_VER
-# include <process.h>
-#endif
-
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
