@@ -12,6 +12,7 @@
 #include <fcntl.h>
 #include <sys/time.h>
 #include <sys/resource.h>
+#include <signal.h>
 
 #ifdef HAVE_PRCTL
 # include <sys/prctl.h>
@@ -42,12 +43,6 @@
  * appended with a preceding space.  The first is the command off course.
  */
 
-struct _ecore_exe_dead_exe
-{
-   pid_t pid;
-   char *cmd;
-};
-
 static inline void _ecore_exe_exec_it(const char     *exe_cmd,
                                       Ecore_Exe_Flags flags);
 static Eina_Bool   _ecore_exe_data_generic_handler(void             *data,
@@ -60,9 +55,8 @@ static Eina_Bool            _ecore_exe_data_read_handler(void             *data,
 static Eina_Bool            _ecore_exe_data_write_handler(void             *data,
                                                           Ecore_Fd_Handler *fd_handler);
 static void                 _ecore_exe_flush(Ecore_Exe *obj);
-static Ecore_Exe           *_ecore_exe_is_it_alive(pid_t pid);
-static Eina_Bool            _ecore_exe_make_sure_its_dead(void *data);
-static Eina_Bool            _ecore_exe_make_sure_its_really_dead(void *data);
+static void                 _ecore_exe_make_sure_its_dead(void *data, const Efl_Event *event);
+static void                 _ecore_exe_make_sure_its_really_dead(void *data, const Efl_Event *event);
 static void                 _ecore_exe_dead_attach(Ecore_Exe *obj);
 
 static const char *shell = NULL;
@@ -186,9 +180,7 @@ _ecore_exe_check_errno(int         result,
        case EPERM:
        case EBUSY:
          { /* Programmer fucked up. */
-            ERR("*** NAUGHTY PROGRAMMER!!!\n"
-                "*** SPANK SPANK SPANK!!!\n"
-                "*** Now go fix your code in %s @%u. Tut tut tut!",
+            ERR("*** Race condition between open() and dup() created in %s @%u.",
                 file, line);
             result = 0;
             break;
@@ -196,10 +188,7 @@ _ecore_exe_check_errno(int         result,
 
        default:
          { /* Unsupported errno code, please add this one. */
-            ERR("*** NAUGHTY PROGRAMMER!!!\n"
-                "*** SPANK SPANK SPANK!!!\n"
-                "*** Unsupported errno code %d, please add this one.\n"
-                "*** Now go fix your code in %s @%u, from %s @%u. Tut tut tut!",
+            ERR("*** Unsupported errno code %d, found in %s @%u, from %s @%u.",
                 saved_errno, __FILE__, __LINE__, file, line);
             result = 0;
             break;
@@ -316,24 +305,58 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
 #warning "Have support for this"
 #endif
          }
-         /* dup2 STDERR, STDIN, and STDOUT.  dup2() allegedly closes the
-          * second pipe if it's open. On the other hand, there was the
-          * Great FD Leak Scare of '06, so let's be paranoid. */
-         if (ok && (flags & ECORE_EXE_PIPE_ERROR))
-         {
-            E_NO_ERRNO(result, close(STDERR_FILENO), ok);
-            E_NO_ERRNO(result, dup2(errorPipe[1], STDERR_FILENO), ok);
-         }
-         if (ok && (flags & ECORE_EXE_PIPE_READ))
-         {
-            E_NO_ERRNO(result, close(STDOUT_FILENO), ok);
-            E_NO_ERRNO(result, dup2(readPipe[1], STDOUT_FILENO), ok);
-         }
-         if (ok && (flags & ECORE_EXE_PIPE_WRITE))
-         {
-            E_NO_ERRNO(result, close(STDIN_FILENO), ok);
-            E_NO_ERRNO(result, dup2(writePipe[0], STDIN_FILENO), ok);
-         }
+         if (ok && (flags & ECORE_EXE_ISOLATE_IO))
+           {
+              int devnull;
+
+              /* we want to isolatie the stdin/out/err of the process so
+               * it can't share those of the parent, so close and replace with
+               * /dev/null */
+              devnull = open("/dev/null", O_RDONLY);
+              if (devnull >= 0)
+                {
+                   E_NO_ERRNO(result, close(STDIN_FILENO), ok);
+                   E_NO_ERRNO(result, dup2(devnull, STDIN_FILENO), ok);
+                   E_NO_ERRNO(result, close(devnull), ok);
+                }
+
+              devnull = open("/dev/null", O_WRONLY);
+              if (devnull >= 0)
+                {
+                   E_NO_ERRNO(result, close(STDOUT_FILENO), ok);
+                   E_NO_ERRNO(result, dup2(devnull, STDOUT_FILENO), ok);
+                   E_NO_ERRNO(result, close(devnull), ok);
+                }
+
+              devnull = open("/dev/null", O_WRONLY);
+              if (devnull >= 0)
+                {
+                   E_NO_ERRNO(result, close(STDERR_FILENO), ok);
+                   E_NO_ERRNO(result, dup2(devnull, STDERR_FILENO), ok);
+                   E_NO_ERRNO(result, close(devnull), ok);
+                }
+           }
+         else
+           {
+              /* dup2 STDERR, STDIN, and STDOUT.  dup2() allegedly closes the
+               * second pipe if it's open. On the other hand, there was the
+               * Great FD Leak Scare of '06, so let's be paranoid. */
+              if (ok && (flags & ECORE_EXE_PIPE_ERROR))
+                {
+                   E_NO_ERRNO(result, close(STDERR_FILENO), ok);
+                   E_NO_ERRNO(result, dup2(errorPipe[1], STDERR_FILENO), ok);
+                }
+              if (ok && (flags & ECORE_EXE_PIPE_READ))
+                {
+                   E_NO_ERRNO(result, close(STDOUT_FILENO), ok);
+                   E_NO_ERRNO(result, dup2(readPipe[1], STDOUT_FILENO), ok);
+                }
+              if (ok && (flags & ECORE_EXE_PIPE_WRITE))
+                {
+                   E_NO_ERRNO(result, close(STDIN_FILENO), ok);
+                   E_NO_ERRNO(result, dup2(writePipe[0], STDIN_FILENO), ok);
+                }
+           }
 
          if (ok)
          {
@@ -430,6 +453,7 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
                               ok) {
                 }
                 {
+                   // XXX: eoify ecore fd handlers
                    exe->error_fd_handler =
                      ecore_main_fd_handler_add(exe->child_fd_error,
                                                ECORE_FD_READ,
@@ -454,6 +478,7 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
                               ok) {
                 }
                 {
+                   // XXX: eoify ecore fd handlers
                    exe->read_fd_handler =
                      ecore_main_fd_handler_add(exe->child_fd_read,
                                                ECORE_FD_READ,
@@ -478,11 +503,13 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
                               ok) {
                 }
                 {
+                   // XXX: eoify ecore fd handlers
                    exe->write_fd_handler =
                      ecore_main_fd_handler_add(exe->child_fd_write,
                                                ECORE_FD_WRITE,
                                                _ecore_exe_data_write_handler,
                                                obj, NULL, NULL);
+                   // XXX: eoify ecore fd handlers
                    if (exe->write_fd_handler)
                      ecore_main_fd_handler_active_set(exe->write_fd_handler, 0);  /* Nothing to write to start with. */
                    else
@@ -490,7 +517,9 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
                 }
              }
 
-             _ecore_exe_exes = eina_list_append(_ecore_exe_exes, obj);
+             exe->loop = efl_provider_find(obj, EFL_LOOP_CLASS);
+             Efl_Loop_Data *loop = efl_data_scope_get(exe->loop, EFL_LOOP_CLASS);
+             if (loop) loop->exes = eina_list_append(loop->exes, obj);
              n = 0;
           }
           else
@@ -502,8 +531,9 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
 
    if (!ok) /* Something went wrong, so pull down everything. */
    {
+      // XXX: eoify terminate method
       if (exe->pid) ecore_exe_terminate(obj);
-      IF_FN_DEL(ecore_exe_free, obj);
+      obj = NULL;
    }
    else
    {
@@ -513,6 +543,7 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
       if (e)
         {
            e->exe = obj;
+           // XXX: eoify ecore_event_add
            /* Send the event. */
            ecore_event_add(ECORE_EXE_EVENT_ADD, e,
                            _ecore_exe_event_add_free, NULL);
@@ -546,6 +577,7 @@ _impl_ecore_exe_send(Ecore_Exe  *obj EINA_UNUSED,
    memcpy((char *)exe->write_data_buf + exe->write_data_size, data, size);
    exe->write_data_size += size;
 
+   // XXX: eoify ecore_fd_handlers
    if (exe->write_fd_handler)
       ecore_main_fd_handler_active_set(exe->write_fd_handler, ECORE_FD_WRITE);
 
@@ -758,20 +790,9 @@ _impl_ecore_exe_efl_object_destructor(Eo *obj, Ecore_Exe_Data *exe)
    if (exe->pre_free_cb)
      exe->pre_free_cb(data, obj);
 
-   if (exe->doomsday_clock)
-   {
-      struct _ecore_exe_dead_exe *dead;
+   exe->doomsday_clock = NULL;
 
-      ecore_timer_del(exe->doomsday_clock);
-      exe->doomsday_clock = NULL;
-      dead = exe->doomsday_clock_dead;
-      if (dead)
-      {
-         IF_FREE(dead->cmd);
-         free(dead);
-         exe->doomsday_clock_dead = NULL;
-      }
-   }
+   // XXX: eoify ecore fd handlers
    IF_FN_DEL(ecore_main_fd_handler_del, exe->write_fd_handler);
    IF_FN_DEL(ecore_main_fd_handler_del, exe->read_fd_handler);
    IF_FN_DEL(ecore_main_fd_handler_del, exe->error_fd_handler);
@@ -792,7 +813,8 @@ _impl_ecore_exe_efl_object_destructor(Eo *obj, Ecore_Exe_Data *exe)
    IF_FREE(exe->error_data_buf);
    IF_FREE(exe->cmd);
 
-   _ecore_exe_exes = eina_list_remove(_ecore_exe_exes, obj);
+   Efl_Loop_Data *loop = efl_data_scope_get(exe->loop, EFL_LOOP_CLASS);
+   if (loop) loop->exes = eina_list_remove(loop->exes, obj);
    IF_FREE(exe->tag);
 }
 
@@ -833,17 +855,13 @@ _impl_ecore_exe_terminate(Ecore_Exe *obj, Ecore_Exe_Data *exe)
 void
 _impl_ecore_exe_kill(Ecore_Exe *obj EINA_UNUSED, Ecore_Exe_Data *exe)
 {
-   struct _ecore_exe_dead_exe *dead;
-   dead = calloc(1, sizeof(struct _ecore_exe_dead_exe));
-   if (dead)
-   {
-      dead->pid = exe->pid;
-      dead->cmd = strdup(exe->cmd);
-      IF_FN_DEL(ecore_timer_del, exe->doomsday_clock);
-      exe->doomsday_clock =
-        ecore_timer_add(10.0, _ecore_exe_make_sure_its_really_dead, dead);
-   }
-
+   efl_del(exe->doomsday_clock);
+   exe->doomsday_clock = efl_add(EFL_LOOP_TIMER_CLASS, obj,
+                                 efl_event_callback_add(efl_added,
+                                                        EFL_LOOP_TIMER_EVENT_TICK,
+                                                        _ecore_exe_make_sure_its_really_dead,
+                                                        obj),
+                                 efl_loop_timer_interval_set(efl_added, 10.0));
    INF("Sending KILL signal to %s (%d).", exe->cmd, exe->pid);
    kill(exe->pid, SIGKILL);
 }
@@ -865,105 +883,46 @@ _impl_ecore_exe_hup(Ecore_Exe *obj EINA_UNUSED, Ecore_Exe_Data *exe)
    kill(exe->pid, SIGHUP);
 }
 
-static Ecore_Exe *
-_ecore_exe_is_it_alive(pid_t pid)
+static void
+_ecore_exe_make_sure_its_dead(void *data, const Efl_Event *event)
 {
-   Ecore_Exe *exe = NULL;
-
-   /* FIXME: There is no nice, safe, OS independent way to tell if a
-    * particular PID is still alive.  I have written code to do so
-    * for my urunlevel busybox applet (http://urunlevel.sourceforge.net/),
-    * but it's for linux only, and still not guaranteed.
-    *
-    * So for now, we just check that a valid Ecore_Exe structure
-    * exists for it.  Even that is not a guarantee, as the structure
-    * can be freed without killing the process.
-    *
-    * I think we can safely put exe's into two categories, those users
-    * that care about the life of the exe, and the run and forget type.
-    * The run and forget type starts up the exe, then free's the
-    * Ecore_Exe structure straight away.  They can never call any of
-    * the functions that can call this, so we don't worry about them.
-    *
-    * Those user's that care about the life of exe's will keep the
-    * Ecore_Exe structure around, terminate them eventually, or
-    * register for exit events.  For these ones the assumption
-    * that valid Ecore_Exe struct == live exe is almost valid.
-    *
-    * I will probably copy my urunlevel code into here someday.
-    */
-   exe = _ecore_exe_find(pid);
-
-   return exe;
-}
-
-static Eina_Bool
-_ecore_exe_make_sure_its_dead(void *data)
-{
-   struct _ecore_exe_dead_exe *dead;
-
-   dead = data;
-   if (dead)
+   Eo *exe_obj = data;
+   Ecore_Exe_Data *exe = efl_data_scope_get(exe_obj, MY_CLASS);
+   if (exe)
      {
-        Ecore_Exe *obj = NULL;
-
-        if ((obj = _ecore_exe_is_it_alive(dead->pid)))
-          {
-             Ecore_Exe_Data *exe = efl_data_scope_get(obj, MY_CLASS);
-             if (exe)
-               {
-                  if (dead->cmd)
-                    INF("Sending KILL signal to allegedly dead %s (%d).",
-                        dead->cmd, dead->pid);
-                  else
-                    INF("Sending KILL signal to allegedly dead PID %d.",
-                        dead->pid);
-                  exe->doomsday_clock =
-                    ecore_timer_add(10.0, _ecore_exe_make_sure_its_really_dead,
-                                    dead);
-                  kill(dead->pid, SIGKILL);
-               }
-          }
+        if (exe->cmd)
+          INF("Sending KILL signal to allegedly dead %s (%d).", exe->cmd, exe->pid);
         else
-          {
-             IF_FREE(dead->cmd);
-             free(dead);
-          }
+          INF("Sending KILL signal to allegedly dead PID %d.", exe->pid);
+        exe->doomsday_clock = efl_add(EFL_LOOP_TIMER_CLASS, exe_obj,
+                                      efl_event_callback_add(efl_added,
+                                                             EFL_LOOP_TIMER_EVENT_TICK,
+                                                             _ecore_exe_make_sure_its_really_dead,
+                                                             exe_obj),
+                                      efl_loop_timer_interval_set(efl_added, 10.0));
+        kill(exe->pid, SIGKILL);
      }
-   return ECORE_CALLBACK_CANCEL;
+   efl_del(event->object);
 }
 
-static Eina_Bool
-_ecore_exe_make_sure_its_really_dead(void *data)
+static void
+_ecore_exe_make_sure_its_really_dead(void *data, const Efl_Event *event)
 {
-   struct _ecore_exe_dead_exe *dead;
-
-   dead = data;
-   if (dead)
+   Eo *exe_obj = data;
+   Ecore_Exe_Data *exe = efl_data_scope_get(exe_obj, MY_CLASS);
+   if (exe)
      {
-        Ecore_Exe *obj = NULL;
-
-        if ((obj = _ecore_exe_is_it_alive(dead->pid)))
-          {
-             Ecore_Exe_Data *exe = efl_data_scope_get(obj, MY_CLASS);
-
-             if (exe)
-               {
-                  ERR("RUN!  The zombie wants to eat your brains!  And your CPU!");
-                  if (dead->cmd)
-                    INF("%s (%d) is not really dead.", dead->cmd, dead->pid);
-                  else
-                    INF("PID %d is not really dead.", dead->pid);
-                  exe->doomsday_clock = NULL;
-               }
-             IF_FREE(dead->cmd);
-             free(dead);
-          }
+        ERR("RUN!  The zombie wants to eat your brains!  And your CPU!");
+        if (exe->cmd)
+          INF("%s (%d) is not really dead.", exe->cmd, exe->pid);
+        else
+          INF("PID %d is not really dead.", exe->pid);
+        exe->doomsday_clock = NULL;
      }
-   return ECORE_CALLBACK_CANCEL;
+   efl_del(event->object);
 }
 
-Ecore_Timer *
+Efl_Loop_Timer *
 _ecore_exe_doomsday_clock_get(Ecore_Exe *obj)
 {
    Ecore_Exe_Data *exe = efl_data_scope_get(obj, MY_CLASS);
@@ -972,8 +931,7 @@ _ecore_exe_doomsday_clock_get(Ecore_Exe *obj)
 }
 
 void
-_ecore_exe_doomsday_clock_set(Ecore_Exe   *obj,
-                              Ecore_Timer *dc)
+_ecore_exe_doomsday_clock_set(Ecore_Exe *obj, Efl_Loop_Timer *dc)
 {
    Ecore_Exe_Data *exe = efl_data_scope_get(obj, MY_CLASS);
    if (!exe) return;
@@ -1194,9 +1152,11 @@ _ecore_exe_data_generic_handler(void             *data,
 
                if (!(exe->flags & ECORE_EXE_PIPE_AUTO))
                {
+                  // XXX: use eo method
                   e = ecore_exe_event_data_get(obj, flags);
                   if (e) /* Send the event. */
                     {
+                       // XXX: eoify ecore event
                        ecore_event_add(event_type, e,
                              _ecore_exe_event_exe_data_free,
                              NULL);
@@ -1225,6 +1185,7 @@ _ecore_exe_data_generic_handler(void             *data,
                 * mechanism should kick in.  But let's give it a good
                 * kick in the head anyway.
                 */
+               // XXX: use eo method
                ecore_exe_terminate(obj);
             }
             break;
@@ -1260,6 +1221,7 @@ _ecore_exe_data_write_handler(void             *data,
 
    if (!exe) return EINA_FALSE;
 
+   // XXX: use eo method
    if ((exe->write_fd_handler) &&
        (ecore_main_fd_handler_active_get
         (exe->write_fd_handler, ECORE_FD_WRITE)))
@@ -1302,7 +1264,9 @@ _ecore_exe_flush(Ecore_Exe *obj)
      {
         if (errno == EIO || errno == EBADF || errno == EPIPE || errno == EINVAL || errno == ENOSPC) /* we lost our exe! */
           {
+             // XXX: use eo method (eoify)
              ecore_exe_terminate(obj);
+             // XXX: eoify fd handlers
              if (exe->write_fd_handler)
                ecore_main_fd_handler_active_set(exe->write_fd_handler, 0);
           }
@@ -1315,6 +1279,7 @@ _ecore_exe_flush(Ecore_Exe *obj)
              exe->write_data_size = 0;
              exe->write_data_offset = 0;
              IF_FREE(exe->write_data_buf);
+             // XXX: eoify fd handlers
              if (exe->write_fd_handler)
                ecore_main_fd_handler_active_set(exe->write_fd_handler, 0);
           }
@@ -1324,19 +1289,14 @@ _ecore_exe_flush(Ecore_Exe *obj)
 static void
 _ecore_exe_dead_attach(Ecore_Exe *obj)
 {
-   struct _ecore_exe_dead_exe *dead;
    Ecore_Exe_Data *exe = efl_data_scope_get(obj, MY_CLASS);
 
    if (!exe) return;
-   if (exe->doomsday_clock_dead) return;
-   dead = calloc(1, sizeof(struct _ecore_exe_dead_exe));
-   if (dead)
-     {
-        dead->pid = exe->pid;
-        if (exe->cmd) dead->cmd = strdup(exe->cmd);
-        IF_FN_DEL(ecore_timer_del, exe->doomsday_clock);
-        exe->doomsday_clock =
-          ecore_timer_add(10.0, _ecore_exe_make_sure_its_dead, dead);
-        exe->doomsday_clock_dead = dead;
-     }
+   if (exe->doomsday_clock) return;
+   exe->doomsday_clock = efl_add(EFL_LOOP_TIMER_CLASS, obj,
+                                 efl_event_callback_add(efl_added,
+                                                        EFL_LOOP_TIMER_EVENT_TICK,
+                                                        _ecore_exe_make_sure_its_dead,
+                                                        obj),
+                                 efl_loop_timer_interval_set(efl_added, 10.0));
 }
