@@ -64,11 +64,7 @@ _ecore_exe_close_cb(void *data,
 
    /* FIXME : manage the STILL_ACTIVE returned error */
    if (!GetExitCodeProcess(exe->process, &exit_code))
-     {
-        char *msg = evil_last_error_get();
-        DBG("%s", msg);
-        free(msg);
-     }
+     DBG("%s", evil_last_error_get());
 
    e->exit_code = exit_code;
    e->exited = 1;
@@ -498,16 +494,8 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
    if (!CreateProcess(shell, exe_cmd_buf, NULL, NULL, EINA_TRUE,
                       run_pri | CREATE_SUSPENDED, NULL, NULL, &si, &pi))
      {
-        char *msg;
-
-        msg = evil_last_error_get();
-        if (msg)
-          {
-             WRN("Failed to create process %s: %s", exe_cmd_buf, msg);
-             free(msg);
-          }
-        else
-          WRN("Failed to create process %s: %ld", exe_cmd_buf, GetLastError());
+        WRN("Failed to create process %s: %s",
+            exe_cmd_buf, evil_last_error_get());
         goto error;
      }
 
@@ -540,7 +528,9 @@ _impl_ecore_exe_efl_object_finalize(Eo *obj, Ecore_Exe_Data *exe)
         goto error;
      }
 
-   _ecore_exe_exes = eina_list_append(_ecore_exe_exes, obj);
+   exe->loop = efl_provider_find(obj, EFL_LOOP_CLASS);
+   Efl_Loop_Data *loop = efl_data_scope_get(exe->loop, EFL_LOOP_CLASS);
+   if (loop) loop->exes = eina_list_append(loop->exes, obj);
 
    e = calloc(1, sizeof(Ecore_Exe_Event_Add));
    if (!e) goto error;
@@ -723,7 +713,8 @@ _impl_ecore_exe_efl_object_destructor(Eo *obj, Ecore_Exe_Data *exe)
 
    IF_FREE(exe->cmd);
 
-   _ecore_exe_exes = eina_list_remove(_ecore_exe_exes, obj);
+   Efl_Loop_Data *loop = efl_data_scope_get(exe->loop, EFL_LOOP_CLASS);
+   if (loop) loop->exes = eina_list_remove(loop->exes, obj);
    IF_FREE(exe->tag);
 }
 
