@@ -16,6 +16,7 @@ typedef struct
    Eo *outgoing;
    Eo *sender;
    Eo *receiver;
+   Eina_Bool is_closing;
    Eina_Bool closed;
    Eina_Bool eos;
    Eina_Bool can_read;
@@ -149,28 +150,10 @@ _efl_io_buffered_stream_efl_object_finalize(Eo *o, Efl_Io_Buffered_Stream_Data *
 }
 
 EOLIAN static void
-_efl_io_buffered_stream_efl_object_destructor(Eo *o, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_efl_object_invalidate(Eo *o, Efl_Io_Buffered_Stream_Data *pd)
 {
-   if (pd->incoming)
-     {
-        efl_del(pd->incoming);
-        pd->incoming = NULL;
-     }
-   if (pd->outgoing)
-     {
-        efl_del(pd->outgoing);
-        pd->outgoing = NULL;
-     }
-   if (pd->sender)
-     {
-        efl_del(pd->sender);
-        pd->sender = NULL;
-     }
-   if (pd->receiver)
-     {
-        efl_del(pd->receiver);
-        pd->receiver = NULL;
-     }
+   if (!efl_io_closer_closed_get(o))
+     efl_io_closer_close(o);
 
    if (pd->inner_io)
      {
@@ -182,7 +165,18 @@ _efl_io_buffered_stream_efl_object_destructor(Eo *o, Efl_Io_Buffered_Stream_Data
         pd->inner_io = NULL;
      }
 
-   efl_destructor(efl_super(o, MY_CLASS));
+   pd->incoming = NULL;
+   pd->outgoing = NULL;
+   pd->sender = NULL;
+   pd->receiver = NULL;
+
+   if (!pd->is_finished)
+     {
+        pd->is_finished = EINA_TRUE;
+        efl_event_callback_call(o, EFL_IO_BUFFERED_STREAM_EVENT_FINISHED, NULL);
+     }
+
+   efl_invalidate(efl_super(o, MY_CLASS));
 }
 
 EOLIAN static Eina_Error
@@ -191,6 +185,8 @@ _efl_io_buffered_stream_efl_io_closer_close(Eo *o, Efl_Io_Buffered_Stream_Data *
    Eina_Error err = 0;
 
    EINA_SAFETY_ON_TRUE_RETURN_VAL(pd->closed, EINVAL);
+   if (pd->is_closing) return 0;
+   pd->is_closing = EINA_TRUE;
 
    if (pd->outgoing)
      {
@@ -218,13 +214,13 @@ _efl_io_buffered_stream_efl_io_closer_close(Eo *o, Efl_Io_Buffered_Stream_Data *
 }
 
 EOLIAN static Eina_Bool
-_efl_io_buffered_stream_efl_io_closer_closed_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_efl_io_closer_closed_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    return pd->closed || efl_io_closer_closed_get(pd->inner_io);
 }
 
 EOLIAN static Eina_Bool
-_efl_io_buffered_stream_efl_io_closer_close_on_exec_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_efl_io_closer_close_on_exec_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    return efl_io_closer_close_on_exec_get(pd->inner_io);
 }
@@ -236,15 +232,15 @@ _efl_io_buffered_stream_efl_io_closer_close_on_exec_set(Eo *o EINA_UNUSED, Efl_I
 }
 
 EOLIAN static Eina_Bool
-_efl_io_buffered_stream_efl_io_closer_close_on_destructor_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_efl_io_closer_close_on_invalidate_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
-   return efl_io_closer_close_on_destructor_get(pd->inner_io);
+   return efl_io_closer_close_on_invalidate_get(pd->inner_io);
 }
 
 EOLIAN static void
-_efl_io_buffered_stream_efl_io_closer_close_on_destructor_set(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd, Eina_Bool value)
+_efl_io_buffered_stream_efl_io_closer_close_on_invalidate_set(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd, Eina_Bool value)
 {
-   efl_io_closer_close_on_destructor_set(pd->inner_io, value);
+   efl_io_closer_close_on_invalidate_set(pd->inner_io, value);
 }
 
 EOLIAN static Eina_Error
@@ -266,7 +262,7 @@ _efl_io_buffered_stream_efl_io_reader_read(Eo *o, Efl_Io_Buffered_Stream_Data *p
 }
 
 EOLIAN static Eina_Bool
-_efl_io_buffered_stream_efl_io_reader_can_read_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_efl_io_reader_can_read_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    return pd->can_read;
 }
@@ -281,7 +277,7 @@ _efl_io_buffered_stream_efl_io_reader_can_read_set(Eo *o, Efl_Io_Buffered_Stream
 }
 
 EOLIAN static Eina_Bool
-_efl_io_buffered_stream_efl_io_reader_eos_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_efl_io_reader_eos_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    return pd->eos;
 }
@@ -332,7 +328,7 @@ _efl_io_buffered_stream_efl_io_writer_write(Eo *o, Efl_Io_Buffered_Stream_Data *
 }
 
 EOLIAN static Eina_Bool
-_efl_io_buffered_stream_efl_io_writer_can_write_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_efl_io_writer_can_write_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    return pd->can_write;
 }
@@ -378,7 +374,7 @@ _efl_io_buffered_stream_inner_io_set(Eo *o, Efl_Io_Buffered_Stream_Data *pd, Efl
                                efl_io_copier_buffer_limit_set(efl_added, 4096),
                                efl_io_copier_source_set(efl_added, io),
                                efl_io_copier_destination_set(efl_added, pd->incoming),
-                               efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                               efl_io_closer_close_on_invalidate_set(efl_added, efl_io_closer_close_on_invalidate_get(io)),
                                efl_event_callback_array_add(efl_added, _efl_io_buffered_stream_receiver_cbs(), o));
         EINA_SAFETY_ON_NULL_RETURN(pd->receiver);
      }
@@ -403,7 +399,7 @@ _efl_io_buffered_stream_inner_io_set(Eo *o, Efl_Io_Buffered_Stream_Data *pd, Efl
                              efl_io_copier_buffer_limit_set(efl_added, 4096),
                              efl_io_copier_source_set(efl_added, pd->outgoing),
                              efl_io_copier_destination_set(efl_added, io),
-                             efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                             efl_io_closer_close_on_invalidate_set(efl_added, efl_io_closer_close_on_invalidate_get(io)),
                              efl_event_callback_array_add(efl_added, _efl_io_buffered_stream_sender_cbs(), o));
         EINA_SAFETY_ON_NULL_RETURN(pd->sender);
      }
@@ -412,7 +408,7 @@ _efl_io_buffered_stream_inner_io_set(Eo *o, Efl_Io_Buffered_Stream_Data *pd, Efl
 }
 
 EOLIAN static Efl_Object *
-_efl_io_buffered_stream_inner_io_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_inner_io_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    return pd->inner_io;
 }
@@ -429,7 +425,7 @@ _efl_io_buffered_stream_max_queue_size_input_set(Eo *o EINA_UNUSED, Efl_Io_Buffe
 }
 
 EOLIAN static size_t
-_efl_io_buffered_stream_max_queue_size_input_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_max_queue_size_input_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    if (!pd->incoming) return 0;
    return efl_io_queue_limit_get(pd->incoming);
@@ -447,7 +443,7 @@ _efl_io_buffered_stream_max_queue_size_output_set(Eo *o EINA_UNUSED, Efl_Io_Buff
 }
 
 EOLIAN static size_t
-_efl_io_buffered_stream_max_queue_size_output_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_max_queue_size_output_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    if (!pd->outgoing) return 0;
    return efl_io_queue_limit_get(pd->outgoing);
@@ -465,7 +461,7 @@ _efl_io_buffered_stream_line_delimiter_set(Eo *o EINA_UNUSED, Efl_Io_Buffered_St
 }
 
 EOLIAN static Eina_Slice
-_efl_io_buffered_stream_line_delimiter_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_line_delimiter_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    if (!pd->receiver) return (Eina_Slice){};
    return efl_io_copier_line_delimiter_get(pd->receiver);
@@ -481,7 +477,7 @@ _efl_io_buffered_stream_timeout_inactivity_set(Eo *o EINA_UNUSED, Efl_Io_Buffere
 }
 
 EOLIAN static double
-_efl_io_buffered_stream_timeout_inactivity_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_timeout_inactivity_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    if (pd->receiver)
      return efl_io_copier_timeout_inactivity_get(pd->receiver);
@@ -507,28 +503,28 @@ _efl_io_buffered_stream_read_chunk_size_set(Eo *o EINA_UNUSED, Efl_Io_Buffered_S
 }
 
 EOLIAN static size_t
-_efl_io_buffered_stream_read_chunk_size_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_read_chunk_size_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    if (!pd->receiver) return 0;
    return efl_io_copier_read_chunk_size_get(pd->receiver);
 }
 
 EOLIAN static size_t
-_efl_io_buffered_stream_pending_write_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_pending_write_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    if (!pd->outgoing) return 0;
    return efl_io_queue_usage_get(pd->outgoing);
 }
 
 EOLIAN static size_t
-_efl_io_buffered_stream_pending_read_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_pending_read_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    if (!pd->incoming) return 0;
    return efl_io_queue_usage_get(pd->incoming);
 }
 
 EOLIAN static void
-_efl_io_buffered_stream_progress_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd, size_t *pr, size_t *pw)
+_efl_io_buffered_stream_progress_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd, size_t *pr, size_t *pw)
 {
    uint64_t r = 0, w = 0;
 
@@ -540,7 +536,7 @@ _efl_io_buffered_stream_progress_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_D
 }
 
 EOLIAN static Eina_Slice
-_efl_io_buffered_stream_slice_get(Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
+_efl_io_buffered_stream_slice_get(const Eo *o EINA_UNUSED, Efl_Io_Buffered_Stream_Data *pd)
 {
    Eina_Slice slice = { };
 
