@@ -10,11 +10,16 @@
 # include <sys/socket.h>
 #endif
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
+#define EFL_NET_SOCKET_SSL_PROTECTED
+
 #include "Ecore.h"
+
+#include "Efl_Net.h"
+
 #include "ecore_private.h"
 #include "Ecore_Con.h"
 #include "ecore_con_private.h"
@@ -31,7 +36,7 @@ struct _Ecore_Con_Server
    Eo *dialer;
    Eo *server;
    struct {
-      Efl_Future *job;
+      Eina_Future *job;
       Eina_Binbuf *pending_send; /* until job is fulfilled, no dialer exists,
                                   * this binbuf allows immediate
                                   * ecore_con_server_send() in that situation */
@@ -71,7 +76,7 @@ struct _Ecore_Con_Client
    const void *data;
    Eina_Stringshare *ip;
    struct {
-      Efl_Future *job;
+      Eina_Future *job;
       Eo *ctx;
       Eina_Bool upgrading;
    } ssl;
@@ -88,15 +93,16 @@ typedef struct _Ecore_Con_Lookup_Ctx {
 } Ecore_Con_Lookup_Ctx;
 
 /* allows delete_me to be true */
-#define ECORE_CON_SERVER_CHECK_RELAXED_RETURN(svr, ...) \
-  do \
-    { \
-       if (!ECORE_MAGIC_CHECK(svr, ECORE_MAGIC_CON_SERVER)) \
-         { \
+#define ECORE_CON_SERVER_CHECK_RELAXED_RETURN(svr, ...)                 \
+  do                                                                    \
+    {                                                                   \
+       if (!svr) return __VA_ARGS__;                                    \
+       if (!ECORE_MAGIC_CHECK(svr, ECORE_MAGIC_CON_SERVER))             \
+         {                                                              \
             ECORE_MAGIC_FAIL(svr, ECORE_MAGIC_CON_SERVER, __FUNCTION__); \
-            return __VA_ARGS__; \
-         } \
-    } \
+            return __VA_ARGS__;                                         \
+         }                                                              \
+    }                                                                   \
   while (0)
 
 #define ECORE_CON_SERVER_CHECK_RETURN(svr, ...) \
@@ -107,15 +113,16 @@ typedef struct _Ecore_Con_Lookup_Ctx {
     } \
   while (0)
 
-#define ECORE_CON_CLIENT_CHECK_RELAXED_RETURN(cl, ...) \
-  do \
-    { \
-       if (!ECORE_MAGIC_CHECK(cl, ECORE_MAGIC_CON_CLIENT)) \
-         { \
+#define ECORE_CON_CLIENT_CHECK_RELAXED_RETURN(cl, ...)                  \
+  do                                                                    \
+    {                                                                   \
+       if (!cl) return __VA_ARGS__;                                     \
+       if (!ECORE_MAGIC_CHECK(cl, ECORE_MAGIC_CON_CLIENT))              \
+         {                                                              \
             ECORE_MAGIC_FAIL(cl, ECORE_MAGIC_CON_CLIENT, __FUNCTION__); \
-            return __VA_ARGS__; \
-         } \
-    } \
+            return __VA_ARGS__;                                         \
+         }                                                              \
+    }                                                                   \
   while (0)
 
 #define ECORE_CON_CLIENT_CHECK_RETURN(cl, ...) \
@@ -258,38 +265,42 @@ _ecore_con_client_socket_close(Ecore_Con_Client *cl)
 {
    if (!cl->socket) return;
 
-   /* socket may remain alive due other references, we don't own it */
-   efl_event_callback_array_del(cl->socket, _ecore_con_client_socket_cbs(), cl);
-
    if (!efl_io_closer_closed_get(cl->socket))
      efl_io_closer_close(cl->socket);
+
+   /* socket may remain alive due other references, we don't own it */
+   efl_event_callback_array_del(cl->socket, _ecore_con_client_socket_cbs(), cl);
 }
 
 static void
 _ecore_con_client_free(Ecore_Con_Client *cl)
 {
-   cl->delete_me = EINA_TRUE;
+   Ecore_Con_Server *svr = cl->svr;
 
-   if (cl->svr)
-     cl->svr->clients = eina_list_remove(cl->svr->clients, cl);
+   cl->delete_me = EINA_TRUE;
+   cl->svr = NULL;
+
+   if (svr)
+     svr->clients = eina_list_remove(svr->clients, cl);
 
    _ecore_con_client_socket_close(cl);
 
    if (cl->socket)
      {
-        Eo *inner_socket = efl_io_buffered_stream_inner_io_get(cl->socket);
-        efl_event_callback_array_del(cl->socket, _ecore_con_client_socket_cbs(), cl);
+        Eo *parent, *inner_socket = efl_io_buffered_stream_inner_io_get(cl->socket);
+
         if (efl_isa(inner_socket, EFL_NET_SOCKET_SSL_CLASS))
           efl_event_callback_array_del(inner_socket, _ecore_con_client_socket_ssl_cbs(), cl);
 
-        if (efl_parent_get(cl->socket) != cl->svr->server)
+        parent = efl_parent_get(cl->socket);
+        if (parent && (parent != svr->server))
           efl_del(cl->socket); /* we own it */
         else
           efl_unref(cl->socket);
         cl->socket = NULL;
      }
 
-   if (cl->ssl.job) efl_future_cancel(cl->ssl.job);
+   if (cl->ssl.job) eina_future_cancel(cl->ssl.job);
 
    if (cl->ssl.ctx)
      {
@@ -299,6 +310,9 @@ _ecore_con_client_free(Ecore_Con_Client *cl)
 
    if (cl->event_count) return;
 
+   if (svr && (!svr->event_count) && (svr->delete_me))
+     _ecore_con_server_free(svr);
+
    cl->data = NULL;
    eina_stringshare_replace(&cl->ip, NULL);
 
@@ -778,9 +792,21 @@ ecore_con_client_fd_get(const Ecore_Con_Client *cl)
    ECORE_CON_CLIENT_CHECK_RETURN(cl, SOCKET_TO_LOOP_FD(INVALID_SOCKET));
    if (cl->socket)
      {
-        if (efl_isa(cl->socket, EFL_LOOP_FD_CLASS))
-          return efl_loop_fd_get(cl->socket);
-        return SOCKET_TO_LOOP_FD(INVALID_SOCKET);
+        Eo *inner_socket = efl_io_buffered_stream_inner_io_get(cl->socket);
+        if (efl_isa(inner_socket, EFL_LOOP_FD_CLASS))
+          {
+             return efl_loop_fd_get(inner_socket);
+          }
+        else
+          {
+             if (efl_isa(inner_socket, EFL_NET_SOCKET_SSL_CLASS))
+               {
+                  Eo* adopted_socket = NULL;
+                  if (efl_net_socket_ssl_adopted_get(inner_socket, &adopted_socket, NULL))
+                    if (efl_isa(adopted_socket, EFL_LOOP_FD_CLASS))
+                      return efl_loop_fd_get(adopted_socket);
+               }
+          }
      }
    return SOCKET_TO_LOOP_FD(INVALID_SOCKET);
 }
@@ -813,15 +839,19 @@ EFL_CALLBACKS_ARRAY_DEFINE(_ecore_con_client_socket_ssl_cbs,
                            { EFL_NET_SOCKET_SSL_EVENT_SSL_READY, _ecore_con_client_socket_ssl_ready },
                            { EFL_NET_SOCKET_SSL_EVENT_SSL_ERROR, _ecore_con_client_socket_ssl_error });
 
-static void
-_ecore_con_client_ssl_upgrade_job(void *data, const Efl_Event *event EINA_UNUSED)
+static Eina_Value
+_ecore_con_client_ssl_upgrade_job(void *data, const Eina_Value v,
+                                  const Eina_Future *dead EINA_UNUSED)
 {
    Ecore_Con_Client *cl = data;
-   Eo *loop = ecore_main_loop_get();
+   Eo *loop = efl_main_loop_get();
    Eo *inner_socket;
    Eo *socket;
    Eo *tcp_socket;
 
+   //Canceled
+   if (v.type == EINA_VALUE_TYPE_ERROR) return v;
+
    tcp_socket = cl->socket;
    cl->socket = NULL; /* take it, will be wrapped */
 
@@ -838,11 +868,9 @@ _ecore_con_client_ssl_upgrade_job(void *data, const Efl_Event *event EINA_UNUSED
 
    efl_parent_set(inner_socket, socket);
 
-   efl_unref(inner_socket); /* socket keeps it */
-
    cl->socket = socket;
    efl_io_closer_close_on_exec_set(socket, EINA_TRUE);
-   efl_io_closer_close_on_destructor_set(socket, EINA_TRUE);
+   efl_io_closer_close_on_invalidate_set(socket, EINA_TRUE);
    efl_event_callback_array_del(tcp_socket, _ecore_con_client_socket_cbs(), cl);
    efl_event_callback_array_add(socket, _ecore_con_client_socket_cbs(), cl);
    efl_event_callback_array_add(inner_socket, _ecore_con_client_socket_ssl_cbs(), cl);
@@ -852,7 +880,7 @@ _ecore_con_client_ssl_upgrade_job(void *data, const Efl_Event *event EINA_UNUSED
        efl_io_buffered_stream_inner_io_get(cl->socket),
        cl->ssl.ctx,
        tcp_socket);
-   return;
+   return v;
 
  error_socket:
    efl_del(inner_socket);
@@ -860,10 +888,18 @@ _ecore_con_client_ssl_upgrade_job(void *data, const Efl_Event *event EINA_UNUSED
    cl->socket = tcp_socket; /* put it back */
    if (_ecore_con_post_event_client_error(cl, "Couldn't finish SSL setup"))
      _ecore_con_post_event_client_del(cl);
+   return v;
 }
 
 static Eo * _ecore_con_server_ssl_ctx_create(const Ecore_Con_Server *svr);
 
+static void
+_ecore_con_server_job_schedule(Ecore_Con_Server *svr, Eo *loop,
+                               Eina_Future_Cb cb)
+{
+   eina_future_then(efl_loop_job(loop), cb, svr, &svr->ssl.job);
+}
+
 EAPI Eina_Bool
 ecore_con_ssl_client_upgrade(Ecore_Con_Client *cl, Ecore_Con_Type compl_type)
 {
@@ -905,8 +941,9 @@ ecore_con_ssl_client_upgrade(Ecore_Con_Client *cl, Ecore_Con_Type compl_type)
 
    cl->ssl.upgrading = EINA_TRUE;
    cl->ssl.ctx = ssl_ctx;
-   efl_future_use(&cl->ssl.job, efl_loop_job(efl_loop_get(cl->socket), cl));
-   efl_future_then(cl->ssl.job, _ecore_con_client_ssl_upgrade_job, NULL, NULL, cl);
+
+   eina_future_then(efl_loop_job(efl_loop_get(cl->socket)),
+                    _ecore_con_client_ssl_upgrade_job, cl, &cl->ssl.job);
 
    DBG("cl=%p SSL upgrading from %#x to type=%#x", cl, svr->type, compl_type);
 
@@ -927,6 +964,8 @@ ecore_con_server_check(const Ecore_Con_Server *svr)
 static Ecore_Con_Server *
 _ecore_con_server_new(Eina_Bool is_dialer, Ecore_Con_Type type, const char *name, int port, const void *data)
 {
+   EINA_SAFETY_ON_TRUE_RETURN_VAL(!name || (!name[0]), NULL);
+
    Ecore_Con_Server *svr = calloc(1, sizeof(Ecore_Con_Server));
    EINA_SAFETY_ON_NULL_RETURN_VAL(svr, NULL);
    svr->start_time = ecore_time_get();
@@ -944,6 +983,7 @@ _ecore_con_server_new(Eina_Bool is_dialer, Ecore_Con_Type type, const char *name
 static void
 _ecore_con_server_dialer_close(Ecore_Con_Server *svr)
 {
+   svr->connecting = EINA_FALSE;
    if (!svr->dialer) return;
 
    if (!efl_io_closer_closed_get(svr->dialer))
@@ -963,6 +1003,14 @@ _ecore_con_server_free(Ecore_Con_Server *svr)
 
    _ecore_con_server_dialer_close(svr);
 
+   if (svr->ssl.clients_ctx)
+     {
+        // This is always created with efl_add_ref
+        efl_parent_set(svr->ssl.clients_ctx, NULL);
+        efl_unref(svr->ssl.clients_ctx);
+        svr->ssl.clients_ctx = NULL;
+     }
+
    if (svr->dialer)
      {
         efl_del(svr->dialer);
@@ -975,13 +1023,7 @@ _ecore_con_server_free(Ecore_Con_Server *svr)
         svr->server = NULL;
      }
 
-   if (svr->ssl.clients_ctx)
-     {
-        efl_unref(svr->ssl.clients_ctx);
-        svr->ssl.clients_ctx = NULL;
-     }
-
-   if (svr->ssl.job) efl_future_cancel(svr->ssl.job);
+   if (svr->ssl.job) eina_future_cancel(svr->ssl.job);
 
    if (svr->ssl.pending_send)
      {
@@ -1304,8 +1346,8 @@ _ecore_con_server_dialer_error(void *data, const Efl_Event *event)
 
    WRN("error reaching server %s: %s", efl_net_dialer_address_dial_get(svr->dialer), eina_error_msg_get(*perr));
 
-   _ecore_con_server_dialer_close(svr);
    _ecore_con_post_event_server_error(svr, eina_error_msg_get(*perr));
+   _ecore_con_server_dialer_close(svr);
 }
 
 static void
@@ -1502,20 +1544,18 @@ _ecore_con_server_server_set(Ecore_Con_Server *svr, Eo *server)
    if (efl_isa(inner_server, EFL_NET_SERVER_TCP_CLASS))
      {
         /* old ecore_con did not map ipv4 to ipv6... */
-        efl_net_server_tcp_ipv6_only_set(inner_server, EINA_TRUE);
+        efl_net_server_ip_ipv6_only_set(inner_server, EINA_TRUE);
      }
    else if (efl_isa(inner_server, EFL_NET_SERVER_UDP_CLASS))
      {
         /* old ecore_con did not map ipv4 to ipv6... */
-        efl_net_server_udp_ipv6_only_set(inner_server, EINA_TRUE);
+        efl_net_server_ip_ipv6_only_set(inner_server, EINA_TRUE);
         svr->want_mcast = type == ECORE_CON_REMOTE_MCAST;
      }
    else if (efl_isa(inner_server, EFL_NET_SERVER_SSL_CLASS))
      {
         /* old ecore_con did not map ipv4 to ipv6... */
-        efl_net_server_ssl_ipv6_only_set(inner_server, EINA_TRUE);
-        efl_net_server_ssl_reuse_address_set(inner_server, EINA_TRUE);
-        efl_net_server_ssl_reuse_port_set(inner_server, EINA_TRUE);
+        efl_net_server_ip_ipv6_only_set(inner_server, EINA_TRUE);
      }
 #ifdef EFL_NET_SERVER_UNIX_CLASS
    else if (efl_isa(inner_server, EFL_NET_SERVER_UNIX_CLASS))
@@ -1528,8 +1568,6 @@ _ecore_con_server_server_set(Ecore_Con_Server *svr, Eo *server)
      {
         if (efl_isa(inner_server, EFL_NET_SERVER_FD_CLASS))
           efl_net_server_fd_socket_activate(inner_server, address);
-        else if (efl_isa(inner_server, EFL_NET_SERVER_SSL_CLASS))
-          efl_net_server_ssl_socket_activate(inner_server, address);
         else
           {
              ERR("svr=%p (%s): not able to socket-activate this type!", svr, efl_class_name_get(inner_server));
@@ -1572,7 +1610,10 @@ _ecore_con_server_ssl_ctx_create(const Ecore_Con_Server *svr)
    else if (ssl_type & ECORE_CON_USE_TLS)
      cipher = EFL_NET_SSL_CIPHER_TLSV1;
    else if (ssl_type & ECORE_CON_USE_SSL3)
-     cipher = EFL_NET_SSL_CIPHER_SSLV3;
+     {
+        ERR("SSLv3 is unsupported!");
+        return NULL;
+     }
    else if (ssl_type & ECORE_CON_USE_SSL2)
      {
         ERR("SSLv2 is unsupported!");
@@ -1581,24 +1622,27 @@ _ecore_con_server_ssl_ctx_create(const Ecore_Con_Server *svr)
 
    /* legacy compatibility: server never verified peer, only dialer did */
 
-   return efl_add(EFL_NET_SSL_CONTEXT_CLASS, NULL,
-                  efl_net_ssl_context_certificates_set(efl_added, eina_list_iterator_new(svr->ssl.certs)),
-                  efl_net_ssl_context_private_keys_set(efl_added, eina_list_iterator_new(svr->ssl.privkeys)),
-                  efl_net_ssl_context_certificate_revocation_lists_set(efl_added, eina_list_iterator_new(svr->ssl.crls)),
-                  efl_net_ssl_context_certificate_authorities_set(efl_added, eina_list_iterator_new(svr->ssl.cafiles)),
-                  efl_net_ssl_context_default_paths_load_set(efl_added, EINA_FALSE), /* old API didn't load default paths */
-                  efl_net_ssl_context_setup(efl_added, cipher, EINA_FALSE));
+   return efl_add_ref(EFL_NET_SSL_CONTEXT_CLASS, efl_main_loop_get(),
+                      efl_net_ssl_context_certificates_set(efl_added, eina_list_iterator_new(svr->ssl.certs)),
+                      efl_net_ssl_context_private_keys_set(efl_added, eina_list_iterator_new(svr->ssl.privkeys)),
+                      efl_net_ssl_context_certificate_revocation_lists_set(efl_added, eina_list_iterator_new(svr->ssl.crls)),
+                      efl_net_ssl_context_certificate_authorities_set(efl_added, eina_list_iterator_new(svr->ssl.cafiles)),
+                      efl_net_ssl_context_default_paths_load_set(efl_added, EINA_FALSE), /* old API didn't load default paths */
+                      efl_net_ssl_context_setup(efl_added, cipher, EINA_FALSE));
 }
 
-static void
-_ecore_con_server_server_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
+static Eina_Value
+_ecore_con_server_server_ssl_job(void *data, const Eina_Value v,
+                                 const Eina_Future *dead EINA_UNUSED)
 {
    Ecore_Con_Server *svr = data;
-   Eo *loop = ecore_main_loop_get();
+   Eo *loop = efl_main_loop_get();
    Eo *ssl_ctx;
    Eo *inner_server;
    Eo *server;
 
+   if (v.type == EINA_VALUE_TYPE_ERROR) return v;
+
    ssl_ctx = _ecore_con_server_ssl_ctx_create(svr);
    EINA_SAFETY_ON_NULL_GOTO(ssl_ctx, error_ssl_ctx);
 
@@ -1613,7 +1657,6 @@ _ecore_con_server_server_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
    efl_parent_set(inner_server, server);
 
    efl_unref(ssl_ctx); /* inner_server keeps it */
-   efl_unref(inner_server); /* server keeps it */
 
    if (!_ecore_con_server_server_set(svr, server))
      goto error_serve;
@@ -1623,12 +1666,12 @@ _ecore_con_server_server_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
        efl_net_server_simple_inner_server_get(svr->server),
        efl_net_server_ssl_context_get(efl_net_server_simple_inner_server_get(svr->server)));
 
-   return;
+   return v;
 
  error_serve:
    if (_ecore_con_post_event_server_error(svr, "Couldn't serve using SSL"))
      _ecore_con_post_event_server_del(svr);
-   return;
+   return v;
 
  error_server:
    efl_del(inner_server);
@@ -1637,6 +1680,7 @@ _ecore_con_server_server_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
  error_ssl_ctx:
    if (_ecore_con_post_event_server_error(svr, "Couldn't finish SSL setup"))
      _ecore_con_post_event_server_del(svr);
+   return v;
 }
 
 /**
@@ -1661,7 +1705,16 @@ ecore_con_server_add(Ecore_Con_Type compl_type,
 
    type = compl_type & ECORE_CON_TYPE;
 
-   loop = ecore_main_loop_get();
+   /* The allowable port number is an unsigned 16-bit integer for remote connection, so 1-65535, 0 is reserved */
+   if (((type == ECORE_CON_REMOTE_TCP) || (type == ECORE_CON_REMOTE_NODELAY) || (type == ECORE_CON_REMOTE_CORK) ||
+        (type == ECORE_CON_REMOTE_UDP) || (type == ECORE_CON_REMOTE_MCAST)) &&
+       ((port < 0) || (port > 65535)))
+     {
+        ERR("Port %i invalid (0 <= port <= 65535)", port);
+        return NULL;
+     }
+
+   loop = efl_main_loop_get();
    EINA_SAFETY_ON_NULL_RETURN_VAL(loop, NULL);
 
    svr = _ecore_con_server_new(EINA_FALSE, compl_type, name, port, data);
@@ -1724,8 +1777,7 @@ ecore_con_server_add(Ecore_Con_Type compl_type,
          * > against loaded certificates.
          */
         svr->ssl.upgrade_type = compl_type;
-        efl_future_use(&svr->ssl.job, efl_loop_job(loop, svr));
-        efl_future_then(svr->ssl.job, _ecore_con_server_server_ssl_job, NULL, NULL, svr);
+        _ecore_con_server_job_schedule(svr, loop, _ecore_con_server_server_ssl_job);
         return svr;
      }
 
@@ -1830,7 +1882,7 @@ _ecore_con_server_dialer_set(Ecore_Con_Server *svr, Eo *dialer)
 
    svr->dialer = dialer;
    efl_io_closer_close_on_exec_set(dialer, EINA_TRUE);
-   efl_io_closer_close_on_destructor_set(dialer, EINA_TRUE);
+   efl_io_closer_close_on_invalidate_set(dialer, EINA_TRUE);
    efl_io_buffered_stream_timeout_inactivity_set(dialer, svr->timeout);
    efl_event_callback_array_add(dialer, _ecore_con_server_dialer_cbs(), svr);
 
@@ -1920,11 +1972,12 @@ _ecore_con_server_dialer_set(Ecore_Con_Server *svr, Eo *dialer)
    return EINA_TRUE;
 }
 
-static void
-_ecore_con_server_dialer_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
+static Eina_Value
+_ecore_con_server_dialer_ssl_job(void *data, const Eina_Value v,
+                                 const Eina_Future *dead EINA_UNUSED)
 {
    Ecore_Con_Server *svr = data;
-   Eo *loop = ecore_main_loop_get();
+   Eo *loop = efl_main_loop_get();
    Eo *ssl_ctx;
    Eo *inner_dialer;
    Eo *dialer;
@@ -1937,7 +1990,10 @@ _ecore_con_server_dialer_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
    else if (ssl_type & ECORE_CON_USE_TLS)
      cipher = EFL_NET_SSL_CIPHER_TLSV1;
    else if (ssl_type & ECORE_CON_USE_SSL3)
-     cipher = EFL_NET_SSL_CIPHER_SSLV3;
+     {
+        ERR("SSLv3 is unsupported!");
+        goto error_ssl_ctx;
+     }
    else if (ssl_type & ECORE_CON_USE_SSL2)
      {
         ERR("SSLv2 is unsupported!");
@@ -1947,7 +2003,7 @@ _ecore_con_server_dialer_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
    if (svr->ssl.verify)
      verify_mode = EFL_NET_SSL_VERIFY_MODE_REQUIRED;
 
-   ssl_ctx = efl_add(EFL_NET_SSL_CONTEXT_CLASS, NULL,
+   ssl_ctx = efl_add(EFL_NET_SSL_CONTEXT_CLASS, efl_main_loop_get(),
                      efl_net_ssl_context_certificates_set(efl_added, eina_list_iterator_new(svr->ssl.certs)),
                      efl_net_ssl_context_private_keys_set(efl_added, eina_list_iterator_new(svr->ssl.privkeys)),
                      efl_net_ssl_context_certificate_revocation_lists_set(efl_added, eina_list_iterator_new(svr->ssl.crls)),
@@ -1968,9 +2024,7 @@ _ecore_con_server_dialer_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
    EINA_SAFETY_ON_NULL_GOTO(dialer, error_dialer);
 
    efl_parent_set(inner_dialer, dialer);
-
-   efl_unref(ssl_ctx); /* inner_dialer keeps it */
-   efl_unref(inner_dialer); /* dialer keeps it */
+   efl_parent_set(ssl_ctx, inner_dialer);
 
    if (!_ecore_con_server_dialer_set(svr, dialer))
      goto error_dial;
@@ -1992,12 +2046,12 @@ _ecore_con_server_dialer_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
         svr->ssl.pending_send = NULL;
      }
 
-   return;
+   return v;
 
  error_dial:
    if (_ecore_con_post_event_server_error(svr, "Couldn't dial using SSL"))
      _ecore_con_post_event_server_del(svr);
-   return;
+   return v;
 
  error_dialer:
    efl_del(inner_dialer);
@@ -2006,13 +2060,15 @@ _ecore_con_server_dialer_ssl_job(void *data, const Efl_Event *event EINA_UNUSED)
  error_ssl_ctx:
    if (_ecore_con_post_event_server_error(svr, "Couldn't finish SSL setup"))
      _ecore_con_post_event_server_del(svr);
+   return v;
 }
 
-static void
-_ecore_con_server_dialer_ssl_upgrade_job(void *data, const Efl_Event *event EINA_UNUSED)
+static Eina_Value
+_ecore_con_server_dialer_ssl_upgrade_job(void *data, const Eina_Value v,
+                                         const Eina_Future *dead EINA_UNUSED)
 {
    Ecore_Con_Server *svr = data;
-   Eo *loop = ecore_main_loop_get();
+   Eo *loop = efl_main_loop_get();
    Eo *ssl_ctx;
    Eo *inner_dialer;
    Eo *dialer;
@@ -2021,12 +2077,18 @@ _ecore_con_server_dialer_ssl_upgrade_job(void *data, const Efl_Event *event EINA
    Efl_Net_Ssl_Verify_Mode verify_mode = EFL_NET_SSL_VERIFY_MODE_NONE; /* was the default */
    Ecore_Con_Type ssl_type = svr->ssl.upgrade_type & ECORE_CON_SSL;
 
+   //Canceled
+   if (v.type == EINA_VALUE_TYPE_ERROR) return v;
+
    if (ssl_type & ECORE_CON_USE_MIXED)
      cipher = EFL_NET_SSL_CIPHER_AUTO;
    else if (ssl_type & ECORE_CON_USE_TLS)
      cipher = EFL_NET_SSL_CIPHER_TLSV1;
    else if (ssl_type & ECORE_CON_USE_SSL3)
-     cipher = EFL_NET_SSL_CIPHER_SSLV3;
+     {
+        ERR("SSLv3 is unsupported!");
+        goto error_ssl_ctx;
+     }
    else if (ssl_type & ECORE_CON_USE_SSL2)
      {
         ERR("SSLv2 is unsupported!");
@@ -2036,16 +2098,16 @@ _ecore_con_server_dialer_ssl_upgrade_job(void *data, const Efl_Event *event EINA
    if (svr->ssl.verify)
      verify_mode = EFL_NET_SSL_VERIFY_MODE_REQUIRED;
 
-   ssl_ctx = efl_add(EFL_NET_SSL_CONTEXT_CLASS, NULL,
-                     efl_net_ssl_context_certificates_set(efl_added, eina_list_iterator_new(svr->ssl.certs)),
-                     efl_net_ssl_context_private_keys_set(efl_added, eina_list_iterator_new(svr->ssl.privkeys)),
-                     efl_net_ssl_context_certificate_revocation_lists_set(efl_added, eina_list_iterator_new(svr->ssl.crls)),
-                     efl_net_ssl_context_certificate_authorities_set(efl_added, eina_list_iterator_new(svr->ssl.cafiles)),
-                     efl_net_ssl_context_verify_mode_set(efl_added, verify_mode),
-                     efl_net_ssl_context_hostname_set(efl_added, svr->ssl.verify_name ? svr->ssl.verify_name : svr->name),
-                     efl_net_ssl_context_hostname_verify_set(efl_added, svr->ssl.verify_basic),
-                     efl_net_ssl_context_default_paths_load_set(efl_added, EINA_FALSE), /* old API didn't load default paths */
-                     efl_net_ssl_context_setup(efl_added, cipher, EINA_TRUE));
+   ssl_ctx = efl_add_ref(EFL_NET_SSL_CONTEXT_CLASS, efl_main_loop_get(),
+                         efl_net_ssl_context_certificates_set(efl_added, eina_list_iterator_new(svr->ssl.certs)),
+                         efl_net_ssl_context_private_keys_set(efl_added, eina_list_iterator_new(svr->ssl.privkeys)),
+                         efl_net_ssl_context_certificate_revocation_lists_set(efl_added, eina_list_iterator_new(svr->ssl.crls)),
+                         efl_net_ssl_context_certificate_authorities_set(efl_added, eina_list_iterator_new(svr->ssl.cafiles)),
+                         efl_net_ssl_context_verify_mode_set(efl_added, verify_mode),
+                         efl_net_ssl_context_hostname_set(efl_added, svr->ssl.verify_name ? svr->ssl.verify_name : svr->name),
+                         efl_net_ssl_context_hostname_verify_set(efl_added, svr->ssl.verify_basic),
+                         efl_net_ssl_context_default_paths_load_set(efl_added, EINA_FALSE), /* old API didn't load default paths */
+                         efl_net_ssl_context_setup(efl_added, cipher, EINA_TRUE));
    EINA_SAFETY_ON_NULL_GOTO(ssl_ctx, error_ssl_ctx);
 
    tcp_dialer = svr->dialer;
@@ -2064,11 +2126,10 @@ _ecore_con_server_dialer_ssl_upgrade_job(void *data, const Efl_Event *event EINA
    efl_parent_set(inner_dialer, dialer);
 
    efl_unref(ssl_ctx); /* inner_dialer keeps it */
-   efl_unref(inner_dialer); /* dialer keeps it */
 
    svr->dialer = dialer;
    efl_io_closer_close_on_exec_set(dialer, EINA_TRUE);
-   efl_io_closer_close_on_destructor_set(dialer, EINA_TRUE);
+   efl_io_closer_close_on_invalidate_set(dialer, EINA_TRUE);
    efl_event_callback_array_del(tcp_dialer, _ecore_con_server_dialer_cbs(), svr);
    efl_event_callback_array_add(dialer, _ecore_con_server_dialer_cbs(), svr);
 
@@ -2077,7 +2138,7 @@ _ecore_con_server_dialer_ssl_upgrade_job(void *data, const Efl_Event *event EINA
        efl_io_buffered_stream_inner_io_get(svr->dialer),
        efl_net_dialer_ssl_context_get(efl_io_buffered_stream_inner_io_get(svr->dialer)),
        tcp_dialer);
-   return;
+   return v;
 
  error_dialer:
    efl_del(inner_dialer);
@@ -2087,6 +2148,7 @@ _ecore_con_server_dialer_ssl_upgrade_job(void *data, const Efl_Event *event EINA
  error_ssl_ctx:
    if (_ecore_con_post_event_server_error(svr, "Couldn't finish SSL setup"))
      _ecore_con_post_event_server_del(svr);
+   return v;
 }
 
 /**
@@ -2112,7 +2174,7 @@ ecore_con_server_connect(Ecore_Con_Type compl_type,
 
    type = compl_type & ECORE_CON_TYPE;
 
-   loop = ecore_main_loop_get();
+   loop = efl_main_loop_get();
    EINA_SAFETY_ON_NULL_RETURN_VAL(loop, NULL);
 
    svr = _ecore_con_server_new(EINA_TRUE, compl_type, name, port, data);
@@ -2173,8 +2235,7 @@ ecore_con_server_connect(Ecore_Con_Type compl_type,
          * > has started to enable verification of certificates
          * > against loaded certificates.
          */
-        efl_future_use(&svr->ssl.job, efl_loop_job(loop, svr));
-        efl_future_then(svr->ssl.job, _ecore_con_server_dialer_ssl_job, NULL, NULL, svr);
+        _ecore_con_server_job_schedule(svr, loop, _ecore_con_server_dialer_ssl_job);
         return svr;
      }
 
@@ -2375,7 +2436,19 @@ ecore_con_server_fd_get(const Ecore_Con_Server *svr)
      {
         Eo *inner_dialer = efl_io_buffered_stream_inner_io_get(svr->dialer);
         if (efl_isa(inner_dialer, EFL_LOOP_FD_CLASS))
-          return efl_loop_fd_get(inner_dialer);
+          {
+             return efl_loop_fd_get(inner_dialer);
+          }
+        else
+          {
+             if (efl_isa(inner_dialer, EFL_NET_DIALER_SSL_CLASS))
+               {
+                  Eo* adopted_dialer = NULL;
+                  if (efl_net_socket_ssl_adopted_get(inner_dialer, &adopted_dialer, NULL))
+                    if (efl_isa(adopted_dialer, EFL_LOOP_FD_CLASS))
+                      return efl_loop_fd_get(adopted_dialer);
+               }
+          }
         return SOCKET_TO_LOOP_FD(INVALID_SOCKET);
      }
    if (svr->server)
@@ -2534,8 +2607,9 @@ ecore_con_ssl_server_upgrade(Ecore_Con_Server *svr, Ecore_Con_Type compl_type)
 
    svr->ssl.upgrading = EINA_TRUE;
    svr->ssl.upgrade_type = compl_type;
-   efl_future_use(&svr->ssl.job, efl_loop_job(efl_loop_get(svr->dialer), svr));
-   efl_future_then(svr->ssl.job, _ecore_con_server_dialer_ssl_upgrade_job, NULL, NULL, svr);
+
+   _ecore_con_server_job_schedule(svr, efl_loop_get(svr->dialer),
+                                  _ecore_con_server_dialer_ssl_upgrade_job);
 
    DBG("svr=%p SSL upgrading from %#x to type=%#x", svr, svr->type, compl_type);
 
@@ -2606,7 +2680,7 @@ ecore_con_lookup(const char *name, Ecore_Con_Dns_Cb done_cb, const void *data)
      .ai_flags = AI_ADDRCONFIG | AI_V4MAPPED | AI_CANONNAME,
    };
 
-   EINA_SAFETY_ON_NULL_RETURN_VAL(name, EINA_FALSE);
+   EINA_SAFETY_ON_TRUE_RETURN_VAL(!name || (!name[0]), EINA_FALSE);
    EINA_SAFETY_ON_NULL_RETURN_VAL(done_cb, EINA_FALSE);
 
    ctx = malloc(sizeof(Ecore_Con_Lookup_Ctx));
