@@ -17,6 +17,7 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <fcntl.h>
+#include <libgen.h>
 
 #include "Ecore.h"
 #include "ecore_private.h"
@@ -703,7 +704,7 @@ _ecore_con_url_request_prepare(Ecore_Con_Url *url_con, const char *method)
    if (proxy_url)
      DBG("proxy_url='%s'", proxy_url);
 
-   url_con->dialer = efl_add(EFL_NET_DIALER_HTTP_CLASS, ecore_main_loop_get(),
+   url_con->dialer = efl_add(EFL_NET_DIALER_HTTP_CLASS, efl_main_loop_get(),
                              efl_net_dialer_http_method_set(efl_added, url_con->custom_request ? url_con->custom_request : method),
                              efl_net_dialer_http_primary_mode_set(efl_added, (strcmp(method, "PUT") == 0) ? EFL_NET_DIALER_HTTP_PRIMARY_MODE_UPLOAD : EFL_NET_DIALER_HTTP_PRIMARY_MODE_DOWNLOAD),
                              efl_net_dialer_proxy_set(efl_added, proxy_url),
@@ -921,7 +922,7 @@ ecore_con_url_post(Ecore_Con_Url *url_con,
 
    buffer = efl_add(EFL_IO_BUFFER_CLASS, efl_loop_get(url_con->dialer),
                     efl_name_set(efl_added, "post-buffer"),
-                    efl_io_closer_close_on_destructor_set(efl_added, EINA_TRUE),
+                    efl_io_closer_close_on_invalidate_set(efl_added, EINA_TRUE),
                     efl_io_closer_close_on_exec_set(efl_added, EINA_TRUE));
    EINA_SAFETY_ON_NULL_GOTO(buffer, error_buffer);
 
@@ -937,7 +938,7 @@ ecore_con_url_post(Ecore_Con_Url *url_con,
                     efl_name_set(efl_added, "send-copier"),
                     efl_io_copier_source_set(efl_added, buffer),
                     efl_io_copier_destination_set(efl_added, url_con->dialer),
-                    efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                    efl_io_closer_close_on_invalidate_set(efl_added, EINA_FALSE),
                     efl_event_callback_array_add(efl_added, _ecore_con_url_copier_cbs(), url_con));
    EINA_SAFETY_ON_NULL_GOTO(copier, error_copier);
 
@@ -1178,7 +1179,7 @@ ecore_con_url_ftp_upload(Ecore_Con_Url *url_con,
                   efl_name_set(efl_added, "upload-file"),
                   efl_file_set(efl_added, filename, NULL),
                   efl_io_file_flags_set(efl_added, O_RDONLY),
-                  efl_io_closer_close_on_destructor_set(efl_added, EINA_TRUE),
+                  efl_io_closer_close_on_invalidate_set(efl_added, EINA_TRUE),
                   efl_io_closer_close_on_exec_set(efl_added, EINA_TRUE));
    EINA_SAFETY_ON_NULL_GOTO(file, error_file);
 
@@ -1186,7 +1187,7 @@ ecore_con_url_ftp_upload(Ecore_Con_Url *url_con,
                     efl_name_set(efl_added, "send-copier"),
                     efl_io_copier_source_set(efl_added, file),
                     efl_io_copier_destination_set(efl_added, url_con->dialer),
-                    efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                    efl_io_closer_close_on_invalidate_set(efl_added, EINA_FALSE),
                     efl_event_callback_array_add(efl_added, _ecore_con_url_copier_cbs(), url_con));
    EINA_SAFETY_ON_NULL_GOTO(copier, error_copier);
 
@@ -1220,6 +1221,34 @@ ecore_con_url_ftp_use_epsv_set(Ecore_Con_Url *url_con,
    url_con->ftp_use_epsv = use_epsv;
 }
 
+EAPI void
+ecore_con_url_limit_upload_speed(Ecore_Con_Url *url_con, off_t max_speed)
+{
+   CURL *curl_easy;
+
+   ECORE_CON_URL_CHECK_RETURN(url_con);
+   EINA_SAFETY_ON_NULL_RETURN(_c);
+
+   curl_easy = efl_net_dialer_http_curl_get(url_con->dialer);
+   EINA_SAFETY_ON_NULL_RETURN(curl_easy);
+
+   _c->curl_easy_setopt(curl_easy, CURLOPT_MAX_SEND_SPEED_LARGE, max_speed);
+}
+
+EAPI void
+ecore_con_url_limit_download_speed(Ecore_Con_Url *url_con, off_t max_speed)
+{
+   CURL *curl_easy;
+
+   ECORE_CON_URL_CHECK_RETURN(url_con);
+   EINA_SAFETY_ON_NULL_RETURN(_c);
+
+   curl_easy = efl_net_dialer_http_curl_get(url_con->dialer);
+   EINA_SAFETY_ON_NULL_RETURN(curl_easy);
+
+   _c->curl_easy_setopt(curl_easy, CURLOPT_MAX_RECV_SPEED_LARGE, max_speed);
+}
+
 /* LEGACY: proxy */
 EAPI Eina_Bool
 ecore_con_url_proxy_password_set(Ecore_Con_Url *url_con, const char *password)
