@@ -75,7 +75,7 @@ _efl_net_control_access_point_property_set_cb(void *data, const Eldbus_Message *
 }
 
 static void
-_efl_net_control_access_point_property_set_string_array(Eo *o, Efl_Net_Control_Access_Point_Data *pd, const char *name, Eina_Iterator *it)
+_efl_net_control_access_point_property_set_string_array(const Eo *o, Efl_Net_Control_Access_Point_Data *pd, const char *name, Eina_Iterator *it)
 {
    Eldbus_Message *msg;
    Eldbus_Message_Iter *msg_itr, *var, *array;
@@ -112,7 +112,7 @@ _efl_net_control_access_point_property_set_string_array(Eo *o, Efl_Net_Control_A
 }
 
 static void
-_efl_net_control_access_point_property_set(Eo *o, Efl_Net_Control_Access_Point_Data *pd, const char *name, const char *signature, ...)
+_efl_net_control_access_point_property_set(const Eo *o, Efl_Net_Control_Access_Point_Data *pd, const char *name, const char *signature, ...)
 {
    Eldbus_Message *msg;
    Eldbus_Message_Iter *msg_itr, *var;
@@ -205,19 +205,19 @@ _efl_net_control_access_point_efl_object_destructor(Eo *o, Efl_Net_Control_Acces
 }
 
 EOLIAN static Efl_Net_Control_Access_Point_State
-_efl_net_control_access_point_state_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_state_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->state;
 }
 
 EOLIAN static Efl_Net_Control_Access_Point_Error
-_efl_net_control_access_point_error_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_error_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->error;
 }
 
 EOLIAN static const char *
-_efl_net_control_access_point_name_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_ssid_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->name;
 }
@@ -261,7 +261,7 @@ _efl_net_control_access_point_priority_set(Eo *o, Efl_Net_Control_Access_Point_D
         return;
      }
 
-   it = efl_net_control_access_points_get(efl_parent_get(o));
+   it = efl_net_control_manager_access_points_get(efl_parent_get(o));
    EINA_ITERATOR_FOREACH(it, ap)
      {
         unsigned other_prio;
@@ -312,25 +312,25 @@ _efl_net_control_access_point_priority_set(Eo *o, Efl_Net_Control_Access_Point_D
 }
 
 EOLIAN static unsigned int
-_efl_net_control_access_point_priority_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_priority_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->priority;
 }
 
 EOLIAN static Efl_Net_Control_Technology *
-_efl_net_control_access_point_technology_get(Eo *o, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_technology_get(const Eo *o, Efl_Net_Control_Access_Point_Data *pd)
 {
    return efl_net_connman_control_find_technology_by_type(efl_parent_get(o), pd->techname);
 }
 
 EOLIAN static uint8_t
-_efl_net_control_access_point_strength_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_strength_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->strength;
 }
 
 EOLIAN static Eina_Bool
-_efl_net_control_access_point_roaming_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_roaming_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->roaming;
 }
@@ -342,49 +342,49 @@ _efl_net_control_access_point_auto_connect_set(Eo *o, Efl_Net_Control_Access_Poi
 }
 
 EOLIAN static Eina_Bool
-_efl_net_control_access_point_auto_connect_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_auto_connect_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->auto_connect;
 }
 
 EOLIAN static Eina_Bool
-_efl_net_control_access_point_remembered_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_remembered_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->remembered;
 }
 
 EOLIAN static Eina_Bool
-_efl_net_control_access_point_immutable_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_immutable_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->immutable;
 }
 
 EOLIAN static Efl_Net_Control_Access_Point_Security
-_efl_net_control_access_point_security_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_security_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return pd->security;
 }
 
 EOLIAN static Eina_Iterator *
-_efl_net_control_access_point_name_servers_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_name_servers_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return eina_list_iterator_new(pd->actual.name_servers);
 }
 
 EOLIAN static Eina_Iterator *
-_efl_net_control_access_point_time_servers_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_time_servers_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return eina_list_iterator_new(pd->actual.time_servers);
 }
 
 EOLIAN static Eina_Iterator *
-_efl_net_control_access_point_domains_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_domains_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return eina_list_iterator_new(pd->actual.domains);
 }
 
 EOLIAN static void
-_efl_net_control_access_point_ipv4_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway)
+_efl_net_control_access_point_ipv4_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway)
 {
    if (method) *method = pd->actual.ipv4.method;
    if (address) *address = pd->actual.ipv4.address;
@@ -393,7 +393,7 @@ _efl_net_control_access_point_ipv4_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access
 }
 
 EOLIAN static void
-_efl_net_control_access_point_ipv6_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway)
+_efl_net_control_access_point_ipv6_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway)
 {
    if (method) *method = pd->actual.ipv6.method;
    if (address) *address = pd->actual.ipv6.address;
@@ -403,7 +403,7 @@ _efl_net_control_access_point_ipv6_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access
 }
 
 EOLIAN static void
-_efl_net_control_access_point_proxy_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes)
+_efl_net_control_access_point_proxy_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes)
 {
    if (method) *method = pd->actual.proxy.method;
    if (url) *url = pd->actual.proxy.url;
@@ -418,7 +418,7 @@ _efl_net_control_access_point_configuration_name_servers_set(Eo *o, Efl_Net_Cont
 }
 
 EOLIAN static Eina_Iterator *
-_efl_net_control_access_point_configuration_name_servers_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_configuration_name_servers_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return eina_list_iterator_new(pd->configured.name_servers);
 }
@@ -430,7 +430,7 @@ _efl_net_control_access_point_configuration_time_servers_set(Eo *o, Efl_Net_Cont
 }
 
 EOLIAN static Eina_Iterator *
-_efl_net_control_access_point_configuration_time_servers_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_configuration_time_servers_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return eina_list_iterator_new(pd->configured.time_servers);
 }
@@ -442,7 +442,7 @@ _efl_net_control_access_point_configuration_domains_set(Eo *o, Efl_Net_Control_A
 }
 
 EOLIAN static Eina_Iterator *
-_efl_net_control_access_point_configuration_domains_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
+_efl_net_control_access_point_configuration_domains_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd)
 {
    return eina_list_iterator_new(pd->configured.domains);
 }
@@ -518,7 +518,6 @@ _efl_net_control_access_point_configuration_ipv4_set(Eo *o, Efl_Net_Control_Acce
 
    switch (method)
      {
-      case EFL_NET_CONTROL_ACCESS_POINT_IPV4_METHOD_UNSET: goto error_send;
       case EFL_NET_CONTROL_ACCESS_POINT_IPV4_METHOD_OFF:
          _append_dict_entry(array, "Method", "s", "off");
          break;
@@ -534,6 +533,8 @@ _efl_net_control_access_point_configuration_ipv4_set(Eo *o, Efl_Net_Control_Acce
          if (gateway)
            _append_dict_entry(array, "Gateway", "s", gateway);
          break;
+      default:
+         break;
      }
 
    eldbus_message_iter_container_close(var, array);
@@ -551,7 +552,7 @@ _efl_net_control_access_point_configuration_ipv4_set(Eo *o, Efl_Net_Control_Acce
 }
 
 EOLIAN static void
-_efl_net_control_access_point_configuration_ipv4_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway)
+_efl_net_control_access_point_configuration_ipv4_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway)
 {
    if (method) *method = pd->configured.ipv4.method;
    if (address) *address = pd->configured.ipv4.address;
@@ -594,9 +595,6 @@ _efl_net_control_access_point_configuration_ipv6_set(Eo *o, Efl_Net_Control_Acce
 
    switch (method)
      {
-      case EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_UNSET: goto error_send;
-      case EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_FIXED: goto error_send;
-      case EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_TUNNEL6TO4: goto error_send;
       case EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_OFF:
          _append_dict_entry(array, "Method", "s", "off");
          break;
@@ -621,7 +619,9 @@ _efl_net_control_access_point_configuration_ipv6_set(Eo *o, Efl_Net_Control_Acce
          break;
       case EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_TEMPORARY:
          _append_dict_entry(array, "Method", "s", "auto");
-         _append_dict_entry(array, "Privacy", "s", "prefered");
+         _append_dict_entry(array, "Privacy", "s", "preferred");
+         break;
+      default:
          break;
      }
 
@@ -640,7 +640,7 @@ _efl_net_control_access_point_configuration_ipv6_set(Eo *o, Efl_Net_Control_Acce
 }
 
 EOLIAN static void
-_efl_net_control_access_point_configuration_ipv6_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway)
+_efl_net_control_access_point_configuration_ipv6_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway)
 {
    if (method) *method = pd->configured.ipv6.method;
    if (address) *address = pd->configured.ipv6.address;
@@ -676,7 +676,6 @@ _efl_net_control_access_point_configuration_proxy_set(Eo *o, Efl_Net_Control_Acc
 
    switch (method)
      {
-      case EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_UNSET: goto error_send;
       case EFL_NET_CONTROL_ACCESS_POINT_PROXY_METHOD_OFF:
          _append_dict_entry(array, "Method", "s", "direct");
          break;
@@ -692,6 +691,8 @@ _efl_net_control_access_point_configuration_proxy_set(Eo *o, Efl_Net_Control_Acc
          if (excludes)
            _append_dict_entry_string_array(array, "Excludes", excludes);
          break;
+      default:
+         break;
      }
 
    eldbus_message_iter_container_close(var, array);
@@ -713,7 +714,7 @@ _efl_net_control_access_point_configuration_proxy_set(Eo *o, Efl_Net_Control_Acc
 }
 
 EOLIAN static void
-_efl_net_control_access_point_configuration_proxy_get(Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes)
+_efl_net_control_access_point_configuration_proxy_get(const Eo *o EINA_UNUSED, Efl_Net_Control_Access_Point_Data *pd, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers, Eina_Iterator **excludes)
 {
    if (method) *method = pd->configured.proxy.method;
    if (url) *url = pd->configured.proxy.url;
@@ -724,15 +725,14 @@ _efl_net_control_access_point_configuration_proxy_get(Eo *o EINA_UNUSED, Efl_Net
 static void
 _efl_net_control_access_point_connect_cb(void *data, const Eldbus_Message *msg, Eldbus_Pending *pending)
 {
-   Efl_Promise *promise = data;
-   Eo *o = efl_parent_get(promise);
+   Eina_Promise *promise = data;
+   Efl_Object *o = eina_promise_data_get(promise);
    Efl_Net_Control_Access_Point_Data *pd = efl_data_scope_get(o, MY_CLASS);
    const char *err_name, *err_msg;
 
    EINA_SAFETY_ON_NULL_RETURN(pd);
 
    pd->pending = eina_list_remove(pd->pending, pending);
-   efl_key_data_set(promise, "eldbus_pending", NULL);
    if (eldbus_message_error_get(msg, &err_name, &err_msg))
      {
         Eina_Error err = EINVAL;
@@ -742,53 +742,55 @@ _efl_net_control_access_point_connect_cb(void *data, const Eldbus_Message *msg,
         else if (strcmp(err_name, "net.connman.Error.AlreadyConnected") == 0)
           err = EALREADY;
         WRN("Could not Connect %p: %s=%s", o, err_name, err_msg);
-        efl_promise_failed_set(promise, err);
+
+        eina_promise_reject(promise, err);
         return;
      }
 
-   efl_promise_value_set(promise, o, NULL);
-   efl_del(promise);
+   eina_promise_resolve(promise, EINA_VALUE_EMPTY);
 }
 
 static void
-_efl_net_control_access_point_connect_promise_del(void *data, const Efl_Event *event)
+_efl_net_control_access_point_connect_promise_del(void *data, const Eina_Promise *dead_ptr)
 {
-   Eldbus_Pending *p;
-   Eo *o = data;
-   Efl_Net_Control_Access_Point_Data *pd = efl_data_scope_get(o, MY_CLASS);
+   Eldbus_Pending *p = data;
+   Efl_Net_Control_Access_Point_Data *pd;
 
-   EINA_SAFETY_ON_NULL_RETURN(pd);
-
-   p = efl_key_data_get(event->object, "eldbus_pending");
+   p = eina_promise_data_get(dead_ptr);
    if (!p) return; /* already gone, nothing to do */
 
+   pd = eldbus_pending_data_get(p, ".object");
+
    pd->pending = eina_list_remove(pd->pending, p);
    DBG("cancel pending connect %p", p);
    eldbus_pending_cancel(p);
 }
 
-EOLIAN static Efl_Future *
+EOLIAN static Eina_Future *
 _efl_net_control_access_point_connect(Eo *o, Efl_Net_Control_Access_Point_Data *pd)
 {
    Eldbus_Pending *p;
-   Efl_Promise *promise;
+   Eina_Promise *promise;
+   Eina_Future *f = NULL;
 
-   promise = efl_add(EFL_PROMISE_CLASS, o,
-                     efl_event_callback_add(efl_added, EFL_EVENT_DEL, _efl_net_control_access_point_connect_promise_del, o));
+   promise = eina_promise_new(efl_loop_future_scheduler_get(o),
+                              _efl_net_control_access_point_connect_promise_del, o);
    EINA_SAFETY_ON_NULL_RETURN_VAL(promise, NULL);
 
+   f = eina_future_new(promise);
+
    p = eldbus_proxy_call(pd->proxy, "Connect",
                          _efl_net_control_access_point_connect_cb, promise, -1.0, "");
    EINA_SAFETY_ON_NULL_GOTO(p, error_dbus);
 
    pd->pending = eina_list_append(pd->pending, p);
-   efl_key_data_set(promise, "eldbus_pending", p);
+   eldbus_pending_data_set(p, ".object", pd);
 
-   return efl_promise_future_get(promise);
+   return efl_future_Eina_FutureXXX_then(o, f);
 
  error_dbus:
-   efl_promise_failed_set(promise, ENOSYS);
-   return promise;
+   eina_promise_reject(promise, ENOSYS);
+   return efl_future_Eina_FutureXXX_then(o, f);
 }
 
 static void
@@ -1238,7 +1240,7 @@ _efl_net_control_access_point_property_actual_ipv6_changed(Eo *o EINA_UNUSED, Ef
                pd->actual.ipv6.method = EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_NONE;
              else if (strcmp(str, "enabled") == 0)
                pd->actual.ipv6.method = EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_PUBLIC;
-             else if (strcmp(str, "prefered") == 0)
+             else if (strcmp(str, "preferred") == 0)
                pd->actual.ipv6.method = EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_TEMPORARY;
              else
                WRN("Unexpected IPV6 Privacy value '%s'", str);
@@ -1460,7 +1462,7 @@ _efl_net_control_access_point_property_configured_ipv6_changed(Eo *o EINA_UNUSED
                pd->configured.ipv6.method = EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_NONE;
              else if (strcmp(str, "enabled") == 0)
                pd->configured.ipv6.method = EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_PUBLIC;
-             else if (strcmp(str, "prefered") == 0)
+             else if (strcmp(str, "preferred") == 0)
                pd->configured.ipv6.method = EFL_NET_CONTROL_ACCESS_POINT_IPV6_METHOD_AUTO_PRIVACY_TEMPORARY;
              else
                WRN("Unexpected IPV6 Privacy value '%s'", str);
@@ -1616,7 +1618,7 @@ _efl_net_control_access_point_property_changed(void *data, const Eldbus_Message
 }
 
 Efl_Net_Control_Access_Point *
-efl_net_connman_access_point_new(Efl_Net_Control *ctl, const char *path, Eldbus_Message_Iter *properties, unsigned int priority)
+efl_net_connman_access_point_new(Efl_Net_Control_Manager *ctl, const char *path, Eldbus_Message_Iter *properties, unsigned int priority)
 {
    Eo *o;
    Efl_Net_Control_Access_Point_Data *pd;
@@ -1674,7 +1676,7 @@ efl_net_connman_access_point_path_get(Efl_Net_Control_Access_Point *o)
 }
 
 void
-efl_net_connman_access_point_update(Efl_Net_Control *o, Eldbus_Message_Iter *properties, unsigned int priority)
+efl_net_connman_access_point_update(Efl_Net_Control_Manager *o, Eldbus_Message_Iter *properties, unsigned int priority)
 {
    Eldbus_Message_Iter *entry;
    Efl_Net_Control_Access_Point_Data *pd = efl_data_scope_get(o, MY_CLASS);
