@@ -207,7 +207,7 @@ typedef struct
       Eina_Bool verify_peer;
       Eina_Bool verify_hostname;
    } ssl;
-   Efl_Future *pending_close;
+   Eina_Future *pending_close;
    unsigned int in_curl_callback;
    SOCKET fd;
    Eina_Error error;
@@ -218,7 +218,7 @@ typedef struct
    Eina_Bool connected;
    Eina_Bool closed;
    Eina_Bool close_on_exec;
-   Eina_Bool close_on_destructor;
+   Eina_Bool close_on_invalidate;
    Eina_Bool pending_eos;
    Eina_Bool eos;
    Eina_Bool can_read;
@@ -325,7 +325,8 @@ _efl_net_dialer_http_curlm_check(Efl_Net_Dialer_Http_Curlm *cm)
              if (!efl_io_closer_closed_get(dialer))
                {
                   efl_io_reader_eos_set(dialer, EINA_TRUE);
-                  efl_io_closer_close(dialer);
+                  if (!efl_io_closer_closed_get(dialer))
+                    efl_io_closer_close(dialer);
                }
           }
 
@@ -796,30 +797,31 @@ _efl_net_dialer_http_curl_safe_begin(Eo *o, Efl_Net_Dialer_Http_Data *pd)
    return pd->easy;
 }
 
-static void
-_efl_net_dialer_http_curl_cleanup(void *data, const Efl_Event *ev EINA_UNUSED)
+static Eina_Value
+_efl_net_dialer_http_curl_cleanup(void *data, const Eina_Value v)
 {
    CURL *easy = data;
    DBG("cleanup curl=%p", easy);
    curl_easy_cleanup(easy);
+   return v;
 }
 
-static void
-_efl_net_dialer_http_curl_cleanup_error(void *data, const Efl_Event *ev)
+static Eina_Value
+_efl_net_dialer_http_curl_cleanup_error(void *data, const Eina_Error err)
 {
-   Efl_Future_Event_Failure *failure = ev->info;
    CURL *easy = data;
-   DBG("cleanup curl=%p, promise error=%d '%s'", easy, failure->error, eina_error_msg_get(failure->error));
+   DBG("cleanup curl=%p, promise error=%d '%s'", easy, err, eina_error_msg_get(err));
    curl_easy_cleanup(easy);
+   return EINA_VALUE_EMPTY;
 }
 
 static void
 _efl_net_dialer_http_curl_safe_end(Eo *o, Efl_Net_Dialer_Http_Data *pd, CURL *easy)
 {
-   Efl_Future *f;
+   Eina_Future *f;
    int refs;
 
-   refs = efl_ref_get(o);
+   refs = efl_ref_count(o);
    if (refs >= 2)
      {
         pd->in_curl_callback--;
@@ -828,7 +830,7 @@ _efl_net_dialer_http_curl_safe_end(Eo *o, Efl_Net_Dialer_Http_Data *pd, CURL *ea
      }
 
    if (pd->pending_close)
-     efl_future_cancel(pd->pending_close);
+     eina_future_cancel(pd->pending_close);
 
    if (!pd->easy)
      {
@@ -861,12 +863,10 @@ _efl_net_dialer_http_curl_safe_end(Eo *o, Efl_Net_Dialer_Http_Data *pd, CURL *ea
    /* object deleted from CURL callback, CURL* easy was
     * dissociated and we must delete it ourselves.
     */
-   f = efl_loop_job(ecore_main_loop_get(), easy);
-   efl_future_then(f,
-                   _efl_net_dialer_http_curl_cleanup,
-                   _efl_net_dialer_http_curl_cleanup_error,
-                   NULL,
-                   easy);
+   f = efl_loop_job(efl_loop_get(o));
+   eina_future_then_from_desc(f, eina_future_cb_easy(.success = _efl_net_dialer_http_curl_cleanup,
+                                                     .error = _efl_net_dialer_http_curl_cleanup_error,
+                                                     .data = easy));
    DBG("dialer=%p deleted from CURL callback, cleanup curl from job=%p.", o, f);
 }
 
@@ -1129,7 +1129,7 @@ _efl_net_dialer_http_efl_object_constructor(Eo *o, Efl_Net_Dialer_Http_Data *pd)
 }
 
 EOLIAN static void
-_efl_net_dialer_http_efl_object_destructor(Eo *o, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_object_invalidate(Eo *o, Efl_Net_Dialer_Http_Data *pd)
 {
    if (pd->libproxy_thread)
      {
@@ -1144,12 +1144,12 @@ _efl_net_dialer_http_efl_object_destructor(Eo *o, Efl_Net_Dialer_Http_Data *pd)
      }
    else if (pd->pending_close)
      {
-        efl_future_cancel(pd->pending_close);
+        eina_future_cancel(pd->pending_close);
         efl_event_freeze(o);
         efl_io_closer_close(o);
         efl_event_thaw(o);
      }
-   else if (efl_io_closer_close_on_destructor_get(o) &&
+   else if (efl_io_closer_close_on_invalidate_get(o) &&
             (!efl_io_closer_closed_get(o)))
      {
         efl_event_freeze(o);
@@ -1157,6 +1157,12 @@ _efl_net_dialer_http_efl_object_destructor(Eo *o, Efl_Net_Dialer_Http_Data *pd)
         efl_event_thaw(o);
      }
 
+   efl_invalidate(efl_super(o, MY_CLASS));
+}
+
+EOLIAN static void
+_efl_net_dialer_http_efl_object_destructor(Eo *o, Efl_Net_Dialer_Http_Data *pd)
+{
    efl_net_dialer_http_response_headers_clear(o);
 
    if (pd->easy)
@@ -1202,7 +1208,7 @@ _efl_net_dialer_http_curl_start(Eo *o, Efl_Net_Dialer_Http_Data *pd)
    // TODO: move this to be per-loop once multiple mainloops are supported
    // this would need to attach something to the loop
    cm = &_cm_global;
-   if (!cm->loop) cm->loop = efl_loop_get(o);
+   cm->loop = efl_loop_get(o);
    if (!_efl_net_dialer_http_curlm_add(cm, o, pd->easy))
      {
         ERR("dialer=%p could not add curl easy handle to multi manager", o);
@@ -1220,10 +1226,10 @@ typedef struct _Efl_Net_Dialer_Http_Libproxy_Context {
 } Efl_Net_Dialer_Http_Libproxy_Context;
 
 static void
-_efl_net_dialer_http_libproxy_run(void *data, Ecore_Thread *thread EINA_UNUSED)
+_efl_net_dialer_http_libproxy_run(void *data, Ecore_Thread *thread)
 {
    Efl_Net_Dialer_Http_Libproxy_Context *ctx = data;
-   char **proxies = ecore_con_libproxy_proxies_get(ctx->url);
+   char **proxies = ecore_con_libproxy_proxies_get(ctx->url, thread);
    char **itr;
 
    if (!proxies) return;
@@ -1442,7 +1448,7 @@ _efl_net_dialer_http_efl_net_dialer_address_dial_set(Eo *o, Efl_Net_Dialer_Http_
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_efl_net_dialer_address_dial_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_net_dialer_address_dial_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->address_dial;
 }
@@ -1458,7 +1464,7 @@ _efl_net_dialer_http_efl_net_dialer_connected_set(Eo *o, Efl_Net_Dialer_Http_Dat
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_efl_net_dialer_connected_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_net_dialer_connected_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->connected;
 }
@@ -1477,7 +1483,7 @@ _efl_net_dialer_http_efl_net_dialer_proxy_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_efl_net_dialer_proxy_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_net_dialer_proxy_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->proxy;
 }
@@ -1497,7 +1503,7 @@ _efl_net_dialer_http_efl_net_dialer_timeout_dial_set(Eo *o, Efl_Net_Dialer_Http_
 }
 
 EOLIAN static double
-_efl_net_dialer_http_efl_net_dialer_timeout_dial_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_net_dialer_timeout_dial_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->timeout_dial;
 }
@@ -1509,7 +1515,7 @@ _efl_net_dialer_http_efl_net_socket_address_local_set(Eo *o EINA_UNUSED, Efl_Net
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_efl_net_socket_address_local_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_net_socket_address_local_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->address_local;
 }
@@ -1522,7 +1528,7 @@ _efl_net_dialer_http_efl_net_socket_address_remote_set(Eo *o, Efl_Net_Dialer_Htt
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_efl_net_socket_address_remote_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_net_socket_address_remote_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->address_remote;
 }
@@ -1534,6 +1540,8 @@ _efl_net_dialer_http_pause_reset(Eo *o, Efl_Net_Dialer_Http_Data *pd)
    CURLMcode rm;
    Eina_Error err;
 
+   EINA_SAFETY_ON_TRUE_RETURN_VAL(pd->cm == NULL, EALREADY);
+
    re = curl_easy_pause(pd->easy, pd->pause);
    if (re != CURLE_OK)
      {
@@ -1607,7 +1615,7 @@ _efl_net_dialer_http_efl_io_reader_read(Eo *o, Efl_Net_Dialer_Http_Data *pd, Ein
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_efl_io_reader_can_read_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_io_reader_can_read_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->can_read;
 }
@@ -1622,7 +1630,7 @@ _efl_net_dialer_http_efl_io_reader_can_read_set(Eo *o, Efl_Net_Dialer_Http_Data
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_efl_io_reader_eos_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_io_reader_eos_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->eos;
 }
@@ -1655,6 +1663,11 @@ _efl_net_dialer_http_efl_io_writer_write(Eo *o, Efl_Net_Dialer_Http_Data *pd, Ei
    err = _efl_net_dialer_http_pause_reset(o, pd);
    if (err) goto error;
 
+   if (!pd->cm)
+     {
+        err = EISCONN;
+        goto error;
+     }
    pd->error = 0;
    rm = curl_multi_socket_action(pd->cm->multi,
                                  pd->fd,
@@ -1690,7 +1703,7 @@ _efl_net_dialer_http_efl_io_writer_write(Eo *o, Efl_Net_Dialer_Http_Data *pd, Ei
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_efl_io_writer_can_write_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_io_writer_can_write_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->can_write;
 }
@@ -1704,7 +1717,7 @@ _efl_net_dialer_http_efl_io_writer_can_write_set(Eo *o, Efl_Net_Dialer_Http_Data
    efl_event_callback_call(o, EFL_IO_WRITER_EVENT_CAN_WRITE_CHANGED, NULL);
 }
 
-static void _efl_net_dialer_http_pending_close(void *data, const Efl_Event *ev);
+static Eina_Value _efl_net_dialer_http_pending_close(Eo *o, Eina_Value value);
 
 EOLIAN static Eina_Error
 _efl_net_dialer_http_efl_io_closer_close(Eo *o, Efl_Net_Dialer_Http_Data *pd)
@@ -1719,8 +1732,9 @@ _efl_net_dialer_http_efl_io_closer_close(Eo *o, Efl_Net_Dialer_Http_Data *pd)
      {
         if ((!pd->pending_close) && (pd->easy))
           {
-             efl_future_use(&pd->pending_close, efl_loop_job(efl_loop_get(o), o));
-             efl_future_then(pd->pending_close, _efl_net_dialer_http_pending_close, NULL, NULL, o);
+             efl_future_Eina_FutureXXX_then(o, efl_loop_job(efl_loop_get(o)),
+                                            .success = _efl_net_dialer_http_pending_close,
+                                            .storage = &pd->pending_close);
              DBG("dialer=%p closed from CURL callback, schedule close job=%p", o, pd->pending_close);
           }
         return 0;
@@ -1751,18 +1765,17 @@ _efl_net_dialer_http_efl_io_closer_close(Eo *o, Efl_Net_Dialer_Http_Data *pd)
    return err;
 }
 
-static void
-_efl_net_dialer_http_pending_close(void *data, const Efl_Event *ev EINA_UNUSED)
+static Eina_Value
+_efl_net_dialer_http_pending_close(Eo *o, const Eina_Value value EINA_UNUSED)
 {
-   Eo *o = data;
    Efl_Net_Dialer_Http_Data *pd = efl_data_scope_get(o, MY_CLASS);
 
-   pd->pending_close = NULL; /* XXX TODO this should be NULL-ified by efl_promise before calling this function */
    _efl_net_dialer_http_efl_io_closer_close(o, pd);
+   return value;
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_efl_io_closer_closed_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_io_closer_closed_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->closed || (!!pd->pending_close);
 }
@@ -1793,21 +1806,21 @@ _efl_net_dialer_http_efl_io_closer_close_on_exec_set(Eo *o EINA_UNUSED, Efl_Net_
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_efl_io_closer_close_on_exec_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_io_closer_close_on_exec_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->close_on_exec;
 }
 
 EOLIAN static void
-_efl_net_dialer_http_efl_io_closer_close_on_destructor_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, Eina_Bool close_on_destructor)
+_efl_net_dialer_http_efl_io_closer_close_on_invalidate_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, Eina_Bool close_on_invalidate)
 {
-   pd->close_on_destructor = close_on_destructor;
+   pd->close_on_invalidate = close_on_invalidate;
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_efl_io_closer_close_on_destructor_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_io_closer_close_on_invalidate_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
-   return pd->close_on_destructor;
+   return pd->close_on_invalidate;
 }
 
 EOLIAN static Eina_Error
@@ -1832,7 +1845,7 @@ _efl_net_dialer_http_efl_io_sizer_resize(Eo *o, Efl_Net_Dialer_Http_Data *pd, ui
 }
 
 EOLIAN static uint64_t
-_efl_net_dialer_http_efl_io_sizer_size_get(Eo *o, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_efl_io_sizer_size_get(const Eo *o, Efl_Net_Dialer_Http_Data *pd)
 {
    Efl_Net_Dialer_Http_Primary_Mode pm;
    int64_t len;
@@ -1913,7 +1926,7 @@ _efl_net_dialer_http_method_set(Eo *o, Efl_Net_Dialer_Http_Data *pd, const char
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_method_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_method_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->method;
 }
@@ -1926,7 +1939,7 @@ _efl_net_dialer_http_primary_mode_set(Eo *o, Efl_Net_Dialer_Http_Data *pd, Efl_N
 }
 
 EOLIAN static Efl_Net_Dialer_Http_Primary_Mode
-_efl_net_dialer_http_primary_mode_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_primary_mode_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return _efl_net_dialer_http_primary_mode_effective_get(pd);
 }
@@ -1945,7 +1958,7 @@ _efl_net_dialer_http_user_agent_set(Eo *o, Efl_Net_Dialer_Http_Data *pd, const c
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_user_agent_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_user_agent_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->user_agent;
 }
@@ -1964,7 +1977,7 @@ _efl_net_dialer_http_http_version_set(Eo *o, Efl_Net_Dialer_Http_Data *pd, Efl_N
 }
 
 EOLIAN static Efl_Net_Http_Version
-_efl_net_dialer_http_http_version_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_http_version_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->version;
 }
@@ -2002,7 +2015,7 @@ _efl_net_dialer_http_authentication_set(Eo *o, Efl_Net_Dialer_Http_Data *pd, con
 }
 
 EOLIAN static void
-_efl_net_dialer_http_authentication_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, const char **username, const char **password, Efl_Net_Http_Authentication_Method *method, Eina_Bool *restricted)
+_efl_net_dialer_http_authentication_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, const char **username, const char **password, Efl_Net_Http_Authentication_Method *method, Eina_Bool *restricted)
 {
    if (username) *username = pd->authentication.username;
    if (password) *password = pd->authentication.password;
@@ -2024,13 +2037,13 @@ _efl_net_dialer_http_allow_redirects_set(Eo *o, Efl_Net_Dialer_Http_Data *pd, Ei
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_http_allow_redirects_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_allow_redirects_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->allow_redirects;
 }
 
 EOLIAN static Efl_Net_Http_Status
-_efl_net_dialer_http_response_status_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_response_status_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->response.status;
 }
@@ -2160,7 +2173,7 @@ _efl_net_dialer_http_request_content_length_set(Eo *o, Efl_Net_Dialer_Http_Data
 }
 
 EOLIAN static int64_t
-_efl_net_dialer_http_request_content_length_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_request_content_length_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->request.content_length;
 }
@@ -2180,7 +2193,7 @@ _efl_net_dialer_http_response_content_length_set(Eo *o, Efl_Net_Dialer_Http_Data
 }
 
 EOLIAN static int64_t
-_efl_net_dialer_http_response_content_length_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_response_content_length_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->response.content_length;
 }
@@ -2192,7 +2205,7 @@ _efl_net_dialer_http_response_content_type_set(Eo *o EINA_UNUSED, Efl_Net_Dialer
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_response_content_type_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_response_content_type_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->response.content_type;
 }
@@ -2226,14 +2239,14 @@ _efl_net_dialer_http_response_headers_clear(Eo *o EINA_UNUSED, Efl_Net_Dialer_Ht
 }
 
 EOLIAN static void
-_efl_net_dialer_http_progress_download_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, uint64_t *now, uint64_t *total)
+_efl_net_dialer_http_progress_download_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, uint64_t *now, uint64_t *total)
 {
    if (now) *now = pd->progress.download.now;
    if (total) *total = pd->progress.download.total;
 }
 
 EOLIAN static void
-_efl_net_dialer_http_progress_upload_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, uint64_t *now, uint64_t *total)
+_efl_net_dialer_http_progress_upload_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, uint64_t *now, uint64_t *total)
 {
    if (now) *now = pd->progress.upload.now;
    if (total) *total = pd->progress.upload.total;
@@ -2284,7 +2297,7 @@ _efl_net_dialer_http_cookie_jar_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_cookie_jar_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_cookie_jar_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->cookie_jar;
 }
@@ -2312,7 +2325,7 @@ _efl_net_dialer_http_ssl_verify_set(Eo *o, Efl_Net_Dialer_Http_Data *pd, Eina_Bo
 }
 
 EOLIAN static void
-_efl_net_dialer_http_ssl_verify_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, Eina_Bool *peer, Eina_Bool *hostname)
+_efl_net_dialer_http_ssl_verify_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd, Eina_Bool *peer, Eina_Bool *hostname)
 {
    if (peer) *peer = pd->ssl.verify_peer;
    if (hostname) *hostname = pd->ssl.verify_hostname;
@@ -2337,7 +2350,7 @@ _efl_net_dialer_http_ssl_certificate_authority_set(Eo *o EINA_UNUSED, Efl_Net_Di
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_ssl_certificate_authority_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_ssl_certificate_authority_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->ssl.ca;
 }
@@ -2356,7 +2369,7 @@ _efl_net_dialer_http_ssl_certificate_revocation_list_set(Eo *o EINA_UNUSED, Efl_
 }
 
 EOLIAN static const char *
-_efl_net_dialer_http_ssl_certificate_revocation_list_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
+_efl_net_dialer_http_ssl_certificate_revocation_list_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Http_Data *pd)
 {
    return pd->ssl.crl;
 }
