@@ -159,8 +159,8 @@ typedef struct _Efl_Net_Dialer_Websocket_Pending_Read {
 
 typedef struct _Efl_Net_Dialer_Websocket_Data {
    Eo *http;
-   Efl_Future *close_timeout;
-   Efl_Future *job;
+   Eina_Future *close_timeout;
+   Eina_Future *job;
    Eina_Stringshare *address_dial; /* must rewrite ws->http, wss->https */
    Eina_Stringshare *address_remote; /* must rewrite ws->http, wss->https */
    struct {
@@ -544,7 +544,7 @@ _efl_net_dialer_websocket_job_dispatch_frame(Eo *o, Efl_Net_Dialer_Websocket_Dat
            else
              efl_event_callback_call(o, EFL_IO_CLOSER_EVENT_CLOSED, NULL);
            if (pd->close_timeout)
-             efl_future_cancel(pd->close_timeout);
+             eina_future_cancel(pd->close_timeout);
            break;
         }
 
@@ -734,10 +734,9 @@ _efl_net_dialer_websocket_job_receive(Eo *o, Efl_Net_Dialer_Websocket_Data *pd)
    efl_unref(o);
 }
 
-static void
-_efl_net_dialer_websocket_job(void *data, const Efl_Event *ev EINA_UNUSED)
+static Eina_Value
+_efl_net_dialer_websocket_job(Eo *o, const Eina_Value v)
 {
-   Eo *o = data;
    Efl_Net_Dialer_Websocket_Data *pd = efl_data_scope_get(o, MY_CLASS);
 
    efl_ref(o);
@@ -752,6 +751,7 @@ _efl_net_dialer_websocket_job(void *data, const Efl_Event *ev EINA_UNUSED)
      _efl_net_dialer_websocket_job_schedule(o, pd);
 
    efl_unref(o);
+   return v;
 }
 
 static void
@@ -763,9 +763,10 @@ _efl_net_dialer_websocket_job_schedule(Eo *o, Efl_Net_Dialer_Websocket_Data *pd)
 
    loop = efl_loop_get(o);
    if (!loop) return;
-   efl_future_use(&pd->job, efl_loop_job(loop, o));
-   efl_future_then(pd->job, _efl_net_dialer_websocket_job, NULL, NULL, o);
-   efl_future_link(o, pd->job);
+
+   efl_future_Eina_FutureXXX_then(o, efl_loop_job(loop),
+                                  .success = _efl_net_dialer_websocket_job,
+                                  .storage = &pd->job);
 }
 
 static void
@@ -954,6 +955,14 @@ _efl_net_dialer_websocket_efl_object_constructor(Eo *o, Efl_Net_Dialer_Websocket
    return o;
 }
 
+EOLIAN static void
+_efl_net_dialer_websocket_efl_object_invalidate(Eo *o, Efl_Net_Dialer_Websocket_Data *pd)
+{
+   pd->http = NULL;
+
+   efl_invalidate(efl_super(o, MY_CLASS));
+}
+
 EOLIAN static void
 _efl_net_dialer_websocket_efl_object_destructor(Eo *o, Efl_Net_Dialer_Websocket_Data *pd)
 {
@@ -961,9 +970,6 @@ _efl_net_dialer_websocket_efl_object_destructor(Eo *o, Efl_Net_Dialer_Websocket_
 
    efl_event_callback_array_del(pd->http, _efl_net_dialer_websocket_http_cbs(), o);
 
-   efl_del(pd->http);
-   pd->http = NULL;
-
    efl_destructor(efl_super(o, MY_CLASS));
 
    eina_stringshare_replace(&pd->address_dial, NULL);
@@ -1165,7 +1171,7 @@ _efl_net_dialer_websocket_efl_net_dialer_address_dial_set(Eo *o EINA_UNUSED, Efl
 }
 
 EOLIAN static const char *
-_efl_net_dialer_websocket_efl_net_dialer_address_dial_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_net_dialer_address_dial_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return pd->address_dial;
 }
@@ -1180,7 +1186,7 @@ _efl_net_dialer_websocket_efl_net_dialer_connected_set(Eo *o, Efl_Net_Dialer_Web
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_efl_net_dialer_connected_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_net_dialer_connected_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return pd->connected;
 }
@@ -1192,7 +1198,7 @@ _efl_net_dialer_websocket_efl_net_dialer_proxy_set(Eo *o EINA_UNUSED, Efl_Net_Di
 }
 
 EOLIAN static const char *
-_efl_net_dialer_websocket_efl_net_dialer_proxy_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_net_dialer_proxy_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return efl_net_dialer_proxy_get(pd->http);
 }
@@ -1204,13 +1210,13 @@ _efl_net_dialer_websocket_efl_net_dialer_timeout_dial_set(Eo *o EINA_UNUSED, Efl
 }
 
 EOLIAN static double
-_efl_net_dialer_websocket_efl_net_dialer_timeout_dial_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_net_dialer_timeout_dial_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return efl_net_dialer_timeout_dial_get(pd->http);
 }
 
 EOLIAN static const char *
-_efl_net_dialer_websocket_efl_net_socket_address_local_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_net_socket_address_local_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return efl_net_socket_address_local_get(pd->http);
 }
@@ -1223,7 +1229,7 @@ _efl_net_dialer_websocket_efl_net_socket_address_remote_set(Eo *o EINA_UNUSED, E
 }
 
 EOLIAN static const char *
-_efl_net_dialer_websocket_efl_net_socket_address_remote_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_net_socket_address_remote_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return pd->address_remote;
 }
@@ -1280,7 +1286,7 @@ _efl_net_dialer_websocket_efl_io_reader_read(Eo *o, Efl_Net_Dialer_Websocket_Dat
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_efl_io_reader_can_read_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_io_reader_can_read_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return pd->can_read;
 }
@@ -1295,7 +1301,7 @@ _efl_net_dialer_websocket_efl_io_reader_can_read_set(Eo *o, Efl_Net_Dialer_Webso
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_efl_io_reader_eos_get(Eo *o, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_io_reader_eos_get(const Eo *o, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return !pd->can_read && efl_io_closer_closed_get(o);
 }
@@ -1325,7 +1331,7 @@ _efl_net_dialer_websocket_efl_io_writer_write(Eo *o, Efl_Net_Dialer_Websocket_Da
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_efl_io_writer_can_write_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_io_writer_can_write_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return pd->can_write;
 }
@@ -1350,7 +1356,7 @@ _efl_net_dialer_websocket_efl_io_closer_close(Eo *o, Efl_Net_Dialer_Websocket_Da
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_efl_io_closer_closed_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_io_closer_closed_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return pd->close_requested || efl_io_closer_closed_get(pd->http);
 }
@@ -1362,21 +1368,21 @@ _efl_net_dialer_websocket_efl_io_closer_close_on_exec_set(Eo *o EINA_UNUSED, Efl
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_efl_io_closer_close_on_exec_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_io_closer_close_on_exec_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return efl_io_closer_close_on_exec_get(pd->http);
 }
 
 EOLIAN static void
-_efl_net_dialer_websocket_efl_io_closer_close_on_destructor_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd, Eina_Bool close_on_destructor)
+_efl_net_dialer_websocket_efl_io_closer_close_on_invalidate_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd, Eina_Bool close_on_invalidate)
 {
-   efl_io_closer_close_on_destructor_set(pd->http, close_on_destructor);
+   efl_io_closer_close_on_invalidate_set(pd->http, close_on_invalidate);
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_efl_io_closer_close_on_destructor_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_efl_io_closer_close_on_invalidate_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
-   return efl_io_closer_close_on_destructor_get(pd->http);
+   return efl_io_closer_close_on_invalidate_get(pd->http);
 }
 
 EOLIAN static void
@@ -1392,7 +1398,7 @@ _efl_net_dialer_websocket_streaming_mode_set(Eo *o, Efl_Net_Dialer_Websocket_Dat
 }
 
 EOLIAN static Efl_Net_Dialer_Websocket_Streaming_Mode
-_efl_net_dialer_websocket_streaming_mode_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_streaming_mode_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return pd->streaming_mode;
 }
@@ -1404,7 +1410,7 @@ _efl_net_dialer_websocket_user_agent_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_Webso
 }
 
 EOLIAN static const char *
-_efl_net_dialer_websocket_user_agent_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_user_agent_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return efl_net_dialer_http_user_agent_get(pd->http);
 }
@@ -1416,7 +1422,7 @@ _efl_net_dialer_websocket_authentication_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_W
 }
 
 EOLIAN static void
-_efl_net_dialer_websocket_authentication_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd, const char **username, const char **password, Efl_Net_Http_Authentication_Method *method, Eina_Bool *restricted)
+_efl_net_dialer_websocket_authentication_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd, const char **username, const char **password, Efl_Net_Http_Authentication_Method *method, Eina_Bool *restricted)
 {
    efl_net_dialer_http_authentication_get(pd->http, username, password, method, restricted);
 }
@@ -1428,7 +1434,7 @@ _efl_net_dialer_websocket_allow_redirects_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_
 }
 
 EOLIAN static Eina_Bool
-_efl_net_dialer_websocket_allow_redirects_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_allow_redirects_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return efl_net_dialer_http_allow_redirects_get(pd->http);
 }
@@ -1440,7 +1446,7 @@ _efl_net_dialer_websocket_cookie_jar_set(Eo *o EINA_UNUSED, Efl_Net_Dialer_Webso
 }
 
 EOLIAN static const char *
-_efl_net_dialer_websocket_cookie_jar_get(Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
+_efl_net_dialer_websocket_cookie_jar_get(const Eo *o EINA_UNUSED, Efl_Net_Dialer_Websocket_Data *pd)
 {
    return efl_net_dialer_http_cookie_jar_get(pd->http);
 }
@@ -1479,13 +1485,12 @@ _efl_net_dialer_websocket_binary_send(Eo *o, Efl_Net_Dialer_Websocket_Data *pd,
                                   blob.mem, blob.len);
 }
 
-static void
-_efl_net_dialer_websocket_close_request_timeout(void *data, const Efl_Event *ev EINA_UNUSED)
+static Eina_Value
+_efl_net_dialer_websocket_close_request_timeout(Eo *o, const Eina_Value v)
 {
-   Eo *o = data;
-
    DBG("server did not close the TCP socket, timeout");
    efl_event_callback_call(o, EFL_IO_CLOSER_EVENT_CLOSED, NULL);
+   return v;
 }
 
 EOLIAN static void
@@ -1497,11 +1502,11 @@ _efl_net_dialer_websocket_close_request(Eo *o, Efl_Net_Dialer_Websocket_Data *pd
    EINA_SAFETY_ON_TRUE_RETURN(pd->close_requested);
 
    if (pd->close_timeout)
-     efl_future_cancel(pd->close_timeout);
+     eina_future_cancel(pd->close_timeout);
 
-   efl_future_use(&pd->close_timeout, efl_loop_timeout(efl_loop_get(o), 2.0, o));
-   efl_future_then(pd->close_timeout, _efl_net_dialer_websocket_close_request_timeout, NULL, NULL, o);
-   efl_future_link(o, pd->close_timeout);
+   efl_future_Eina_FutureXXX_then(o, efl_loop_timeout(efl_loop_get(o), 2.0),
+                                  .success = _efl_net_dialer_websocket_close_request_timeout,
+                                  .storage = &pd->close_timeout);
 
    efl_io_writer_can_write_set(o, EINA_FALSE);
 
