@@ -12,23 +12,15 @@
 #  undef EAPI
 # endif
 
-# ifdef _MSC_VER
-#  ifdef BUILDING_DLL
-#   define EAPI __declspec(dllexport)
-#  else // ifdef BUILDING_DLL
-#   define EAPI __declspec(dllimport)
-#  endif // ifdef BUILDING_DLL
-# else // ifdef _MSC_VER
-#  ifdef __GNUC__
-#   if __GNUC__ >= 4
-#    define EAPI __attribute__ ((visibility("default")))
-#   else // if __GNUC__ >= 4
-#    define EAPI
-#   endif // if __GNUC__ >= 4
-#  else // ifdef __GNUC__
+# ifdef __GNUC__
+#  if __GNUC__ >= 4
+#   define EAPI __attribute__ ((visibility("default")))
+#  else // if __GNUC__ >= 4
 #   define EAPI
-#  endif // ifdef __GNUC__
-# endif // ifdef _MSC_VER
+#  endif // if __GNUC__ >= 4
+# else // ifdef __GNUC__
+#  define EAPI
+# endif // ifdef __GNUC__
 
 # warning The Ecore_Drm library has been deprecated. Please use the Ecore_Drm2 library
 
