@@ -585,7 +585,6 @@ _device_handle_button(struct libinput_device *device, struct libinput_event_poin
      ecore_event_add(ECORE_EVENT_MOUSE_BUTTON_UP, ev, NULL, NULL);
 }
 
-#if LIBINPUT_HIGHER_08
 static double
 _event_scroll_get(struct libinput_event_pointer *pe, enum libinput_pointer_axis axis)
 {
@@ -599,7 +598,6 @@ _event_scroll_get(struct libinput_event_pointer *pe, enum libinput_pointer_axis
      }
    return 0.0;
 }
-#endif
 
 static void 
 _device_handle_axis(struct libinput_device *device, struct libinput_event_pointer *event)
@@ -631,7 +629,6 @@ _device_handle_axis(struct libinput_device *device, struct libinput_event_pointe
    ev->root.x = ev->x;
    ev->root.y = ev->y;
 
-#if LIBINPUT_HIGHER_08
    axis = LIBINPUT_POINTER_AXIS_SCROLL_VERTICAL;
    if (libinput_event_pointer_has_axis(event, axis))
      ev->z = _event_scroll_get(event, axis);
@@ -642,11 +639,6 @@ _device_handle_axis(struct libinput_device *device, struct libinput_event_pointe
         ev->direction = 1;
         ev->z = _event_scroll_get(event, axis);
      }
-#else
-   axis = libinput_event_pointer_get_axis(event);
-   if (axis == LIBINPUT_POINTER_AXIS_SCROLL_HORIZONTAL) ev->direction = 1;
-   ev->z = libinput_event_pointer_get_axis_value(event);
-#endif
 
    ecore_event_add(ECORE_EVENT_MOUSE_WHEEL, ev, NULL, NULL);
 }
