@@ -95,9 +95,8 @@ static const char *
 _drm2_device_find(Elput_Manager *em, const char *seat)
 {
    Eina_List *devs, *l;
-   const char *dev, *ret = NULL;
+   const char *dev, *ret = NULL, *chosen_dev = NULL;
    Eina_Bool found = EINA_FALSE;
-   Eina_Bool platform = EINA_FALSE;
    Eina_Bool modeset;
    int fd;
 
@@ -127,29 +126,19 @@ _drm2_device_find(Elput_Manager *em, const char *seat)
         if (!modeset)
           goto cont;
 
-        dparent = eeze_udev_syspath_get_parent_filtered(dev, "pci", NULL);
-        if (!dparent)
-          {
-             dparent =
-               eeze_udev_syspath_get_parent_filtered(dev, "platform", NULL);
-             platform = EINA_TRUE;
-          }
+        chosen_dev = dev;
 
+        dparent = eeze_udev_syspath_get_parent_filtered(dev, "pci", NULL);
         if (dparent)
           {
-             if (!platform)
-               {
-                  const char *id;
+             const char *id;
 
-                  id = eeze_udev_syspath_get_sysattr(dparent, "boot_vga");
-                  if (id)
-                    {
-                       if (!strcmp(id, "1")) found = EINA_TRUE;
-                       eina_stringshare_del(id);
-                    }
+             id = eeze_udev_syspath_get_sysattr(dparent, "boot_vga");
+             if (id)
+               {
+                  if (!strcmp(id, "1")) found = EINA_TRUE;
+                  eina_stringshare_del(id);
                }
-             else
-               found = EINA_TRUE;
 
              eina_stringshare_del(dparent);
           }
@@ -160,11 +149,9 @@ cont:
         if (found) break;
      }
 
-   if (!found) goto out;
+   if (chosen_dev)
+     ret = eeze_udev_syspath_get_devpath(chosen_dev);
 
-   ret = eeze_udev_syspath_get_devpath(dev);
-
-out:
    EINA_LIST_FREE(devs, dev)
      eina_stringshare_del(dev);
 
@@ -593,43 +580,29 @@ _drm2_atomic_state_free(Ecore_Drm2_Atomic_State *state)
 }
 
 EAPI Ecore_Drm2_Device *
-ecore_drm2_device_find(const char *seat, unsigned int tty)
+ecore_drm2_device_open(const char *seat, unsigned int tty)
 {
-   Ecore_Drm2_Device *dev;
+   Ecore_Drm2_Device *device;
 
-   dev = calloc(1, sizeof(Ecore_Drm2_Device));
-   if (!dev) return NULL;
+   device = calloc(1, sizeof(Ecore_Drm2_Device));
+   if (!device) return NULL;
 
-   dev->em = elput_manager_connect(seat, tty);
-   if (!dev->em)
+   device->em = elput_manager_connect(seat, tty);
+   if (!device->em)
      {
         ERR("Could not connect to input manager");
         goto man_err;
      }
 
-   dev->path = _drm2_device_find(dev->em, seat);
-   if (!dev->path)
+   device->path = _drm2_device_find(device->em, seat);
+   if (!device->path)
      {
         ERR("Could not find drm device on seat %s", seat);
         goto path_err;
      }
 
-   return dev;
-
-path_err:
-   elput_manager_disconnect(dev->em);
-man_err:
-   free(dev);
-   return NULL;
-}
-
-EAPI int
-ecore_drm2_device_open(Ecore_Drm2_Device *device)
-{
-   EINA_SAFETY_ON_NULL_RETURN_VAL(device, -1);
-
    device->fd = elput_manager_open(device->em, device->path, -1);
-   if (device->fd < 0) goto open_err;
+   if (device->fd < 0) goto path_err;
 
    if (!elput_input_init(device->em))
      {
@@ -681,29 +654,24 @@ ecore_drm2_device_open(Ecore_Drm2_Device *device)
      ecore_event_handler_add(ELPUT_EVENT_DEVICE_CHANGE,
                              _cb_device_change, device);
 
-   return device->fd;
+   return device;
 
 input_err:
    elput_manager_close(device->em, device->fd);
-open_err:
-   return -1;
+path_err:
+   elput_manager_disconnect(device->em);
+man_err:
+   free(device);
+   return NULL;
 }
 
 EAPI void
 ecore_drm2_device_close(Ecore_Drm2_Device *device)
 {
    EINA_SAFETY_ON_NULL_RETURN(device);
-   EINA_SAFETY_ON_TRUE_RETURN(device->fd < 0);
 
    elput_input_shutdown(device->em);
    elput_manager_close(device->em, device->fd);
-}
-
-EAPI void
-ecore_drm2_device_free(Ecore_Drm2_Device *device)
-{
-   EINA_SAFETY_ON_NULL_RETURN(device);
-
    if (_ecore_drm2_use_atomic)
      _drm2_atomic_state_free(device->state);
 
@@ -720,7 +688,6 @@ ecore_drm2_device_clock_id_get(Ecore_Drm2_Device *device)
    int ret;
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(device, -1);
-   EINA_SAFETY_ON_TRUE_RETURN_VAL((device->fd < 0), -1);
 
    ret = sym_drmGetCap(device->fd, DRM_CAP_TIMESTAMP_MONOTONIC, &caps);
    if ((ret == 0) && (caps == 1))
@@ -736,7 +703,6 @@ ecore_drm2_device_cursor_size_get(Ecore_Drm2_Device *device, int *width, int *he
    int ret;
 
    EINA_SAFETY_ON_NULL_RETURN(device);
-   EINA_SAFETY_ON_TRUE_RETURN((device->fd < 0));
 
    if (width)
      {
@@ -795,6 +761,22 @@ ecore_drm2_device_pointer_rotation_set(Ecore_Drm2_Device *device, int rotation)
    return elput_input_pointer_rotation_set(device->em, rotation);
 }
 
+EAPI void
+ecore_drm2_device_pointer_accel_speed_set(Ecore_Drm2_Device *device, double speed)
+{
+   EINA_SAFETY_ON_NULL_RETURN(device);
+
+   elput_input_pointer_accel_speed_set(device->em, NULL, speed);
+}
+
+EAPI void
+ecore_drm2_device_pointer_accel_profile_set(Ecore_Drm2_Device *device, uint32_t profile)
+{
+   EINA_SAFETY_ON_NULL_RETURN(device);
+
+   elput_input_pointer_accel_profile_set(device->em, NULL, profile);
+}
+
 EAPI void
 ecore_drm2_device_window_set(Ecore_Drm2_Device *device, unsigned int window)
 {
@@ -876,7 +858,6 @@ ecore_drm2_device_prefer_shadow(Ecore_Drm2_Device *device)
    int ret;
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(device, EINA_FALSE);
-   EINA_SAFETY_ON_TRUE_RETURN_VAL((device->fd < 0), EINA_FALSE);
 
    ret = sym_drmGetCap(device->fd, DRM_CAP_DUMB_PREFER_SHADOW, &caps);
    if ((ret == 0) && (caps == 1))
@@ -885,6 +866,14 @@ ecore_drm2_device_prefer_shadow(Ecore_Drm2_Device *device)
      return EINA_FALSE;
 }
 
+EAPI int
+ecore_drm2_device_fd_get(Ecore_Drm2_Device *device)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(device, -1);
+
+   return device->fd;
+}
+
 /* prevent crashing with old apps compiled against these functions */
 EAPI void ecore_drm2_device_keyboard_cached_context_set(){};
 EAPI void ecore_drm2_device_keyboard_cached_keymap_set(){};
