@@ -87,8 +87,6 @@ _output_event_send(Ecore_Drm2_Output *output)
 {
    Ecore_Drm2_Event_Output_Changed *ev;
 
-   if ((!output->enabled) && (!output->connected)) return;
-
    ev = calloc(1, sizeof(Ecore_Drm2_Event_Output_Changed));
    if (!ev) return;
 
@@ -771,8 +769,6 @@ _output_create(Ecore_Drm2_Device *dev, const drmModeRes *res, const drmModeConne
         output->enabled = EINA_FALSE;
      }
 
-   dev->alloc.crtc |= (1 << output->crtc_id);
-   dev->alloc.conn |= (1 << output->conn_id);
    dev->outputs = eina_list_append(dev->outputs, output);
 
    _output_debug(output, conn);
@@ -785,17 +781,38 @@ _output_create(Ecore_Drm2_Device *dev, const drmModeRes *res, const drmModeConne
    return EINA_TRUE;
 }
 
+static Ecore_Drm2_Output *
+_output_find_by_con(Ecore_Drm2_Device *dev, uint32_t id)
+{
+   Ecore_Drm2_Output *output;
+   Eina_List *l;
+
+   EINA_LIST_FOREACH(dev->outputs, l, output)
+     if (output->conn_id == id) return output;
+
+   return NULL;
+}
+
 static void
 _outputs_update(Ecore_Drm2_Device *dev)
 {
+   Ecore_Drm2_Output *output;
+   Eina_List *l, *ll;
    drmModeRes *res;
    drmModeConnector *conn;
-   uint32_t connected = 0, disconnected = 0;
+   uint32_t *connected;
    int i = 0, x = 0, y = 0;
 
    res = sym_drmModeGetResources(dev->fd);
    if (!res) return;
 
+   connected = calloc(res->count_connectors, sizeof(uint32_t));
+   if (!connected)
+     {
+        sym_drmModeFreeResources(res);
+        return;
+     }
+
    for (i = 0; i < res->count_connectors; i++)
      {
         conn = sym_drmModeGetConnector(dev->fd, res->connectors[i]);
@@ -803,9 +820,8 @@ _outputs_update(Ecore_Drm2_Device *dev)
 
         if (conn->connection != DRM_MODE_CONNECTED) goto next;
 
-        connected |= (1 << res->connectors[i]);
-
-        if (!(dev->alloc.conn & (1 << res->connectors[i])))
+        connected[i] = res->connectors[i];
+        if (!_output_find_by_con(dev, res->connectors[i]))
           {
              if (dev->outputs)
                {
@@ -828,41 +844,31 @@ next:
 
    sym_drmModeFreeResources(res);
 
-   disconnected = (dev->alloc.conn & ~connected);
-   if (disconnected)
+   EINA_LIST_FOREACH_SAFE(dev->outputs, l, ll, output)
      {
-        Ecore_Drm2_Output *output;
-        Eina_List *l;
+        Eina_Bool disconnected = EINA_TRUE;
 
-        EINA_LIST_FOREACH(dev->outputs, l, output)
+        for (i = 0; i < res->count_connectors; i++)
+          if (connected[i] == output->conn_id)
+            {
+               disconnected = EINA_FALSE;
+               break;
+            }
+
+        if (disconnected)
           {
-             if (disconnected & (1 << output->conn_id))
-               {
-                  disconnected &= ~(1 << output->conn_id);
-                  output->connected = EINA_FALSE;
-                  output->enabled = EINA_FALSE;
-                  _output_event_send(output);
-               }
+             output->connected = EINA_FALSE;
+             output->enabled = EINA_FALSE;
+             _output_event_send(output);
           }
-     }
-
-   connected = (dev->alloc.conn & connected);
-   if (connected)
-     {
-        Ecore_Drm2_Output *output;
-        Eina_List *l;
-
-        EINA_LIST_FOREACH(dev->outputs, l, output)
+        else
           {
-             if (connected & (1 << output->conn_id))
-               {
-                  connected &= ~(1 << output->conn_id);
-                  output->connected = EINA_TRUE;
-                  output->enabled = EINA_TRUE;
-                  _output_event_send(output);
-               }
+             output->connected = EINA_TRUE;
+             output->enabled = EINA_TRUE;
+             _output_event_send(output);
           }
      }
+   free(connected);
 }
 
 static void
@@ -875,7 +881,7 @@ _cb_output_event(const char *device EINA_UNUSED, Eeze_Udev_Event event EINA_UNUS
 }
 
 static void
-_output_destroy(Ecore_Drm2_Device *dev, Ecore_Drm2_Output *output)
+_output_destroy(Ecore_Drm2_Device *dev EINA_UNUSED, Ecore_Drm2_Output *output)
 {
    Ecore_Drm2_Output_Mode *mode;
    Ecore_Drm2_Plane *plane;
@@ -906,14 +912,12 @@ _output_destroy(Ecore_Drm2_Device *dev, Ecore_Drm2_Output *output)
         free(mode);
      }
 
-   dev->alloc.crtc &= ~(1 << output->crtc_id);
-   dev->alloc.conn &= ~(1 << output->conn_id);
-
    eina_stringshare_del(output->backlight.path);
    eina_stringshare_del(output->name);
    eina_stringshare_del(output->make);
    eina_stringshare_del(output->model);
    eina_stringshare_del(output->serial);
+   eina_stringshare_del(output->relative.to);
 
    sym_drmModeFreeProperty(output->dpms);
    free(output->edid.blob);
@@ -1112,18 +1116,6 @@ ecore_drm2_output_find(Ecore_Drm2_Device *device, int x, int y)
    return NULL;
 }
 
-EAPI void
-ecore_drm2_output_geometry_get(Ecore_Drm2_Output *output, int *x, int *y, int *w, int *h)
-{
-   EINA_SAFETY_ON_NULL_RETURN(output);
-   EINA_SAFETY_ON_TRUE_RETURN(!output->enabled);
-
-   if (x) *x = output->x;
-   if (y) *y = output->y;
-   if (w) *w = output->current_mode->width;
-   if (h) *h = output->current_mode->height;
-}
-
 EAPI void
 ecore_drm2_output_dpi_get(Ecore_Drm2_Output *output, int *xdpi, int *ydpi)
 {
@@ -1153,25 +1145,6 @@ ecore_drm2_output_latest_fb_get(Ecore_Drm2_Output *output)
    return output->next.fb;
 }
 
-EAPI void
-ecore_drm2_output_crtc_size_get(Ecore_Drm2_Output *output, int *w, int *h)
-{
-   drmModeCrtcPtr crtc;
-
-   if (w) *w = 0;
-   if (h) *h = 0;
-
-   EINA_SAFETY_ON_NULL_RETURN(output);
-
-   crtc = sym_drmModeGetCrtc(output->fd, output->crtc_id);
-   if (!crtc) return;
-
-   if (w) *w = crtc->width;
-   if (h) *h = crtc->height;
-
-   sym_drmModeFreeCrtc(crtc);
-}
-
 EAPI Eina_Bool
 ecore_drm2_output_primary_get(Ecore_Drm2_Output *output)
 {
@@ -1409,7 +1382,8 @@ EAPI Eina_Bool
 ecore_drm2_output_cloned_get(Ecore_Drm2_Output *output)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(output, EINA_FALSE);
-   return output->cloned;
+   return (output->cloned ||
+           output->relative.mode == ECORE_DRM2_RELATIVE_MODE_CLONE);
 }
 
 EAPI unsigned int
@@ -1419,21 +1393,6 @@ ecore_drm2_output_connector_type_get(Ecore_Drm2_Output *output)
    return output->conn_type;
 }
 
-EAPI void
-ecore_drm2_output_resolution_get(Ecore_Drm2_Output *output, int *w, int *h, unsigned int *refresh)
-{
-   if (w) *w = 0;
-   if (h) *h = 0;
-   if (refresh) *refresh = 0;
-
-   EINA_SAFETY_ON_NULL_RETURN(output);
-   EINA_SAFETY_ON_TRUE_RETURN(!output->current_mode);
-
-   if (w) *w = output->current_mode->width;
-   if (h) *h = output->current_mode->height;
-   if (refresh) *refresh = output->current_mode->refresh;
-}
-
 EAPI Eina_Bool
 ecore_drm2_output_possible_crtc_get(Ecore_Drm2_Output *output, unsigned int crtc)
 {
@@ -1497,6 +1456,13 @@ ecore_drm2_output_user_data_set(Ecore_Drm2_Output *o, void *data)
    o->user_data = data;
 }
 
+EAPI void *
+ecore_drm2_output_user_data_get(Ecore_Drm2_Output *output)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(output, NULL);
+   return output->user_data;
+}
+
 EAPI void
 ecore_drm2_output_gamma_set(Ecore_Drm2_Output *output, uint16_t size, uint16_t *red, uint16_t *green, uint16_t *blue)
 {
@@ -1605,6 +1571,7 @@ _blank_fallback_handler(int fd EINA_UNUSED, unsigned int frame EINA_UNUSED, unsi
    output->fallback_usec = usec;
    output->fallback_sec = sec;
 }
+
 static int
 _blanktime_fallback(Ecore_Drm2_Output *output, int sequence, long *sec, long *usec)
 {
@@ -1644,6 +1611,7 @@ ecore_drm2_output_blanktime_get(Ecore_Drm2_Output *output, int sequence, long *s
 {
   drmVBlank v;
   int ret;
+  Eina_Bool success;
 
   EINA_SAFETY_ON_NULL_RETURN_VAL(output, EINA_FALSE);
   EINA_SAFETY_ON_NULL_RETURN_VAL(sec, EINA_FALSE);
@@ -1653,16 +1621,72 @@ ecore_drm2_output_blanktime_get(Ecore_Drm2_Output *output, int sequence, long *s
   v.request.type = DRM_VBLANK_RELATIVE;
   v.request.sequence = sequence;
   ret = sym_drmWaitVBlank(output->fd, &v);
-  if (ret)
+  success = (ret == 0) && (v.reply.tval_sec > 0 || v.reply.tval_usec > 0);
+  if (!success)
     {
        ret = _blanktime_fallback(output, sequence, sec, usec);
        if (ret) return EINA_FALSE;
        return EINA_TRUE;
     }
-  if (v.reply.tval_sec < 0) return EINA_FALSE;
-  if (v.reply.tval_usec < 0) return EINA_FALSE;
 
   *sec = v.reply.tval_sec;
   *usec = v.reply.tval_usec;
   return EINA_TRUE;
 }
+
+EAPI void
+ecore_drm2_output_info_get(Ecore_Drm2_Output *output, int *x, int *y, int *w, int *h, unsigned int *refresh)
+{
+   if (x) *x = 0;
+   if (y) *y = 0;
+   if (w) *w = 0;
+   if (h) *h = 0;
+   if (refresh) *refresh = 0;
+
+   EINA_SAFETY_ON_NULL_RETURN(output);
+   EINA_SAFETY_ON_TRUE_RETURN(!output->current_mode);
+
+   if (w) *w = output->current_mode->width;
+   if (h) *h = output->current_mode->height;
+   if (refresh) *refresh = output->current_mode->refresh;
+   if (x) *x = output->x;
+   if (y) *y = output->y;
+}
+
+EAPI Eina_Bool
+ecore_drm2_output_pending_get(Ecore_Drm2_Output *output)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(output, EINA_FALSE);
+
+   if (output->pending.fb) return EINA_TRUE;
+
+   return EINA_FALSE;
+}
+
+EAPI void
+ecore_drm2_output_relative_mode_set(Ecore_Drm2_Output *output, Ecore_Drm2_Relative_Mode mode)
+{
+   EINA_SAFETY_ON_NULL_RETURN(output);
+   output->relative.mode = mode;
+}
+
+EAPI Ecore_Drm2_Relative_Mode
+ecore_drm2_output_relative_mode_get(Ecore_Drm2_Output *output)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(output, ECORE_DRM2_RELATIVE_MODE_UNKNOWN);
+   return output->relative.mode;
+}
+
+EAPI void
+ecore_drm2_output_relative_to_set(Ecore_Drm2_Output *output, const char *relative)
+{
+   EINA_SAFETY_ON_NULL_RETURN(output);
+   eina_stringshare_replace(&output->relative.to, relative);
+}
+
+EAPI const char *
+ecore_drm2_output_relative_to_get(Ecore_Drm2_Output *output)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(output, NULL);
+   return output->relative.to;
+}
