@@ -6,15 +6,15 @@
 #endif
 
 #ifdef _WIN32
-# ifdef EFL_ECORE_EVAS_BUILD
+# ifdef EFL_BUILD
 #  ifdef DLL_EXPORT
 #   define EAPI __declspec(dllexport)
 #  else
 #   define EAPI
-#  endif /* ! DLL_EXPORT */
+#  endif
 # else
 #  define EAPI __declspec(dllimport)
-# endif /* ! EFL_ECORE_EVAS_BUILD */
+# endif
 #else
 # ifdef __GNUC__
 #  if __GNUC__ >= 4
@@ -25,7 +25,7 @@
 # else
 #  define EAPI
 # endif
-#endif /* ! _WIN32 */
+#endif
 
 #define ECORE_MAGIC_EVAS 0x76543211
 
@@ -213,7 +213,7 @@ struct _Ecore_Evas
    short       rotation;
    Eina_Bool   shaped  : 1;
    Eina_Bool   visible : 1;
-   Eina_Bool   draw_ok : 1;
+   Eina_Bool   draw_block : 1;
    Eina_Bool   should_be_visible : 1;
    Eina_Bool   alpha  : 1;
    Eina_Bool   transparent  : 1;
@@ -330,7 +330,7 @@ struct _Ecore_Evas
 
    // Animator code
    Ecore_Animator *anim;
-   unsigned int anim_count;
+   unsigned int animator_count;
 
    struct {
       unsigned char avoid_damage;
@@ -347,7 +347,7 @@ struct _Ecore_Evas
    } delayed;
 
    int refcount;
-#define ECORE_EVAS_ASYNC_RENDER_DEBUG 1 /* TODO: remove me */
+//#define ECORE_EVAS_ASYNC_RENDER_DEBUG 1 /* TODO: remove me */
 #ifdef ECORE_EVAS_ASYNC_RENDER_DEBUG
    double async_render_start;
 #endif
@@ -487,6 +487,17 @@ Eina_Bool _ecore_evas_cursors_init(Ecore_Evas *ee);
 EAPI void ecore_evas_render_wait(Ecore_Evas *ee);
 EAPI Eina_Bool ecore_evas_render(Ecore_Evas *ee);
 
+EAPI Evas *ecore_evas_evas_new(Ecore_Evas *ee, int w, int h);
+EAPI void ecore_evas_done(Ecore_Evas *ee, Eina_Bool single_window);
+
+#ifdef IPA_YLNO_ESU_LANRETNI_MLE
+EAPI Ecore_Evas *_wayland_shm_new(const char *disp_name, Ecore_Window parent, int x, int y, int w, int h, Eina_Bool frame);
+EAPI Ecore_Evas *_wayland_egl_new(const char *disp_name, Ecore_Window parent, int x, int y, int w, int h, Eina_Bool frame);
+#else
+#define _wayland_shm_new DONT_USE_INTERNAL_API
+#define _wayland_egl_new DONT_USE_INTERNAL_API
+#endif
+
 static inline Eina_Bool
 ecore_evas_render_prepare(Ecore_Evas *ee)
 {
