@@ -382,7 +382,7 @@ EAPI Ecore_Ipc_Server *
 ecore_ipc_server_add(Ecore_Ipc_Type type, const char *name, int port, const void *data)
 {
    Ecore_Ipc_Server *svr;
-   Eo *loop = ecore_main_loop_get();
+   Eo *loop = efl_main_loop_get();
    char *address = NULL;
    Eina_Error err;
 #ifdef EFL_NET_SERVER_UNIX_CLASS
@@ -404,7 +404,7 @@ ecore_ipc_server_add(Ecore_Ipc_Type type, const char *name, int port, const void
 
         new_mask = S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IWOTH | S_IXOTH;
 
-        svr->server = efl_add(EFL_NET_SERVER_UNIX_CLASS, ecore_main_loop_get(),
+        svr->server = efl_add(EFL_NET_SERVER_UNIX_CLASS, efl_main_loop_get(),
                               efl_net_server_unix_leading_directories_create_set(efl_added, EINA_TRUE, S_IRUSR | S_IWUSR | S_IXUSR));
         EINA_SAFETY_ON_NULL_GOTO(svr->server, error_server);
      }
@@ -418,7 +418,7 @@ ecore_ipc_server_add(Ecore_Ipc_Type type, const char *name, int port, const void
         new_mask = 0;
         local_system = EINA_TRUE;
 
-        svr->server = efl_add(EFL_NET_SERVER_UNIX_CLASS, ecore_main_loop_get());
+        svr->server = efl_add(EFL_NET_SERVER_UNIX_CLASS, efl_main_loop_get());
         EINA_SAFETY_ON_NULL_GOTO(svr->server, error_server);
      }
 #endif /* EFL_NET_SERVER_UNIX_CLASS */
@@ -431,7 +431,7 @@ ecore_ipc_server_add(Ecore_Ipc_Type type, const char *name, int port, const void
         // TODO: specify SECURITY_ATTRIBUTES to use or some
         // Efl_Net_Server_Windows API to limit access
 
-        svr->server = efl_add(EFL_NET_SERVER_WINDOWS_CLASS, ecore_main_loop_get());
+        svr->server = efl_add(EFL_NET_SERVER_WINDOWS_CLASS, efl_main_loop_get());
         EINA_SAFETY_ON_NULL_GOTO(svr->server, error_server);
      }
    else if ((type & ECORE_IPC_TYPE) == ECORE_IPC_LOCAL_SYSTEM)
@@ -442,7 +442,7 @@ ecore_ipc_server_add(Ecore_Ipc_Type type, const char *name, int port, const void
         // TODO: specify SECURITY_ATTRIBUTES to use or some
         // Efl_Net_Server_Windows API to limit access
 
-        svr->server = efl_add(EFL_NET_SERVER_WINDOWS_CLASS, ecore_main_loop_get());
+        svr->server = efl_add(EFL_NET_SERVER_WINDOWS_CLASS, efl_main_loop_get());
         EINA_SAFETY_ON_NULL_GOTO(svr->server, error_server);
      }
 #endif /* EFL_NET_SERVER_WINDOWS_CLASS */
@@ -488,14 +488,7 @@ ecore_ipc_server_add(Ecore_Ipc_Type type, const char *name, int port, const void
    if (efl_isa(svr->server, EFL_NET_SERVER_TCP_CLASS))
      {
         /* old ecore_con did not map ipv4 to ipv6... */
-        efl_net_server_tcp_ipv6_only_set(svr->server, EINA_TRUE);
-     }
-   else if (efl_isa(svr->server, EFL_NET_SERVER_SSL_CLASS))
-     {
-        /* old ecore_con did not map ipv4 to ipv6... */
-        efl_net_server_ssl_ipv6_only_set(svr->server, EINA_TRUE);
-        efl_net_server_ssl_reuse_address_set(svr->server, EINA_TRUE);
-        efl_net_server_ssl_reuse_port_set(svr->server, EINA_TRUE);
+        efl_net_server_ip_ipv6_only_set(svr->server, EINA_TRUE);
      }
 
 #ifdef EFL_NET_SERVER_UNIX_CLASS
@@ -660,7 +653,7 @@ EAPI Ecore_Ipc_Server *
 ecore_ipc_server_connect(Ecore_Ipc_Type type, char *name, int port, const void *data)
 {
    Ecore_Ipc_Server *svr;
-   Eo *loop = ecore_main_loop_get();
+   Eo *loop = efl_main_loop_get();
    char *address = NULL;
    Eina_Error err;
 
@@ -688,7 +681,7 @@ ecore_ipc_server_connect(Ecore_Ipc_Type type, char *name, int port, const void *
              goto error_dialer;
           }
 
-        svr->dialer.dialer = efl_add(EFL_NET_DIALER_UNIX_CLASS, ecore_main_loop_get());
+        svr->dialer.dialer = efl_add(EFL_NET_DIALER_UNIX_CLASS, efl_main_loop_get());
         EINA_SAFETY_ON_NULL_GOTO(svr->dialer.dialer, error_dialer);
      }
    else if ((type & ECORE_IPC_TYPE) == ECORE_IPC_LOCAL_SYSTEM)
@@ -696,7 +689,7 @@ ecore_ipc_server_connect(Ecore_Ipc_Type type, char *name, int port, const void *
         address = ecore_con_local_path_new(EINA_TRUE, name, port);
         EINA_SAFETY_ON_NULL_GOTO(address, error_dialer);
 
-        svr->dialer.dialer = efl_add(EFL_NET_DIALER_UNIX_CLASS, ecore_main_loop_get());
+        svr->dialer.dialer = efl_add(EFL_NET_DIALER_UNIX_CLASS, efl_main_loop_get());
         EINA_SAFETY_ON_NULL_GOTO(svr->dialer.dialer, error_dialer);
      }
 #endif /* EFL_NET_DIALER_UNIX_CLASS */
@@ -706,7 +699,7 @@ ecore_ipc_server_connect(Ecore_Ipc_Type type, char *name, int port, const void *
         address = ecore_con_local_path_new(EINA_FALSE, name, port);
         EINA_SAFETY_ON_NULL_GOTO(address, error_dialer);
 
-        svr->dialer.dialer = efl_add(EFL_NET_DIALER_WINDOWS_CLASS, ecore_main_loop_get());
+        svr->dialer.dialer = efl_add(EFL_NET_DIALER_WINDOWS_CLASS, efl_main_loop_get());
         EINA_SAFETY_ON_NULL_GOTO(svr->dialer.dialer, error_dialer);
      }
    else if ((type & ECORE_IPC_TYPE) == ECORE_IPC_LOCAL_SYSTEM)
@@ -714,7 +707,7 @@ ecore_ipc_server_connect(Ecore_Ipc_Type type, char *name, int port, const void *
         address = ecore_con_local_path_new(EINA_TRUE, name, port);
         EINA_SAFETY_ON_NULL_GOTO(address, error_dialer);
 
-        svr->dialer.dialer = efl_add(EFL_NET_DIALER_WINDOWS_CLASS, ecore_main_loop_get());
+        svr->dialer.dialer = efl_add(EFL_NET_DIALER_WINDOWS_CLASS, efl_main_loop_get());
         EINA_SAFETY_ON_NULL_GOTO(svr->dialer.dialer, error_dialer);
      }
 #endif /* EFL_NET_DIALER_WINDOWS_CLASS */
@@ -752,21 +745,21 @@ ecore_ipc_server_connect(Ecore_Ipc_Type type, char *name, int port, const void *
         goto error_dialer;
      }
 
-   efl_io_closer_close_on_destructor_set(svr->dialer.dialer, EINA_TRUE);
+   efl_io_closer_close_on_invalidate_set(svr->dialer.dialer, EINA_TRUE);
    efl_event_callback_array_add(svr->dialer.dialer, _ecore_ipc_dialer_cbs(), svr);
 
    svr->dialer.input = efl_add(EFL_IO_QUEUE_CLASS, loop);
    EINA_SAFETY_ON_NULL_GOTO(svr->dialer.input, error);
 
    svr->dialer.send_copier = efl_add(EFL_IO_COPIER_CLASS, loop,
-                                     efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                                     efl_io_closer_close_on_invalidate_set(efl_added, EINA_FALSE),
                                      efl_io_copier_source_set(efl_added, svr->dialer.input),
                                      efl_io_copier_destination_set(efl_added, svr->dialer.dialer),
                                      efl_event_callback_array_add(efl_added, _ecore_ipc_dialer_copier_cbs(), svr));
    EINA_SAFETY_ON_NULL_GOTO(svr->dialer.send_copier, error);
 
    svr->dialer.recv_copier = efl_add(EFL_IO_COPIER_CLASS, loop,
-                                     efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                                     efl_io_closer_close_on_invalidate_set(efl_added, EINA_FALSE),
                                      efl_io_copier_source_set(efl_added, svr->dialer.dialer),
                                      efl_event_callback_array_add(efl_added, _ecore_ipc_dialer_copier_cbs(), svr),
                                      efl_event_callback_add(efl_added, EFL_IO_COPIER_EVENT_DATA, _ecore_ipc_dialer_copier_data, svr));
@@ -976,20 +969,23 @@ ecore_ipc_server_send(Ecore_Ipc_Server *svr, int major, int minor, int ref, int
              return 0;
           }
 
-        slice.mem = data;
-        slice.len = size;
-        err = efl_io_writer_write(svr->dialer.input, &slice, NULL);
-        if (err)
+        if ((data) && (size > 0))
           {
-             ERR("could not write queue=%p %zd bytes: %s",
-                 svr->dialer.input, slice.len, eina_error_msg_get(err));
-             return 0;
-          }
-        if (slice.len < (size_t)size)
-          {
-             ERR("only wrote %zd of %d bytes to queue %p",
-                 slice.len, size, svr->dialer.input);
-             return 0;
+             slice.mem = data;
+             slice.len = size;
+             err = efl_io_writer_write(svr->dialer.input, &slice, NULL);
+             if (err)
+               {
+                  ERR("could not write queue=%p %zd bytes: %s",
+                      svr->dialer.input, slice.len, eina_error_msg_get(err));
+                  return 0;
+               }
+             if (slice.len < (size_t)size)
+               {
+                  ERR("only wrote %zd of %d bytes to queue %p",
+                      slice.len, size, svr->dialer.input);
+                  return 0;
+               }
           }
 
         return s + size;
@@ -1085,7 +1081,8 @@ ecore_ipc_server_flush(Ecore_Ipc_Server *svr)
         while (!efl_io_closer_closed_get(svr->dialer.dialer) &&
                !efl_net_dialer_connected_get(svr->dialer.dialer))
           ecore_main_loop_iterate();
-        while (efl_io_queue_usage_get(svr->dialer.input) > 0)
+        while ((efl_io_queue_usage_get(svr->dialer.input) > 0) ||
+               (efl_io_copier_pending_size_get(svr->dialer.send_copier) > 0))
           efl_io_copier_flush(svr->dialer.send_copier, EINA_TRUE, EINA_TRUE);
         return;
      }
@@ -1194,21 +1191,23 @@ ecore_ipc_client_send(Ecore_Ipc_Client *cl, int major, int minor, int ref, int r
                  slice.len, s, cl->socket.input);
              return 0;
           }
-
-        slice.mem = data;
-        slice.len = size;
-        err = efl_io_writer_write(cl->socket.input, &slice, NULL);
-        if (err)
+        if ((data) && (size > 0))
           {
-             ERR("could not write queue=%p %zd bytes: %s",
-                 cl->socket.input, slice.len, eina_error_msg_get(err));
-             return 0;
-          }
-        if (slice.len < (size_t)size)
-          {
-             ERR("only wrote %zd of %d bytes to queue %p",
-                 slice.len, size, cl->socket.input);
-             return 0;
+             slice.mem = data;
+             slice.len = size;
+             err = efl_io_writer_write(cl->socket.input, &slice, NULL);
+             if (err)
+               {
+                  ERR("could not write queue=%p %zd bytes: %s",
+                      cl->socket.input, slice.len, eina_error_msg_get(err));
+                  return 0;
+               }
+             if (slice.len < (size_t)size)
+               {
+                  ERR("only wrote %zd of %d bytes to queue %p",
+                      slice.len, size, cl->socket.input);
+                  return 0;
+               }
           }
 
         return s + size;
@@ -1344,14 +1343,14 @@ _ecore_ipc_server_client_add(void *data, const Efl_Event *event)
    EINA_SAFETY_ON_NULL_GOTO(cl->socket.input, error);
 
    cl->socket.send_copier = efl_add(EFL_IO_COPIER_CLASS, loop,
-                                     efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                                     efl_io_closer_close_on_invalidate_set(efl_added, EINA_FALSE),
                                      efl_io_copier_source_set(efl_added, cl->socket.input),
                                      efl_io_copier_destination_set(efl_added, cl->socket.socket),
                                      efl_event_callback_array_add(efl_added, _ecore_ipc_client_socket_copier_cbs(), cl));
    EINA_SAFETY_ON_NULL_GOTO(cl->socket.send_copier, error);
 
    cl->socket.recv_copier = efl_add(EFL_IO_COPIER_CLASS, loop,
-                                     efl_io_closer_close_on_destructor_set(efl_added, EINA_FALSE),
+                                     efl_io_closer_close_on_invalidate_set(efl_added, EINA_FALSE),
                                      efl_io_copier_source_set(efl_added, cl->socket.socket),
                                      efl_event_callback_array_add(efl_added, _ecore_ipc_client_socket_copier_cbs(), cl),
                                      efl_event_callback_add(efl_added, EFL_IO_COPIER_EVENT_DATA, _ecore_ipc_client_socket_copier_data, cl));
