@@ -27,10 +27,8 @@
 
 /* FIXME: uncomment when mingw-w64 will be updated in win-builds */
 
-/* #if _WIN32_WINNT >= 0x0600 */
-/* # ifndef WM_CLIPBOARDUPDATE */
-#  define WM_CLIPBOARDUPDATE 0x031D
-/* # endif */
+/* #ifndef WM_CLIPBOARDUPDATE */
+# define WM_CLIPBOARDUPDATE 0x031D
 /* #endif */
 
 /* OLE IID for Drag'n Drop */
@@ -255,7 +253,7 @@ _ecore_win32_window_procedure(HWND   window,
        return TRUE;
      case WM_MOVING:
        INF("moving window message");
-       _ecore_win32_event_handle_configure_notify(data);
+       _ecore_win32_event_handle_configure_notify(data, EINA_FALSE);
        return TRUE;
      case WM_MOVE:
        INF("move window message");
@@ -263,10 +261,11 @@ _ecore_win32_window_procedure(HWND   window,
      case WM_SIZING:
        INF("sizing window message");
        _ecore_win32_event_handle_resize(data);
-       _ecore_win32_event_handle_configure_notify(data);
+       _ecore_win32_event_handle_configure_notify(data, EINA_FALSE);
        return TRUE;
      case WM_SIZE:
        INF("size window message");
+       _ecore_win32_event_handle_configure_notify(data, EINA_TRUE);
        return 0;
 /*      case WM_WINDOWPOSCHANGING: */
 /*        { */
@@ -275,11 +274,11 @@ _ecore_win32_window_procedure(HWND   window,
 /*          printf (" *** ecore message : WINDOWPOSCHANGING %ld %ld\n", */
 /*                  rect.right - rect.left, rect.bottom - rect.top); */
 /*        } */
-/*        _ecore_win32_event_handle_configure_notify(data); */
+/*        _ecore_win32_event_handle_configure_notify(data, EINA_FALSE); */
 /*        return 0; */
      case WM_WINDOWPOSCHANGED:
        INF("position changed window message");
-       _ecore_win32_event_handle_configure_notify(data);
+       _ecore_win32_event_handle_configure_notify(data, EINA_FALSE);
        _ecore_win32_event_handle_property_notify(data);
        _ecore_win32_event_handle_expose(data);
        return 0;
@@ -529,6 +528,8 @@ ecore_win32_init()
         goto shutdown_ecore_event;
      }
 
+   ecore_win32_monitor_init();
+
    icon = LoadImage(_ecore_win32_instance,
                     MAKEINTRESOURCE(IDI_ICON),
                     IMAGE_ICON,
@@ -572,30 +573,25 @@ ecore_win32_init()
         goto unregister_class;
      }
 
-   if (!ECORE_WIN32_EVENT_MOUSE_IN)
-     {
-        ECORE_WIN32_EVENT_MOUSE_IN              = ecore_event_type_new();
-        ECORE_WIN32_EVENT_MOUSE_OUT             = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_FOCUS_IN       = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_FOCUS_OUT      = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_DAMAGE         = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_CREATE         = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_DESTROY        = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_SHOW           = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_HIDE           = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_CONFIGURE      = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_RESIZE         = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_PROPERTY       = ecore_event_type_new();
-        ECORE_WIN32_EVENT_WINDOW_DELETE_REQUEST = ecore_event_type_new();
-        ECORE_WIN32_EVENT_SELECTION_CLEAR       = ecore_event_type_new();
-        ECORE_WIN32_EVENT_SELECTION_NOTIFY      = ecore_event_type_new();
-     }
+   ECORE_WIN32_EVENT_MOUSE_IN              = ecore_event_type_new();
+   ECORE_WIN32_EVENT_MOUSE_OUT             = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_FOCUS_IN       = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_FOCUS_OUT      = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_DAMAGE         = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_CREATE         = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_DESTROY        = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_SHOW           = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_HIDE           = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_CONFIGURE      = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_RESIZE         = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_PROPERTY       = ecore_event_type_new();
+   ECORE_WIN32_EVENT_WINDOW_DELETE_REQUEST = ecore_event_type_new();
+   ECORE_WIN32_EVENT_SELECTION_CLEAR       = ecore_event_type_new();
+   ECORE_WIN32_EVENT_SELECTION_NOTIFY      = ecore_event_type_new();
 
    for (i = 0; i < 77; i++)
      _ecore_win32_cursor_x[i] = _ecore_win32_cursor_x11_shaped_new(i);
 
-   ecore_win32_monitor_init();
-
    return _ecore_win32_init_count;
 
  unregister_class:
@@ -630,8 +626,6 @@ ecore_win32_shutdown()
    if (--_ecore_win32_init_count != 0)
      return _ecore_win32_init_count;
 
-   ecore_win32_monitor_shutdown();
-
    for (i = 0; i < 77; i++)
      ecore_win32_cursor_free(_ecore_win32_cursor_x[i]);
 
@@ -656,6 +650,8 @@ ecore_win32_shutdown()
    if (!UnregisterClass(ECORE_WIN32_WINDOW_CLASS, _ecore_win32_instance))
      INF("UnregisterClass() failed");
 
+   ecore_win32_monitor_shutdown();
+
    if (!FreeLibrary(_ecore_win32_instance))
      INF("FreeLibrary() failed");
 
