@@ -5,6 +5,7 @@
 #include "ecore_wl2_private.h"
 
 #include "linux-dmabuf-unstable-v1-client-protocol.h"
+#include "efl-hints-client-protocol.h"
 
 static Eina_Hash *_server_displays = NULL;
 static Eina_Hash *_client_displays = NULL;
@@ -13,6 +14,8 @@ static Eina_Bool _cb_connect_idle(void *data);
 static Eina_Bool _cb_connect_data(void *data, Ecore_Fd_Handler *hdl);
 static Eina_Bool _ecore_wl2_display_connect(Ecore_Wl2_Display *ewd, Eina_Bool sync);
 
+static void _ecore_wl2_display_sync_add(Ecore_Wl2_Display *ewd);
+
 void
 _display_event_free(void *d, void *event)
 {
@@ -44,17 +47,6 @@ _ecore_wl2_display_signal_exit(void)
    ecore_event_add(ECORE_EVENT_SIGNAL_EXIT, ev, NULL, NULL);
 }
 
-static void
-_xdg_shell_cb_ping(void *data EINA_UNUSED, struct xdg_shell *shell, uint32_t serial)
-{
-   xdg_shell_pong(shell, serial);
-}
-
-static const struct xdg_shell_listener _xdg_shell_listener =
-{
-   _xdg_shell_cb_ping
-};
-
 static void
 _dmabuf_cb_format(void *data EINA_UNUSED, struct zwp_linux_dmabuf_v1 *dmabuf EINA_UNUSED, uint32_t format EINA_UNUSED)
 {
@@ -67,9 +59,22 @@ static const struct zwp_linux_dmabuf_v1_listener _dmabuf_listener =
 };
 
 static void
-_zxdg_shell_cb_ping(void *data EINA_UNUSED, struct zxdg_shell_v6 *shell, uint32_t serial)
+_xdg_shell_cb_ping(void *data, struct xdg_wm_base *shell, uint32_t serial)
+{
+   xdg_wm_base_pong(shell, serial);
+   ecore_wl2_display_flush(data);
+}
+
+static const struct xdg_wm_base_listener _xdg_shell_listener =
+{
+   _xdg_shell_cb_ping,
+};
+
+static void
+_zxdg_shell_cb_ping(void *data, struct zxdg_shell_v6 *shell, uint32_t serial)
 {
    zxdg_shell_v6_pong(shell, serial);
+   ecore_wl2_display_flush(data);
 }
 
 static const struct zxdg_shell_v6_listener _zxdg_shell_listener =
@@ -140,7 +145,7 @@ _aux_hints_supported_aux_hints(void *data, struct efl_aux_hints *aux_hints EINA_
      }
 
    if (!(ev = calloc(1, sizeof(Ecore_Wl2_Event_Aux_Hint_Supported)))) return;
-   ev->win = win->id;
+   ev->win = win;
    ev->display = ewd;
    ewd->refs++;
    ecore_event_add(ECORE_WL2_EVENT_AUX_HINT_SUPPORTED, ev, _display_event_free, ewd);
@@ -159,7 +164,7 @@ _aux_hints_allowed_aux_hint(void *data, struct efl_aux_hints *aux_hints  EINA_UN
    if (!win) return;
 
    if (!(ev = calloc(1, sizeof(Ecore_Wl2_Event_Aux_Hint_Allowed)))) return;
-   ev->win = win->id;
+   ev->win = win;
    ev->id = id;
    ev->display = ewd;
    ewd->refs++;
@@ -207,7 +212,7 @@ _aux_hints_aux_message(void *data, struct efl_aux_hints *aux_hints EINA_UNUSED,
           }
      }
 
-   ev->win = win->id;
+   ev->win = win;
    ev->key = eina_stringshare_add(key);
    ev->val = eina_stringshare_add(val);
    ev->options = opt_list;
@@ -286,11 +291,13 @@ _cb_global_add(void *data, struct wl_registry *registry, unsigned int id, const
         ewd->wl.shm =
           wl_registry_bind(registry, id, &wl_shm_interface, 1);
      }
-   else if (!strcmp(interface, "zwp_linux_dmabuf_v1"))
+   else if (!strcmp(interface, "zwp_linux_dmabuf_v1") && (version >= 2))
      {
         ewd->wl.dmabuf =
-          wl_registry_bind(registry, id, &zwp_linux_dmabuf_v1_interface, 1);
+          wl_registry_bind(registry, id, &zwp_linux_dmabuf_v1_interface, 2);
         zwp_linux_dmabuf_v1_add_listener(ewd->wl.dmabuf, &_dmabuf_listener, ewd);
+        _ecore_wl2_buffer_test(ewd);
+        _ecore_wl2_display_sync_add(ewd);
      }
    else if (!strcmp(interface, "wl_data_device_manager"))
      {
@@ -336,6 +343,22 @@ _cb_global_add(void *data, struct wl_registry *registry, unsigned int id, const
      _ecore_wl2_output_add(ewd, id);
    else if (!strcmp(interface, "wl_seat"))
      _ecore_wl2_input_add(ewd, id, version);
+   else if (!strcmp(interface, "efl_hints"))
+     {
+        Ecore_Wl2_Window *window;
+
+        ewd->wl.efl_hints = wl_registry_bind(registry, id, &efl_hints_interface, MIN(version, 2));
+        EINA_INLIST_FOREACH(ewd->windows, window)
+          {
+             if (!window->xdg_surface) continue;
+             if (window->aspect.set)
+               efl_hints_set_aspect(window->display->wl.efl_hints, window->xdg_surface,
+                 window->aspect.w, window->aspect.h, window->aspect.aspect);
+             if (window->weight.set)
+               efl_hints_set_weight(window->display->wl.efl_hints,
+                 window->xdg_surface, window->weight.w, window->weight.h);
+          }
+     }
 
 event:
    /* allocate space for event structure */
@@ -428,8 +451,8 @@ _ecore_wl2_display_globals_cleanup(Ecore_Wl2_Display *ewd)
    if (ewd->wl.session_recovery)
      zwp_e_session_recovery_destroy(ewd->wl.session_recovery);
    if (ewd->wl.www) www_destroy(ewd->wl.www);
+   if (ewd->wl.xdg_wm_base) xdg_wm_base_destroy(ewd->wl.xdg_wm_base);
    if (ewd->wl.zxdg_shell) zxdg_shell_v6_destroy(ewd->wl.zxdg_shell);
-   if (ewd->wl.xdg_shell) xdg_shell_destroy(ewd->wl.xdg_shell);
    if (ewd->wl.shm) wl_shm_destroy(ewd->wl.shm);
    if (ewd->wl.data_device_manager)
      wl_data_device_manager_destroy(ewd->wl.data_device_manager);
@@ -437,6 +460,7 @@ _ecore_wl2_display_globals_cleanup(Ecore_Wl2_Display *ewd)
    if (ewd->wl.subcompositor) wl_subcompositor_destroy(ewd->wl.subcompositor);
    if (ewd->wl.dmabuf) zwp_linux_dmabuf_v1_destroy(ewd->wl.dmabuf);
    if (ewd->wl.efl_aux_hints) efl_aux_hints_destroy(ewd->wl.efl_aux_hints);
+   if (ewd->wl.efl_hints) efl_hints_destroy(ewd->wl.efl_hints);
 
    if (ewd->wl.registry) wl_registry_destroy(ewd->wl.registry);
 }
@@ -457,6 +481,8 @@ _recovery_timer_add(Ecore_Wl2_Display *ewd)
    ewd->fd_hdl = NULL;
 
    ewd->shell_done = EINA_FALSE;
+   ewd->sync_done = EINA_FALSE;
+   ewd->recovering = EINA_TRUE;
 
    _ecore_wl2_display_globals_cleanup(ewd);
 
@@ -474,8 +500,14 @@ _recovery_timer_add(Ecore_Wl2_Display *ewd)
         EINA_INLIST_FOREACH_SAFE(window->subsurfs, tmp2, subsurf)
           _ecore_wl2_subsurf_unmap(subsurf);
         _ecore_wl2_window_semi_free(window);
-        window->configure_serial = 0;
-        window->configure_ack = NULL;
+        window->set_config.serial = 0;
+        window->req_config.serial = 0;
+        window->xdg_configure_ack = NULL;
+        window->xdg_set_min_size = NULL;
+        window->xdg_set_max_size = NULL;
+        window->zxdg_configure_ack = NULL;
+        window->zxdg_set_min_size = NULL;
+        window->zxdg_set_max_size = NULL;
      }
 
    ewd->recovery_timer =
@@ -512,7 +544,7 @@ _cb_connect_data(void *data, Ecore_Fd_Handler *hdl)
      {
         ret = wl_display_flush(ewd->wl.display);
         code = errno;
-        if (ret == 0)
+        if (ret >= 0)
           ecore_main_fd_handler_active_set(hdl, ECORE_FD_READ);
 
         if ((ret < 0) && (code != EAGAIN)) goto err;
@@ -553,12 +585,6 @@ _cb_connect_idle(void *data)
    code = errno;
    if (ret < 0) goto err;
 
-   ret = wl_display_flush(ewd->wl.display);
-   code = errno;
-   if ((ret < 0) && (code == EAGAIN))
-     ecore_main_fd_handler_active_set(ewd->fd_hdl,
-                                      (ECORE_FD_READ | ECORE_FD_WRITE));
-
    return ECORE_CALLBACK_RENEW;
 
 err:
@@ -602,8 +628,8 @@ _ecore_wl2_shell_bind(Ecore_Wl2_Display *ewd)
    const char **itr;
    const char *shells[] =
      {
+        "xdg_wm_base",
         "zxdg_shell_v6",
-        "xdg_shell",
         NULL
      };
 
@@ -618,25 +644,14 @@ _ecore_wl2_shell_bind(Ecore_Wl2_Display *ewd)
 
    if (!global) return;
 
-   if ((!strcmp(global->interface, "xdg_shell")) &&
-            (!getenv("EFL_WAYLAND_DONT_USE_XDG_SHELL")))
+   if (!strcmp(global->interface, "xdg_wm_base"))
      {
-        Ecore_Wl2_Window *window;
-
-        ewd->wl.xdg_shell =
+        ewd->wl.xdg_wm_base =
           wl_registry_bind(ewd->wl.registry, global->id,
-                           &xdg_shell_interface, 1);
-        xdg_shell_use_unstable_version(ewd->wl.xdg_shell,
-                                       XDG_V5_UNSTABLE_VERSION);
-        xdg_shell_add_listener(ewd->wl.xdg_shell, &_xdg_shell_listener, NULL);
+                           &xdg_wm_base_interface, 1);
+        xdg_wm_base_add_listener(ewd->wl.xdg_wm_base,
+                                   &_xdg_shell_listener, ewd);
         ewd->shell_done = EINA_TRUE;
-
-        EINA_INLIST_FOREACH(ewd->windows, window)
-          if ((window->type != ECORE_WL2_WINDOW_TYPE_DND) &&
-              (window->type != ECORE_WL2_WINDOW_TYPE_NONE))
-                _ecore_wl2_window_shell_surface_init(window);
-          else
-            window->pending.configure = EINA_FALSE;
      }
    else if (!strcmp(global->interface, "zxdg_shell_v6"))
      {
@@ -644,7 +659,7 @@ _ecore_wl2_shell_bind(Ecore_Wl2_Display *ewd)
           wl_registry_bind(ewd->wl.registry, global->id,
                            &zxdg_shell_v6_interface, 1);
         zxdg_shell_v6_add_listener(ewd->wl.zxdg_shell,
-                                   &_zxdg_shell_listener, NULL);
+                                   &_zxdg_shell_listener, ewd);
         ewd->shell_done = EINA_TRUE;
      }
 }
@@ -656,11 +671,15 @@ _cb_sync_done(void *data, struct wl_callback *cb, uint32_t serial EINA_UNUSED)
    Ecore_Wl2_Display *ewd;
 
    ewd = data;
+   if (--ewd->syncs) return;
+   if (ewd->sync_done) return;
+
    ewd->sync_done = EINA_TRUE;
 
    _ecore_wl2_shell_bind(ewd);
 
    wl_callback_destroy(cb);
+   ecore_wl2_display_flush(ewd);
 
    ev = calloc(1, sizeof(Ecore_Wl2_Event_Sync_Done));
    if (!ev) return;
@@ -675,20 +694,29 @@ static const struct wl_callback_listener _sync_listener =
    _cb_sync_done
 };
 
-static Eina_Bool
-_ecore_wl2_display_connect(Ecore_Wl2_Display *ewd, Eina_Bool sync)
+static void
+_ecore_wl2_display_sync_add(Ecore_Wl2_Display *ewd)
 {
    struct wl_callback *cb;
 
+   ewd->syncs++;
+   cb = wl_display_sync(ewd->wl.display);
+   wl_callback_add_listener(cb, &_sync_listener, ewd);
+}
+
+static Eina_Bool
+_ecore_wl2_display_connect(Ecore_Wl2_Display *ewd, Eina_Bool sync)
+{
    /* try to connect to wayland display with this name */
    ewd->wl.display = wl_display_connect(ewd->name);
    if (!ewd->wl.display) return EINA_FALSE;
 
+   ewd->recovering = EINA_FALSE;
+
    ewd->wl.registry = wl_display_get_registry(ewd->wl.display);
    wl_registry_add_listener(ewd->wl.registry, &_registry_listener, ewd);
 
-   cb = wl_display_sync(ewd->wl.display);
-   wl_callback_add_listener(cb, &_sync_listener, ewd);
+   _ecore_wl2_display_sync_add(ewd);
 
    if (sync)
      {
@@ -855,26 +883,7 @@ found:
 Eina_Bool
 _ecore_wl2_display_sync_get(void)
 {
-   Ecore_Wl2_Display *sewd;
-   Eina_Iterator *itr;
-   Eina_Bool ret = EINA_TRUE;
-   void *data;
-
-   if (eina_hash_population(_server_displays) < 1) return ret;
-
-   itr = eina_hash_iterator_data_new(_server_displays);
-   while (eina_iterator_next(itr, &data))
-     {
-        sewd = (Ecore_Wl2_Display *)data;
-        if (sewd->pid == getpid())
-          {
-             ret = EINA_FALSE;
-             break;
-          }
-     }
-   eina_iterator_free(itr);
-
-   return ret;
+   return !_server_displays || !eina_hash_population(_server_displays);
 }
 
 EAPI Ecore_Wl2_Display *
@@ -921,24 +930,23 @@ ecore_wl2_display_connect(const char *name)
 
    ewd->globals = eina_hash_int32_new(_cb_globals_hash_del);
 
+   ewd->xkb_context = xkb_context_new(0);
+   if (!ewd->xkb_context) goto context_err;
+
    /* check server display hash and match on pid. If match, skip sync */
    if (!_ecore_wl2_display_connect(ewd, _ecore_wl2_display_sync_get()))
      goto connect_err;
 
-   ewd->xkb_context = xkb_context_new(0);
-   if (!ewd->xkb_context) goto context_err;
-
    /* add this new client display to hash */
    eina_hash_add(_client_displays, ewd->name, ewd);
 
    return ewd;
 
-context_err:
-   ecore_main_fd_handler_del(ewd->fd_hdl);
-   wl_registry_destroy(ewd->wl.registry);
-   wl_display_disconnect(ewd->wl.display);
-
 connect_err:
+   xkb_context_unref(ewd->xkb_context);
+   ewd->xkb_context = NULL;
+
+context_err:
    eina_hash_free(ewd->globals);
    free(ewd->name);
    free(ewd);
@@ -1075,19 +1083,6 @@ ecore_wl2_display_screen_size_get(Ecore_Wl2_Display *display, int *w, int *h)
    if (h) *h = oh;
 }
 
-EAPI Ecore_Wl2_Window *
-ecore_wl2_display_window_find(Ecore_Wl2_Display *display, unsigned int id)
-{
-   Ecore_Wl2_Window *window;
-
-   EINA_SAFETY_ON_NULL_RETURN_VAL(display, NULL);
-
-   EINA_INLIST_FOREACH(display->windows, window)
-     if (window->id == (int)id) return window;
-
-   return NULL;
-}
-
 EAPI struct wl_registry *
 ecore_wl2_display_registry_get(Ecore_Wl2_Display *display)
 {
@@ -1149,3 +1144,24 @@ ecore_wl2_display_name_get(const Ecore_Wl2_Display *display)
    EINA_SAFETY_ON_NULL_RETURN_VAL(display, NULL);
    return display->name;
 }
+
+EAPI void
+ecore_wl2_display_flush(Ecore_Wl2_Display *display)
+{
+   int ret, code;
+
+   EINA_SAFETY_ON_NULL_RETURN(display);
+
+   ret = wl_display_flush(display->wl.display);
+   if (ret >= 0) return;
+
+   code = errno;
+   if (code == EAGAIN)
+     {
+        ecore_main_fd_handler_active_set(display->fd_hdl,
+                                         (ECORE_FD_READ | ECORE_FD_WRITE));
+        return;
+     }
+
+   _begin_recovery_maybe(display, code);
+}
