@@ -89,7 +89,8 @@ struct _Edje_Size_Class
  * @{
  */
 
-typedef void         (*Edje_Signal_Cb)          (void *data, Evas_Object *obj, const char *emission, const char *source); /**< Edje signal callback functions's prototype definition. @c data will have the auxiliary data pointer set at the time the callback registration. @c obj will be a pointer the Edje object where the signal comes from. @c emission will identify the exact signal's emission string and @c source the exact signal's source one. */
+typedef void (*Efl_Signal_Cb) (void *data, Evas_Object *obj, const char *emission, const char *source); /**< Edje signal callback functions's prototype definition. @c data will have the auxiliary data pointer set at the time the callback registration. @c obj will be a pointer the Edje object where the signal comes from. @c emission will identify the exact signal's emission string and @c source the exact signal's source one. */
+typedef Efl_Signal_Cb Edje_Signal_Cb;
 
 /**
  * @brief Gets extra data passed to callbacks.
@@ -1238,6 +1239,8 @@ EAPI Eina_Iterator *edje_color_class_active_iterator_new(void);
 /**
  * @brief Iterates over all the color class provided by an Edje file.
  *
+ * @param f The mapped edje file.
+ *
  * @return an iterator of Edje_Color_Class provided by the Edje file.
  *
  * @since 1.14
@@ -1268,37 +1271,6 @@ EAPI Eina_Iterator *edje_mmap_color_class_iterator_new(Eina_File *f);
  * @{
  */
 
-/**
- * @typedef Edje_Part_Type
- *
- * All possible "part" types in Edje.
- */
-typedef enum _Edje_Part_Type
-{
-   EDJE_PART_TYPE_NONE      = 0,  /**< None type value */
-   EDJE_PART_TYPE_RECTANGLE = 1,  /**< Rectangle type value */
-   EDJE_PART_TYPE_TEXT      = 2,  /**< Text type value */
-   EDJE_PART_TYPE_IMAGE     = 3,  /**< Image type value */
-   EDJE_PART_TYPE_SWALLOW   = 4,  /**< Swallow  type value */
-   EDJE_PART_TYPE_TEXTBLOCK = 5,  /**< Text block type value */
-   EDJE_PART_TYPE_GRADIENT  = 6,  /**< Gradient type value */
-   EDJE_PART_TYPE_GROUP     = 7,  /**< Group type value */
-   EDJE_PART_TYPE_BOX       = 8,  /**< Box type value */
-   EDJE_PART_TYPE_TABLE     = 9,  /**< Table type value */
-   EDJE_PART_TYPE_EXTERNAL  = 10, /**< External type value */
-   EDJE_PART_TYPE_PROXY     = 11, /**< Proxy type value */
-   EDJE_PART_TYPE_SPACER    = 12, /**< Spacer type value @since 1.7 */
-   EDJE_PART_TYPE_MESH_NODE = 13,
-   EDJE_PART_TYPE_LIGHT     = 14,
-   EDJE_PART_TYPE_CAMERA    = 15,
-   EDJE_PART_TYPE_SNAPSHOT  = 16, /**< Snapshot @since 1.16 */
-   EDJE_PART_TYPE_VECTOR    = 17, /**< Vector @since 1.18 */
-   EDJE_PART_TYPE_LAST      = 18  /**< Last type value */
-} Edje_Part_Type;
-/**
- * @}
- */
-
 /**
  * @defgroup Edje_Part_Text Edje Text Part
  * @ingroup Edje_Object_Part
@@ -1353,18 +1325,6 @@ typedef enum _Edje_Text_Effect
    EDJE_TEXT_EFFECT_SHADOW_DIRECTION_RIGHT        = (0x7 << 4)  /**< right shadow direction value */
 } Edje_Text_Effect;
 
-/**
- * @typedef (*Edje_Text_Change_Cb)
- *
- * Callback prototype for Edje_Text_Change.
- * @param data User provided data to pass to the callback
- * @param obj The Evas_Object
- * @param part The edje part
- */
-typedef void         (*Edje_Text_Change_Cb)     (void *data, Evas_Object *obj, const char *part);
-/**
- * @}
- */
 
 /**
  * @defgroup Edje_Text_Selection Edje Text Selection
@@ -1627,6 +1587,8 @@ EAPI Eina_Iterator *edje_text_class_active_iterator_new(void);
 /**
  * @brief Iterate over all text classes provided by an Edje file.
  *
+ * @param f The mapped edje file.
+ *
  * @return an iterator of Edje_Text_Class provided by the Edje file.
  *
  * @since 1.17
@@ -1734,6 +1696,8 @@ EAPI Eina_Iterator *edje_size_class_active_iterator_new(void);
 /**
  * @brief Iterates over all size classes provided by an Edje file.
  *
+ * @param f The mapped edje file.
+ *
  * @return an iterator of Edje_Size_Class provided by the Edje file.
  *
  * @since 1.17
@@ -1803,9 +1767,9 @@ EAPI Eina_Bool         edje_mmap_group_exists(Eina_File *f, const char *glob);
 EAPI Eina_Bool         edje_mmap_3d_has(Eina_File *f, const char *group);
 
 /**
- * @brief Iterates over all the opened Edje file.
+ * @brief Iterates over all the opened Edje files.
  *
- * @return an iterator of Eina_File currently opened Edje file.
+ * @return an iterator of Eina_File for all currently open Edje files.
  *
  * @since 1.14
  */
@@ -1973,6 +1937,8 @@ EAPI void         edje_thaw                       (void);
 /**
  * @brief Sets Edje language.
  *
+ * @param locale The locale specifier.
+ *
  * This function sets the given language.
  *
  * @note: emits signal edje,language,"locale".
@@ -2051,124 +2017,6 @@ EAPI double       edje_transition_duration_factor_get                  (void);
  */
 EAPI void         edje_message_signal_process             (void);
 
-/**
- * @}
- */
-
-/**
- * @defgroup Edje_Perspective Edje Perspective
- * @ingroup Edje_Object_Group
- *
- * @brief Functions that deal with 3D projection of an 2D object.
- *
- * Perspective is a graphical tool that makes objets represented in 2D
- * look like they have a 3D appearance.
- *
- * Edje allows us to use perspective on any edje object. This group of
- * functions deal with the use of perspective, by creating and configuring
- * a perspective object that must set to a edje object or a canvas,
- * affecting all the objects inside that have no particular perspective
- * set already.
- *
- * @{
- */
-
-/**
- * @brief Creates a new perspective in the given canvas.
- *
- * @param e The given canvas (Evas).
- * @return An @ref Edje_Perspective object for this canvas, or @c NULL on errors.
- *
- * This function creates a perspective object that can be set on an Edje
- * object, or globally to all Edje objects on this canvas.
- *
- * @see edje_perspective_set()
- * @see edje_perspective_free()
- */
-EAPI Edje_Perspective       *edje_perspective_new            (Evas *e);
-/**
- * @brief Deletes the given perspective object.
- *
- * @param ps A valid perspective object, or @c NULL.
- *
- * This function will delete the perspective object. If the perspective
- * effect was being applied to any Edje object or part, this effect won't be
- * applied anymore.
- *
- * @see edje_perspective_new()
- */
-EAPI void                    edje_perspective_free           (Edje_Perspective *ps);
-/**
- * @brief Sets up the transform for this perspective object.
- *
- * This sets the parameters of the perspective transformation. X, Y and Z
- * values are used. The px and py points specify the "infinite distance" point
- * in the 3D conversion (where all lines converge to like when artists draw
- * 3D by hand). The @p z0 value specifies the z value at which there is a 1:1
- * mapping between spatial coordinates and screen coordinates. Any points
- * on this z value will not have their X and Y values modified in the transform.
- * Those further away (Z value higher) will shrink into the distance, and
- * those less than this value will expand and become bigger. The @p foc value
- * determines the "focal length" of the camera. This is in reality the distance
- * between the camera lens plane itself (at or closer than this rendering
- * results are undefined) and the "z0" z value. This allows for some "depth"
- * control and @p foc must be greater than 0.
- *
- * @param ps The perspective object
- * @param px The perspective distance X coordinate
- * @param py The perspective distance Y coordinate
- * @param z0 The "0" z plane value
- * @param foc The focal distance
- */
-EAPI void                    edje_perspective_set            (Edje_Perspective *ps, Evas_Coord px, Evas_Coord py, Evas_Coord z0, Evas_Coord foc);
-/**
- * @brief Makes this perspective object be global for its canvas.
- *
- * @param ps The given perspective object
- * @param global @c EINA_TRUE if the perspective should be global, @c
- * EINA_FALSE otherwise.
- *
- * The canvas which this perspective object is being set as global is the one
- * given as argument upon the object creation (the @p evas parameter on the
- * function @c edje_perspective_new(evas) ).
- *
- * There can be only one global perspective object set per canvas, and if
- * a perspective object is set to global when there was already another
- * global perspective set, the old one will be set as non-global.
- *
- * A global perspective just affects a part if its Edje object doesn't have a
- * perspective object set to it, and if the part doesn't point to another
- * part to be used as perspective.
- *
- * @see edje_object_perspective_set()
- * @see edje_perspective_global_get()
- * @see edje_perspective_new()
- */
-EAPI void                    edje_perspective_global_set     (Edje_Perspective *ps, Eina_Bool global);
-/**
- * @brief Gets whether the given perspective object is global or not.
- *
- * @param ps The given perspective object.
- * @return @c EINA_TRUE if this perspective object is global, @c EINA_FALSE
- * otherwise.
- *
- * @see edje_perspective_global_set()
- */
-EAPI Eina_Bool               edje_perspective_global_get     (const Edje_Perspective *ps);
-/**
- * @brief Gets the global perspective object set for this canvas.
- *
- * @param e The given canvas (Evas).
- * @return The perspective object set as global for this canvas. Or @c NULL
- * if there is no global perspective set and on errors.
- *
- * This function will return the perspective object that was set as global
- * with edje_perspective_global_set().
- *
- * @see edje_perspective_global_set()
- * @see edje_perspective_global_get()
- */
-EAPI const Edje_Perspective *edje_evas_global_perspective_get(const Evas *e);
 /**
  * @}
  */
@@ -2262,6 +2110,24 @@ EAPI const char *edje_object_part_object_name_get(const Evas_Object *obj);
  */
 EAPI Eina_Bool edje_3d_object_add(Evas_Object *obj, Eo **root_node, Eo *scene);
 
+/**
+ * @brief Gets seat data passed to callbacks.
+ *
+ * @return The seat data for that callback.
+ *
+ * When a callback is initiated by an input event from a seat, we try to
+ * provide seat information with it.
+ *
+ * Signals fired as programmed responses to these signals will also try
+ * to carry the seat data along.
+ *
+ * This returns an opaque pointer to the seat data.
+ *
+ * @see edje_object_signal_callback_add() for more on Edje signals.
+ * @since 1.21
+ */
+EAPI void *edje_object_signal_callback_seat_data_get(void);
+
 #endif
 
 /**
