@@ -1,7 +1,7 @@
 #include "edje_private.h"
 #include "edje_part_helper.h"
 
-#define MY_CLASS EFL_CANVAS_LAYOUT_EXTERNAL_CLASS
+#define MY_CLASS EFL_CANVAS_LAYOUT_PART_EXTERNAL_CLASS
 
 static void _external_compose(Eo *obj, Edje *ed, const char *part);
 
@@ -15,11 +15,11 @@ _external_compose(Eo *obj, Edje *ed, const char *part)
    efl_composite_attach(obj, ext_obj);
 }
 
-EOLIAN static Efl_Gfx *
-_efl_canvas_layout_external_efl_container_content_get(Eo *obj, void *_pd EINA_UNUSED)
+EOLIAN static Efl_Gfx_Entity *
+_efl_canvas_layout_part_external_efl_content_content_get(const Eo *obj, void *_pd EINA_UNUSED)
 {
    PROXY_DATA_GET(obj, pd);
-   RETURN_VAL(_edje_object_part_external_object_get(pd->ed, pd->part));
+   return _edje_object_part_external_object_get(pd->ed, pd->part);
 }
 
-#include "efl_canvas_layout_external.eo.c"
+#include "efl_canvas_layout_part_external.eo.c"
