@@ -21,7 +21,11 @@ static inline void
 part_get_geometry(Edje_Real_Part *rp, Evas_Coord *w, Evas_Coord *h)
 {
    if (!rp->part->use_alternate_font_metrics)
-     efl_gfx_size_get(rp->object, w, h);
+     {
+        Eina_Size2D sz = efl_gfx_entity_size_get(rp->object);
+        if (w) *w = sz.w;
+        if (h) *h = sz.h;
+     }
    else
      {
         if (w) *w = evas_object_text_horiz_advance_get(rp->object);
@@ -137,9 +141,9 @@ _edje_text_fit_x(Edje *ed, Edje_Real_Part *ep,
    if (ep->part->scale) evas_object_scale_set(ep->object, TO_DOUBLE(sc));
 
    evas_obj_text_ellipsis_set(ep->object, params->type.text->ellipsis);
-   efl_text_properties_font_set(ep->object, font, size);
+   efl_text_font_set(ep->object, font, size);
    efl_text_set(ep->object, text);
-   efl_gfx_size_set(ep->object, sw, sh);
+   efl_gfx_entity_size_set(ep->object, EINA_SIZE2D(sw,  sh));
 
    return text;
 }
@@ -329,25 +333,25 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
    ep->typedata.text->cache.in_size = size;
    if (chosen_desc->text.fit_x && (ep->typedata.text->cache.in_str && eina_stringshare_strlen(ep->typedata.text->cache.in_str) > 0))
      {
-        if (inlined_font) efl_text_properties_font_source_set(ep->object, ed->path);
-        else efl_text_properties_font_source_set(ep->object, NULL);
+        if (inlined_font) efl_text_font_source_set(ep->object, ed->path);
+        else efl_text_font_source_set(ep->object, NULL);
 
-        if (ep->part->scale) efl_canvas_object_scale_set(ep->object, TO_DOUBLE(sc));
+        if (ep->part->scale) efl_gfx_entity_scale_set(ep->object, TO_DOUBLE(sc));
 
         efl_text_set(ep->object, text);
         /* the fit shoult not depend on font size, because it give the differet
          * size calculation. As base font size for calculate fit size I take
          * 10 (ten), because this value used for calculate fit by Y below */
-        efl_text_properties_font_set(ep->object, font, 10);
+        efl_text_font_set(ep->object, font, 10);
         part_get_geometry(ep, &tw, &th);
 
         size = (10 * sw) / tw;
-        efl_text_properties_font_set(ep->object, font, size);
+        efl_text_font_set(ep->object, font, size);
         part_get_geometry(ep, &tw, &th);
         while ((tw > sw) && (size > 1))
           {
              size--;
-             efl_text_properties_font_set(ep->object, font, size);
+             efl_text_font_set(ep->object, font, size);
              part_get_geometry(ep, &tw, &th);
           }
      }
@@ -359,12 +363,12 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
          */
         if (!chosen_desc->text.fit_x) size = sh;
 
-           if (inlined_font) efl_text_properties_font_source_set(ep->object, ed->path);
-           else efl_text_properties_font_source_set(ep->object, NULL);
+           if (inlined_font) efl_text_font_source_set(ep->object, ed->path);
+           else efl_text_font_source_set(ep->object, NULL);
 
-           if (ep->part->scale) efl_canvas_object_scale_set(ep->object, TO_DOUBLE(sc));
+           if (ep->part->scale) efl_gfx_entity_scale_set(ep->object, TO_DOUBLE(sc));
 
-           efl_text_properties_font_set(ep->object, font, size);
+           efl_text_font_set(ep->object, font, size);
            efl_text_set(ep->object, text);
         part_get_geometry(ep, &tw, &th);
 
@@ -382,11 +386,11 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
                   size += dif;
                   if (size <= 0) break;
 
-                  if (inlined_font) efl_text_properties_font_source_set(ep->object, ed->path);
-                  else efl_text_properties_font_source_set(ep->object, NULL);
+                  if (inlined_font) efl_text_font_source_set(ep->object, ed->path);
+                  else efl_text_font_source_set(ep->object, NULL);
 
-                  if (ep->part->scale) efl_canvas_object_scale_set(ep->object, TO_DOUBLE(sc));
-                  efl_text_properties_font_set(ep->object, font, size);
+                  if (ep->part->scale) efl_gfx_entity_scale_set(ep->object, TO_DOUBLE(sc));
+                  efl_text_font_set(ep->object, font, size);
 
                   part_get_geometry(ep, &tw, &th);
                   if ((size > 0) && (th == 0)) break;
@@ -397,8 +401,8 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
           {
              int current;
 
-             if (ep->part->scale) efl_canvas_object_scale_set(ep->object, TO_DOUBLE(sc));
-             efl_text_properties_font_set(ep->object, font, 10);
+             if (ep->part->scale) efl_gfx_entity_scale_set(ep->object, TO_DOUBLE(sc));
+             efl_text_font_set(ep->object, font, 10);
 
              part_get_geometry(ep, &tw, &th);
 
@@ -419,8 +423,8 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
                     {
                        current = (top + bottom) / 2;
 
-                       if (ep->part->scale) efl_canvas_object_scale_set(ep->object, TO_DOUBLE(sc));
-                       efl_text_properties_font_set(ep->object, font, current);
+                       if (ep->part->scale) efl_gfx_entity_scale_set(ep->object, TO_DOUBLE(sc));
+                       efl_text_font_set(ep->object, font, current);
 
                        part_get_geometry(ep, &tw, &th);
 
@@ -435,8 +439,8 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
                {
                   current++;
 
-                  if (ep->part->scale) efl_canvas_object_scale_set(ep->object, TO_DOUBLE(sc));
-                  efl_text_properties_font_set(ep->object, font, current);
+                  if (ep->part->scale) efl_gfx_entity_scale_set(ep->object, TO_DOUBLE(sc));
+                  efl_text_font_set(ep->object, font, current);
 
                   part_get_geometry(ep, &tw, &th);
                } while (th <= sh);
@@ -456,8 +460,8 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
    /* Handle ellipsis */
    if (!chosen_desc->text.min_x)
      {
-        if (inlined_font) efl_text_properties_font_source_set(ep->object, ed->path);
-        else efl_text_properties_font_source_set(ep->object, NULL);
+        if (inlined_font) efl_text_font_source_set(ep->object, ed->path);
+        else efl_text_font_source_set(ep->object, NULL);
 
         text = _edje_text_fit_x(ed, ep, params, chosen_desc,
                                 text, font, size,
@@ -481,12 +485,12 @@ _edje_text_recalc_apply(Edje *ed, Edje_Real_Part *ep,
    ep->typedata.text->cache.fit_y = chosen_desc->text.fit_y;
 arrange_text:
 
-   if (inlined_font) efl_text_properties_font_source_set(ep->object, ed->path);
-   else efl_text_properties_font_source_set(ep->object, NULL);
+   if (inlined_font) efl_text_font_source_set(ep->object, ed->path);
+   else efl_text_font_source_set(ep->object, NULL);
 
-   if (ep->part->scale) efl_canvas_object_scale_set(ep->object, TO_DOUBLE(sc));
+   if (ep->part->scale) efl_gfx_entity_scale_set(ep->object, TO_DOUBLE(sc));
 
-   efl_text_properties_font_set(ep->object, font, size);
+   efl_text_font_set(ep->object, font, size);
    efl_text_set(ep->object, text);
    part_get_geometry(ep, &tw, &th);
 
@@ -515,8 +519,11 @@ arrange_text:
 
    if (!calc_only)
      {
-        efl_gfx_position_set(ep->object, ed->x + TO_INT(params->eval.x) + ep->typedata.text->offset.x, ed->y + TO_INT(params->eval.y) + ep->typedata.text->offset.y);
-        efl_gfx_visible_set(ep->object, params->visible);
+        Eina_Position2D pos;
+        pos.x = ed->x + TO_INT(params->eval.x) + ep->typedata.text->offset.x;
+        pos.y = ed->y + TO_INT(params->eval.y) + ep->typedata.text->offset.y;
+        efl_gfx_entity_position_set(ep->object, pos);
+        efl_gfx_entity_visible_set(ep->object, params->visible);
      }
 
    {
