@@ -16,6 +16,7 @@
 #include <Ecore.h>
 #include <Ecore_File.h>
 #include <Ecore_Ipc.h>
+#include <Ecore_Con.h>
 
 /* define macros and variable for using the eina logging system  */
 #define EFREET_MODULE_LOG_DOM _efreet_cache_log_dom
@@ -24,7 +25,7 @@ static int _efreet_cache_log_dom = -1;
 #include "Efreet.h"
 #include "efreet_private.h"
 #include "efreet_cache_private.h"
-
+#include "../../static_libs/buildsystem/buildsystem.h"
 #define NON_EXISTING (void *)-1
 
 typedef struct _Efreet_Old_Cache Efreet_Old_Cache;
@@ -36,7 +37,6 @@ struct _Efreet_Old_Cache
 };
 
 static Ecore_Ipc_Server    *ipc = NULL;
-static Eina_Prefix         *pfx = NULL;
 static Ecore_Event_Handler *hnd_add = NULL;
 static Ecore_Event_Handler *hnd_del = NULL;
 static Ecore_Event_Handler *hnd_data = NULL;
@@ -99,6 +99,9 @@ static void icon_cache_update_free(void *data, void *ev);
 
 static void *hash_array_string_add(void *hash, const char *key, void *data);
 
+static Eina_Bool disable_cache;
+static Eina_Bool run_in_tree;
+
 EAPI int EFREET_EVENT_ICON_CACHE_UPDATE = 0;
 EAPI int EFREET_EVENT_DESKTOP_CACHE_UPDATE = 0;
 EAPI int EFREET_EVENT_DESKTOP_CACHE_BUILD = 0;
@@ -114,8 +117,10 @@ _ipc_launch(void)
    char buf[PATH_MAX];
    int num = 0;
 
-   if (!pfx) snprintf(buf, sizeof(buf), "efreetd");
-   else snprintf(buf, sizeof(buf), "%s/efreetd", eina_prefix_bin_get(pfx));
+   if (run_in_tree)
+     bs_binary_get(buf, sizeof(buf), "efreet", "efreetd");
+   else
+     snprintf(buf, sizeof(buf), PACKAGE_BIN_DIR "/efreetd");
    ecore_exe_run(buf, NULL);
    while ((!ipc) && (num < 500))
      {
@@ -162,11 +167,14 @@ _cb_server_del(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
    double t;
    IPC_HEAD(Del);
    ipc = NULL;
+
+   if (disable_cache) return ECORE_CALLBACK_RENEW;
    if (reconnect_count > 10)
      {
+        char *address = ecore_con_local_path_new(EINA_FALSE, "efreetd", 0);
         reconnect_timer = NULL;
-        ERR("efreetd connection failed 10 times! check for stale socket files in %s/.ecore/efreetd",
-          efreet_runtime_dir_get());
+        ERR("efreetd connection failed 10 times! check for stale socket file at %s", address);
+        free(address);
         return EINA_FALSE;
      }
    t = ecore_time_get();
@@ -188,7 +196,9 @@ _efreet_cache_reset()
    int len = 0;
 
    if (ipc) ecore_ipc_server_del(ipc);
-   ipc = ecore_ipc_server_connect(ECORE_IPC_LOCAL_USER, "efreetd", 0, NULL);
+   ipc = NULL;
+   if (!disable_cache)
+     ipc = ecore_ipc_server_connect(ECORE_IPC_LOCAL_USER, "efreetd", 0, NULL);
    if (!ipc) return;
 
    s = efreet_language_get();
@@ -299,12 +309,11 @@ efreet_cache_init(void)
         ERR("Failed to create directory '%s'", buf);
     }
 
-    if (EFREET_EVENT_ICON_CACHE_UPDATE == 0)
-      {
-         EFREET_EVENT_ICON_CACHE_UPDATE = ecore_event_type_new();
-         EFREET_EVENT_DESKTOP_CACHE_UPDATE = ecore_event_type_new();
-         EFREET_EVENT_DESKTOP_CACHE_BUILD = ecore_event_type_new();
-      }
+    run_in_tree = !!getenv("EFL_RUN_IN_TREE");
+
+    EFREET_EVENT_ICON_CACHE_UPDATE = ecore_event_type_new();
+    EFREET_EVENT_DESKTOP_CACHE_UPDATE = ecore_event_type_new();
+    EFREET_EVENT_DESKTOP_CACHE_BUILD = ecore_event_type_new();
 
     themes = eina_hash_string_superfast_new(EINA_FREE_CB(efreet_cache_icon_theme_free));
     icons = eina_hash_string_superfast_new(EINA_FREE_CB(efreet_cache_icon_free));
@@ -316,11 +325,13 @@ efreet_cache_init(void)
 
     if (efreet_cache_update)
     {
-       pfx = eina_prefix_new
-         (NULL, efreet_icon_cache_file, "EFREET", "efreet", "checkme",
-          PACKAGE_BIN_DIR, PACKAGE_LIB_DIR, PACKAGE_DATA_DIR, PACKAGE_DATA_DIR);
-       ipc = ecore_ipc_server_connect(ECORE_IPC_LOCAL_USER, "efreetd", 0, NULL);
-       if (!ipc) _ipc_launch();
+       if (disable_cache)
+         ipc = NULL;
+       else
+         {
+            ipc = ecore_ipc_server_connect(ECORE_IPC_LOCAL_USER, "efreetd", 0, NULL);
+            if (!ipc) _ipc_launch();
+         }
        if (ipc)
          {
             const char *s;
@@ -340,7 +351,8 @@ efreet_cache_init(void)
          {
             Efreet_Event_Cache_Update *ev;
 
-            WRN("Can't contact efreetd daemon for desktop/icon etc. changes");
+            if (!disable_cache)
+              WRN("Can't contact efreetd daemon for desktop/icon etc. changes");
             ev = NEW(Efreet_Event_Cache_Update, 1);
             if (ev)
               {
@@ -417,7 +429,6 @@ efreet_cache_shutdown(void)
     IF_RELEASE(util_cache_file);
 
    if (ipc) ecore_ipc_server_del(ipc);
-   if (pfx) eina_prefix_free(pfx);
    if (hnd_add) ecore_event_handler_del(hnd_add);
    if (hnd_del) ecore_event_handler_del(hnd_del);
    if (hnd_data) ecore_event_handler_del(hnd_data);
@@ -425,7 +436,6 @@ efreet_cache_shutdown(void)
    ecore_ipc_shutdown();
 
    ipc = NULL;
-   pfx = NULL;
    hnd_add = NULL;
    hnd_del = NULL;
    hnd_data = NULL;
@@ -1343,3 +1353,31 @@ hash_array_string_add(void *hash, const char *key, void *data)
     eina_hash_add(hash, key, data);
     return hash;
 }
+
+EAPI void
+efreet_cache_disable(void)
+{
+   Eina_Bool prev = disable_cache;
+
+   disable_cache = EINA_TRUE;
+
+   if (_efreet_cache_log_dom < 0) return; // not yet initialized
+   if (prev == disable_cache) return; // same value
+   if (ipc)
+     {
+        ecore_ipc_server_del(ipc);
+        ipc = NULL;
+     }
+}
+
+EAPI void
+efreet_cache_enable(void)
+{
+   Eina_Bool prev = disable_cache;
+
+   disable_cache = EINA_FALSE;
+
+   if (_efreet_cache_log_dom < 0) return; // not yet initialized
+   if (prev == disable_cache) return; // same value
+   if (!ipc) _ipc_launch();
+}
