@@ -23,14 +23,11 @@
 #include <string.h>
 #include <stdint.h>
 #include <stdio.h>
-#ifdef HAVE_DIRENT_H
-# include <dirent.h>
-#endif
 #include <unistd.h>
 #include <fcntl.h>
 #include <errno.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
@@ -477,18 +474,16 @@ eina_file_dup(const Eina_File *f)
      {
         EINA_FILE_MAGIC_CHECK(f, NULL);
         eina_lock_take(&file->lock);
-        if (file->virtual)
+
+        // For ease of use and safety of the API, if you dup a virtualized file, we prefer to make a copy
+        if (file->virtual && !file->copied)
           {
-             // For ease of use and safety of the API, if you dup a virtualized file, we prefer to make a copy
-             if (file->global_map != (void*)(file->filename + strlen(file->filename) + 1))
-               {
-                  Eina_File *r;
+             Eina_File *r;
 
-                  r = eina_file_virtualize(file->filename, file->global_map, file->length, EINA_TRUE);
-                  eina_lock_release(&file->lock);
+             r = eina_file_virtualize(file->filename, file->global_map, file->length, EINA_TRUE);
+             eina_lock_release(&file->lock);
 
-                  return r;
-               }
+             return r;
           }
         file->refcount++;
         eina_lock_release(&file->lock);
@@ -509,7 +504,7 @@ eina_file_clean_close(Eina_File *file)
 
    // Final death
    EINA_MAGIC_SET(file, 0);
-   free(file);   
+   free(file);
 }
 
 EAPI void
@@ -518,6 +513,7 @@ eina_file_close(Eina_File *file)
    Eina_Bool leave = EINA_TRUE;
    unsigned int key;
 
+   if (!file) return ;
    EINA_FILE_MAGIC_CHECK(file);
 
    eina_lock_take(&_eina_file_lock_cache);
