@@ -330,14 +330,13 @@ _eina_file_win32_direct_ls_iterator_next(Eina_File_Direct_Iterator *it, void **d
 
    if (attr & FILE_ATTRIBUTE_DIRECTORY)
      it->info.type = EINA_FILE_DIR;
-   else if (attr & FILE_ATTRIBUTE_REPARSE_POINT)
-     it->info.type = EINA_FILE_LNK;
    else if (attr & (FILE_ATTRIBUTE_ARCHIVE |
                     FILE_ATTRIBUTE_COMPRESSED |
                     FILE_ATTRIBUTE_HIDDEN |
                     FILE_ATTRIBUTE_NORMAL |
                     FILE_ATTRIBUTE_SPARSE_FILE |
-                    FILE_ATTRIBUTE_TEMPORARY))
+                    FILE_ATTRIBUTE_TEMPORARY |
+                    FILE_ATTRIBUTE_REPARSE_POINT))
      it->info.type = EINA_FILE_REG;
    else
      it->info.type = EINA_FILE_UNKNOWN;
@@ -385,7 +384,7 @@ eina_file_real_close(Eina_File *file)
 
    if (file->handle != INVALID_HANDLE_VALUE)
      {
-        if (file->global_map != MAP_FAILED)
+        if (!file->copied && file->global_map != MAP_FAILED)
           UnmapViewOfFile(file->global_map);
         CloseHandle(file->handle);
      }
@@ -547,7 +546,7 @@ eina_file_split(char *path)
      {
         length = current - path;
 
-        if (length <= 0)
+        if (length == 0)
            continue;
 
         eina_array_push(ea, path);
@@ -737,16 +736,9 @@ eina_file_open(const char *path, Eina_Bool shared)
 
    if (handle == INVALID_HANDLE_VALUE)
      {
-        char *msg;
-
-        msg = evil_last_error_get();
-        if (msg)
-          {
-             WRN("eina_file_open() failed with file %s: %s", filename, msg);
-             free(msg);
-          }
-        else
-          goto free_file;
+       WRN("eina_file_open() failed with file %s: %s",
+           filename, evil_last_error_get());
+       goto free_file;
      }
 
    if (!GetFileAttributesEx(filename, GetFileExInfoStandard, &fad))
@@ -812,7 +804,7 @@ eina_file_open(const char *path, Eina_Bool shared)
  close_handle:
    CloseHandle(handle);
  free_file:
-   ERR("Could not open file [%s].", filename);
+   WRN("Could not open file [%s].", filename);
    eina_stringshare_del(filename);
 
    return NULL;
@@ -849,9 +841,10 @@ eina_file_unlink(const char *pathname)
           }
      }
 
-   if ( unlink(unlink_path) >= 0) r = EINA_TRUE;
+   if (unlink(unlink_path) >= 0) r = EINA_TRUE;
    eina_stringshare_del(unlink_path);
 
+ finish:
    return r;
 }
 
@@ -1067,8 +1060,7 @@ eina_file_statat(void *container EINA_UNUSED, Eina_File_Direct_Info *info, Eina_
 
    if (stat64(info->path, &buf))
      {
-        if (info->type != EINA_FILE_LNK)
-          info->type = EINA_FILE_UNKNOWN;
+        info->type = EINA_FILE_UNKNOWN;
         return -1;
      }
 
