@@ -26,10 +26,6 @@
 #include <stdint.h>
 #include <string.h>
 
-#ifdef _MSC_VER
-# include <Evil.h>
-#endif
-
 #include "eina_config.h"
 #include "eina_private.h"
 #include "eina_rbtree.h"
@@ -143,7 +139,7 @@ struct _Eina_Hash_Each
 
 #undef get16bits
 #if (defined(__GNUC__) && defined(__i386__)) || defined(__WATCOMC__) \
-  || defined(_MSC_VER) || defined (__BORLANDC__) || defined (__TURBOC__)
+  || defined (__BORLANDC__) || defined (__TURBOC__)
 # define get16bits(d) (*((const uint16_t *)(d)))
 #endif
 
@@ -467,6 +463,13 @@ _eina_hash_del_by_key_hash(Eina_Hash *hash,
    return _eina_hash_del_by_hash_el(hash, hash_element, hash_head, key_hash);
 }
 
+static void
+_eina_hash_compute(const Eina_Hash *hash, const void *key, int *key_length, int *key_hash)
+{
+   *key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
+   *key_hash = hash->key_hash_cb(key, *key_length);
+}
+
 static Eina_Bool
 _eina_hash_del_by_key(Eina_Hash *hash, const void *key, const void *data)
 {
@@ -479,15 +482,14 @@ _eina_hash_del_by_key(Eina_Hash *hash, const void *key, const void *data)
    if (!hash->buckets)
      return EINA_FALSE;
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   key_hash = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
    return _eina_hash_del_by_key_hash(hash, key, key_length, key_hash, data);
 }
 
 static int
 _eina_stringshared_hash(const void *key, int key_length EINA_UNUSED)
 {
-   return eina_hash_superfast(&key, sizeof (void*));
+   return eina_hash_superfast((const void*) &key, sizeof (void*));
 }
 
 static unsigned int
@@ -927,7 +929,7 @@ eina_hash_direct_add_by_hash(Eina_Hash *hash,
 EAPI Eina_Bool
 eina_hash_add(Eina_Hash *hash, const void *key, const void *data)
 {
-   unsigned int key_length;
+   int key_length;
    int key_hash;
 
    EINA_MAGIC_CHECK_HASH(hash);
@@ -936,8 +938,7 @@ eina_hash_add(Eina_Hash *hash, const void *key, const void *data)
    EINA_SAFETY_ON_NULL_RETURN_VAL(key, EINA_FALSE);
    EINA_SAFETY_ON_NULL_RETURN_VAL(data, EINA_FALSE);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   key_hash = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
    return eina_hash_add_alloc_by_hash(hash, key, key_length, key_length, key_hash, data);
 }
@@ -954,8 +955,7 @@ eina_hash_direct_add(Eina_Hash *hash, const void *key, const void *data)
    EINA_SAFETY_ON_NULL_RETURN_VAL(data, EINA_FALSE);
    EINA_MAGIC_CHECK_HASH(hash);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   key_hash = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
    return eina_hash_add_alloc_by_hash(hash, key, key_length, 0, key_hash, data);
 }
@@ -1068,7 +1068,7 @@ EAPI void *
 eina_hash_find(const Eina_Hash *hash, const void *key)
 {
    int key_length;
-   int hash_num;
+   int key_hash;
 
    if (!hash)
      return NULL;
@@ -1077,10 +1077,9 @@ eina_hash_find(const Eina_Hash *hash, const void *key)
    EINA_SAFETY_ON_NULL_RETURN_VAL(key, NULL);
    EINA_MAGIC_CHECK_HASH(hash);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   hash_num = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
-   return eina_hash_find_by_hash(hash, key, key_length, hash_num);
+   return eina_hash_find_by_hash(hash, key, key_length, key_hash);
 }
 
 EAPI void *
@@ -1128,8 +1127,7 @@ eina_hash_set(Eina_Hash *hash, const void *key, const void *data)
    EINA_SAFETY_ON_NULL_RETURN_VAL(key, NULL);
    EINA_MAGIC_CHECK_HASH(hash);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   key_hash = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
    tuple.key = key;
    tuple.key_length = key_length;
@@ -1172,7 +1170,7 @@ EAPI void *
 eina_hash_modify(Eina_Hash *hash, const void *key, const void *data)
 {
    int key_length;
-   int hash_num;
+   int key_hash;
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(hash, NULL);
    EINA_SAFETY_ON_NULL_RETURN_VAL(hash->key_hash_cb, NULL);
@@ -1180,10 +1178,9 @@ eina_hash_modify(Eina_Hash *hash, const void *key, const void *data)
    EINA_SAFETY_ON_NULL_RETURN_VAL(data, NULL);
    EINA_MAGIC_CHECK_HASH(hash);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   hash_num = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
-   return eina_hash_modify_by_hash(hash, key, key_length, hash_num, data);
+   return eina_hash_modify_by_hash(hash, key, key_length, key_hash, data);
 }
 
 EAPI Eina_Bool
@@ -1392,8 +1389,7 @@ eina_hash_list_append(Eina_Hash *hash, const void *key, const void *data)
    EINA_SAFETY_ON_NULL_RETURN(data);
    EINA_MAGIC_CHECK_HASH(hash);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   key_hash = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
    tuple.key = key;
    tuple.key_length = key_length;
@@ -1426,8 +1422,7 @@ eina_hash_list_prepend(Eina_Hash *hash, const void *key, const void *data)
    EINA_SAFETY_ON_NULL_RETURN(data);
    EINA_MAGIC_CHECK_HASH(hash);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   key_hash = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
    tuple.key = key;
    tuple.key_length = key_length;
@@ -1460,8 +1455,7 @@ eina_hash_list_remove(Eina_Hash *hash, const void *key, const void *data)
    EINA_SAFETY_ON_NULL_RETURN(data);
    EINA_MAGIC_CHECK_HASH(hash);
 
-   key_length = hash->key_length_cb ? hash->key_length_cb(key) : 0;
-   key_hash = hash->key_hash_cb(key, key_length);
+   _eina_hash_compute(hash, key, &key_length, &key_hash);
 
    tuple.key = key;
    tuple.key_length = key_length;
