@@ -62,7 +62,7 @@
 #include <string.h>
 #include <time.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
