@@ -23,12 +23,6 @@
 #include <stdio.h>
 #include <time.h>
 
-#ifdef EFL_HAVE_WIN32_THREADS
-# define WIN32_LEAN_AND_MEAN
-# include <windows.h>
-# undef WIN32_LEAN_AND_MEAN
-#endif
-
 #ifdef EFL_HAVE_THREADS
 # ifdef HAVE_SYS_TYPES_H
 #  include <sys/types.h>
@@ -74,6 +68,7 @@
 #include "eina_evlog.h"
 #include "eina_freeq.h"
 #include "eina_slstr.h"
+#include "eina_vpath.h"
 
 /*============================================================================*
 *                                  Local                                     *
@@ -103,6 +98,7 @@ static int _eina_log_dom = -1;
 
 EAPI Eina_Bool _eina_threads_activated = EINA_FALSE;
 EAPI Eina_Error EINA_ERROR_NOT_MAIN_LOOP = 0;
+EAPI Eina_Error EINA_ERROR_NOT_IMPLEMENTED = 0;
 EAPI unsigned int eina_seed = 0;
 
 #ifdef EFL_HAVE_THREADS
@@ -117,6 +113,7 @@ static int _mt_enabled = 0;
 EAPI int _eina_threads_debug = 0;
 EAPI pthread_mutex_t _eina_tracking_lock;
 EAPI Eina_Inlist *_eina_tracking = NULL;
+extern Eina_Lock       _sysmon_lock;
 #endif
 
 /* place module init/shutdown functions here to avoid other modules
@@ -159,6 +156,8 @@ EAPI Eina_Inlist *_eina_tracking = NULL;
    S(file);
    S(safepointer);
    S(slstr);
+   S(promise);
+   S(vpath);
 #undef S
 
 struct eina_desc_setup
@@ -171,6 +170,9 @@ struct eina_desc_setup
 static const struct eina_desc_setup _eina_desc_setup[] = {
 #define S(x) {# x, eina_ ## x ## _init, eina_ ## x ## _shutdown}
    /* log is a special case as it needs printf */
+   S(module),
+   S(mempool),
+   S(list),
    S(debug),
    S(evlog),
    S(stringshare),
@@ -181,9 +183,6 @@ static const struct eina_desc_setup _eina_desc_setup[] = {
    S(accessor),
    S(inarray),
    S(array),
-   S(module),
-   S(mempool),
-   S(list),
    S(binshare),
    S(ustringshare),
    S(matrixsparse),
@@ -205,6 +204,8 @@ static const struct eina_desc_setup _eina_desc_setup[] = {
    S(file),
    S(safepointer),
    S(slstr),
+   S(promise),
+   S(vpath),
 #undef S
 };
 static const size_t _eina_desc_setup_len = sizeof(_eina_desc_setup) /
@@ -224,6 +225,39 @@ _eina_shutdown_from_desc(const struct eina_desc_setup *itr)
    eina_log_shutdown();
 }
 
+static void
+_eina_threads_do_shutdown(void)
+{
+#ifdef EINA_HAVE_DEBUG_THREADS
+   const Eina_Lock *lk;
+
+   pthread_mutex_lock(&_eina_tracking_lock);
+   if (_eina_tracking)
+     {
+       if (((Eina_Lock*)_eina_tracking != (&_sysmon_lock)) || (_eina_tracking->next))
+         {
+            fprintf(stderr, "*************************\n");
+            fprintf(stderr, "* The IMPOSSIBLE HAPPEN *\n");
+            fprintf(stderr, "* LOCK STILL TAKEN :    *\n");
+            fprintf(stderr, "*************************\n");
+            EINA_INLIST_FOREACH(_eina_tracking, lk)
+              {
+                 fprintf(stderr, "=======\n");
+                 eina_lock_debug(lk);
+              }
+            fprintf(stderr, "*************************\n");
+            abort();
+         }
+     }
+   pthread_mutex_unlock(&_eina_tracking_lock);
+#endif
+
+   eina_share_common_threads_shutdown();
+   eina_log_threads_shutdown();
+
+   _eina_threads_activated = EINA_FALSE;
+}
+
 /**
  * @endcond
  */
@@ -304,6 +338,9 @@ eina_init(void)
 
    eina_cpu_count_internal();
 
+   EINA_ERROR_NOT_MAIN_LOOP = eina_error_msg_static_register("Not in main loop.");
+   EINA_ERROR_NOT_IMPLEMENTED = eina_error_msg_static_register("Functionality not implemented.");
+
    eina_log_timing(_eina_log_dom, EINA_LOG_STATE_STOP, EINA_LOG_STATE_INIT);
 
    _eina_main_count = 1;
@@ -328,6 +365,8 @@ eina_shutdown(void)
 
         _eina_shutdown_from_desc(_eina_desc_setup + _eina_desc_setup_len);
 
+        if (_eina_threads_activated && (!_eina_main_thread_count))
+          _eina_threads_do_shutdown();
 #ifdef EINA_HAVE_DEBUG_THREADS
 	pthread_mutex_destroy(&_eina_tracking_lock);
 #endif
@@ -378,8 +417,6 @@ eina_threads_shutdown(void)
    int ret;
 
 #ifdef EINA_HAVE_DEBUG_THREADS
-   const Eina_Lock *lk;
-
    assert(pthread_equal(_eina_main_loop, pthread_self()));
    assert(_eina_main_thread_count > 0);
 #endif
@@ -388,29 +425,8 @@ eina_threads_shutdown(void)
    if(_eina_main_thread_count > 0)
      return ret;
 
-#ifdef EINA_HAVE_DEBUG_THREADS
-   pthread_mutex_lock(&_eina_tracking_lock);
-   if (_eina_tracking)
-     {
-       fprintf(stderr, "*************************\n");
-       fprintf(stderr, "* The IMPOSSIBLE HAPPEN *\n");
-       fprintf(stderr, "* LOCK STILL TAKEN :    *\n");
-       fprintf(stderr, "*************************\n");
-       EINA_INLIST_FOREACH(_eina_tracking, lk)
-	 {
-            fprintf(stderr, "=======\n");
-            eina_lock_debug(lk);
-	 }
-       fprintf(stderr, "*************************\n");
-       abort();
-     }
-   pthread_mutex_unlock(&_eina_tracking_lock);
-#endif
-
-   eina_share_common_threads_shutdown();
-   eina_log_threads_shutdown();
-
-   _eina_threads_activated = EINA_FALSE;
+   if (!_eina_main_count)
+     _eina_threads_do_shutdown();
 
    return ret;
 #else
