@@ -26,7 +26,7 @@
 #include <string.h>
 #include <ctype.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
