@@ -2,7 +2,8 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
@@ -11,8 +12,7 @@
 
 #define MY_CLASS EFL_UI_CLOCK_CLASS
 
-#define MY_CLASS_NAME "Efl_Ui_Clock"
-#define MY_CLASS_NAME_LEGACY "efl_ui_clock"
+#define MY_CLASS_NAME "Efl.Ui.Clock"
 
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
@@ -30,10 +30,8 @@
  * EFL_UI_CLOCK_TYPE_COUNT are in the valid range, and must get in the
  * place of "%d".
  */
-#define EDC_CLOCK_FOCUSIN_SIG_STR   "elm,action,focus"
-#define EDC_CLOCK_FOCUSOUT_SIG_STR  "elm,action,unfocus"
-#define EDC_PART_FIELD_STR             "field%d"
-#define EDC_PART_SEPARATOR_STR         "separator%d"
+#define EDC_PART_FIELD_STR             "efl.field%d"
+#define EDC_PART_SEPARATOR_STR         "efl.separator%d"
 #define EDC_PART_FIELD_ENABLE_SIG_STR  "field%d,enable"
 #define EDC_PART_FIELD_DISABLE_SIG_STR "field%d,disable"
 
@@ -66,7 +64,7 @@ static Format_Map mapping[EFL_UI_CLOCK_TYPE_COUNT] = {
 
 static const char *multifield_formats = "cxXrRTDF";
 static const char *ignore_separators = "()";
-static Clock_Mod_Api *dt_mod = NULL;
+static const char *ignore_extensions = "E0_-O^#";
 
 static const char SIG_CHANGED[] = "changed";
 static const Evas_Smart_Cb_Description _smart_callbacks[] = {
@@ -78,27 +76,49 @@ static const Evas_Smart_Cb_Description _smart_callbacks[] = {
    {NULL, NULL}
 };
 
+static void _part_name_snprintf(char *buffer, int buffer_size,
+   const Evas_Object *obj, const char *template, int n)
+{
+   snprintf(buffer, buffer_size, template, n);
+   if (edje_object_part_exists (obj, buffer)) return;
+   // Try 'elm' prefix instead of 'efl'
+   buffer[0] = 'e';
+   buffer[1] = 'l';
+   buffer[2] = 'm';
+   if (edje_object_part_exists (obj, buffer)) return;
+   // Skip the namespace prefix "elm." which was not present
+   // in previous versions
+   snprintf(buffer, buffer_size, template + 4, n);
+}
+
+static Elm_Module *
+_dt_mod_find(void)
+{
+   static int tried_fallback = 0;
+   Elm_Module *mod = _elm_module_find_as("clock/api");
+
+   if (mod) return mod;
+   if (!tried_fallback &&
+       (!_elm_config->modules || !strstr(_elm_config->modules, "clock/api")))
+     {
+        // See also _config_update(): we hardcode here the default module
+        ERR("Elementary config does not contain the required module "
+            "name for the clock widget! Verify your installation.");
+        _elm_module_add("clock_input_ctxpopup", "clock/api");
+        mod = _elm_module_find_as("clock/api");
+        tried_fallback = EINA_TRUE;
+     }
+   return mod;
+}
+
 static Clock_Mod_Api *
 _dt_mod_init()
 {
-   static int tried_fallback = 0;
-   Elm_Module *mod = NULL;
-
-   if (!(mod = _elm_module_find_as("clock/api")))
-     {
-        if (!tried_fallback &&
-            (!_elm_config->modules || !strstr(_elm_config->modules, "clock/api")))
-          {
-             // See also _config_update(): we hardcode here the default module
-             ERR("Elementary config does not contain the required module "
-                 "name for the clock widget! Verify your installation.");
-             _elm_module_add("clock_input_ctxpopup", "clock/api");
-             mod = _elm_module_find_as("clock/api");
-             tried_fallback = EINA_TRUE;
-          }
-        if (!mod) return NULL;
-     }
+   Elm_Module *mod;
 
+   mod = _dt_mod_find();
+   if (!mod) return NULL;
+   if (mod->api) return mod->api;
    mod->api = malloc(sizeof(Clock_Mod_Api));
    if (!mod->api) return NULL;
 
@@ -121,9 +141,11 @@ _field_list_display(Evas_Object *obj)
 {
    Clock_Field *field;
    unsigned int idx = 0;
+   Clock_Mod_Api *dt_mod;
 
    EFL_UI_CLOCK_DATA_GET(obj, sd);
 
+   dt_mod = _dt_mod_init();
    if (!dt_mod || !dt_mod->field_value_display) return;
 
    for (idx = 0; idx < EFL_UI_CLOCK_TYPE_COUNT; idx++)
@@ -143,7 +165,7 @@ _expanded_fmt_str_get(char ch)
    switch (ch)
      {
       case 'c':
-#if defined(HAVE_LANGINFO_H) || defined (HAVE_EVIL)
+#if defined(HAVE_LANGINFO_H) || defined (_WIN32)
         exp_fmt = nl_langinfo(D_T_FMT);
 #else
         exp_fmt = "";
@@ -151,7 +173,7 @@ _expanded_fmt_str_get(char ch)
         break;
 
       case 'x':
-#if defined(HAVE_LANGINFO_H) || defined (HAVE_EVIL)
+#if defined(HAVE_LANGINFO_H) || defined (_WIN32)
         exp_fmt = nl_langinfo(D_FMT);
 #else
         exp_fmt = "";
@@ -159,7 +181,7 @@ _expanded_fmt_str_get(char ch)
         break;
 
       case 'X':
-#if defined(HAVE_LANGINFO_H) || defined (HAVE_EVIL)
+#if defined(HAVE_LANGINFO_H) || defined (_WIN32)
         exp_fmt = nl_langinfo(T_FMT);
 #else
         exp_fmt = "";
@@ -167,7 +189,7 @@ _expanded_fmt_str_get(char ch)
         break;
 
       case 'r':
-#if defined(HAVE_LANGINFO_H) || defined (HAVE_EVIL)
+#if defined(HAVE_LANGINFO_H) || defined (_WIN32)
         exp_fmt = nl_langinfo(T_FMT_AMPM);
 #else
         exp_fmt = "";
@@ -202,33 +224,39 @@ static void
 _expand_format(char *dt_fmt)
 {
    char *ptr, *expanded_fmt, ch;
-   unsigned int idx = 0, len = 0;
+   unsigned int idx, len = 0;
    char buf[EFL_UI_CLOCK_MAX_FORMAT_LEN] = {0, };
-   Eina_Bool fmt_char = EINA_FALSE;
+   Eina_Bool fmt_char, fmt_expanded;
 
-   ptr = dt_fmt;
-   while ((ch = *ptr))
-     {
-        if ((fmt_char) && (strchr(multifield_formats, ch)))
-          {
-             /* replace the multi-field format characters with
-              * corresponding expanded format */
-             expanded_fmt = _expanded_fmt_str_get(ch);
-             len = strlen(expanded_fmt);
-             buf[--idx] = 0;
-             strncat(buf, expanded_fmt, len);
-             idx += len;
-          }
-        else buf[idx++] = ch;
+   do {
+     idx = 0;
+     fmt_char = EINA_FALSE;
+     fmt_expanded = EINA_FALSE;
+     ptr = dt_fmt;
+     while ((ch = *ptr))
+       {
+          if ((fmt_char) && (strchr(multifield_formats, ch)))
+            {
+               /* replace the multi-field format characters with
+                * corresponding expanded format */
+               expanded_fmt = _expanded_fmt_str_get(ch);
+               len = strlen(expanded_fmt);
+               if (len > 0) fmt_expanded = EINA_TRUE;
+               buf[--idx] = 0;
+               strncat(buf, expanded_fmt, len);
+               idx += len;
+            }
+          else buf[idx++] = ch;
 
-        if (ch == '%') fmt_char = EINA_TRUE;
-        else fmt_char = EINA_FALSE;
+          if (ch == '%') fmt_char = EINA_TRUE;
+          else fmt_char = EINA_FALSE;
 
-        ptr++;
-     }
+          ptr++;
+       }
 
-   buf[idx] = 0;
-   strncpy(dt_fmt, buf, EFL_UI_CLOCK_MAX_FORMAT_LEN);
+     buf[idx] = 0;
+     strncpy(dt_fmt, buf, EFL_UI_CLOCK_MAX_FORMAT_LEN);
+   } while (fmt_expanded);
 }
 
 static void
@@ -246,7 +274,8 @@ _field_list_arrange(Evas_Object *obj)
    for (idx = 0; idx < EFL_UI_CLOCK_TYPE_COUNT; idx++)
      {
         field = sd->field_list + idx;
-        snprintf(buf, sizeof(buf), EDC_PART_FIELD_STR, field->location);
+        _part_name_snprintf(buf, sizeof(buf), obj, EDC_PART_FIELD_STR,
+                            field->location);
 
         if (field->visible && field->fmt_exist)
           {
@@ -279,7 +308,7 @@ _parse_format(Evas_Object *obj,
      {
         if (fmt_parsing)
           {
-             if (cur == '_' || cur == '-' || cur == '0' || cur == '^' || cur == '#')
+             if (strchr(ignore_extensions, cur))
                {
                   fmt_ptr++;
                   continue;
@@ -340,7 +369,7 @@ _reload_format(Evas_Object *obj)
    // FIXME: provide nl_langinfo on Windows if possible
    // fetch the default format from Libc.
    if (!sd->user_format)
-#if defined(HAVE_LANGINFO_H) || defined (HAVE_EVIL)
+#if defined(HAVE_LANGINFO_H) || defined (_WIN32)
      strncpy(sd->format, nl_langinfo(D_T_FMT), EFL_UI_CLOCK_MAX_FORMAT_LEN);
 #else
      strncpy(sd->format, "", EFL_UI_CLOCK_MAX_FORMAT_LEN);
@@ -383,68 +412,39 @@ _reload_format(Evas_Object *obj)
           {
              snprintf(buf, sizeof(buf), EDC_PART_FIELD_ENABLE_SIG_STR,
                       field->location);
-             elm_layout_signal_emit(obj, buf, "elm");
+             if (elm_widget_is_legacy(obj))
+               elm_layout_signal_emit(obj, buf, "elm");
+             else
+               elm_layout_signal_emit(obj, buf, "efl");
           }
         else
           {
              snprintf(buf, sizeof(buf), EDC_PART_FIELD_DISABLE_SIG_STR,
                       field->location);
-             elm_layout_signal_emit(obj, buf, "elm");
+             if (elm_widget_is_legacy(obj))
+               elm_layout_signal_emit(obj, buf, "elm");
+             else
+               elm_layout_signal_emit(obj, buf, "efl");
+          }
+        if (field->location + 1)
+          {
+             _part_name_snprintf(buf, sizeof(buf), obj, EDC_PART_SEPARATOR_STR,
+                                 field->location + 1);
+             elm_layout_text_set(obj, buf, field->separator);
           }
-        snprintf
-          (buf, sizeof(buf), EDC_PART_SEPARATOR_STR, (field->location + 1));
-        elm_layout_text_set(obj, buf, field->separator);
      }
 
    edje_object_message_signal_process(wd->resize_obj);
    _field_list_arrange(obj);
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_clock_elm_widget_translate(Eo *obj, Efl_Ui_Clock_Data *sd)
+EOLIAN static void
+_efl_ui_clock_efl_ui_translatable_translation_update(Eo *obj, Efl_Ui_Clock_Data *sd)
 {
    if (!sd->user_format) _reload_format(obj);
    else _field_list_display(obj);
 
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-
-   return EINA_TRUE;
-}
-
-static Eina_List *
-_clock_items_get(const Evas_Object *obj)
-{
-   Eina_List *items = NULL;
-   Clock_Field *field;
-   unsigned int idx;
-   Clock_Field *sorted_fields[EFL_UI_CLOCK_TYPE_COUNT];
-
-   EFL_UI_CLOCK_DATA_GET(obj, sd);
-
-   for (idx = 0; idx < EFL_UI_CLOCK_TYPE_COUNT; idx++)
-     {
-        field = sd->field_list + idx;
-        sorted_fields[field->location] = field;
-     }
-
-   for (idx = 0; idx < EFL_UI_CLOCK_TYPE_COUNT; idx++)
-     {
-        field = sorted_fields[idx];
-        if (field->fmt_exist && field->visible)
-          items = eina_list_append(items, field->item_obj);
-     }
-
-   // ACCESS
-   if (_elm_config->access_mode == ELM_ACCESS_MODE_ON)
-     items = eina_list_append(items, sd->access_obj);
-
-   return items;
-}
-
-EOLIAN static Eina_Bool
-_efl_ui_clock_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
 }
 
 EOLIAN static void
@@ -461,7 +461,7 @@ _efl_ui_clock_pause_set(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, Eina_Bool pa
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_clock_pause_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
+_efl_ui_clock_pause_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
 {
    return sd->paused;
 }
@@ -473,49 +473,22 @@ _efl_ui_clock_edit_mode_set(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, Eina_Boo
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_clock_edit_mode_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
+_efl_ui_clock_edit_mode_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
 {
    return sd->edit_mode;
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_clock_elm_widget_focus_next(Eo *obj, Efl_Ui_Clock_Data *_pd EINA_UNUSED, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   const Eina_List *items;
-   Eina_List *(*list_free)(Eina_List *list);
-   void *(*list_data_get)(const Eina_List *list);
-
-   Eina_Bool int_ret;
-
-   if ((items = elm_widget_focus_custom_chain_get(obj)))
-     {
-        list_data_get = eina_list_data_get;
-        list_free = NULL;
-     }
-   else
-     {
-        items = _clock_items_get(obj);
-        list_data_get = eina_list_data_get;
-        list_free = eina_list_free;
-        if (!items) return EINA_FALSE;
-     }
-
-   int_ret = elm_widget_focus_list_next_get(obj, items, list_data_get, dir, next, next_item);
-   if (list_free) list_free((Eina_List *)items);
-
-   return int_ret;
-}
-
-EOLIAN static Eina_Bool
-_efl_ui_clock_elm_widget_on_focus(Eo *obj, Efl_Ui_Clock_Data *sd, Elm_Object_Item *item EINA_UNUSED)
+_efl_ui_clock_efl_ui_focus_object_on_focus_update(Eo *obj, Efl_Ui_Clock_Data *sd)
 {
    Eina_Bool int_ret = EINA_FALSE;
 
-   int_ret = elm_obj_widget_on_focus(efl_super(obj, MY_CLASS), NULL);
+   int_ret = efl_ui_focus_object_on_focus_update(efl_super(obj, MY_CLASS));
    if (!int_ret) return EINA_FALSE;
 
-   if (!elm_widget_focus_get(obj))
+   if (!efl_ui_focus_object_focus_get(obj))
      {
+        Clock_Mod_Api *dt_mod = _dt_mod_init();
         if ((dt_mod) && (dt_mod->obj_hide))
           dt_mod->obj_hide(sd->mod_data);
      }
@@ -524,19 +497,18 @@ _efl_ui_clock_elm_widget_on_focus(Eo *obj, Efl_Ui_Clock_Data *sd, Elm_Object_Ite
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_clock_elm_widget_disable(Eo *obj, Efl_Ui_Clock_Data *sd)
+_efl_ui_clock_efl_ui_widget_on_disabled_update(Eo *obj, Efl_Ui_Clock_Data *sd, Eina_Bool disabled)
 {
    Clock_Field *field;
    unsigned int idx = 0;
-   Eina_Bool int_ret = EINA_FALSE;
 
-   int_ret = elm_obj_widget_disable(efl_super(obj, MY_CLASS));
-   if (!int_ret) return EINA_FALSE;
+   if (!efl_ui_widget_on_disabled_update(efl_super(obj, MY_CLASS), disabled))
+     return EINA_FALSE;
 
    for (idx = 0; idx < EFL_UI_CLOCK_TYPE_COUNT; idx++)
      {
         field = sd->field_list + idx;
-        elm_object_disabled_set(field->item_obj, elm_object_disabled_get(obj));
+        elm_object_disabled_set(field->item_obj, disabled);
      }
    return EINA_TRUE;
 }
@@ -559,34 +531,44 @@ _efl_ui_clock_elm_layout_sizing_eval(Eo *obj, Efl_Ui_Clock_Data *sd)
    evas_object_size_hint_max_set(obj, -1, -1);
 }
 
-EOLIAN static Elm_Theme_Apply
-_efl_ui_clock_elm_widget_theme_apply(Eo *obj, Efl_Ui_Clock_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_efl_ui_clock_efl_ui_widget_theme_apply(Eo *obj, Efl_Ui_Clock_Data *sd)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
 
    Clock_Field *field;
    char buf[BUFFER_SIZE];
    unsigned int idx;
+   Clock_Mod_Api *dt_mod;
 
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EINA_FALSE);
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
+   dt_mod = _dt_mod_init();
    if ((!dt_mod) || (!dt_mod->field_value_display)) return EINA_TRUE;
 
    for (idx = 0; idx < EFL_UI_CLOCK_TYPE_COUNT; idx++)
      {
         field = sd->field_list + idx;
+        // TODO: Different group name for each field_obj may be needed.
+        elm_widget_element_update(obj, field->item_obj, PART_NAME_ARRAY[idx]);
         if (field->fmt_exist && field->visible)
           {
              snprintf(buf, sizeof(buf), EDC_PART_FIELD_ENABLE_SIG_STR,
                       field->location);
-             elm_layout_signal_emit(obj, buf, "elm");
+             if (elm_widget_is_legacy(obj))
+               elm_layout_signal_emit(obj, buf, "elm");
+             else
+               elm_layout_signal_emit(obj, buf, "efl");
 
-             snprintf
-               (buf, sizeof(buf), EDC_PART_SEPARATOR_STR, field->location);
-             elm_layout_text_set(obj, buf, field->separator);
+             if (field->location)
+               {
+                  _part_name_snprintf(buf, sizeof(buf), obj, EDC_PART_SEPARATOR_STR,
+                                      field->location);
+                  elm_layout_text_set(obj, buf, field->separator);
+               }
 
              dt_mod->field_value_display(sd->mod_data, field->item_obj);
           }
@@ -594,7 +576,10 @@ _efl_ui_clock_elm_widget_theme_apply(Eo *obj, Efl_Ui_Clock_Data *sd)
           {
              snprintf(buf, sizeof(buf), EDC_PART_FIELD_DISABLE_SIG_STR,
                       field->location);
-             elm_layout_signal_emit(obj, buf, "elm");
+             if (elm_widget_is_legacy(obj))
+               elm_layout_signal_emit(obj, buf, "elm");
+             else
+               elm_layout_signal_emit(obj, buf, "efl");
           }
      }
 
@@ -743,7 +728,7 @@ _field_format_get(Evas_Object *obj,
 {
    Clock_Field *field;
 
-   if (field_type > EFL_UI_CLOCK_TYPE_DAY) return NULL;
+   if (field_type > EFL_UI_CLOCK_TYPE_AMPM) return NULL;
 
    EFL_UI_CLOCK_DATA_GET(obj, sd);
 
@@ -860,6 +845,7 @@ _ticker(void *data)
 
    if (sd->curr_time.tm_sec > 0)
      {
+        Clock_Mod_Api *dt_mod = _dt_mod_init();
         field = sd->field_list + EFL_UI_CLOCK_TYPE_SECOND;
         if (field->fmt_exist && field->visible &&
             dt_mod && dt_mod->field_value_display)
@@ -879,13 +865,23 @@ EOLIAN static void
 _efl_ui_clock_efl_canvas_group_group_add(Eo *obj, Efl_Ui_Clock_Data *priv)
 {
    Clock_Field *field;
+   Clock_Mod_Api *dt_mod;
    int idx;
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
+   if (!elm_widget_theme_klass_get(obj))
+     elm_widget_theme_klass_set(obj, "uiclock");
    efl_canvas_group_add(efl_super(obj, MY_CLASS));
    elm_widget_sub_object_parent_add(obj);
 
+   if (!elm_widget_theme_object_set(obj, wd->resize_obj,
+                                       elm_widget_theme_klass_get(obj),
+                                       elm_widget_theme_element_get(obj),
+                                       elm_widget_theme_style_get(obj)))
+     CRI("Failed to set layout!");
+
    // module - initialise module for clock
-   if (!dt_mod) dt_mod = _dt_mod_init();
+   dt_mod = _dt_mod_init();
    if (dt_mod)
      {
         if (dt_mod->obj_hook)
@@ -913,9 +909,6 @@ _efl_ui_clock_efl_canvas_group_group_add(Eo *obj, Efl_Ui_Clock_Data *priv)
    else WRN("Failed to load clock module, clock widget may not show properly!");
 
    priv->freeze_sizing = EINA_TRUE;
-   if (!elm_layout_theme_set(obj, "uiclock", "base",
-                             elm_widget_style_get(obj)))
-     CRI("Failed to set layout!");
 
    _field_list_init(obj);
    _reload_format(obj);
@@ -932,7 +925,7 @@ _efl_ui_clock_efl_canvas_group_group_add(Eo *obj, Efl_Ui_Clock_Data *priv)
         Elm_Access_Info *ai;
 
         priv->access_obj = _elm_access_edje_object_part_object_register
-          (obj, elm_layout_edje_get(obj), "elm.access");
+          (obj, elm_layout_edje_get(obj), "efl.access");
         if (!priv->access_obj)
           priv->access_obj = _elm_access_edje_object_part_object_register
           (obj, elm_layout_edje_get(obj), "access");
@@ -948,6 +941,7 @@ _efl_ui_clock_efl_canvas_group_group_del(Eo *obj, Efl_Ui_Clock_Data *sd)
 {
    Clock_Field *tmp;
    unsigned int idx;
+   Clock_Mod_Api *dt_mod;
 
    ecore_timer_del(sd->ticker);
    for (idx = 0; idx < EFL_UI_CLOCK_TYPE_COUNT; idx++)
@@ -957,6 +951,7 @@ _efl_ui_clock_efl_canvas_group_group_del(Eo *obj, Efl_Ui_Clock_Data *sd)
         eina_stringshare_del(tmp->separator);
      }
 
+   dt_mod = _dt_mod_init();
    if ((dt_mod) && (dt_mod->obj_unhook))
      dt_mod->obj_unhook(sd->mod_data);  // module - unhook
 
@@ -967,15 +962,14 @@ EOLIAN static Eo *
 _efl_ui_clock_efl_object_constructor(Eo *obj, Efl_Ui_Clock_Data *_pd EINA_UNUSED)
 {
    obj = efl_constructor(efl_super(obj, MY_CLASS));
-   efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_DATE_EDITOR);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_DATE_EDITOR);
 
    return obj;
 }
 
 EOLIAN static const char*
-_efl_ui_clock_format_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
+_efl_ui_clock_format_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
 {
    return sd->format;
 }
@@ -995,11 +989,11 @@ _efl_ui_clock_format_set(Eo *obj, Efl_Ui_Clock_Data *sd, const char *fmt)
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_clock_field_visible_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Type fieldtype)
+_efl_ui_clock_field_visible_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Type fieldtype)
 {
    Clock_Field *field;
 
-   if (fieldtype > EFL_UI_CLOCK_TYPE_DAY) return EINA_FALSE;
+   if (fieldtype > EFL_UI_CLOCK_TYPE_AMPM) return EINA_FALSE;
 
    field = sd->field_list + fieldtype;
 
@@ -1012,7 +1006,7 @@ _efl_ui_clock_field_visible_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Typ
    char buf[BUFFER_SIZE];
    Clock_Field *field;
 
-   if (fieldtype > EFL_UI_CLOCK_TYPE_DAY) return;
+   if (fieldtype > EFL_UI_CLOCK_TYPE_AMPM) return;
 
    field = sd->field_list + fieldtype;
    visible = !!visible;
@@ -1029,12 +1023,16 @@ _efl_ui_clock_field_visible_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Typ
 
         snprintf(buf, sizeof(buf), EDC_PART_FIELD_ENABLE_SIG_STR,
                  field->location);
-        elm_layout_signal_emit(obj, buf, "elm");
+        if (elm_widget_is_legacy(obj))
+          elm_layout_signal_emit(obj, buf, "elm");
+        else
+          elm_layout_signal_emit(obj, buf, "efl");
 
         ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
         edje_object_message_signal_process(wd->resize_obj);
 
-        snprintf(buf, sizeof(buf), EDC_PART_FIELD_STR, field->location);
+        _part_name_snprintf(buf, sizeof(buf), obj, EDC_PART_FIELD_STR,
+                            field->location);
         elm_layout_content_unset(obj, buf);
         elm_layout_content_set(obj, buf, field->item_obj);
      }
@@ -1046,12 +1044,16 @@ _efl_ui_clock_field_visible_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Typ
 
         snprintf(buf, sizeof(buf), EDC_PART_FIELD_DISABLE_SIG_STR,
                  field->location);
-        elm_layout_signal_emit(obj, buf, "elm");
+        if (elm_widget_is_legacy(obj))
+          elm_layout_signal_emit(obj, buf, "elm");
+        else
+          elm_layout_signal_emit(obj, buf, "efl");
 
         ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
         edje_object_message_signal_process(wd->resize_obj);
 
-        snprintf(buf, sizeof(buf), EDC_PART_FIELD_STR, field->location);
+        _part_name_snprintf(buf, sizeof(buf), obj, EDC_PART_FIELD_STR,
+                            field->location);
         evas_object_hide(elm_layout_content_unset(obj, buf));
      }
    sd->freeze_sizing = EINA_FALSE;
@@ -1059,17 +1061,19 @@ _efl_ui_clock_field_visible_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Typ
    elm_layout_sizing_eval(obj);
 
    if (!visible) return;
-   if (!dt_mod || !dt_mod->field_value_display) return;
-
-   dt_mod->field_value_display(sd->mod_data, field->item_obj);
+   {
+      Clock_Mod_Api *dt_mod = _dt_mod_init();
+      if (!dt_mod || !dt_mod->field_value_display) return;
+      dt_mod->field_value_display(sd->mod_data, field->item_obj);
+   }
 }
 
 EOLIAN static void
-_efl_ui_clock_field_limit_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Type fieldtype, int *min, int *max)
+_efl_ui_clock_field_limit_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Type fieldtype, int *min, int *max)
 {
    Clock_Field *field;
 
-   if (fieldtype >= EFL_UI_CLOCK_TYPE_DAY) return;
+   if (fieldtype >= EFL_UI_CLOCK_TYPE_AMPM) return;
 
    field = sd->field_list + fieldtype;
    if (min) *min = field->min;
@@ -1082,7 +1086,7 @@ _efl_ui_clock_field_limit_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Type
    Clock_Field *field;
    struct tm old_time;
 
-   if (fieldtype >= EFL_UI_CLOCK_TYPE_DAY) return;
+   if (fieldtype >= EFL_UI_CLOCK_TYPE_AMPM) return;
 
    if (min > max) return;
 
@@ -1101,25 +1105,19 @@ _efl_ui_clock_field_limit_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Ui_Clock_Type
 
    if (!_field_cmp(fieldtype, &old_time, &sd->curr_time))
      efl_event_callback_legacy_call(obj, EFL_UI_CLOCK_EVENT_CHANGED, NULL);
-
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_clock_value_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, struct tm *currtime)
+EOLIAN static Efl_Time
+_efl_ui_clock_time_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
 {
-   EINA_SAFETY_ON_NULL_RETURN_VAL(currtime, EINA_FALSE);
-
-   *currtime = sd->curr_time;
-   return EINA_TRUE;
+   return sd->curr_time;
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_clock_value_set(Eo *obj, Efl_Ui_Clock_Data *sd, struct tm *newtime)
+EOLIAN static void
+_efl_ui_clock_time_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Time newtime)
 {
-   EINA_SAFETY_ON_NULL_RETURN_VAL(newtime, EINA_FALSE);
-
-   if (_date_cmp(&sd->curr_time, newtime)) return EINA_TRUE;
-   sd->curr_time = *newtime;
+   if (_date_cmp(&sd->curr_time, &newtime)) return;
+   sd->curr_time = newtime;
    // apply default field restrictions for curr_time
    _apply_range_restrictions(&sd->curr_time);
    // validate the curr_time according to the min_limt and max_limt
@@ -1128,28 +1126,21 @@ _efl_ui_clock_value_set(Eo *obj, Efl_Ui_Clock_Data *sd, struct tm *newtime)
    _apply_field_limits(obj);
 
    efl_event_callback_legacy_call(obj, EFL_UI_CLOCK_EVENT_CHANGED, NULL);
-
-   return EINA_TRUE;
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_clock_value_min_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, Efl_Time *mintime)
+EOLIAN static Efl_Time
+_efl_ui_clock_time_min_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
 {
-   EINA_SAFETY_ON_NULL_RETURN_VAL(mintime, EINA_FALSE);
-
-   *mintime = sd->min_limit;
-   return EINA_TRUE;
+   return sd->min_limit;
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_clock_value_min_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Time *mintime)
+EOLIAN static void
+_efl_ui_clock_time_min_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Time mintime)
 {
    struct tm old_time;
 
-   EINA_SAFETY_ON_NULL_RETURN_VAL(mintime, EINA_FALSE);
-
-   if (_date_cmp(&sd->min_limit, mintime)) return EINA_TRUE;
-   sd->min_limit = *mintime;
+   if (_date_cmp(&sd->min_limit, &mintime)) return;
+   sd->min_limit = mintime;
    old_time = sd->curr_time;
    // apply default field restrictions for min_limit
    _apply_range_restrictions(&sd->min_limit);
@@ -1160,28 +1151,21 @@ _efl_ui_clock_value_min_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Time *mintime)
 
    if (!_date_cmp(&old_time, &sd->curr_time))
      efl_event_callback_legacy_call(obj, EFL_UI_CLOCK_EVENT_CHANGED, NULL);
-
-   return EINA_TRUE;
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_clock_value_max_get(Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd, struct tm *maxtime)
+EOLIAN static Efl_Time
+_efl_ui_clock_time_max_get(const Eo *obj EINA_UNUSED, Efl_Ui_Clock_Data *sd)
 {
-   EINA_SAFETY_ON_NULL_RETURN_VAL(maxtime, EINA_FALSE);
-
-   *maxtime = sd->max_limit;
-   return EINA_TRUE;
+   return sd->max_limit;
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_clock_value_max_set(Eo *obj, Efl_Ui_Clock_Data *sd, struct tm *maxtime)
+EOLIAN static void
+_efl_ui_clock_time_max_set(Eo *obj, Efl_Ui_Clock_Data *sd, Efl_Time maxtime)
 {
    struct tm old_time;
 
-   EINA_SAFETY_ON_NULL_RETURN_VAL(maxtime, EINA_FALSE);
-
-   if (_date_cmp(&sd->max_limit, maxtime)) return EINA_TRUE;
-   sd->max_limit = *maxtime;
+   if (_date_cmp(&sd->max_limit, &maxtime)) return;
+   sd->max_limit = maxtime;
    old_time = sd->curr_time;
    // apply default field restrictions for max_limit
    _apply_range_restrictions(&sd->max_limit);
@@ -1192,19 +1176,12 @@ _efl_ui_clock_value_max_set(Eo *obj, Efl_Ui_Clock_Data *sd, struct tm *maxtime)
 
    if (!_date_cmp(&old_time, &sd->curr_time))
      efl_event_callback_legacy_call(obj, EFL_UI_CLOCK_EVENT_CHANGED, NULL);
-
-   return EINA_TRUE;
-}
-
-EOLIAN static void
-_efl_ui_clock_class_constructor(Efl_Class *klass)
-{
-   evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
 
 /* Internal EO APIs and hidden overrides */
 
 #define EFL_UI_CLOCK_EXTRA_OPS \
+   ELM_LAYOUT_SIZING_EVAL_OPS(efl_ui_clock), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(efl_ui_clock)
 
 #include "efl_ui_clock.eo.c"
