@@ -2,19 +2,19 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "efl_ui_widget_flip.h"
 #include "elm_widget_container.h"
 
-#include "efl_ui_flip_internal_part.eo.h"
+#include "efl_ui_flip_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS EFL_UI_FLIP_CLASS
 #define MY_CLASS_NAME "Efl.Ui.Flip"
-#define MY_CLASS_NAME_LEGACY "elm_flip"
 
 static const char SIG_ANIMATE_BEGIN[] = "animate,begin";
 static const char SIG_ANIMATE_DONE[] = "animate,done";
@@ -73,9 +73,9 @@ _sizing_eval(Evas_Object *obj)
    EFL_UI_FLIP_DATA_GET(obj, sd);
 
    if (sd->front.content)
-     efl_gfx_size_hint_combined_min_get(sd->front.content, &minw, &minh);
+     evas_object_size_hint_combined_min_get(sd->front.content, &minw, &minh);
    if (sd->back.content)
-     efl_gfx_size_hint_combined_min_get(sd->back.content, &minw2, &minh2);
+     evas_object_size_hint_combined_min_get(sd->back.content, &minw2, &minh2);
    if (sd->front.content)
      evas_object_size_hint_max_get(sd->front.content, &maxw, &maxh);
    if (sd->back.content)
@@ -97,67 +97,18 @@ _sizing_eval(Evas_Object *obj)
    evas_object_size_hint_max_set(obj, maxw, maxh);
 }
 
-EOLIAN static Elm_Theme_Apply
-_efl_ui_flip_elm_widget_theme_apply(Eo *obj, Efl_Ui_Flip_Data *sd EINA_UNUSED)
+EOLIAN static Efl_Ui_Theme_Apply
+_efl_ui_flip_efl_ui_widget_theme_apply(Eo *obj, Efl_Ui_Flip_Data *sd EINA_UNUSED)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    _sizing_eval(obj);
 
    return int_ret;
 }
 
-EOLIAN static Eina_Bool
-_efl_ui_flip_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_efl_ui_flip_elm_widget_focus_next(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-
-   /* attempt to cycle focus on in sub-items */
-   if (sd->state)
-     return elm_widget_focus_next_get(sd->front.content, dir, next, next_item);
-   else
-     return elm_widget_focus_next_get(sd->back.content, dir, next, next_item);
-}
-
-EOLIAN static Eina_Bool
-_efl_ui_flip_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *_pd EINA_UNUSED)
-{
-   if (!elm_widget_can_focus_get(obj))
-     return EINA_TRUE;
-   else
-     return EINA_FALSE;
-}
-
-EOLIAN static Eina_Bool
-_efl_ui_flip_elm_widget_focus_direction(Eo *obj, Efl_Ui_Flip_Data *sd, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Eina_Bool ret;
-
-   Eina_List *l = NULL;
-   void *(*list_data_get)(const Eina_List *list);
-
-   list_data_get = eina_list_data_get;
-
-   if (sd->front.content)
-     l = eina_list_append(l, sd->front.content);
-   if (sd->back.content)
-     l = eina_list_append(l, sd->back.content);
-
-   ret = elm_widget_focus_list_direction_get
-            (obj, base, l, list_data_get, degree, direction, direction_item, weight);
-
-   eina_list_free(l);
-
-   return ret;
-}
-
 static void
 _changed_size_hints_cb(void *data,
                        Evas *e EINA_UNUSED,
@@ -168,14 +119,14 @@ _changed_size_hints_cb(void *data,
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_elm_widget_sub_object_add(Eo *obj, Efl_Ui_Flip_Data *_pd EINA_UNUSED, Evas_Object *sobj)
+_efl_ui_flip_efl_ui_widget_widget_sub_object_add(Eo *obj, Efl_Ui_Flip_Data *_pd EINA_UNUSED, Evas_Object *sobj)
 {
    Eina_Bool int_ret = EINA_FALSE;
 
    if (evas_object_data_get(sobj, "elm-parent") == obj)
      return EINA_TRUE;
 
-   int_ret = elm_obj_widget_sub_object_add(efl_super(obj, MY_CLASS), sobj);
+   int_ret = elm_widget_sub_object_add(efl_super(obj, MY_CLASS), sobj);
    if (!int_ret) return EINA_FALSE;
 
    evas_object_data_set(sobj, "_elm_leaveme", sobj);
@@ -188,12 +139,12 @@ _efl_ui_flip_elm_widget_sub_object_add(Eo *obj, Efl_Ui_Flip_Data *_pd EINA_UNUSE
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_elm_widget_sub_object_del(Eo *obj, Efl_Ui_Flip_Data *sd, Evas_Object *sobj)
+_efl_ui_flip_efl_ui_widget_widget_sub_object_del(Eo *obj, Efl_Ui_Flip_Data *sd, Evas_Object *sobj)
 {
    Eina_Bool int_ret = EINA_FALSE;
 
 
-   int_ret = elm_obj_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
+   int_ret = elm_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
    if (!int_ret) return EINA_FALSE;
 
    if (sobj == sd->front.content)
@@ -1792,7 +1743,7 @@ _flip_content_set(Evas_Object *obj,
         //evas_object_smart_member_add(content, obj);
         evas_object_clip_set
           (content, front ? sd->front.clip : sd->back.clip);
-        if (efl_isa(content, ELM_WIDGET_CLASS) && sd->state != front)
+        if (efl_isa(content, EFL_UI_WIDGET_CLASS) && sd->state != front)
           elm_widget_tree_unfocusable_set(content, EINA_TRUE);
      }
 
@@ -1911,28 +1862,20 @@ _efl_ui_flip_efl_canvas_group_group_del(Eo *obj, Efl_Ui_Flip_Data *sd)
    efl_canvas_group_del(efl_super(obj, MY_CLASS));
 }
 
-EAPI Evas_Object *
-elm_flip_add(Evas_Object *parent)
-{
-   EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
-}
-
 EOLIAN static Eo *
 _efl_ui_flip_efl_object_constructor(Eo *obj, Efl_Ui_Flip_Data *sd)
 {
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    sd->obj = obj;
 
-   efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_PAGE_TAB_LIST);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_PAGE_TAB_LIST);
 
    return obj;
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_front_visible_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd)
+_efl_ui_flip_front_visible_get(const Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd)
 {
    return sd->state;
 }
@@ -2014,9 +1957,9 @@ _internal_elm_flip_go_to(Evas_Object *obj,
         else elm_object_focus_set(sd->back.content, EINA_TRUE);
      }
 
-   if (sd->front.content && efl_isa(sd->front.content, ELM_WIDGET_CLASS))
+   if (sd->front.content && efl_isa(sd->front.content, EFL_UI_WIDGET_CLASS))
      elm_widget_tree_unfocusable_set(sd->front.content, !front);
-   if (sd->back.content && efl_isa(sd->back.content, ELM_WIDGET_CLASS))
+   if (sd->back.content && efl_isa(sd->back.content, EFL_UI_WIDGET_CLASS))
      elm_widget_tree_unfocusable_set(sd->back.content, front);
 
 
@@ -2087,25 +2030,50 @@ _efl_ui_flip_interaction_set(Eo *obj, Efl_Ui_Flip_Data *sd, Efl_Ui_Flip_Interact
 }
 
 EOLIAN static Efl_Ui_Flip_Interaction
-_efl_ui_flip_interaction_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd)
+_efl_ui_flip_interaction_get(const Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd)
 {
    return sd->intmode;
 }
 
-static int
-_orient_dir_xlate(Efl_Orient dir)
+static Efl_Ui_Dir
+_flip_dir_to_efl_ui_dir(Elm_Flip_Direction dir)
 {
-   if      (dir == EFL_ORIENT_UP)    return ELM_FLIP_DIRECTION_UP;
-   else if (dir == EFL_ORIENT_DOWN)  return ELM_FLIP_DIRECTION_DOWN;
-   else if (dir == EFL_ORIENT_LEFT)  return ELM_FLIP_DIRECTION_LEFT;
-   else if (dir == EFL_ORIENT_RIGHT) return ELM_FLIP_DIRECTION_RIGHT;
-   return 0;
+   switch (dir)
+     {
+      case ELM_FLIP_DIRECTION_RIGHT: return EFL_UI_DIR_RIGHT;
+      case ELM_FLIP_DIRECTION_DOWN: return EFL_UI_DIR_DOWN;
+      case ELM_FLIP_DIRECTION_LEFT: return EFL_UI_DIR_LEFT;
+      case ELM_FLIP_DIRECTION_UP: return EFL_UI_DIR_UP;
+     }
+   ERR("Invalid value for Elm_Flip_Direction: %d", (int) dir);
+   return EFL_UI_DIR_DEFAULT;
+}
+
+static Elm_Flip_Direction
+_efl_ui_dir_to_flip_dir(Efl_Ui_Dir dir)
+{
+   switch (dir)
+     {
+      case EFL_UI_DIR_RIGHT:
+      case EFL_UI_DIR_HORIZONTAL:
+        return ELM_FLIP_DIRECTION_RIGHT;
+      case EFL_UI_DIR_DOWN:
+        return ELM_FLIP_DIRECTION_DOWN;
+      case EFL_UI_DIR_LEFT:
+        return ELM_FLIP_DIRECTION_LEFT;
+      case EFL_UI_DIR_UP:
+      case EFL_UI_DIR_VERTICAL:
+      case EFL_UI_DIR_DEFAULT:
+        return ELM_FLIP_DIRECTION_UP;
+     }
+   ERR("Invalid value for Efl_Ui_Dir: %d", (int) dir);
+   return ELM_FLIP_DIRECTION_UP;
 }
 
 EOLIAN static void
-_efl_ui_flip_interaction_direction_enabled_set(Eo *obj, Efl_Ui_Flip_Data *sd, Efl_Orient dir, Eina_Bool enabled)
+_efl_ui_flip_interaction_direction_enabled_set(Eo *obj, Efl_Ui_Flip_Data *sd, Efl_Ui_Dir dir, Eina_Bool enabled)
 {
-   int i = _orient_dir_xlate(dir);;
+   int i = _efl_ui_dir_to_flip_dir(dir);
    int area;
 
    enabled = !!enabled;
@@ -2125,15 +2093,15 @@ _efl_ui_flip_interaction_direction_enabled_set(Eo *obj, Efl_Ui_Flip_Data *sd, Ef
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_interaction_direction_enabled_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd, Efl_Orient dir)
+_efl_ui_flip_interaction_direction_enabled_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd, Efl_Ui_Dir dir)
 {
-   return sd->dir_enabled[_orient_dir_xlate(dir)];
+   return sd->dir_enabled[_efl_ui_dir_to_flip_dir(dir)];
 }
 
 EOLIAN static void
-_efl_ui_flip_interaction_direction_hitsize_set(Eo *obj, Efl_Ui_Flip_Data *sd, Efl_Orient dir, double hitsize)
+_efl_ui_flip_interaction_direction_hitsize_set(Eo *obj, Efl_Ui_Flip_Data *sd, Efl_Ui_Dir dir, double hitsize)
 {
-   int i = _orient_dir_xlate(dir);
+   int i = _efl_ui_dir_to_flip_dir(dir);
 
 
    if (hitsize < 0.0)
@@ -2157,7 +2125,7 @@ static void
 _update_front_back(Eo *obj, Efl_Ui_Flip_Data *pd)
 {
    int count, index;
-   Efl_Gfx *content;
+   Efl_Gfx_Entity *content;
 
    count = eina_list_count(pd->content_list);
    if (count <= 2) return;
@@ -2174,7 +2142,7 @@ _update_front_back(Eo *obj, Efl_Ui_Flip_Data *pd)
 }
 
 static void
-_content_added(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *content)
+_content_added(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *content)
 {
    evas_object_smart_member_add(content, obj);
 
@@ -2191,14 +2159,14 @@ _content_added(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *content)
 }
 
 static void
-_content_removed(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *content)
+_content_removed(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *content)
 {
-   Efl_Gfx *back_face, *cur_face, *face;
+   Efl_Gfx_Entity *back_face, *cur_face, *face;
    int index, count;
    Eina_Bool state;
 
    evas_object_smart_member_del(content);
-   // if its not the front or back object just return. 
+   // if its not the front or back object just return.
    if ((pd->front.content != content) ||
        (pd->back.content != content))
      return;
@@ -2229,9 +2197,9 @@ _content_removed(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *content)
 }
 
 EOLIAN static double
-_efl_ui_flip_interaction_direction_hitsize_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd, Efl_Orient dir)
+_efl_ui_flip_interaction_direction_hitsize_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *sd, Efl_Ui_Dir dir)
 {
-   int i = _orient_dir_xlate(dir);
+   int i = _efl_ui_dir_to_flip_dir(dir);
 
    return sd->dir_hitsize[i];
 }
@@ -2249,7 +2217,7 @@ _efl_ui_flip_efl_container_content_count(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_container_content_remove(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *content)
+_efl_ui_flip_efl_container_content_remove(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *content)
 {
    pd->content_list = eina_list_remove(pd->content_list, content);
    _content_removed(obj, pd, content);
@@ -2257,7 +2225,7 @@ _efl_ui_flip_efl_container_content_remove(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_pack_unpack(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj)
+_efl_ui_flip_efl_pack_unpack(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *subobj)
 {
    pd->content_list = eina_list_remove(pd->content_list, subobj);
    _content_removed(obj, pd, subobj);
@@ -2265,7 +2233,7 @@ _efl_ui_flip_efl_pack_unpack(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj)
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_pack_pack(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj)
+_efl_ui_flip_efl_pack_pack(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *subobj)
 {
    pd->content_list = eina_list_append(pd->content_list, subobj);
    _content_added(obj, pd, subobj);
@@ -2273,7 +2241,7 @@ _efl_ui_flip_efl_pack_pack(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj)
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_pack_linear_pack_begin(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj)
+_efl_ui_flip_efl_pack_linear_pack_begin(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *subobj)
 {
    pd->content_list = eina_list_prepend(pd->content_list, subobj);
    _content_added(obj, pd, subobj);
@@ -2282,7 +2250,7 @@ _efl_ui_flip_efl_pack_linear_pack_begin(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_pack_linear_pack_end(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj)
+_efl_ui_flip_efl_pack_linear_pack_end(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *subobj)
 {
    pd->content_list = eina_list_append(pd->content_list, subobj);
    _content_added(obj, pd, subobj);
@@ -2290,7 +2258,7 @@ _efl_ui_flip_efl_pack_linear_pack_end(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *su
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_pack_linear_pack_before(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj, const Efl_Gfx *existing)
+_efl_ui_flip_efl_pack_linear_pack_before(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *subobj, const Efl_Gfx_Entity *existing)
 {
    pd->content_list = eina_list_prepend_relative(pd->content_list, subobj, existing);
    _content_added(obj, pd, subobj);
@@ -2298,7 +2266,7 @@ _efl_ui_flip_efl_pack_linear_pack_before(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_pack_linear_pack_after(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj, const Efl_Gfx *existing)
+_efl_ui_flip_efl_pack_linear_pack_after(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *subobj, const Efl_Gfx_Entity *existing)
 {
    pd->content_list = eina_list_append_relative(pd->content_list, subobj, existing);
    _content_added(obj, pd, subobj);
@@ -2306,25 +2274,25 @@ _efl_ui_flip_efl_pack_linear_pack_after(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_flip_efl_pack_linear_pack_at(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx *subobj, int index)
+_efl_ui_flip_efl_pack_linear_pack_at(Eo *obj, Efl_Ui_Flip_Data *pd, Efl_Gfx_Entity *subobj, int index)
 {
-   Efl_Gfx *existing = NULL;
+   Efl_Gfx_Entity *existing = NULL;
    existing = eina_list_nth(pd->content_list, index);
    pd->content_list = eina_list_prepend_relative(pd->content_list, subobj, existing);
    _content_added(obj, pd, subobj);
    return EINA_TRUE;
 }
 
-EOLIAN static Efl_Gfx *
+EOLIAN static Efl_Gfx_Entity *
 _efl_ui_flip_efl_pack_linear_pack_content_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *pd, int index)
 {
    return eina_list_nth(pd->content_list, index);
 }
 
-EOLIAN static Efl_Gfx *
+EOLIAN static Efl_Gfx_Entity *
 _efl_ui_flip_efl_pack_linear_pack_unpack_at(Eo *obj, Efl_Ui_Flip_Data *pd, int index)
 {
-   Efl_Gfx *content = eina_list_nth(pd->content_list ,index);
+   Efl_Gfx_Entity *content = eina_list_nth(pd->content_list ,index);
 
    pd->content_list = eina_list_remove(pd->content_list, content);
    _content_removed(obj, pd, content);
@@ -2332,75 +2300,53 @@ _efl_ui_flip_efl_pack_linear_pack_unpack_at(Eo *obj, Efl_Ui_Flip_Data *pd, int i
 }
 
 EOLIAN static int
-_efl_ui_flip_efl_pack_linear_pack_index_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *pd, const Efl_Gfx *subobj)
+_efl_ui_flip_efl_pack_linear_pack_index_get(Eo *obj EINA_UNUSED, Efl_Ui_Flip_Data *pd, const Efl_Gfx_Entity *subobj)
 {
    return eina_list_data_idx(pd->content_list, (void *)subobj);
 }
 
-static void
-_efl_ui_flip_class_constructor(Efl_Class *klass)
-{
-   evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
-}
-
-static Efl_Orient
-_to_efl_orientation(Elm_Flip_Direction dir)
-{
-   Efl_Orient res;
-   switch (dir)
-      {
-        case ELM_FLIP_DIRECTION_RIGHT:
-           res = EFL_ORIENT_RIGHT;
-           break;
-        case ELM_FLIP_DIRECTION_DOWN:
-           res = EFL_ORIENT_DOWN;
-           break;
-        case ELM_FLIP_DIRECTION_LEFT:
-           res = EFL_ORIENT_LEFT;
-           break;
-        default:
-           res = EFL_ORIENT_UP;
-           break;
-      }
-   return res;
-}
-
-EAPI void 
+EAPI void
 elm_flip_interaction_direction_hitsize_set(Efl_Ui_Flip *obj, Elm_Flip_Direction dir, double hitsize)
 {
-   Efl_Orient orient = _to_efl_orientation(dir);
-   efl_ui_flip_interaction_direction_hitsize_set((Efl_Ui_Flip *)obj, orient, hitsize);
+   Efl_Ui_Dir uidir = _flip_dir_to_efl_ui_dir(dir);
+   efl_ui_flip_interaction_direction_hitsize_set(obj, uidir, hitsize);
 }
 
-EAPI double 
+EAPI double
 elm_flip_interaction_direction_hitsize_get(Efl_Ui_Flip *obj, Elm_Flip_Direction dir)
 {
-   Efl_Orient orient = _to_efl_orientation(dir);
-   return efl_ui_flip_interaction_direction_hitsize_get((Efl_Ui_Flip *)obj, orient);
+   Efl_Ui_Dir uidir = _flip_dir_to_efl_ui_dir(dir);
+   return efl_ui_flip_interaction_direction_hitsize_get(obj, uidir);
 }
 
-EOAPI void 
+EOAPI void
 elm_flip_interaction_direction_enabled_set(Efl_Ui_Flip *obj, Elm_Flip_Direction dir, Eina_Bool enabled)
 {
-   Efl_Orient orient = _to_efl_orientation(dir);
-   efl_ui_flip_interaction_direction_enabled_set((Efl_Ui_Flip *)obj, orient, enabled);
+   Efl_Ui_Dir uidir = _flip_dir_to_efl_ui_dir(dir);
+   efl_ui_flip_interaction_direction_enabled_set(obj, uidir, enabled);
 }
 
-EOAPI Eina_Bool 
+EOAPI Eina_Bool
 elm_flip_interaction_direction_enabled_get(Efl_Ui_Flip *obj, Elm_Flip_Direction dir)
 {
-   Efl_Orient orient = _to_efl_orientation(dir);
-   return efl_ui_flip_interaction_direction_enabled_get((Efl_Ui_Flip *)obj, orient);
+   Efl_Ui_Dir uidir = _flip_dir_to_efl_ui_dir(dir);
+   return efl_ui_flip_interaction_direction_enabled_get(obj, uidir);
 }
 
 /* Efl.Part begin */
 
-ELM_PART_IMPLEMENT(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_SET(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_GET(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_UNSET(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data, Elm_Part_Data)
-ELM_PART_CONTENT_DEFAULT_SET(efl_ui_flip, "front")
-#include "efl_ui_flip_internal_part.eo.c"
+static Eina_Bool
+_part_is_efl_ui_flip_entry_part(const Eo *obj EINA_UNUSED, const char *part)
+{
+   return ((eina_streq(part, "front")) || (eina_streq(part, "back")));
+}
+
+ELM_PART_OVERRIDE_PARTIAL(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data, _part_is_efl_ui_flip_entry_part)
+ELM_PART_OVERRIDE_CONTENT_SET(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(efl_ui_flip, EFL_UI_FLIP, Efl_Ui_Flip_Data)
+ELM_PART_CONTENT_DEFAULT_GET(efl_ui_flip, "front")
+#include "efl_ui_flip_part.eo.c"
 
 /* Efl.Part end */
 
@@ -2411,3 +2357,30 @@ ELM_PART_CONTENT_DEFAULT_SET(efl_ui_flip, "front")
    EFL_CANVAS_GROUP_ADD_DEL_OPS(efl_ui_flip)
 
 #include "efl_ui_flip.eo.c"
+
+#include "efl_ui_flip_legacy.eo.h"
+
+#define MY_CLASS_NAME_LEGACY "elm_flip"
+
+static void
+_efl_ui_flip_legacy_class_constructor(Efl_Class *klass)
+{
+   evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
+}
+
+EOLIAN static Eo *
+_efl_ui_flip_legacy_efl_object_constructor(Eo *obj, void *pd EINA_UNUSED)
+{
+   obj = efl_constructor(efl_super(obj, EFL_UI_FLIP_LEGACY_CLASS));
+   efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
+   return obj;
+}
+
+EAPI Evas_Object *
+elm_flip_add(Evas_Object *parent)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
+   return elm_legacy_add(EFL_UI_FLIP_LEGACY_CLASS, parent);
+}
+
+#include "efl_ui_flip_legacy.eo.c"
