@@ -334,9 +334,10 @@ _entry_imf_event_delete_surrounding_cb(void *data, Ecore_IMF_Context *ctx EINA_U
    Efl_Ui_Internal_Text_Interactive_Data *en = efl_data_scope_get(obj, MY_CLASS);
    Ecore_IMF_Event_Delete_Surrounding *ev = event_info;
    Evas_Textblock_Cursor *del_start, *del_end;
-   Efl_Ui_Text_Interactive_Change_Info info = { NULL, 0, 0, 0, 0 };
+   Efl_Ui_Text_Change_Info info = { NULL, 0, 0, 0, 0 };
    int cursor_pos;
    int start, end;
+   char *tmp;
 
    cursor_pos = evas_textblock_cursor_pos_get(cur);
 
@@ -350,13 +351,14 @@ _entry_imf_event_delete_surrounding_cb(void *data, Ecore_IMF_Context *ctx EINA_U
    end = evas_textblock_cursor_pos_get(del_end);
    if (start == end) goto end;
 
+   tmp = efl_canvas_text_range_text_get(obj, del_start, del_end);
+
    info.insert = EINA_FALSE;
    info.position = start;
    info.length = end - start;
+   info.content = tmp;
 
-   char *tmp = efl_canvas_text_range_text_get(obj, en->sel_start, en->sel_end);
-
-   efl_event_callback_legacy_call(obj, EFL_UI_TEXT_INTERACTIVE_EVENT_CHANGED_USER, &info);
+   efl_event_callback_call(obj, EFL_UI_TEXT_EVENT_CHANGED_USER, &info);
 
    free(tmp);
 
@@ -508,7 +510,7 @@ _sel_cursor_changed(void *data, const Efl_Event *event EINA_UNUSED)
 {
    Eo *obj = data;
 
-   efl_event_callback_legacy_call(obj, EFL_UI_TEXT_INTERACTIVE_EVENT_SELECTION_CHANGED, NULL);
+   efl_event_callback_call(obj, EFL_TEXT_INTERACTIVE_EVENT_SELECTION_CHANGED, NULL);
 }
 
 static void
@@ -585,7 +587,7 @@ _range_del_emit(Evas_Object *obj, Efl_Text_Cursor_Cursor *cur1, Efl_Text_Cursor_
 {
    size_t start, end;
    char *tmp;
-   Efl_Ui_Text_Interactive_Change_Info info = { NULL, 0, 0, 0, 0 };
+   Efl_Ui_Text_Change_Info info = { NULL, 0, 0, 0, 0 };
 
    start = evas_textblock_cursor_pos_get(cur1);
    end = evas_textblock_cursor_pos_get(cur2);
@@ -599,7 +601,7 @@ _range_del_emit(Evas_Object *obj, Efl_Text_Cursor_Cursor *cur1, Efl_Text_Cursor_
    tmp = efl_canvas_text_range_text_get(obj, cur1, cur2);
    info.content = tmp;
 
-   efl_event_callback_legacy_call(obj, EFL_UI_TEXT_INTERACTIVE_EVENT_CHANGED_USER, &info);
+   efl_event_callback_call(obj, EFL_UI_TEXT_EVENT_CHANGED_USER, &info);
 
    if (tmp) free(tmp);
 
@@ -616,7 +618,7 @@ _sel_range_del_emit(Evas_Object *obj, Efl_Ui_Internal_Text_Interactive_Data *en)
 static void
 _delete_emit(Eo *obj, Evas_Textblock_Cursor *c, Efl_Ui_Internal_Text_Interactive_Data *en EINA_UNUSED, size_t pos)
 {
-   Efl_Ui_Text_Interactive_Change_Info info = { NULL, 0, 0, 0, 0 };
+   Efl_Ui_Text_Change_Info info = { NULL, 0, 0, 0, 0 };
    Eina_Unicode content[2];
    content[0] = efl_text_cursor_content_get(obj, c);
    content[1] = 0;
@@ -630,8 +632,7 @@ _delete_emit(Eo *obj, Evas_Textblock_Cursor *c, Efl_Ui_Internal_Text_Interactive
    info.length = 1;
    info.content = tmp;
 
-   efl_event_callback_legacy_call(obj,
-         EFL_UI_TEXT_INTERACTIVE_EVENT_CHANGED_USER, &info);
+   efl_event_callback_call(obj, EFL_UI_TEXT_EVENT_CHANGED_USER, &info);
    if (tmp) free(tmp);
 
    evas_textblock_cursor_char_delete(c);
@@ -711,6 +712,9 @@ _key_down_cb(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void
    int old_cur_pos;
    char *string = (char *)ev->string;
    Eina_Bool free_string = EINA_FALSE;
+   Eina_Bool changed_user = EINA_FALSE;
+   Efl_Ui_Text_Change_Info info = { NULL, 0, 0, 0, 0 };
+
    if (!ev->key) return;
    if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
 
@@ -1031,7 +1035,6 @@ _key_down_cb(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void
           }
         if (string)
           {
-             Efl_Ui_Text_Interactive_Change_Info info = { NULL, 0, 0, 0, 0 };
              if (en->have_selection)
                {
                   _sel_range_del_emit(obj, en);
@@ -1042,9 +1045,10 @@ _key_down_cb(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void
              info.position = efl_text_cursor_position_get(obj, cur);
              info.length = eina_unicode_utf8_get_len(string);
 
+             efl_event_freeze(obj);
              efl_text_cursor_text_insert(obj, cur, string);
-             efl_event_callback_legacy_call(obj,
-                   EFL_UI_TEXT_INTERACTIVE_EVENT_CHANGED_USER, &info);
+             efl_event_thaw(obj);
+             changed_user = EINA_TRUE;
 
              ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
 
@@ -1052,6 +1056,10 @@ _key_down_cb(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, void
           }
      }
 end:
+   if (changed_user)
+     {
+        efl_event_callback_call(obj, EFL_UI_TEXT_EVENT_CHANGED_USER, &info);
+     }
    (void) 0;
 }
 
@@ -1304,9 +1312,10 @@ _mouse_move_cb(void *data EINA_UNUSED, Evas *e EINA_UNUSED, Evas_Object *obj, vo
 EOLIAN static Efl_Object *
 _efl_ui_internal_text_interactive_efl_object_constructor(Eo *obj, Efl_Ui_Internal_Text_Interactive_Data *en)
 {
+   obj = efl_constructor(efl_super(obj, MY_CLASS));
    en->select_allow = EINA_TRUE;
    en->editable = EINA_TRUE;
-   return efl_constructor(efl_super(obj, MY_CLASS));
+   return obj;
 }
 
 EOLIAN static Efl_Object *
@@ -1395,35 +1404,35 @@ done:
 }
 
 EOLIAN static void
-_efl_ui_internal_text_interactive_efl_ui_text_interactive_selection_allowed_set(Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *pd, Eina_Bool allowed)
+_efl_ui_internal_text_interactive_efl_text_interactive_selection_allowed_set(Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *pd, Eina_Bool allowed)
 {
    pd->select_allow = allowed;
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_internal_text_interactive_efl_ui_text_interactive_selection_allowed_get(Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *pd)
+_efl_ui_internal_text_interactive_efl_text_interactive_selection_allowed_get(const Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *pd)
 {
    return pd->select_allow;
 }
 
 EOLIAN static void
-_efl_ui_internal_text_interactive_efl_ui_text_interactive_selection_cursors_get(Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *pd, Efl_Text_Cursor_Cursor **start, Evas_Textblock_Cursor **end)
+_efl_ui_internal_text_interactive_efl_text_interactive_selection_cursors_get(const Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *pd, Efl_Text_Cursor_Cursor **start, Evas_Textblock_Cursor **end)
 {
    if (start) *start = pd->sel_start;
    if (end) *end = pd->sel_end;
 }
 
 EOLIAN static void
-_efl_ui_internal_text_interactive_efl_ui_text_interactive_editable_set(Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *sd, Eina_Bool editable)
+_efl_ui_internal_text_interactive_efl_text_interactive_editable_set(Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *sd, Eina_Bool editable)
 {
    sd->editable = editable;
 }
 
 EOLIAN static Eina_Bool
-_efl_ui_internal_text_interactive_efl_ui_text_interactive_editable_get(Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *sd)
+_efl_ui_internal_text_interactive_efl_text_interactive_editable_get(const Eo *obj EINA_UNUSED, Efl_Ui_Internal_Text_Interactive_Data *sd)
 {
    return sd->editable;
 }
 
 #include "efl_ui_internal_text_interactive.eo.c"
-#include "efl_ui_text_interactive.eo.c"
+#include "efl_text_interactive.eo.c"
