@@ -2,12 +2,18 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define ELM_WIDGET_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_widget_combobox.h"
+#include "elm_entry.eo.h"
+#include "elm_combobox.eo.h"
+#include "elm_genlist.eo.h"
+#include "elm_hover.eo.h"
 
 #define MY_CLASS ELM_COMBOBOX_CLASS
 
@@ -43,28 +49,26 @@ static const Elm_Action key_actions[] = {
    {NULL, NULL}
 };
 
-EOLIAN static Eina_Bool
-_elm_combobox_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Combobox_Data *sd)
+EOLIAN static void
+_elm_combobox_efl_ui_translatable_translation_update(Eo *obj EINA_UNUSED, Elm_Combobox_Data *sd)
 {
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-   elm_obj_widget_translate(sd->genlist);
-   elm_obj_widget_translate(sd->entry);
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
+   efl_ui_translatable_translation_update(sd->genlist);
+   efl_ui_translatable_translation_update(sd->entry);
 
    if (sd->hover)
-     elm_obj_widget_translate(sd->hover);
-
-   return EINA_TRUE;
+     efl_ui_translatable_translation_update(sd->hover);
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_combobox_elm_widget_theme_apply(Eo *obj, Elm_Combobox_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_combobox_efl_ui_widget_theme_apply(Eo *obj, Elm_Combobox_Data *sd)
 {
    const char *style;
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
    Eina_Bool mirrored;
    char buf[128];
 
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, ELM_THEME_APPLY_FAILED);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EFL_UI_THEME_APPLY_FAILED);
 
    style = eina_stringshare_add(elm_widget_style_get(obj));
 
@@ -73,8 +77,8 @@ _elm_combobox_elm_widget_theme_apply(Eo *obj, Elm_Combobox_Data *sd)
    /* combobox's style has no extra bit for orientation but could have... */
    eina_stringshare_replace(&(wd->style), buf);
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    eina_stringshare_replace(&(wd->style), style);
 
@@ -285,6 +289,25 @@ _on_clicked(void *data, const Efl_Event *event EINA_UNUSED)
    elm_combobox_hover_begin(data);
 }
 
+static Eo *
+_elm_combobox_component_add(Eo *obj, Eo *parent, const Efl_Class *klass, char *style)
+{
+   Eo *component;
+
+   if (elm_widget_is_legacy(obj))
+     {
+        component = elm_legacy_add(klass, parent,
+                       efl_ui_widget_style_set(efl_added, style));
+     }
+   else
+     {
+        component = efl_add(klass, parent,
+                       efl_ui_widget_style_set(efl_added, style));
+     }
+
+   return component;
+}
+
 EOLIAN static void
 _elm_combobox_efl_canvas_group_group_add(Eo *obj, Elm_Combobox_Data *sd EINA_UNUSED)
 {
@@ -296,7 +319,7 @@ _elm_combobox_efl_canvas_group_group_add(Eo *obj, Elm_Combobox_Data *sd EINA_UNU
    efl_event_callback_add(obj, EFL_UI_EVENT_CLICKED, _on_clicked, obj);
 
    //What are you doing here?
-   elm_obj_widget_theme_apply(obj);
+   efl_ui_widget_theme_apply(obj);
 }
 
 EOLIAN static void
@@ -307,12 +330,12 @@ _elm_combobox_efl_canvas_group_group_del(Eo *obj, Elm_Combobox_Data *sd)
 }
 
 EOLIAN static void
-_elm_combobox_efl_gfx_visible_set(Eo *obj, Elm_Combobox_Data *sd, Eina_Bool vis)
+_elm_combobox_efl_gfx_entity_visible_set(Eo *obj, Elm_Combobox_Data *sd, Eina_Bool vis)
 {
    if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_VISIBLE, 0, vis))
      return;
 
-   efl_gfx_visible_set(efl_super(obj, MY_CLASS), vis);
+   efl_gfx_entity_visible_set(efl_super(obj, MY_CLASS), vis);
    if (vis)
      {
         if (sd->expanded) evas_object_show(sd->hover);
@@ -324,7 +347,7 @@ _elm_combobox_efl_gfx_visible_set(Eo *obj, Elm_Combobox_Data *sd, Eina_Bool vis)
 }
 
 EOLIAN static Eina_Bool
-_elm_combobox_efl_ui_autorepeat_autorepeat_supported_get(Eo *obj EINA_UNUSED,
+_elm_combobox_efl_ui_autorepeat_autorepeat_supported_get(const Eo *obj EINA_UNUSED,
                                                          Elm_Combobox_Data *sd EINA_UNUSED)
 {
    return EINA_FALSE;
@@ -334,7 +357,7 @@ EAPI Evas_Object *
 elm_combobox_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -350,20 +373,20 @@ _elm_combobox_efl_object_constructor(Eo *obj, Elm_Combobox_Data *sd)
 
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_GLASS_PANE);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_GLASS_PANE);
 
    //hover-parent
    sd->hover_parent = elm_object_top_widget_get(obj);
 
+   snprintf(buf, sizeof(buf), "combobox_vertical/%s", elm_widget_style_get(obj));
+
    //hover
-   sd->hover = efl_add(ELM_HOVER_CLASS, sd->hover_parent);
+   sd->hover = _elm_combobox_component_add(obj, sd->hover_parent, ELM_HOVER_CLASS, buf);
+   efl_gfx_entity_visible_set(sd->hover, EINA_FALSE);
    evas_object_layer_set(sd->hover, EVAS_LAYER_MAX);
    efl_ui_mirrored_automatic_set(sd->hover, EINA_FALSE);
    elm_hover_target_set(sd->hover, obj);
    elm_widget_sub_object_add(obj, sd->hover);
-   snprintf(buf, sizeof(buf), "combobox_vertical/%s",
-              elm_widget_style_get(obj));
-   elm_object_style_set(sd->hover, buf);
 
    efl_event_callback_add
      (sd->hover, EFL_UI_EVENT_CLICKED, _on_hover_clicked, obj);
@@ -383,7 +406,7 @@ _elm_combobox_efl_object_constructor(Eo *obj, Elm_Combobox_Data *sd)
    elm_table_pack(sd->tbl, sd->spacer, 0, 0, 1, 1);
 
    // This is the genlist object that will take over the genlist call
-   sd->genlist = gl = efl_add(ELM_GENLIST_CLASS, obj);
+   sd->genlist = gl = _elm_combobox_component_add(obj, obj, ELM_GENLIST_CLASS, buf);
    elm_genlist_filter_set(gl, NULL);
    efl_ui_mirrored_automatic_set(gl, EINA_FALSE);
    efl_ui_mirrored_set(gl, efl_ui_mirrored_get(obj));
@@ -395,10 +418,9 @@ _elm_combobox_efl_object_constructor(Eo *obj, Elm_Combobox_Data *sd)
    elm_genlist_homogeneous_set(gl, EINA_TRUE);
    elm_genlist_mode_set(gl, ELM_LIST_COMPRESS);
    elm_table_pack(sd->tbl, gl, 0, 0, 1, 1);
-   elm_object_style_set(gl, buf);
 
    // This is the entry object that will take over the entry call
-   sd->entry = entry = efl_add(ELM_ENTRY_CLASS, obj);
+   sd->entry = entry = _elm_combobox_component_add(obj, obj, ELM_ENTRY_CLASS, buf);
    efl_ui_mirrored_automatic_set(entry, EINA_FALSE);
    efl_ui_mirrored_set(entry, efl_ui_mirrored_get(obj));
    elm_scroller_policy_set(entry, ELM_SCROLLER_POLICY_OFF,
@@ -410,7 +432,6 @@ _elm_combobox_efl_object_constructor(Eo *obj, Elm_Combobox_Data *sd)
    evas_object_show(entry);
 
    elm_object_part_content_set(obj, "elm.swallow.content", entry);
-   elm_object_style_set(entry, buf);
 
    efl_composite_attach(obj, gl);
    efl_composite_attach(obj, entry);
@@ -445,7 +466,7 @@ _elm_combobox_hover_end(Eo *obj, Elm_Combobox_Data *sd)
 }
 
 EOLIAN static Eina_Bool
-_elm_combobox_expanded_get(Eo *obj EINA_UNUSED, Elm_Combobox_Data *sd)
+_elm_combobox_expanded_get(const Eo *obj EINA_UNUSED, Elm_Combobox_Data *sd)
 {
    return sd->expanded;
 }
@@ -482,6 +503,7 @@ static Eina_Bool
 _key_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
 {
    ELM_COMBOBOX_DATA_GET(obj, sd);
+   if (!sd->hover) return EINA_FALSE;
    if (!sd->expanded)
      elm_combobox_hover_begin(obj);
    else
@@ -492,34 +514,18 @@ _key_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
-EOLIAN static Eina_Bool
-_elm_combobox_elm_widget_widget_event(Eo *obj, Elm_Combobox_Data *sd,
-                               Evas_Object *src EINA_UNUSED,
-                               Evas_Callback_Type type, void *event_info)
-{
-   Evas_Event_Key_Down *ev = event_info;
-   if (!sd || !sd->hover) return EINA_FALSE;
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions))
-     return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
-}
-
 static void
 _elm_combobox_class_constructor(Efl_Class *klass)
 {
    evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_combobox_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED,
+EOLIAN const Efl_Access_Action_Data *
+_elm_combobox_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED,
                                                                 Elm_Combobox_Data *pd
                                                                 EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
       {"activate", "activate", "return", _key_action_activate},
       {"move,up", "move", "up", _key_action_move},
       {"move,down", "move", "down", _key_action_move},
@@ -536,32 +542,40 @@ _elm_combobox_elm_genlist_filter_set(Eo *obj EINA_UNUSED, Elm_Combobox_Data *pd,
    elm_obj_genlist_filter_set(pd->genlist, key);
 }
 
-EOLIAN void
-_elm_combobox_elm_widget_part_text_set(Eo *obj EINA_UNUSED, Elm_Combobox_Data *pd,
-                                       const char * part, const char *label)
+// FIXME: Combobox part API is badly defined. Efl.Part should be reimplemented
+// properly, but this will be tricky: how to set "guide" on the "entry" part?
+void
+_elm_combobox_part_text_set(Eo *obj, const char * part, const char *label)
 {
+   Elm_Combobox_Data *pd = efl_data_scope_safe_get(obj, MY_CLASS);
+   if (!pd) return;
    elm_object_part_text_set(pd->entry, part, label);
 }
 
-EOLIAN const char *
-_elm_combobox_elm_widget_part_text_get(Eo *obj EINA_UNUSED, Elm_Combobox_Data *pd,
-                                       const char * part)
+const char *
+_elm_combobox_part_text_get(const Eo *obj, const char *part)
 {
+   Elm_Combobox_Data *pd = efl_data_scope_safe_get(obj, MY_CLASS);
+   if (!pd) return NULL;
    return elm_object_part_text_get(pd->entry, part);
 }
 
 EOLIAN static void
-_elm_combobox_efl_gfx_size_set(Eo *obj, Elm_Combobox_Data *pd, Evas_Coord w, Evas_Coord h)
+_elm_combobox_efl_gfx_entity_size_set(Eo *obj, Elm_Combobox_Data *pd, Eina_Size2D sz)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
    if (pd->count > 0) _table_resize(obj);
-   efl_gfx_size_set(efl_super(obj, MY_CLASS), w, h);
+   efl_gfx_entity_size_set(efl_super(obj, MY_CLASS), sz);
 }
 
 /* Internal EO APIs and hidden overrides */
 
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(elm_combobox, Elm_Combobox_Data)
+
+/* Internal EO APIs and hidden overrides */
+
 #define ELM_COMBOBOX_EXTRA_OPS \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_combobox)
 
