@@ -2,18 +2,22 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
-
-#define ELM_WIDGET_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define EFL_UI_WIDGET_PROTECTED
+//#define EFL_UI_WIDGET_BETA
 #define ELM_WIDGET_ITEM_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 
 #include "elm_priv.h"
 #include "elm_widget_ctxpopup.h"
+#include "elm_ctxpopup_item.eo.h"
+#include "elm_ctxpopup.eo.h"
 
-#include "elm_ctxpopup_internal_part.eo.h"
+#include "elm_ctxpopup_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_CTXPOPUP_CLASS
@@ -38,17 +42,15 @@ static const Evas_Smart_Cb_Description _smart_callbacks[] = {
 };
 #undef ELM_PRIV_CTXPOPUP_SIGNALS
 
-static Eina_Bool _key_action_move(Evas_Object *obj, const char *params);
 static Eina_Bool _key_action_escape(Evas_Object *obj, const char *params);
 
 static const Elm_Action key_actions[] = {
-   {"move", _key_action_move},
    {"escape", _key_action_escape},
    {NULL, NULL}
 };
 
-EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_widget_translate(Eo *obj, Elm_Ctxpopup_Data *sd)
+EOLIAN static void
+_elm_ctxpopup_efl_ui_translatable_translation_update(Eo *obj, Elm_Ctxpopup_Data *sd)
 {
    Eina_List *l;
    Elm_Object_Item *it;
@@ -58,84 +60,7 @@ _elm_ctxpopup_elm_widget_translate(Eo *obj, Elm_Ctxpopup_Data *sd)
    EINA_LIST_FOREACH(sd->items, l, it)
      elm_wdg_item_translate(it);
 
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_widget_focus_next(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   if (!sd)
-     return EINA_FALSE;
-
-   if (!elm_widget_focus_next_get(sd->box, dir, next, next_item))
-     {
-        elm_widget_focused_object_clear(sd->box);
-        elm_widget_focus_next_get(sd->box, dir, next, next_item);
-     }
-
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_widget_focus_direction(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Eina_Bool int_ret;
-
-   Eina_List *l = NULL;
-   void *(*list_data_get)(const Eina_List *list);
-
-   if (!sd)
-     return EINA_FALSE;
-
-   list_data_get = eina_list_data_get;
-
-   l = eina_list_append(l, sd->box);
-
-   int_ret = elm_widget_focus_list_direction_get
-            (obj, base, l, list_data_get, degree, direction, direction_item, weight);
-   eina_list_free(l);
-
-   return int_ret;
-}
-
-static Eina_Bool
-_key_action_move(Evas_Object *obj, const char *params)
-{
-   ELM_CTXPOPUP_DATA_GET(obj, sd);
-   const char *dir = params;
-
-   if (!sd->box) return EINA_FALSE;
-
-   _elm_widget_focus_auto_show(obj);
-   if (!strcmp(dir, "previous"))
-     elm_widget_focus_cycle(sd->box, ELM_FOCUS_PREVIOUS);
-   else if (!strcmp(dir, "next"))
-     elm_widget_focus_cycle(sd->box, ELM_FOCUS_NEXT);
-   else if (!strcmp(dir, "left"))
-     elm_widget_focus_cycle(sd->box, ELM_FOCUS_LEFT);
-   else if (!strcmp(dir, "right"))
-     elm_widget_focus_cycle(sd->box, ELM_FOCUS_RIGHT);
-   else if (!strcmp(dir, "up"))
-     elm_widget_focus_cycle(sd->box, ELM_FOCUS_UP);
-   else if (!strcmp(dir, "down"))
-     elm_widget_focus_cycle(sd->box, ELM_FOCUS_DOWN);
-   else return EINA_FALSE;
-
-   return EINA_TRUE;
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
 }
 
 static Eina_Bool
@@ -145,26 +70,10 @@ _key_action_escape(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
-EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_widget_widget_event(Eo *obj, Elm_Ctxpopup_Data *sd EINA_UNUSED, Evas_Object *src, Evas_Callback_Type type, void *event_info)
-{
-   Evas_Event_Key_Down *ev = event_info;
-   (void)src;
-
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions))
-     return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
-}
-
 static void
 _x_pos_adjust(Evas_Coord_Point *pos,
               Evas_Coord_Point *base_size,
-              Evas_Coord_Rectangle *hover_area)
+              Eina_Rectangle *hover_area)
 {
    pos->x -= (base_size->x / 2);
 
@@ -183,7 +92,7 @@ _x_pos_adjust(Evas_Coord_Point *pos,
 static void
 _y_pos_adjust(Evas_Coord_Point *pos,
               Evas_Coord_Point *base_size,
-              Evas_Coord_Rectangle *hover_area)
+              Eina_Rectangle *hover_area)
 {
    pos->y -= (base_size->y / 2);
 
@@ -201,10 +110,10 @@ _y_pos_adjust(Evas_Coord_Point *pos,
 
 static Elm_Ctxpopup_Direction
 _base_geometry_calc(Evas_Object *obj,
-                    Evas_Coord_Rectangle *rect)
+                    Eina_Rectangle *rect)
 {
    Elm_Ctxpopup_Direction dir = ELM_CTXPOPUP_DIRECTION_UNKNOWN;
-   Evas_Coord_Rectangle hover_area;
+   Eina_Rectangle hover_area;
    Evas_Coord_Point pos = {0, 0};
    Evas_Coord_Point arrow_size;
    Evas_Coord_Point base_size;
@@ -245,7 +154,7 @@ _base_geometry_calc(Evas_Object *obj,
    if ((max_size.x > 0) && (base_size.x > max_size.x))
      base_size.x = max_size.x;
    //Limit to Min Size
-   efl_gfx_size_hint_combined_min_get(obj, &min_size.x, &min_size.y);
+   evas_object_size_hint_combined_min_get(obj, &min_size.x, &min_size.y);
 
    if ((min_size.y > 0) && (base_size.y < min_size.y))
      base_size.y = min_size.y;
@@ -310,7 +219,7 @@ _base_geometry_calc(Evas_Object *obj,
      {
         Evas_Coord length[2];
 
-        if (sd->orient == EFL_ORIENT_VERTICAL)
+        if (!sd->horizontal)
           {
              length[0] = pos.y - hover_area.y;
              length[1] = (hover_area.y + hover_area.h) - pos.y;
@@ -382,9 +291,9 @@ _base_geometry_calc(Evas_Object *obj,
 static void
 _arrow_update(Evas_Object *obj,
               Elm_Ctxpopup_Direction dir,
-              Evas_Coord_Rectangle base_size)
+              Eina_Rectangle base_size)
 {
-   Evas_Coord_Rectangle arrow_size;
+   Eina_Rectangle arrow_size;
    Evas_Coord x, y;
    double drag;
 
@@ -586,7 +495,7 @@ _hide_signals_emit(Evas_Object *obj,
 static void
 _base_shift_by_arrow(Evas_Object *arrow,
                      Elm_Ctxpopup_Direction dir,
-                     Evas_Coord_Rectangle *rect)
+                     Eina_Rectangle *rect)
 {
    Evas_Coord arrow_w, arrow_h;
 
@@ -615,15 +524,18 @@ _base_shift_by_arrow(Evas_Object *arrow,
 }
 
 EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_layout_sub_object_add_enable(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *_pd EINA_UNUSED)
+_elm_ctxpopup_efl_ui_widget_widget_sub_object_add(Eo *obj, Elm_Ctxpopup_Data *_pd EINA_UNUSED, Evas_Object *sobj)
 {
-   return EINA_FALSE;
+   /* Skipping elm_layout widget_sub_object_add in order to ignore size hint changes.
+    * Note: It is not clear WHY we are doing this. Same reason as genlist?
+    */
+   return elm_widget_sub_object_add(efl_cast(obj, EFL_UI_WIDGET_CLASS), sobj);
 }
 
 EOLIAN static void
 _elm_ctxpopup_elm_layout_sizing_eval(Eo *obj, Elm_Ctxpopup_Data *sd)
 {
-   Evas_Coord_Rectangle rect = { 0, 0, 1, 1 };
+   Eina_Rectangle rect = { 0, 0, 1, 1 };
    Evas_Coord_Point list_size = { 0, 0 }, parent_size = {0, 0};
 
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
@@ -756,13 +668,13 @@ _on_content_resized(void *data,
 }
 
 //FIXME: lost the content size when theme hook is called.
-EOLIAN static Elm_Theme_Apply
-_elm_ctxpopup_elm_widget_theme_apply(Eo *obj, Elm_Ctxpopup_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_ctxpopup_efl_ui_widget_theme_apply(Eo *obj, Elm_Ctxpopup_Data *sd)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    elm_widget_theme_object_set
      (obj, sd->bg, "ctxpopup", "bg", elm_widget_style_get(obj));
@@ -789,7 +701,7 @@ _elm_ctxpopup_elm_widget_theme_apply(Eo *obj, Elm_Ctxpopup_Data *sd)
 static Eina_Bool
 _elm_ctxpopup_content_set(Eo *obj, Elm_Ctxpopup_Data *sd, const char *part, Evas_Object *content)
 {
-   if ((part) && (strcmp(part, "default")))
+   if ((part) && (strcmp(part, "elm.swallow.content")))
      {
         return efl_content_set(efl_part(efl_super(obj, MY_CLASS), part), content);
      }
@@ -822,7 +734,7 @@ _elm_ctxpopup_content_set(Eo *obj, Elm_Ctxpopup_Data *sd, const char *part, Evas
 static Evas_Object*
 _elm_ctxpopup_content_get(Eo *obj, Elm_Ctxpopup_Data *sd, const char *part)
 {
-   if ((part) && (strcmp(part, "default")))
+   if ((part) && (strcmp(part, "elm.swallow.content")))
      return efl_content_get(efl_part(efl_super(obj, MY_CLASS), part));
 
    return sd->content;
@@ -833,7 +745,7 @@ _elm_ctxpopup_content_unset(Eo *obj, Elm_Ctxpopup_Data *sd, const char *part)
 {
    Evas_Object *content = NULL;
 
-   if ((part) && (strcmp(part, "default")))
+   if ((part) && (strcmp(part, "elm.swallow.content")))
      return efl_content_unset(efl_part(efl_super(obj, MY_CLASS), part));
 
    content = sd->content;
@@ -867,7 +779,7 @@ _elm_ctxpopup_item_elm_widget_item_part_text_set(Eo *eo_ctxpopup_it EINA_UNUSED,
 }
 
 EOLIAN static const char *
-_elm_ctxpopup_item_elm_widget_item_part_text_get(Eo *eo_ctxpopup_it EINA_UNUSED,
+_elm_ctxpopup_item_elm_widget_item_part_text_get(const Eo *eo_ctxpopup_it EINA_UNUSED,
                                                  Elm_Ctxpopup_Item_Data *ctxpopup_it,
                                                  const char *part)
 {
@@ -900,7 +812,7 @@ _elm_ctxpopup_item_elm_widget_item_part_content_set(Eo *eo_ctxpopup_it EINA_UNUS
 }
 
 EOLIAN static Evas_Object *
-_elm_ctxpopup_item_elm_widget_item_part_content_get(Eo *eo_ctxpopup_it EINA_UNUSED,
+_elm_ctxpopup_item_elm_widget_item_part_content_get(const Eo *eo_ctxpopup_it EINA_UNUSED,
                                                     Elm_Ctxpopup_Item_Data *ctxpopup_it,
                                                     const char *part)
 {
@@ -913,6 +825,31 @@ _elm_ctxpopup_item_elm_widget_item_part_content_get(Eo *eo_ctxpopup_it EINA_UNUS
      return elm_object_item_part_content_get(ctxpopup_it->list_item, "start");
 }
 
+EOLIAN static Evas_Object *
+_elm_ctxpopup_item_elm_widget_item_part_content_unset(Eo *eo_ctxpopup_it EINA_UNUSED,
+                                                      Elm_Ctxpopup_Item_Data *ctxpopup_it,
+                                                      const char *part)
+{
+   Evas_Object *content = NULL;
+
+   if ((part) && (strcmp(part, "icon"))
+       && (strcmp(part, "start"))
+       && (strcmp(part, "end"))) return NULL;
+
+   ELM_CTXPOPUP_DATA_GET(WIDGET(ctxpopup_it), sd);
+
+   if ((part) && (!strcmp(part, "end")))
+     content = elm_object_item_part_content_unset(ctxpopup_it->list_item, "end");
+   else
+     content = elm_object_item_part_content_unset(ctxpopup_it->list_item, "start");
+
+   sd->dir = ELM_CTXPOPUP_DIRECTION_UNKNOWN;
+
+   if (sd->visible) elm_layout_sizing_eval(WIDGET(ctxpopup_it));
+
+   return content;
+}
+
 EOLIAN static void
 _elm_ctxpopup_item_elm_widget_item_disable(Eo *eo_ctxpopup_it,
                                            Elm_Ctxpopup_Item_Data *ctxpopup_it)
@@ -921,6 +858,17 @@ _elm_ctxpopup_item_elm_widget_item_disable(Eo *eo_ctxpopup_it,
      (ctxpopup_it->list_item, elm_wdg_item_disabled_get(eo_ctxpopup_it));
 }
 
+EOLIAN static void
+_elm_ctxpopup_item_elm_widget_item_del_pre(Eo *eo_ctxpopup_it EINA_UNUSED,
+                                           Elm_Ctxpopup_Item_Data *ctxpopup_it)
+{
+   if (ctxpopup_it->list_item)
+     {
+        elm_object_item_del(ctxpopup_it->list_item);
+        ctxpopup_it->list_item = NULL;
+     }
+}
+
 EOLIAN static void
 _elm_ctxpopup_item_elm_widget_item_signal_emit(Eo *eo_ctxpopup_it EINA_UNUSED,
                                                Elm_Ctxpopup_Item_Data *ctxpopup_it,
@@ -931,7 +879,7 @@ _elm_ctxpopup_item_elm_widget_item_signal_emit(Eo *eo_ctxpopup_it EINA_UNUSED,
 }
 
 EOLIAN static void
-_elm_ctxpopup_item_elm_widget_item_focus_set(Eo *eo_ctxpopup_it EINA_UNUSED,
+_elm_ctxpopup_item_elm_widget_item_item_focus_set(Eo *eo_ctxpopup_it EINA_UNUSED,
                                              Elm_Ctxpopup_Item_Data *ctxpopup_it,
                                              Eina_Bool focused)
 {
@@ -939,7 +887,7 @@ _elm_ctxpopup_item_elm_widget_item_focus_set(Eo *eo_ctxpopup_it EINA_UNUSED,
 }
 
 EOLIAN static Eina_Bool
-_elm_ctxpopup_item_elm_widget_item_focus_get(Eo *eo_ctxpopup_it EINA_UNUSED,
+_elm_ctxpopup_item_elm_widget_item_item_focus_get(const Eo *eo_ctxpopup_it EINA_UNUSED,
                                              Elm_Ctxpopup_Item_Data *ctxpopup_it)
 {
    return elm_object_item_focus_get(ctxpopup_it->list_item);
@@ -1064,7 +1012,10 @@ _elm_ctxpopup_item_efl_object_destructor(Eo *eo_ctxpopup_it,
    list = elm_object_item_widget_get(ctxpopup_it->list_item);
 
    if (ctxpopup_it->list_item)
-      efl_unref(ctxpopup_it->list_item);
+     {
+        elm_object_item_del(ctxpopup_it->list_item);
+        ctxpopup_it->list_item = NULL;
+     }
    sd->items = eina_list_remove(sd->items, eo_ctxpopup_it);
    if (list && eina_list_count(elm_list_items_get(list)) < 2)
      {
@@ -1079,16 +1030,15 @@ _elm_ctxpopup_item_efl_object_destructor(Eo *eo_ctxpopup_it,
 }
 
 EOLIAN static Eina_Bool
-_elm_ctxpopup_elm_widget_disable(Eo *obj, Elm_Ctxpopup_Data *sd)
+_elm_ctxpopup_efl_ui_widget_on_disabled_update(Eo *obj, Elm_Ctxpopup_Data *sd, Eina_Bool disabled)
 {
-   Eina_Bool int_ret = EINA_FALSE;
+   if (!efl_ui_widget_on_disabled_update(efl_super(obj, MY_CLASS), disabled))
+     return EINA_FALSE;
 
-   int_ret = elm_obj_widget_disable(efl_super(obj, MY_CLASS));
-   if (!int_ret) return EINA_FALSE;
    if (sd->list)
-     elm_object_disabled_set(sd->list, elm_widget_disabled_get(obj));
+     elm_object_disabled_set(sd->list, disabled);
    else if (sd->content)
-     elm_object_disabled_set(sd->content, elm_widget_disabled_get(obj));
+     elm_object_disabled_set(sd->content, disabled);
 
    return EINA_TRUE;
 }
@@ -1129,8 +1079,6 @@ _elm_ctxpopup_efl_canvas_group_group_add(Eo *obj, Elm_Ctxpopup_Data *priv)
    priv->dir = ELM_CTXPOPUP_DIRECTION_UNKNOWN;
    priv->auto_hide = EINA_TRUE;
 
-   priv->orient = EFL_ORIENT_VERTICAL;
-
    priv->box = elm_box_add(obj);
    evas_object_size_hint_weight_set
      (priv->box, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
@@ -1153,23 +1101,22 @@ _elm_ctxpopup_efl_canvas_group_group_del(Eo *obj, Elm_Ctxpopup_Data *sd)
 {
    Elm_Object_Item *it;
 
-   evas_object_event_callback_del_full
-     (sd->box, EVAS_CALLBACK_RESIZE, _on_content_resized, obj);
-   evas_object_event_callback_del(sd->content, EVAS_CALLBACK_DEL, _on_content_del);
+   if (sd->content) evas_object_event_callback_del(sd->content, EVAS_CALLBACK_DEL, _on_content_del);
    _parent_detach(obj);
 
+   //clear the items before clearing the ctxpopup as this will remove the list and all items
+   EINA_LIST_FREE(sd->items, it)
+     efl_del(it);
+
    elm_ctxpopup_clear(obj);
    ELM_SAFE_FREE(sd->arrow, evas_object_del); /* stops _sizing_eval() from going on on deletion */
    ELM_SAFE_FREE(sd->bg, evas_object_del);
 
-   EINA_LIST_FREE(sd->items, it)
-     efl_del(it);
-
    efl_canvas_group_del(efl_super(obj, MY_CLASS));
 }
 
 EOLIAN static void
-_elm_ctxpopup_elm_widget_widget_parent_set(Eo *obj, Elm_Ctxpopup_Data *_pd EINA_UNUSED, Evas_Object *parent)
+_elm_ctxpopup_efl_ui_widget_widget_parent_set(Eo *obj, Elm_Ctxpopup_Data *_pd EINA_UNUSED, Evas_Object *parent)
 {
    //default parent is to be hover parent
    elm_ctxpopup_hover_parent_set(obj, parent);
@@ -1179,7 +1126,7 @@ EAPI Evas_Object *
 elm_ctxpopup_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   Evas_Object *obj = efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   Evas_Object *obj = elm_legacy_add(MY_CLASS, parent);
 
    /* access: parent could be any object such as elm_list which does
       not know elc_ctxpopup as its child object in the focus_next(); */
@@ -1195,7 +1142,7 @@ _elm_ctxpopup_efl_object_constructor(Eo *obj, Elm_Ctxpopup_Data *_pd EINA_UNUSED
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_POPUP_MENU);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_POPUP_MENU);
 
    return obj;
 }
@@ -1229,7 +1176,7 @@ _elm_ctxpopup_hover_parent_set(Eo *obj, Elm_Ctxpopup_Data *sd, Evas_Object *pare
 }
 
 EOLIAN static Evas_Object*
-_elm_ctxpopup_hover_parent_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+_elm_ctxpopup_hover_parent_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
    return sd->parent;
 }
@@ -1241,64 +1188,29 @@ _elm_ctxpopup_clear(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
    sd->dir = ELM_CTXPOPUP_DIRECTION_UNKNOWN;
 }
 
-EAPI void
-elm_ctxpopup_horizontal_set(Evas_Object *obj, Eina_Bool horizontal)
+EOLIAN static void
+_elm_ctxpopup_horizontal_set(Eo *obj, Elm_Ctxpopup_Data *sd, Eina_Bool horizontal)
 {
-   efl_orientation_set(obj, horizontal ? EFL_ORIENT_HORIZONTAL : EFL_ORIENT_VERTICAL);
+   sd->horizontal = !!horizontal;
+
+   if (!sd->list) return;
+
+   elm_list_horizontal_set(sd->list, sd->horizontal);
+
+   sd->dir = ELM_CTXPOPUP_DIRECTION_UNKNOWN;
+
+   if (sd->visible) elm_layout_sizing_eval(obj);
 }
 
-EAPI Eina_Bool
-elm_ctxpopup_horizontal_get(const Evas_Object *obj)
+EOLIAN static Eina_Bool
+_elm_ctxpopup_horizontal_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
-   ELM_CTXPOPUP_DATA_GET_OR_RETURN_VAL(obj, sd, EINA_FALSE);
-
-   return sd->orient == EFL_ORIENT_HORIZONTAL ? EINA_TRUE : EINA_FALSE;
-}
-
-EAPI const Eina_List *
-elm_ctxpopup_items_get(const Evas_Object *obj)
-{
-   Eina_List *lst = NULL;
-   Eina_Iterator *it;
-   void *item_data;
-
-   it = efl_ui_menu_items_get(obj);
-   EINA_ITERATOR_FOREACH(it, item_data)
-     {
-        lst = eina_list_append(lst, item_data);
-     }
-   eina_iterator_free(it);
-   return lst;
-}
-
-EAPI Elm_Widget_Item *
-elm_ctxpopup_first_item_get(const Evas_Object *obj)
-{
-   return efl_ui_menu_first_item_get(obj);
-}
-
-EAPI Elm_Widget_Item *
-elm_ctxpopup_last_item_get(const Evas_Object *obj)
-{
-   return efl_ui_menu_last_item_get(obj);
-}
-
-EAPI Elm_Widget_Item *
-elm_ctxpopup_item_prev_get(const Evas_Object *obj)
-{
-   return efl_ui_item_prev_get(obj);
-}
-
-EAPI Elm_Widget_Item *
-elm_ctxpopup_item_next_get(const Evas_Object *obj)
-{
-   return efl_ui_item_next_get(obj);
+   return sd->horizontal;
 }
 
 static void
-_item_wrap_cb(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+_item_select(Elm_Ctxpopup_Item_Data *item)
 {
-   Elm_Ctxpopup_Item_Data *item = data;
    Elm_Object_Item *eo_item2;
    Eina_List *l;
 
@@ -1314,6 +1226,13 @@ _item_wrap_cb(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UN
    item->wcb.org_func_cb((void *)item->wcb.org_data, item->wcb.cobj, EO_OBJ(item));
 }
 
+static void
+_item_wrap_cb(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED)
+{
+   Elm_Ctxpopup_Item_Data *item = data;
+   _item_select(item);
+}
+
 EOLIAN static Eo *
 _elm_ctxpopup_item_efl_object_constructor(Eo *obj, Elm_Ctxpopup_Item_Data *it)
 {
@@ -1323,6 +1242,56 @@ _elm_ctxpopup_item_efl_object_constructor(Eo *obj, Elm_Ctxpopup_Item_Data *it)
    return obj;
 }
 
+EOLIAN static Elm_Object_Item*
+_elm_ctxpopup_item_insert_before(Eo *obj, Elm_Ctxpopup_Data *sd, Elm_Object_Item *eo_before, const char *label, Evas_Object *icon, Evas_Smart_Cb func, const void *data)
+{
+   Eo *eo_item;
+
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_before, NULL);
+   ELM_CTXPOPUP_ITEM_DATA_GET(eo_before, before_it);
+   ELM_CTXPOPUP_ITEM_CHECK_OR_RETURN(before_it,  NULL);
+
+   if (!before_it->list_item) return NULL;
+
+   eo_item = efl_add(ELM_CTXPOPUP_ITEM_CLASS, obj, elm_obj_ctxpopup_item_init(efl_added, func, data));
+   if (!eo_item) return NULL;
+
+   ELM_CTXPOPUP_ITEM_DATA_GET(eo_item, item);
+
+   item->list_item =
+     elm_list_item_insert_before(sd->list, before_it->list_item, label, icon, NULL, _item_wrap_cb, item);
+   sd->items = eina_list_prepend_relative(sd->items, eo_item, eo_before);
+
+   if (sd->visible) elm_layout_sizing_eval(obj);
+
+   return eo_item;
+}
+
+EOLIAN static Elm_Object_Item*
+_elm_ctxpopup_item_insert_after(Eo *obj, Elm_Ctxpopup_Data *sd, Elm_Object_Item *eo_after, const char *label, Evas_Object *icon, Evas_Smart_Cb func, const void *data)
+{
+   Eo *eo_item;
+
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_after, NULL);
+   ELM_CTXPOPUP_ITEM_DATA_GET(eo_after, after_it);
+   ELM_CTXPOPUP_ITEM_CHECK_OR_RETURN(after_it,  NULL);
+
+   if (!after_it->list_item) return NULL;
+
+   eo_item = efl_add(ELM_CTXPOPUP_ITEM_CLASS, obj, elm_obj_ctxpopup_item_init(efl_added, func, data));
+   if (!eo_item) return NULL;
+
+   ELM_CTXPOPUP_ITEM_DATA_GET(eo_item, item);
+
+   item->list_item =
+     elm_list_item_insert_after(sd->list, after_it->list_item, label, icon, NULL, _item_wrap_cb, item);
+   sd->items = eina_list_append_relative(sd->items, eo_item, eo_after);
+
+   if (sd->visible) elm_layout_sizing_eval(obj);
+
+   return eo_item;
+}
+
 EOLIAN static Elm_Object_Item*
 _elm_ctxpopup_item_append(Eo *obj, Elm_Ctxpopup_Data *sd, const char *label, Evas_Object *icon, Evas_Smart_Cb func, const void *data)
 {
@@ -1335,7 +1304,6 @@ _elm_ctxpopup_item_append(Eo *obj, Elm_Ctxpopup_Data *sd, const char *label, Eva
 
    item->list_item =
      elm_list_item_append(sd->list, label, icon, NULL, _item_wrap_cb, item);
-   efl_ref(item->list_item);
    sd->items = eina_list_append(sd->items, eo_item);
 
    if (sd->visible) elm_layout_sizing_eval(obj);
@@ -1355,7 +1323,7 @@ _elm_ctxpopup_direction_priority_set(Eo *obj, Elm_Ctxpopup_Data *sd, Elm_Ctxpopu
 }
 
 EOLIAN static void
-_elm_ctxpopup_direction_priority_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd, Elm_Ctxpopup_Direction *first, Elm_Ctxpopup_Direction *second, Elm_Ctxpopup_Direction *third, Elm_Ctxpopup_Direction *fourth)
+_elm_ctxpopup_direction_priority_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd, Elm_Ctxpopup_Direction *first, Elm_Ctxpopup_Direction *second, Elm_Ctxpopup_Direction *third, Elm_Ctxpopup_Direction *fourth)
 {
    if (first) *first = sd->dir_priority[0];
    if (second) *second = sd->dir_priority[1];
@@ -1364,7 +1332,7 @@ _elm_ctxpopup_direction_priority_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd,
 }
 
 EOLIAN static Elm_Ctxpopup_Direction
-_elm_ctxpopup_direction_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+_elm_ctxpopup_direction_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
    return sd->dir;
 }
@@ -1383,7 +1351,7 @@ _elm_ctxpopup_auto_hide_disabled_set(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd,
 }
 
 EOLIAN static Eina_Bool
-_elm_ctxpopup_auto_hide_disabled_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+_elm_ctxpopup_auto_hide_disabled_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
    return !sd->auto_hide;
 }
@@ -1394,14 +1362,14 @@ _elm_ctxpopup_class_constructor(Efl_Class *klass)
    evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
 
-EOLIAN static Eina_Iterator*
-_elm_ctxpopup_efl_ui_menu_items_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+EOLIAN static const Eina_List *
+_elm_ctxpopup_items_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
-   return eina_list_iterator_new(sd->items);
+   return sd->items;
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_ctxpopup_efl_ui_menu_first_item_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+_elm_ctxpopup_first_item_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
    if (!sd->items) return NULL;
 
@@ -1409,7 +1377,7 @@ _elm_ctxpopup_efl_ui_menu_first_item_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_ctxpopup_efl_ui_menu_last_item_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+_elm_ctxpopup_last_item_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
    if (!sd->items) return NULL;
 
@@ -1417,7 +1385,7 @@ _elm_ctxpopup_efl_ui_menu_last_item_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_ctxpopup_efl_ui_menu_selected_item_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+_elm_ctxpopup_selected_item_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
 {
    Eina_List *l;
    Elm_Object_Item *eo_item;
@@ -1431,6 +1399,14 @@ _elm_ctxpopup_efl_ui_menu_selected_item_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Da
    return NULL;
 }
 
+EOLIAN static Elm_Object_Item*
+_elm_ctxpopup_efl_ui_widget_focused_item_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd)
+{
+   if (!sd->list) return NULL;
+
+   return elm_object_focused_item_get(sd->list);
+}
+
 EOLIAN static Elm_Object_Item*
 _elm_ctxpopup_item_prepend(Eo *obj, Elm_Ctxpopup_Data *sd, const char *label, Evas_Object *icon, Evas_Smart_Cb func, const void *data)
 {
@@ -1443,7 +1419,6 @@ _elm_ctxpopup_item_prepend(Eo *obj, Elm_Ctxpopup_Data *sd, const char *label, Ev
 
    item->list_item =
      elm_list_item_prepend(sd->list, label, icon, NULL, _item_wrap_cb, item);
-   efl_ref(item->list_item);
    sd->items = eina_list_prepend(sd->items, eo_item);
 
    if (sd->visible) elm_layout_sizing_eval(obj);
@@ -1452,7 +1427,7 @@ _elm_ctxpopup_item_prepend(Eo *obj, Elm_Ctxpopup_Data *sd, const char *label, Ev
 }
 
 EOLIAN static Elm_Object_Item *
-_elm_ctxpopup_item_efl_ui_item_prev_get(Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_Item_Data *item)
+_elm_ctxpopup_item_prev_get(const Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_Item_Data *item)
 {
    Eina_List *l;
 
@@ -1467,7 +1442,7 @@ _elm_ctxpopup_item_efl_ui_item_prev_get(Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_It
 }
 
 EOLIAN static Elm_Object_Item *
-_elm_ctxpopup_item_efl_ui_item_next_get(Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_Item_Data *item)
+_elm_ctxpopup_item_next_get(const Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_Item_Data *item)
 {
    Eina_List *l;
 
@@ -1482,7 +1457,7 @@ _elm_ctxpopup_item_efl_ui_item_next_get(Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_It
 }
 
 EOLIAN static void
-_elm_ctxpopup_item_efl_ui_item_selected_set(Eo *eo_item EINA_UNUSED,
+_elm_ctxpopup_item_selected_set(Eo *eo_item EINA_UNUSED,
                                             Elm_Ctxpopup_Item_Data *item,
                                             Eina_Bool selected)
 {
@@ -1505,7 +1480,7 @@ _elm_ctxpopup_item_efl_ui_item_selected_set(Eo *eo_item EINA_UNUSED,
 }
 
 EOLIAN static Eina_Bool
-_elm_ctxpopup_item_efl_ui_item_selected_get(Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_Item_Data *item)
+_elm_ctxpopup_item_selected_get(const Eo *eo_item EINA_UNUSED, Elm_Ctxpopup_Item_Data *item)
 {
    return item->selected;
 }
@@ -1526,8 +1501,7 @@ _elm_ctxpopup_item_init(Eo *eo_item,
           elm_object_style_set(sd->list, "ctxpopup");
         else elm_object_style_set(sd->list, elm_object_style_get(obj));
         elm_list_mode_set(sd->list, ELM_LIST_EXPAND);
-        //TODO: use orient interface API on list when implemented
-        elm_list_horizontal_set(sd->list, sd->orient == EFL_ORIENT_VERTICAL ? EINA_FALSE : EINA_TRUE);
+        elm_list_horizontal_set(sd->list, sd->horizontal);
         evas_object_event_callback_add
           (sd->list, EVAS_CALLBACK_RESIZE, _list_resize_cb, obj);
         elm_layout_content_set(obj, "default", sd->list);
@@ -1540,67 +1514,65 @@ _elm_ctxpopup_item_init(Eo *eo_item,
    sd->dir = ELM_CTXPOPUP_DIRECTION_UNKNOWN;
 }
 
-EOLIAN static Efl_Orient
-_elm_ctxpopup_efl_orientation_orientation_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *pd)
+EOLIAN static const Efl_Access_Action_Data*
+_elm_ctxpopup_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd EINA_UNUSED)
 {
-   return pd->orient;
-}
-
-EOLIAN static void
-_elm_ctxpopup_efl_orientation_orientation_set(Eo *obj, Elm_Ctxpopup_Data *pd, Efl_Orient orient)
-{
-   if (pd->orient == orient) return;
-   if (pd->orient != EFL_ORIENT_HORIZONTAL && pd->orient != EFL_ORIENT_VERTICAL) return;
-
-   pd->orient = orient;
-   //TODO: use orient API on list when its implemented
-   elm_list_horizontal_set(pd->list, pd->orient == EFL_ORIENT_HORIZONTAL ? EINA_TRUE : EINA_FALSE);
-   pd->dir = ELM_CTXPOPUP_DIRECTION_UNKNOWN;
-   if (pd->visible) elm_layout_sizing_eval(obj);
-}
-
-EOLIAN static const Elm_Atspi_Action*
-_elm_ctxpopup_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Ctxpopup_Data *sd EINA_UNUSED)
-{
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "escape", "escape", NULL, _key_action_escape},
-          { "move,previous", "move", "previous", _key_action_move},
-          { "move,next", "move", "next", _key_action_move},
-          { "move,left", "move", "left", _key_action_move},
-          { "move,right", "move", "right", _key_action_move},
-          { "move,up", "move", "up", _key_action_move},
-          { "move,down", "move", "down", _key_action_move},
           { NULL, NULL, NULL, NULL }
    };
    return &atspi_actions[0];
 }
 
-EOLIAN static Elm_Atspi_State_Set
-_elm_ctxpopup_elm_interface_atspi_accessible_state_set_get(Eo *obj, Elm_Ctxpopup_Data *sd EINA_UNUSED)
+EOLIAN static Efl_Access_State_Set
+_elm_ctxpopup_efl_access_object_state_set_get(const Eo *obj, Elm_Ctxpopup_Data *sd EINA_UNUSED)
 {
-   Elm_Atspi_State_Set ret;
-   ret = elm_interface_atspi_accessible_state_set_get(efl_super(obj, MY_CLASS));
+   Efl_Access_State_Set ret;
+   ret = efl_access_object_state_set_get(efl_super(obj, MY_CLASS));
 
-   STATE_TYPE_SET(ret, ELM_ATSPI_STATE_MODAL);
+   STATE_TYPE_SET(ret, EFL_ACCESS_STATE_MODAL);
 
    return ret;
 }
 
+static Eina_Bool
+_item_access_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
+{
+   ELM_CTXPOPUP_ITEM_DATA_GET(obj, it);
+   if (!it) return EINA_FALSE;
+
+   _item_select(it);
+   return EINA_TRUE;
+}
+
+EOLIAN static const Efl_Access_Action_Data*
+_elm_ctxpopup_item_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Ctxpopup_Item_Data *sd EINA_UNUSED)
+{
+   static Efl_Access_Action_Data atspi_actions[] = {
+          { "activate", NULL, NULL, _item_access_action_activate},
+          { NULL, NULL, NULL, NULL }
+   };
+   return &atspi_actions[0];
+}
+
+/* Internal EO APIs and hidden overrides */
+
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(elm_ctxpopup, Elm_Ctxpopup_Data)
+
 /* Efl.Part begin */
 
-ELM_PART_OVERRIDE(elm_ctxpopup, ELM_CTXPOPUP, ELM_LAYOUT, Elm_Ctxpopup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_SET(elm_ctxpopup, ELM_CTXPOPUP, ELM_LAYOUT, Elm_Ctxpopup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_GET(elm_ctxpopup, ELM_CTXPOPUP, ELM_LAYOUT, Elm_Ctxpopup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_UNSET(elm_ctxpopup, ELM_CTXPOPUP, ELM_LAYOUT, Elm_Ctxpopup_Data, Elm_Part_Data)
-ELM_PART_CONTENT_DEFAULT_SET(elm_ctxpopup, "default")
-#include "elm_ctxpopup_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_ctxpopup, ELM_CTXPOPUP, Elm_Ctxpopup_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_ctxpopup, ELM_CTXPOPUP, Elm_Ctxpopup_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(elm_ctxpopup, ELM_CTXPOPUP, Elm_Ctxpopup_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_ctxpopup, ELM_CTXPOPUP, Elm_Ctxpopup_Data)
+#include "elm_ctxpopup_part.eo.c"
 
 /* Efl.Part end */
 
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_CTXPOPUP_EXTRA_OPS \
-   ELM_PART_CONTENT_DEFAULT_OPS(elm_ctxpopup), \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_ctxpopup), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_ctxpopup)
 
 #include "elm_ctxpopup_item.eo.c"
