@@ -3,16 +3,21 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define ELM_INTERFACE_FILESELECTOR_BETA
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
+#include "Eio_Eo.h"
 #include "elm_priv.h"
 #include "elm_fileselector_button.eo.h"
 #include "elm_fileselector_entry.eo.h"
 #include "elm_interface_fileselector.h"
 #include "elm_widget_fileselector_entry.h"
+#include "elm_entry.eo.h"
+#include "elm_fileselector.eo.h"
 
-#include "elm_fileselector_entry_internal_part.eo.h"
+#include "elm_fileselector_entry_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_FILESELECTOR_ENTRY_CLASS
@@ -57,62 +62,32 @@ SIG_FWD(PRESS, ELM_FILESELECTOR_ENTRY_EVENT_PRESS)
 SIG_FWD(LONGPRESSED, EFL_UI_EVENT_LONGPRESSED)
 SIG_FWD(CLICKED, EFL_UI_EVENT_CLICKED)
 SIG_FWD(CLICKED_DOUBLE, EFL_UI_EVENT_CLICKED_DOUBLE)
-SIG_FWD(FOCUSED, ELM_WIDGET_EVENT_FOCUSED)
-SIG_FWD(UNFOCUSED, ELM_WIDGET_EVENT_UNFOCUSED)
 SIG_FWD(SELECTION_PASTE, EFL_UI_EVENT_SELECTION_PASTE)
 SIG_FWD(SELECTION_COPY, EFL_UI_EVENT_SELECTION_COPY)
 SIG_FWD(SELECTION_CUT, EFL_UI_EVENT_SELECTION_CUT)
 SIG_FWD(UNPRESSED, EFL_UI_EVENT_UNPRESSED)
 #undef SIG_FWD
 
-static void
-_file_chosen_path_then(void *data, Efl_Event const* event)
-{
-   Eina_Array *args = data;
-   const char *file = NULL;
-   char *s;
-   Eo *fs = eina_array_data_get(args, 0);
-   Efl_Model *model = eina_array_data_get(args, 1);
-
-   eina_array_free(args);
-
-   eina_value_get((Eina_Value*)((Efl_Future_Event_Success*)event->info)->value, &file);
-
-   if (!file) return;
-   ELM_FILESELECTOR_ENTRY_DATA_GET(fs, sd);
-
-   s = elm_entry_utf8_to_markup(file);
-   elm_object_text_set(sd->entry, s);
-   free(s);
-
-   _model_event_call
-     (fs, ELM_FILESELECTOR_ENTRY_EVENT_FILE_CHOSEN, model, file);
-}
-
-static void
-_file_chosen_path_then_error(void *data, Efl_Event const* event)
-{
-   Eina_Error err = ((Efl_Future_Event_Failure*)event->info)->error;
-   ERR("Efl.Model property \"path\" error: %s", eina_error_msg_get(err));
-   eina_array_free(data);
-}
-
 static void
 _FILE_CHOSEN_fwd(void *data, const Efl_Event *event)
 {
    Efl_Model *model = event->info;
-   Efl_Future *future = NULL;
-   Eina_Array *args = NULL;
+   Eo *fs = data;
+   Eina_Value *path;
+   char *file = NULL;
+   ELM_FILESELECTOR_ENTRY_DATA_GET(fs, sd);
 
-   if (!model) return;
+   efl_ui_view_model_set(sd->entry, model);
+   efl_ui_model_connect(sd->entry, "default", "path");
 
-   args = eina_array_new(2);
-   eina_array_push(args, data);
-   eina_array_push(args, model);
+   path = efl_model_property_get(model, "path");
+   file = eina_value_to_string(path);
 
-   future = efl_model_property_get(model, "path");
-   efl_future_then
-     (future, _file_chosen_path_then, _file_chosen_path_then_error, NULL, args);
+   _model_event_call
+     (fs, ELM_FILESELECTOR_ENTRY_EVENT_FILE_CHOSEN, model, file);
+
+   eina_value_free(path);
+   free(file);
 }
 
 static void
@@ -126,7 +101,7 @@ _ACTIVATED_fwd(void *data, const Efl_Event *event)
 
    file = elm_object_text_get(sd->entry);
 
-   bmodel = elm_interface_fileselector_model_get(sd->button);
+   bmodel = efl_ui_view_model_get(sd->button);
    if (bmodel)
      {
          model = efl_add(efl_class_get(bmodel), NULL);
@@ -134,19 +109,13 @@ _ACTIVATED_fwd(void *data, const Efl_Event *event)
          eina_value_set(&path, file);
          efl_model_property_set(model, "path", &path);
          eina_value_flush(&path);
-         elm_interface_fileselector_model_set(sd->button, model);
+         efl_ui_view_model_set(sd->button, model);
      }
 
    efl_event_callback_legacy_call
      (data, ELM_FILESELECTOR_ENTRY_EVENT_ACTIVATED, event->info);
 }
 
-static void
-_model_free_eo_cb(void *eo)
-{
-   efl_unref(eo);
-}
-
 EOLIAN static void
 _elm_fileselector_entry_elm_layout_sizing_eval(Eo *obj, Elm_Fileselector_Entry_Data *sd EINA_UNUSED)
 {
@@ -159,65 +128,17 @@ _elm_fileselector_entry_elm_layout_sizing_eval(Eo *obj, Elm_Fileselector_Entry_D
    evas_object_size_hint_max_set(obj, -1, -1);
 }
 
-EOLIAN static Eina_Bool
-_elm_fileselector_entry_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_fileselector_entry_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd EINA_UNUSED)
-{
-   return EINA_FALSE;
-}
-
-EOLIAN static Eina_Bool
-_elm_fileselector_entry_elm_widget_focus_next(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Evas_Object *chain[2];
-   Evas_Object *to_focus;
-   unsigned char i;
-
-   /* Direction */
-   if (dir == ELM_FOCUS_PREVIOUS)
-     {
-        chain[0] = sd->button;
-        chain[1] = sd->entry;
-     }
-   else if (dir == ELM_FOCUS_NEXT)
-     {
-        chain[0] = sd->entry;
-        chain[1] = sd->button;
-     }
-   else
-     return EINA_FALSE;
-
-   i = elm_widget_focus_get(chain[1]);
-
-   if (elm_widget_focus_next_get(chain[i], dir, next, next_item)) return EINA_TRUE;
-
-   i = !i;
-
-   if (elm_widget_focus_next_get(chain[i], dir, &to_focus, next_item))
-     {
-        *next = to_focus;
-        return !!i;
-     }
-
-   return EINA_FALSE;
-}
-
-EOLIAN static Elm_Theme_Apply
-_elm_fileselector_entry_elm_widget_theme_apply(Eo *obj, Elm_Fileselector_Entry_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_fileselector_entry_efl_ui_widget_theme_apply(Eo *obj, Elm_Fileselector_Entry_Data *sd)
 {
    const char *style;
    char buf[1024];
 
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, ELM_THEME_APPLY_FAILED);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EFL_UI_THEME_APPLY_FAILED);
 
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    style = elm_widget_style_get(obj);
 
@@ -239,18 +160,13 @@ _elm_fileselector_entry_elm_widget_theme_apply(Eo *obj, Elm_Fileselector_Entry_D
 }
 
 EOLIAN static Eina_Bool
-_elm_fileselector_entry_elm_widget_disable(Eo *obj, Elm_Fileselector_Entry_Data *sd)
+_elm_fileselector_entry_efl_ui_widget_on_disabled_update(Eo *obj, Elm_Fileselector_Entry_Data *sd, Eina_Bool disabled)
 {
-   Eina_Bool val;
+   if (!efl_ui_widget_on_disabled_update(efl_super(obj, MY_CLASS), disabled))
+     return EINA_FALSE;
 
-   Eina_Bool int_ret = EINA_FALSE;
-   int_ret = elm_obj_widget_disable(efl_super(obj, MY_CLASS));
-   if (!int_ret) return EINA_FALSE;
-
-   val = elm_widget_disabled_get(obj);
-
-   elm_widget_disabled_set(sd->button, val);
-   elm_widget_disabled_set(sd->entry, val);
+   elm_widget_disabled_set(sd->button, disabled);
+   elm_widget_disabled_set(sd->entry, disabled);
 
    return EINA_TRUE;
 }
@@ -258,7 +174,7 @@ _elm_fileselector_entry_elm_widget_disable(Eo *obj, Elm_Fileselector_Entry_Data
 static Eina_Bool
 _elm_fileselector_entry_text_set(Eo *obj, Elm_Fileselector_Entry_Data *sd, const char *part, const char *label)
 {
-   if (part && strcmp(part, "default"))
+   if (part && strcmp(part, "elm.text"))
      {
         efl_text_set(efl_part(efl_super(obj, MY_CLASS), part), label);
      }
@@ -270,7 +186,7 @@ _elm_fileselector_entry_text_set(Eo *obj, Elm_Fileselector_Entry_Data *sd, const
 static const char *
 _elm_fileselector_entry_text_get(Eo *obj, Elm_Fileselector_Entry_Data *sd, const char *part)
 {
-   if (part && strcmp(part, "default"))
+   if (part && strcmp(part, "elm.text"))
      {
         const char *text = NULL;
         text = efl_text_get(efl_part(efl_super(obj, MY_CLASS), part));
@@ -351,13 +267,13 @@ _elm_fileselector_entry_efl_canvas_group_group_add(Eo *obj, Elm_Fileselector_Ent
    SIG_FWD(LONGPRESSED, EFL_UI_EVENT_LONGPRESSED);
    SIG_FWD(CLICKED, EFL_UI_EVENT_CLICKED);
    SIG_FWD(CLICKED_DOUBLE, EFL_UI_EVENT_CLICKED_DOUBLE);
-   SIG_FWD(FOCUSED, ELM_WIDGET_EVENT_FOCUSED);
-   SIG_FWD(UNFOCUSED, ELM_WIDGET_EVENT_UNFOCUSED);
    SIG_FWD(SELECTION_PASTE, EFL_UI_EVENT_SELECTION_PASTE);
    SIG_FWD(SELECTION_COPY, EFL_UI_EVENT_SELECTION_COPY);
    SIG_FWD(SELECTION_CUT, EFL_UI_EVENT_SELECTION_CUT);
 #undef SIG_FWD
 
+   efl_event_callback_forwarder_add(priv->entry, EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED, obj);
+
    if (!elm_layout_theme_set
        (obj, "fileselector_entry", "base", elm_widget_style_get(obj)))
      CRI("Failed to set layout!");
@@ -382,7 +298,7 @@ EAPI Evas_Object *
 elm_fileselector_entry_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -391,7 +307,7 @@ _elm_fileselector_entry_efl_object_constructor(Eo *obj, Elm_Fileselector_Entry_D
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_GROUPING);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_GROUPING);
 
    return obj;
 }
@@ -411,16 +327,14 @@ _elm_fileselector_entry_selected_set_internal(Evas_Object *obj, const char *path
    return EINA_TRUE;
 }
 
-EOLIAN static Efl_Future*
+EOLIAN static Eina_Bool
 _elm_fileselector_entry_elm_interface_fileselector_selected_model_set(Eo *obj EINA_UNUSED,
                                                                       Elm_Fileselector_Entry_Data *sd,
                                                                       Efl_Model *model)
 {
-   Efl_Promise* promise = efl_add(EFL_PROMISE_CLASS, obj);
-   Efl_Future* future = efl_promise_future_get(promise);
-   elm_interface_fileselector_model_set(sd->button, model);
-   efl_promise_value_set(promise, efl_ref(model), _model_free_eo_cb);
-   return future;
+   efl_ui_view_model_set(sd->button, model);
+
+   return EINA_TRUE;
 }
 
 EINA_DEPRECATED EAPI const char *
@@ -438,9 +352,9 @@ _elm_fileselector_entry_selected_get_internal(const Evas_Object *obj)
 }
 
 EOLIAN static Efl_Model *
-_elm_fileselector_entry_elm_interface_fileselector_selected_model_get(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
+_elm_fileselector_entry_elm_interface_fileselector_selected_model_get(const Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
 {
-   return elm_interface_fileselector_model_get(sd->button);
+   return efl_ui_view_model_get(sd->button);
 }
 
 EAPI void
@@ -501,34 +415,12 @@ _elm_fileselector_entry_path_set_internal(Evas_Object *obj, const char *path)
      }
 }
 
-static void
-_fs_entry_model_path_get_then(void *data, Efl_Event const *event)
-{
-   Elm_Fileselector_Entry_Data *sd = data;
-   char *path = NULL;
-   char *s;
-   Eina_Value* v = (Eina_Value*)((Efl_Future_Event_Success*)event->info)->value;
-
-   if (!v)
-     return;
-
-   eina_value_get(v, &path);
-   s = elm_entry_utf8_to_markup(path);
-   if (s)
-     {
-        elm_object_text_set(sd->entry, s);
-        free(s);
-     }
-}
-
 EOLIAN static void
-_elm_fileselector_entry_elm_interface_fileselector_model_set(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd, Efl_Model *model)
+_elm_fileselector_entry_efl_ui_view_model_set(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd, Efl_Model *model)
 {
-   Efl_Future *p = NULL;
-   elm_interface_fileselector_model_set(sd->button, model);
-
-   p = efl_model_property_get(model, "path");
-   efl_future_then(p, _fs_entry_model_path_get_then, NULL, NULL, sd);
+   efl_ui_view_model_set(sd->button, model);
+   efl_ui_view_model_set(sd->entry, model);
+   efl_ui_model_connect(sd->entry, "default", "path");
 }
 
 EINA_DEPRECATED EAPI const char *
@@ -548,11 +440,11 @@ _elm_fileselector_entry_path_get_internal(const Evas_Object *obj)
 }
 
 EOLIAN static Efl_Model *
-_elm_fileselector_entry_elm_interface_fileselector_model_get(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
+_elm_fileselector_entry_efl_ui_view_model_get(const Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
 {
    Efl_Model *bmodel, *ret;
    Eina_Value path;
-   bmodel = elm_interface_fileselector_model_get(sd->button);
+   bmodel = efl_ui_view_model_get(sd->button);
    if (!bmodel)
      {
         WRN("no base Efl.Model");
@@ -592,7 +484,7 @@ elm_fileselector_entry_expandable_get(const Evas_Object *obj)
 }
 
 EOLIAN static Eina_Bool
-_elm_fileselector_entry_elm_interface_fileselector_expandable_get(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
+_elm_fileselector_entry_elm_interface_fileselector_expandable_get(const Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
 {
    return elm_fileselector_expandable_get(sd->button);
 }
@@ -619,7 +511,7 @@ elm_fileselector_entry_folder_only_get(const Evas_Object *obj)
 }
 
 EOLIAN static Eina_Bool
-_elm_fileselector_entry_elm_interface_fileselector_folder_only_get(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
+_elm_fileselector_entry_elm_interface_fileselector_folder_only_get(const Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
 {
    return elm_fileselector_folder_only_get(sd->button);
 }
@@ -646,7 +538,7 @@ elm_fileselector_entry_is_save_get(const Evas_Object *obj)
 }
 
 EOLIAN static Eina_Bool
-_elm_fileselector_entry_elm_interface_fileselector_is_save_get(Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
+_elm_fileselector_entry_elm_interface_fileselector_is_save_get(const Eo *obj EINA_UNUSED, Elm_Fileselector_Entry_Data *sd)
 {
    return elm_fileselector_is_save_get(sd->button);
 }
@@ -675,14 +567,14 @@ _elm_fileselector_entry_class_constructor(Efl_Class *klass)
 
 /* Efl.Part begin */
 
-ELM_PART_OVERRIDE(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, ELM_LAYOUT, Elm_Fileselector_Entry_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_SET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, ELM_LAYOUT, Elm_Fileselector_Entry_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_GET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, ELM_LAYOUT, Elm_Fileselector_Entry_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_UNSET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, ELM_LAYOUT, Elm_Fileselector_Entry_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_SET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, ELM_LAYOUT, Elm_Fileselector_Entry_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_GET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, ELM_LAYOUT, Elm_Fileselector_Entry_Data, Elm_Part_Data)
-ELM_PART_CONTENT_DEFAULT_SET(elm_fileselector_entry, "button icon")
-#include "elm_fileselector_entry_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, Elm_Fileselector_Entry_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, Elm_Fileselector_Entry_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, Elm_Fileselector_Entry_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, Elm_Fileselector_Entry_Data)
+ELM_PART_OVERRIDE_TEXT_SET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, Elm_Fileselector_Entry_Data)
+ELM_PART_OVERRIDE_TEXT_GET(elm_fileselector_entry, ELM_FILESELECTOR_ENTRY, Elm_Fileselector_Entry_Data)
+ELM_PART_CONTENT_DEFAULT_GET(elm_fileselector_entry, "button icon")
+#include "elm_fileselector_entry_part.eo.c"
 
 /* Efl.Part end */
 
@@ -690,6 +582,7 @@ ELM_PART_CONTENT_DEFAULT_SET(elm_fileselector_entry, "button icon")
 
 #define ELM_FILESELECTOR_ENTRY_EXTRA_OPS \
    ELM_PART_CONTENT_DEFAULT_OPS(elm_fileselector_entry), \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_fileselector_entry), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_fileselector_entry)
 
 #include "elm_fileselector_entry.eo.c"
