@@ -2,16 +2,18 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
-
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
 #define ELM_WIDGET_PROTECTED
 #define ELM_WIDGET_ITEM_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
+
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_hoversel.eo.h"
 #include "elm_hoversel_item.eo.h"
 #include "elm_widget_hoversel.h"
+#include "efl_ui_button_legacy.eo.h"
 
 #define MY_CLASS ELM_HOVERSEL_CLASS
 
@@ -40,6 +42,7 @@ static const Evas_Smart_Cb_Description _smart_callbacks[] = {
 static Eina_Bool _key_action_move(Evas_Object *obj, const char *params);
 static Eina_Bool _key_action_activate(Evas_Object *obj, const char *params);
 static Eina_Bool _key_action_escape(Evas_Object *obj, const char *params);
+static Eina_Bool _hoversel_efl_ui_widget_widget_event(Eo *obj, Elm_Hoversel_Data *_pd EINA_UNUSED, const Efl_Event *eo_event, Evas_Object *src EINA_UNUSED);
 
 static const Elm_Action key_actions[] = {
    {"move", _key_action_move},
@@ -48,8 +51,8 @@ static const Elm_Action key_actions[] = {
    {NULL, NULL}
 };
 
-EOLIAN static Eina_Bool
-_elm_hoversel_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
+EOLIAN static void
+_elm_hoversel_efl_ui_translatable_translation_update(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
 {
    Eo *it;
    Eina_List *l;
@@ -57,19 +60,17 @@ _elm_hoversel_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
    EINA_LIST_FOREACH(sd->items, l, it)
      elm_wdg_item_translate(it);
 
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-
-   return EINA_TRUE;
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_hoversel_elm_widget_theme_apply(Eo *obj, Elm_Hoversel_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_hoversel_efl_ui_widget_theme_apply(Eo *obj, Elm_Hoversel_Data *sd)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
    Eina_List *l;
    Elm_Object_Item *eo_item;
 
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, ELM_THEME_APPLY_FAILED);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EFL_UI_THEME_APPLY_FAILED);
 
    char buf[4096];
    const char *style;
@@ -82,12 +83,12 @@ _elm_hoversel_elm_widget_theme_apply(Eo *obj, Elm_Hoversel_Data *sd)
      snprintf(buf, sizeof(buf), "hoversel_vertical/%s", style);
 
    /* hoversel's style has an extra bit: orientation */
-   eina_stringshare_replace(&(wd->style), buf);
+   elm_widget_theme_style_set(obj, buf);
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
-   eina_stringshare_replace(&(wd->style), style);
+   elm_widget_theme_style_set(obj, style);
 
    if (sd->hover)
      efl_ui_mirrored_set(sd->hover, efl_ui_mirrored_get(obj));
@@ -183,19 +184,18 @@ _on_item_clicked(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
 }
 
 static void
-_item_focused_cb(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
+_item_focus_changed(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
 {
    Elm_Hoversel_Item_Data *it = data;
 
-   efl_event_callback_legacy_call(WIDGET(it), ELM_HOVERSEL_EVENT_ITEM_FOCUSED, EO_OBJ(it));
-}
-
-static void
-_item_unfocused_cb(void *data EINA_UNUSED, const Efl_Event *event EINA_UNUSED)
-{
-   Elm_Hoversel_Item_Data *it = data;
-
-   efl_event_callback_legacy_call(WIDGET(it), ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED, EO_OBJ(it));
+   if (efl_ui_focus_object_focus_get(event->object))
+     {
+        efl_event_callback_legacy_call(WIDGET(it), ELM_HOVERSEL_EVENT_ITEM_FOCUSED, EO_OBJ(it));
+     }
+   else
+     {
+        efl_event_callback_legacy_call(WIDGET(it), ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED, EO_OBJ(it));
+     }
 }
 
 static void
@@ -255,7 +255,7 @@ _sizing_eval(void *data)
    edje_object_message_signal_process(elm_layout_edje_get(sd->hover));
 
    elm_box_recalculate(sd->bx);
-   efl_gfx_size_hint_combined_min_get(sd->bx, &box_w, &box_h);
+   evas_object_size_hint_combined_min_get(sd->bx, &box_w, &box_h);
 
    max_size_str = elm_layout_data_get(sd->hover, "max_size");
    if (max_size_str)
@@ -328,7 +328,7 @@ _sizing_eval(void *data)
         if (adjusted.x < 0) adjusted.x = parent.x;
         if ((adjusted.x + adjusted.w) > (parent.x + parent.w))
           {
-             if ((base.x + base.w - parent.x) > ((parent.x + parent.w) - base.x))
+             if ((base.x + base.w) > (parent.x + parent.w))
                {
                   if (efl_ui_mirrored_get(obj))
                     elm_object_signal_emit(sd->hover, "elm,state,align,right", "elm");
@@ -440,6 +440,15 @@ _access_state_cb(void *data EINA_UNUSED, Evas_Object *obj)
    return NULL;
 }
 
+
+static void
+_hover_key_down(void *data, const Efl_Event *ev)
+{
+   ELM_HOVERSEL_DATA_GET(ev->object, sd);
+
+   _hoversel_efl_ui_widget_widget_event(data, sd, ev, ev->object);
+}
+
 static void
 _activate(Evas_Object *obj)
 {
@@ -461,6 +470,8 @@ _activate(Evas_Object *obj)
    sd->expanded = EINA_TRUE;
 
    sd->hover = elm_hover_add(sd->hover_parent);
+   efl_event_callback_add(sd->hover, EFL_EVENT_KEY_DOWN, _hover_key_down, obj);
+
    elm_widget_sub_object_add(obj, sd->hover);
    evas_object_layer_set(sd->hover, evas_object_layer_get(sd->hover_parent));
 
@@ -541,7 +552,7 @@ _elm_hoversel_item_elm_widget_item_part_text_set(Eo *eo_it EINA_UNUSED,
 }
 
 static const char *
-_elm_hoversel_item_elm_widget_item_part_text_get(Eo *eo_it EINA_UNUSED,
+_elm_hoversel_item_elm_widget_item_part_text_get(const Eo *eo_it EINA_UNUSED,
                                             Elm_Hoversel_Item_Data *it,
                                             const char *part)
 {
@@ -567,14 +578,14 @@ _elm_hoversel_item_elm_widget_item_style_set(Eo *eo_it EINA_UNUSED,
 }
 
 EOLIAN static const char *
-_elm_hoversel_item_elm_widget_item_style_get(Eo *eo_it EINA_UNUSED,
+_elm_hoversel_item_elm_widget_item_style_get(const Eo *eo_it EINA_UNUSED,
                                              Elm_Hoversel_Item_Data *it)
 {
    return elm_object_style_get(VIEW(it));
 }
 
 EOLIAN static void
-_elm_hoversel_item_elm_widget_item_focus_set(Eo *eo_it EINA_UNUSED,
+_elm_hoversel_item_elm_widget_item_item_focus_set(Eo *eo_it EINA_UNUSED,
                                              Elm_Hoversel_Item_Data *it,
                                              Eina_Bool focused)
 {
@@ -582,10 +593,10 @@ _elm_hoversel_item_elm_widget_item_focus_set(Eo *eo_it EINA_UNUSED,
 }
 
 EOLIAN static Eina_Bool
-_elm_hoversel_item_elm_widget_item_focus_get(Eo *eo_it EINA_UNUSED,
+_elm_hoversel_item_elm_widget_item_item_focus_get(const Eo *eo_it EINA_UNUSED,
                                              Elm_Hoversel_Item_Data *it)
 {
-   return elm_widget_focus_get(VIEW(it));
+   return efl_ui_focus_object_focus_get(VIEW(it));
 }
 
 EOLIAN static void
@@ -631,7 +642,7 @@ _elm_hoversel_efl_canvas_group_group_add(Eo *obj, Elm_Hoversel_Data *pd)
    efl_event_callback_add(obj, EFL_UI_EVENT_CLICKED, _on_clicked, obj);
 
    //What are you doing here?
-   elm_obj_widget_theme_apply(obj);
+   efl_ui_widget_theme_apply(obj);
 
    evas_object_event_callback_add(obj, EVAS_CALLBACK_MOVE, _on_geometry_changed, pd);
    evas_object_event_callback_add(obj, EVAS_CALLBACK_RESIZE, _on_geometry_changed, pd);
@@ -661,23 +672,23 @@ _elm_hoversel_efl_canvas_group_group_del(Eo *obj, Elm_Hoversel_Data *sd)
 }
 
 EOLIAN static void
-_elm_hoversel_efl_gfx_visible_set(Eo *obj, Elm_Hoversel_Data *sd, Eina_Bool vis)
+_elm_hoversel_efl_gfx_entity_visible_set(Eo *obj, Elm_Hoversel_Data *sd, Eina_Bool vis)
 {
    if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_VISIBLE, 0, vis))
      return;
 
-   efl_gfx_visible_set(efl_super(obj, MY_CLASS), vis);
-   efl_gfx_visible_set(sd->hover, vis);
+   efl_gfx_entity_visible_set(efl_super(obj, MY_CLASS), vis);
+   efl_gfx_entity_visible_set(sd->hover, vis);
 }
 
 EOLIAN static void
-_elm_hoversel_elm_widget_widget_parent_set(Eo *obj, Elm_Hoversel_Data *_pd EINA_UNUSED, Evas_Object *parent)
+_elm_hoversel_efl_ui_widget_widget_parent_set(Eo *obj, Elm_Hoversel_Data *_pd EINA_UNUSED, Evas_Object *parent)
 {
    elm_hoversel_hover_parent_set(obj, parent);
 }
 
 EOLIAN static Eina_Bool
-_elm_hoversel_efl_ui_autorepeat_autorepeat_supported_get(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd EINA_UNUSED)
+_elm_hoversel_efl_ui_autorepeat_autorepeat_supported_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd EINA_UNUSED)
 {
    return EINA_FALSE;
 }
@@ -686,7 +697,7 @@ EAPI Evas_Object *
 elm_hoversel_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -695,7 +706,7 @@ _elm_hoversel_efl_object_constructor(Eo *obj, Elm_Hoversel_Data *_pd EINA_UNUSED
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_PUSH_BUTTON);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_PUSH_BUTTON);
 
    return obj;
 }
@@ -709,7 +720,7 @@ _elm_hoversel_efl_object_destructor(Eo *obj, Elm_Hoversel_Data *_pd EINA_UNUSED)
 
 EFL_CALLBACKS_ARRAY_DEFINE(_on_parent,
                           { EFL_EVENT_DEL, _on_parent_del },
-                          { EFL_GFX_EVENT_RESIZE, _on_parent_resize });
+                          { EFL_GFX_ENTITY_EVENT_RESIZE, _on_parent_resize });
 
 EOLIAN static void
 _elm_hoversel_hover_parent_set(Eo *obj, Elm_Hoversel_Data *sd, Evas_Object *parent)
@@ -727,7 +738,7 @@ _elm_hoversel_hover_parent_set(Eo *obj, Elm_Hoversel_Data *sd, Evas_Object *pare
 }
 
 EOLIAN static Evas_Object*
-_elm_hoversel_hover_parent_get(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
+_elm_hoversel_hover_parent_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
 {
    return sd->hover_parent;
 }
@@ -753,11 +764,11 @@ _elm_hoversel_horizontal_set(Eo *obj, Elm_Hoversel_Data *sd, Eina_Bool horizonta
           }
      }
 
-   elm_obj_widget_theme_apply(obj);
+   efl_ui_widget_theme_apply(obj);
 }
 
 EOLIAN static Eina_Bool
-_elm_hoversel_horizontal_get(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
+_elm_hoversel_horizontal_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
 {
    return sd->horizontal;
 }
@@ -791,7 +802,7 @@ _elm_hoversel_hover_end(Eo *obj, Elm_Hoversel_Data *sd)
 }
 
 EOLIAN static Eina_Bool
-_elm_hoversel_expanded_get(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
+_elm_hoversel_expanded_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
 {
    return (sd->hover) ? EINA_TRUE : EINA_FALSE;
 }
@@ -804,12 +815,12 @@ _elm_hoversel_clear(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
 
    EINA_LIST_FOREACH_SAFE(sd->items, l, ll, it)
      {
-        elm_wdg_item_del(it);
+        efl_del(it);
      }
 }
 
 EOLIAN static const Eina_List*
-_elm_hoversel_items_get(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
+_elm_hoversel_items_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
 {
    return sd->items;
 }
@@ -847,7 +858,8 @@ _elm_hoversel_item_add(Eo *obj, Elm_Hoversel_Data *sd, const char *label, const
      snprintf(buf, sizeof(buf), "hoversel_vertical_entry/%s",
               elm_widget_style_get(obj));
 
-   VIEW(item) = bt = elm_button_add(obj);
+   bt = elm_button_add(obj);
+   VIEW_SET(item, bt);
    efl_ui_mirrored_set(bt, efl_ui_mirrored_get(obj));
    elm_object_style_set(bt, buf);
    elm_object_text_set(bt, item->label);
@@ -866,8 +878,7 @@ _elm_hoversel_item_add(Eo *obj, Elm_Hoversel_Data *sd, const char *label, const
     evas_object_size_hint_weight_set(bt, EVAS_HINT_EXPAND, 0.0);
     evas_object_size_hint_align_set(bt, EVAS_HINT_FILL, EVAS_HINT_FILL);
     efl_event_callback_add(bt, EFL_UI_EVENT_CLICKED, _on_item_clicked, item);
-    efl_event_callback_add(bt, ELM_WIDGET_EVENT_FOCUSED, _item_focused_cb, item);
-    efl_event_callback_add(bt, ELM_WIDGET_EVENT_UNFOCUSED, _item_unfocused_cb, item);
+    efl_event_callback_add(bt, EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED, _item_focus_changed, item);
 
    sd->items = eina_list_append(sd->items, eo_item);
 
@@ -888,7 +899,7 @@ _elm_hoversel_item_icon_set(Eo *eo_item EINA_UNUSED,
 }
 
 EOLIAN static void
-_elm_hoversel_item_icon_get(Eo *eo_item EINA_UNUSED,
+_elm_hoversel_item_icon_get(const Eo *eo_item EINA_UNUSED,
                             Elm_Hoversel_Item_Data *item,
                             const char **icon_file,
                             const char **icon_group,
@@ -934,6 +945,7 @@ _key_action_move(Evas_Object *obj, const char *params)
    ELM_HOVERSEL_DATA_GET(obj, sd);
    const char *dir = params;
 
+   if (!sd->hover) return EINA_FALSE;
    _elm_widget_focus_auto_show(obj);
    if (!strcmp(dir, "down") || !strcmp(dir, "right"))
      {
@@ -983,6 +995,8 @@ _key_action_move(Evas_Object *obj, const char *params)
 static Eina_Bool
 _key_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
 {
+   ELM_HOVERSEL_DATA_GET(obj, sd);
+   if (!sd->hover) return EINA_FALSE;
    _activate(obj);
    return EINA_TRUE;
 }
@@ -990,29 +1004,22 @@ _key_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
 static Eina_Bool
 _key_action_escape(Evas_Object *obj, const char *params EINA_UNUSED)
 {
+   ELM_HOVERSEL_DATA_GET(obj, sd);
+   if (!sd->hover) return EINA_FALSE;
    elm_hoversel_hover_end(obj);
    return EINA_TRUE;
 }
 
+// _hoversel_elm_widget_widget_event()
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(hoversel, Elm_Hoversel_Data)
+
 EOLIAN static Eina_Bool
-_elm_hoversel_elm_widget_widget_event(Eo *obj, Elm_Hoversel_Data *sd, Evas_Object *src, Evas_Callback_Type type, void *event_info)
+_elm_hoversel_efl_ui_widget_widget_event(Eo *obj, Elm_Hoversel_Data *sd, const Efl_Event *eo_event, Evas_Object *src)
 {
-   (void) src;
-   Eina_Bool int_ret = EINA_FALSE;
-   Evas_Event_Key_Down *ev = event_info;
+   if (efl_ui_widget_event(efl_super(obj, MY_CLASS), eo_event, src))
+     return EINA_TRUE; // note: this was FALSE but likely wrong
 
-   int_ret = elm_obj_widget_event(efl_super(obj, MY_CLASS), src, type, event_info);
-   if (int_ret) return EINA_FALSE;
-
-   if (!sd || !sd->hover) return EINA_FALSE;
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions))
-     return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
+   return _hoversel_efl_ui_widget_widget_event(obj, sd, eo_event, src);
 }
 
 static void
@@ -1021,10 +1028,10 @@ _elm_hoversel_class_constructor(Efl_Class *klass)
    evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_hoversel_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_hoversel_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *pd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "activate", "activate", NULL, _key_action_activate},
           { "move,up", "move", "up", _key_action_move},
           { "move,down", "move", "down", _key_action_move},
@@ -1036,6 +1043,12 @@ _elm_hoversel_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNU
    return &atspi_actions[0];
 }
 
+EOLIAN Eina_List*
+_elm_hoversel_efl_access_object_access_children_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *pd)
+{
+	return eina_list_clone(pd->items);
+}
+
 EOLIAN void
 _elm_hoversel_auto_update_set(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd, Eina_Bool auto_update)
 {
@@ -1043,7 +1056,7 @@ _elm_hoversel_auto_update_set(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd, Eina_B
 }
 
 EOLIAN Eina_Bool
-_elm_hoversel_auto_update_get(Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
+_elm_hoversel_auto_update_get(const Eo *obj EINA_UNUSED, Elm_Hoversel_Data *sd)
 {
    return sd->auto_update;
 }
