@@ -2,15 +2,18 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
 #define ELM_WIDGET_ITEM_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+//#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_widget_multibuttonentry.h"
-
-#include "elm_multibuttonentry_internal_part.eo.h"
+#include "elm_multibuttonentry_part.eo.h"
+#include "elm_entry.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_MULTIBUTTONENTRY_CLASS
@@ -33,6 +36,7 @@ static const char SIG_UNFOCUSED[] = "unfocused";
 static const char SIG_EXPANDED[] = "expanded";
 static const char SIG_CONTRACTED[] = "contracted";
 static const char SIG_EXPAND_STATE_CHANGED[] = "expand,state,changed";
+
 static const Evas_Smart_Cb_Description _smart_callbacks[] = {
    {SIG_ITEM_SELECTED, ""},
    {SIG_ITEM_ADDED, ""},
@@ -48,23 +52,26 @@ static const Evas_Smart_Cb_Description _smart_callbacks[] = {
    {NULL, NULL}
 };
 
+static const char PART_NAME_BUTTON[] = "btn";
+static const char PART_NAME_GUIDE_TEXT[] = "guidetext";
+static const char PART_NAME_LABEL[] = "label";
+static const char PART_NAME_CLOSED_BUTTON[] = "closedbutton";
+
 static Eina_Bool _elm_multibuttonentry_smart_focus_next_enable = EINA_FALSE;
 static Eina_Bool _elm_multibuttonentry_smart_focus_direction_enable = EINA_TRUE;
 
 static void _entry_changed_cb(void *data, const Efl_Event *event);
-static void _entry_focus_in_cb(void *data, const Efl_Event *event);
-static void _entry_focus_out_cb(void *data, const Efl_Event *event);
+static void _entry_focus_changed_cb(void *data, const Efl_Event *event);
 static void _entry_clicked_cb(void *data, const Efl_Event *event);
 
 EFL_CALLBACKS_ARRAY_DEFINE(_multi_buttonentry_cb,
    { ELM_ENTRY_EVENT_CHANGED, _entry_changed_cb },
-   { ELM_WIDGET_EVENT_FOCUSED, _entry_focus_in_cb },
-   { ELM_WIDGET_EVENT_UNFOCUSED, _entry_focus_out_cb },
+   { EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED , _entry_focus_changed_cb },
    { EFL_UI_EVENT_CLICKED, _entry_clicked_cb }
 );
 
-EOLIAN static Eina_Bool
-_elm_multibuttonentry_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+EOLIAN static void
+_elm_multibuttonentry_efl_ui_translatable_translation_update(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    Elm_Object_Item *it;
    Eina_List *l;
@@ -72,9 +79,7 @@ _elm_multibuttonentry_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Multibuttone
    EINA_LIST_FOREACH(sd->items, l, it)
      elm_wdg_item_translate(it);
 
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-
-   return EINA_TRUE;
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
 }
 
 static char *
@@ -86,8 +91,8 @@ _format_count(int count, void *data EINA_UNUSED)
    return strdup(buf);
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_multibuttonentry_elm_widget_theme_apply(Eo *obj, Elm_Multibuttonentry_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_multibuttonentry_efl_ui_widget_theme_apply(Eo *obj, Elm_Multibuttonentry_Data *sd)
 {
    const char *str;
    int hpad = 0, vpad = 0;
@@ -95,15 +100,15 @@ _elm_multibuttonentry_elm_widget_theme_apply(Eo *obj, Elm_Multibuttonentry_Data
    Elm_Object_Item *eo_item;
    double pad_scale;
 
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    str = elm_layout_data_get(obj, "horizontal_pad");
    if (str) hpad = atoi(str);
    str = elm_layout_data_get(obj, "vertical_pad");
    if (str) vpad = atoi(str);
-   pad_scale = efl_ui_scale_get(obj) * elm_config_scale_get()
+   pad_scale = efl_gfx_entity_scale_get(obj) * elm_config_scale_get()
       / edje_object_base_scale_get(elm_layout_edje_get(obj));
    elm_box_padding_set(sd->box, (hpad * pad_scale), (vpad * pad_scale));
 
@@ -111,19 +116,19 @@ _elm_multibuttonentry_elm_widget_theme_apply(Eo *obj, Elm_Multibuttonentry_Data
      {
         ELM_MULTIBUTTONENTRY_ITEM_DATA_GET(eo_item, item);
         if (VIEW(item))
-          if (!elm_layout_theme_set
-              (VIEW(item), "multibuttonentry", "btn", elm_widget_style_get(obj)))
+          if (!elm_layout_theme_set(VIEW(item), "multibuttonentry",
+                                    PART_NAME_BUTTON, elm_widget_style_get(obj)))
             CRI("Failed to set layout!");
      }
 
    elm_widget_theme_object_set
-      (obj, sd->label, "multibuttonentry", "label",
+      (obj, sd->label, "multibuttonentry", PART_NAME_LABEL,
        elm_widget_style_get(obj));
    elm_widget_theme_object_set
-      (obj, sd->end, "multibuttonentry", "closedbutton",
+      (obj, sd->end, "multibuttonentry", PART_NAME_CLOSED_BUTTON,
        elm_widget_style_get(obj));
    elm_widget_theme_object_set
-      (obj,sd->guide_text, "multibuttonentry", "guidetext",
+      (obj,sd->guide_text, "multibuttonentry", PART_NAME_GUIDE_TEXT,
        elm_widget_style_get(obj));
 
    elm_layout_sizing_eval(obj);
@@ -140,11 +145,11 @@ _visual_guide_text_set(Evas_Object *obj)
    elm_box_unpack(sd->box, sd->entry);
    if (sd->view_state == MULTIBUTTONENTRY_VIEW_SHRINK) return;
 
-   if (!elm_widget_focus_get(obj))
+   if (!elm_object_focus_get(obj))
      elm_object_focus_set(sd->entry, EINA_FALSE);
 
    if ((!eina_list_count(sd->items)) && sd->guide_text
-       && (!elm_widget_focus_get(obj)) && (!sd->n_str))
+       && (!elm_object_focus_get(obj)) && (!sd->n_str))
      {
         evas_object_hide(sd->entry);
         elm_box_pack_end(sd->box, sd->guide_text);
@@ -159,7 +164,7 @@ _visual_guide_text_set(Evas_Object *obj)
           {
              elm_box_pack_end(sd->box, sd->entry);
              evas_object_show(sd->entry);
-             if (elm_widget_focus_get(obj))
+             if (elm_object_focus_get(obj))
                {
                   if (!sd->selected_it)
                     elm_object_focus_set(sd->entry, EINA_TRUE);
@@ -179,6 +184,7 @@ _shrink_mode_set(Evas_Object *obj,
 
    ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN(obj, sd);
 
+   if (!sd->items) return;
    if (sd->view_state == MULTIBUTTONENTRY_VIEW_ENTRY)
      evas_object_hide(sd->entry);
    else if (sd->view_state == MULTIBUTTONENTRY_VIEW_GUIDETEXT)
@@ -188,7 +194,7 @@ _shrink_mode_set(Evas_Object *obj,
 
    if (shrink == EINA_TRUE)
      {
-        Evas_Coord w = 0, w_tmp = 0;
+        Evas_Coord w = 0;
         Evas_Coord box_inner_item_width_padding = 0;
 
         elm_box_padding_get(sd->box, &box_inner_item_width_padding, NULL);
@@ -206,8 +212,7 @@ _shrink_mode_set(Evas_Object *obj,
         if (sd->label && sd->label_packed)
           {
              elm_box_pack_end(sd->box, sd->label);
-             efl_gfx_size_hint_combined_min_get(sd->label, &w_tmp, NULL);
-             w -= w_tmp;
+             w -= efl_gfx_size_hint_combined_min_get(sd->label).w;
              w -= box_inner_item_width_padding;
           }
 
@@ -216,7 +221,7 @@ _shrink_mode_set(Evas_Object *obj,
 
         EINA_LIST_FOREACH(sd->items, l, eo_item)
           {
-             Evas_Coord item_w, w_label_count = 0, h = 0;
+             Evas_Coord w_label_count = 0, h = 0;
              char *buf;
 
              ELM_MULTIBUTTONENTRY_ITEM_DATA_GET(eo_item, item);
@@ -224,9 +229,7 @@ _shrink_mode_set(Evas_Object *obj,
              evas_object_show(VIEW(item));
              item->visible = EINA_TRUE;
 
-             efl_gfx_size_hint_combined_min_get(VIEW(item), &item_w, NULL);
-
-             w -= item_w;
+             w -= efl_gfx_size_hint_combined_min_get(VIEW(item)).w;
              w -= box_inner_item_width_padding;
              count--;
 
@@ -330,7 +333,7 @@ _view_update(Elm_Multibuttonentry_Data *sd)
 
    // update label
    if (sd->label)
-     efl_gfx_size_hint_combined_min_get(sd->label, &width, &height);
+     evas_object_size_hint_combined_min_get(sd->label, &width, &height);
 
    if (sd->guide_text)
      {
@@ -347,45 +350,6 @@ _view_update(Elm_Multibuttonentry_Data *sd)
    _visual_guide_text_set(obj);
 }
 
-EOLIAN static Eina_Bool
-_elm_multibuttonentry_elm_widget_on_focus(Eo *obj, Elm_Multibuttonentry_Data *sd, Elm_Object_Item *item EINA_UNUSED)
-{
-   if (elm_widget_focus_get(obj))
-     {
-        // ACCESS
-        if (_elm_config->access_mode == ELM_ACCESS_MODE_ON) goto end;
-
-        if (sd->editable)
-          {
-             if ((sd->selected_it))
-               {
-                  elm_entry_input_panel_show(sd->entry);
-               }
-             else if (((!sd->selected_it) || (!eina_list_count(sd->items))))
-               {
-                  elm_entry_cursor_end_set(sd->entry);
-                  _view_update(sd);
-                  elm_entry_input_panel_show(sd->entry);
-               }
-          }
-        efl_event_callback_legacy_call
-          (obj, ELM_WIDGET_EVENT_FOCUSED, NULL);
-     }
-   else
-     {
-        if (sd->editable)
-          {
-             _view_update(sd);
-             elm_entry_input_panel_hide(sd->entry);
-          }
-        efl_event_callback_legacy_call
-          (obj, ELM_WIDGET_EVENT_UNFOCUSED, NULL);
-     }
-
-end:
-   return EINA_TRUE;
-}
-
 static void
 _item_del(Elm_Multibuttonentry_Item_Data *item)
 {
@@ -402,6 +366,9 @@ _item_del(Elm_Multibuttonentry_Item_Data *item)
    if (sd->selected_it == item)
      sd->selected_it = NULL;
 
+   if (sd->focused_it == item)
+     sd->focused_it = NULL;
+
    if (sd->view_state == MULTIBUTTONENTRY_VIEW_SHRINK)
      _shrink_mode_set(obj, EINA_TRUE);
 
@@ -474,7 +441,7 @@ _item_select(Evas_Object *obj,
 
         if (it->func) it->func((void *)(WIDGET_ITEM_DATA_GET(EO_OBJ(it))), WIDGET(it), EO_OBJ(it));
 
-        if (elm_widget_focus_get(obj))
+        if (elm_object_focus_get(obj))
           {
              elm_object_focus_set(sd->entry, EINA_FALSE);
              elm_object_focus_set(VIEW(it), EINA_TRUE);
@@ -482,19 +449,22 @@ _item_select(Evas_Object *obj,
              // ACCESS
              if (_elm_config->access_mode != ELM_ACCESS_MODE_OFF)
                {
-                  Evas_Object *ao, *po;
+                  Evas_Object *ao, *po, *o;
                   Eina_Strbuf *buf;
                   const char *part;
 
                   part = "elm.btn.text";
-                  po = (Evas_Object *)edje_object_part_object_get(elm_layout_edje_get(VIEW(it)), part);
+                  o = elm_layout_edje_get(VIEW(it));
+                  edje_object_freeze(o);
+                  po = (Evas_Object *)edje_object_part_object_get(o, part);
+                  edje_object_thaw(o);
                   ao = evas_object_data_get(po, "_part_access_obj");
                   _elm_access_highlight_set(ao);
 
                   buf = eina_strbuf_new();
                   eina_strbuf_append_printf(buf,
                     "multi button entry item %s is selected",
-                    edje_object_part_text_get(elm_layout_edje_get(VIEW(it)), part));
+                    edje_object_part_text_get(o, part));
 
                   _elm_access_say(eina_strbuf_string_get(buf));
                   eina_strbuf_free(buf);
@@ -505,7 +475,7 @@ _item_select(Evas_Object *obj,
      {
         _current_item_state_change
           (obj, MULTIBUTTONENTRY_BUTTON_STATE_DEFAULT);
-        if (elm_widget_focus_get(obj) && sd->editable)
+        if (elm_object_focus_get(obj) && sd->editable)
           elm_object_focus_set(sd->entry, EINA_TRUE);
      }
 }
@@ -524,9 +494,9 @@ _on_item_clicked(void *data,
    _item_select(WIDGET(it), it);
 
    if (_elm_config->atspi_mode)
-     elm_interface_atspi_accessible_state_changed_signal_emit(eo_it,
-                                                              ELM_ATSPI_STATE_CHECKED,
-                                                              EINA_TRUE);
+     efl_access_state_changed_signal_emit(eo_it,
+                                          EFL_ACCESS_STATE_CHECKED,
+                                          EINA_TRUE);
 
    if (sd->selected_it)
      efl_event_callback_legacy_call
@@ -551,7 +521,7 @@ _on_item_deleted(void *data,
         ELM_MULTIBUTTONENTRY_ITEM_DATA_GET(eo_temp_it, temp_it);
         if (VIEW(temp_it) == obj)
           {
-             elm_wdg_item_del(eo_temp_it);
+             elm_object_item_del(eo_temp_it);
              break;
           }
      }
@@ -567,7 +537,7 @@ _on_item_focused(void *data,
 
    ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN(WIDGET(it), sd);
 
-   sd->selected_it = it;
+   sd->focused_it = it;
 }
 
 static void
@@ -580,8 +550,7 @@ _on_item_unfocused(void *data,
 
    ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN(WIDGET(it), sd);
 
-   sd->selected_it = NULL;
-   elm_layout_signal_emit(VIEW(it), "elm,state,unfocused", "elm");
+   sd->focused_it = NULL;
 }
 
 static Eina_Bool
@@ -670,7 +639,7 @@ _elm_multibuttonentry_item_elm_widget_item_part_text_set(Eo *eo_item EINA_UNUSED
 }
 
 EOLIAN static const char *
-_elm_multibuttonentry_item_elm_widget_item_part_text_get(Eo *eo_item EINA_UNUSED,
+_elm_multibuttonentry_item_elm_widget_item_part_text_get(const Eo *eo_item EINA_UNUSED,
                                                     Elm_Multibuttonentry_Item_Data *item,
                                                     const char *part)
 {
@@ -689,7 +658,7 @@ _elm_multibuttonentry_item_efl_object_destructor(Eo *eo_it,
                                               Elm_Multibuttonentry_Item_Data *it)
 {
    if (_elm_config->atspi_mode)
-     elm_interface_atspi_accessible_children_changed_del_signal_emit(WIDGET(it), eo_it);
+     efl_access_children_changed_del_signal_emit(WIDGET(it), eo_it);
    _item_del(it);
 
    efl_destructor(efl_super(eo_it, ELM_MULTIBUTTONENTRY_ITEM_CLASS));
@@ -701,7 +670,9 @@ _access_multibuttonentry_label_register(Evas_Object *obj, Eina_Bool is_access)
    ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN(obj, sd);
    Evas_Object *po;
 
+   edje_object_freeze(sd->label);
    po = (Evas_Object *)edje_object_part_object_get(sd->label, "elm.text");
+   edje_object_thaw(sd->label);
    if (is_access)
      {
         Evas_Object *ao;
@@ -783,15 +754,15 @@ _item_new(Elm_Multibuttonentry_Data *sd,
      return NULL;
    WIDGET_ITEM_DATA_SET(eo_item, data);
 
-   elm_interface_atspi_accessible_role_set(eo_item, ELM_ATSPI_ROLE_RADIO_BUTTON);
+   efl_access_object_role_set(eo_item, EFL_ACCESS_ROLE_RADIO_BUTTON);
 
    ELM_MULTIBUTTONENTRY_ITEM_DATA_GET(eo_item, item);
-   VIEW(item) = elm_layout_add(obj);
+   VIEW_SET(item, elm_layout_add(obj));
 
-   elm_interface_atspi_accessible_type_set(VIEW(item), ELM_ATSPI_TYPE_DISABLED);
+   efl_access_object_access_type_set(VIEW(item), EFL_ACCESS_TYPE_DISABLED);
 
-   if (!elm_layout_theme_set
-       (VIEW(item), "multibuttonentry", "btn", elm_widget_style_get(obj)))
+   if (!elm_layout_theme_set(VIEW(item), "multibuttonentry", PART_NAME_BUTTON,
+                             elm_widget_style_get(obj)))
      CRI("Failed to set layout!");
 
    elm_object_part_text_set(VIEW(item), "elm.btn.text", str);
@@ -817,7 +788,7 @@ _item_new(Elm_Multibuttonentry_Data *sd,
    evas_object_show(VIEW(item));
 
    evas_object_smart_calculate(VIEW(item));
-   efl_gfx_size_hint_combined_min_get(VIEW(item), &minw, &minh);
+   evas_object_size_hint_combined_min_get(VIEW(item), &minw, &minh);
    evas_object_geometry_get(sd->box, NULL, NULL, &boxw, NULL);
 
    if (sd->w_box && minw > boxw)
@@ -911,9 +882,7 @@ _item_new(Elm_Multibuttonentry_Data *sd,
                   if (sd->view_state == MULTIBUTTONENTRY_VIEW_GUIDETEXT)
                     _visual_guide_text_set(obj);
                   if (sd->editable)
-                    {
-                       elm_box_pack_before(sd->box, VIEW(item), sd->entry);
-                    }
+                    elm_box_pack_before(sd->box, VIEW(item), sd->entry);
                   else
                     elm_box_pack_end(sd->box, VIEW(item));
                }
@@ -939,9 +908,7 @@ _item_new(Elm_Multibuttonentry_Data *sd,
                   if (sd->view_state == MULTIBUTTONENTRY_VIEW_GUIDETEXT)
                     _visual_guide_text_set(obj);
                   if (sd->editable)
-                    {
-                       elm_box_pack_before(sd->box, VIEW(item), sd->entry);
-                    }
+                    elm_box_pack_before(sd->box, VIEW(item), sd->entry);
                   else
                     elm_box_pack_end(sd->box, VIEW(item));
                }
@@ -961,8 +928,8 @@ _item_new(Elm_Multibuttonentry_Data *sd,
 
    if (_elm_config->atspi_mode)
      {
-        elm_interface_atspi_accessible_children_changed_added_signal_emit(obj, eo_item);
-        elm_interface_atspi_accessible_added(eo_item);
+        efl_access_children_changed_added_signal_emit(obj, eo_item);
+        efl_access_added(eo_item);
      }
 
    return eo_item;
@@ -971,16 +938,13 @@ _item_new(Elm_Multibuttonentry_Data *sd,
 //FIXME: having an empty event handling function and reacting on Evas
 //events on specific objects is crazy, someone should fix that.
 EOLIAN static Eina_Bool
-_elm_multibuttonentry_elm_widget_widget_event(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd EINA_UNUSED, Evas_Object *src, Evas_Callback_Type type, void *ev)
+_elm_multibuttonentry_efl_ui_widget_widget_event(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd EINA_UNUSED, const Efl_Event *eo_event EINA_UNUSED, Evas_Object *src EINA_UNUSED)
 {
-   (void)src;
-   (void)type;
-   (void)ev;
-
    // ACCESS
    if (_elm_config->access_mode == ELM_ACCESS_MODE_ON) return EINA_FALSE;
 
-   return EINA_TRUE;
+   //lets stop eating all events
+   return EINA_FALSE;
 }
 
 EOLIAN static void
@@ -1045,7 +1009,7 @@ _box_resize_cb(void *data,
              elm_layout_sizing_eval(VIEW(it));
              evas_object_smart_calculate(VIEW(it));
 
-             efl_gfx_size_hint_combined_min_get(VIEW(it), &mnw, &mnh);
+             evas_object_size_hint_combined_min_get(VIEW(it), &mnw, &mnh);
 
              if (mnw > w - hpad)
                {
@@ -1070,12 +1034,9 @@ _entry_resize_cb(void *data,
                  void *event_info EINA_UNUSED)
 {
    ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN(data, sd);
-   Evas_Coord en_x, en_y, en_w, en_h;
 
-   evas_object_geometry_get(sd->entry, &en_x, &en_y, &en_w, &en_h);
-
-   if (elm_widget_focus_get(sd->parent))
-     elm_widget_show_region_set(sd->entry, en_x, en_y, en_w, en_h, EINA_TRUE);
+   if (elm_object_focus_get(sd->parent))
+     elm_widget_show_region_set(sd->entry, efl_gfx_entity_geometry_get(sd->entry), EINA_TRUE);
 }
 
 static void
@@ -1089,28 +1050,29 @@ _entry_changed_cb(void *data, const Efl_Event *event EINA_UNUSED)
 }
 
 static void
-_entry_focus_in_cb(void *data, const Efl_Event *event EINA_UNUSED)
+_entry_focus_changed_cb(void *data, const Efl_Event *event)
 {
-   Elm_Multibuttonentry_Item_Data *item = NULL;
    ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN(data, sd);
 
-   if (sd->selected_it)
+   if (elm_object_focus_get(event->object))
      {
-        item = sd->selected_it;
-        elm_object_focus_set(sd->entry, EINA_FALSE);
-        elm_object_focus_set(VIEW(item), EINA_TRUE);
+        Elm_Multibuttonentry_Item_Data *item = NULL;
+
+        if (sd->selected_it)
+          {
+             item = sd->selected_it;
+             elm_object_focus_set(sd->entry, EINA_FALSE);
+             elm_object_focus_set(VIEW(item), EINA_TRUE);
+          }
      }
-}
+   else
+     {
+        const char *str;
 
-static void
-_entry_focus_out_cb(void *data, const Efl_Event *event EINA_UNUSED)
-{
-   ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN(data, sd);
-   const char *str;
-
-   str = elm_object_text_get(sd->entry);
-   if (str && str[0])
-     _item_new(sd, str, MULTIBUTTONENTRY_POS_END, NULL, NULL, NULL);
+        str = elm_object_text_get(sd->entry);
+        if (str && str[0])
+          _item_new(sd, str, MULTIBUTTONENTRY_POS_END, NULL, NULL, NULL);
+     }
 }
 
 static void
@@ -1142,15 +1104,15 @@ _layout_key_down_cb(void *data,
              Elm_Multibuttonentry_Item_Data *item = sd->selected_it;
              if (item && sd->editable)
                {
-                  elm_wdg_item_del(EO_OBJ(item));
+                  elm_object_item_del(EO_OBJ(item));
                   elm_object_focus_set(sd->entry, EINA_TRUE);
                }
           }
-        else if (sd->selected_it &&
+        else if (sd->focused_it &&
             ((!strcmp(ev->key, "KP_Enter")) ||
              (!strcmp(ev->key, "Return"))))
           {
-             Elm_Multibuttonentry_Item_Data *item = sd->selected_it;
+             Elm_Multibuttonentry_Item_Data *item = sd->focused_it;
              if (item)
                _on_item_clicked(EO_OBJ(item), NULL, NULL, NULL);
           }
@@ -1281,7 +1243,8 @@ _guide_text_set(Evas_Object *obj,
    if (sd->guide_text)
      {
         elm_widget_theme_object_set(obj, sd->guide_text, "multibuttonentry",
-                                    "guidetext", elm_widget_style_get(obj));
+                                    PART_NAME_GUIDE_TEXT,
+                                    elm_widget_style_get(obj));
         evas_object_size_hint_weight_set
           (sd->guide_text, 0.0, EVAS_HINT_EXPAND);
         evas_object_size_hint_align_set
@@ -1323,14 +1286,14 @@ _box_min_size_calculate(Evas_Object *box,
    Evas_Object_Box_Option *opt;
 
    evas_object_geometry_get(box, NULL, NULL, &w, NULL);
-   efl_gfx_size_hint_combined_min_get(box, &minw, NULL);
+   evas_object_size_hint_combined_min_get(box, &minw, NULL);
 
    if (!w) return EINA_FALSE;
 
    line_num = 1;
    EINA_LIST_FOREACH(priv->children, l, opt)
      {
-        efl_gfx_size_hint_combined_min_get(opt->obj, &mnw, &mnh);
+        evas_object_size_hint_combined_min_get(opt->obj, &mnw, &mnh);
 
         linew += mnw;
         if (lineh < mnh) lineh = mnh;
@@ -1369,7 +1332,7 @@ _box_layout_cb(Evas_Object *o,
 
    evas_object_geometry_get(o, &x, &y, &w, &h);
 
-   efl_gfx_size_hint_combined_min_get(o, &minw, &minh);
+   evas_object_size_hint_combined_min_get(o, &minw, &minh);
    evas_object_size_hint_align_get(o, &ax, &ay);
 
    rtl = efl_ui_mirrored_get(data);
@@ -1399,7 +1362,7 @@ _box_layout_cb(Evas_Object *o,
         obj = opt->obj;
         evas_object_size_hint_align_get(obj, &ax, &ay);
         evas_object_size_hint_weight_get(obj, &wx, &wy);
-        efl_gfx_size_hint_combined_min_get(obj, &mnw, &mnh);
+        evas_object_size_hint_combined_min_get(obj, &mnw, &mnh);
 
         fw = fh = EINA_FALSE;
         if (EINA_DBL_EQ(ax, -1)) {fw = 1; ax = 0.5; }
@@ -1468,19 +1431,20 @@ _view_init(Evas_Object *obj, Elm_Multibuttonentry_Data *sd)
    if (str) hpad = atoi(str);
    str = elm_layout_data_get(obj, "vertical_pad");
    if (str) vpad = atoi(str);
-   pad_scale = efl_ui_scale_get(obj) * elm_config_scale_get()
+   pad_scale = efl_gfx_entity_scale_get(obj) * elm_config_scale_get()
       / edje_object_base_scale_get(elm_layout_edje_get(obj));
    elm_box_padding_set(sd->box, (hpad * pad_scale), (vpad * pad_scale));
 
    elm_box_layout_set(sd->box, _box_layout_cb, obj, NULL);
    elm_box_homogeneous_set(sd->box, EINA_FALSE);
-   elm_layout_content_set(obj, "box.swallow", sd->box);
+   if (!elm_layout_content_set(obj, "elm.swallow.box", sd->box))
+     elm_layout_content_set(obj, "box.swallow", sd->box);
 
    sd->label = edje_object_add(evas_object_evas_get(obj));
    if (!sd->label) return;
    elm_widget_theme_object_set
-     (obj, sd->label, "multibuttonentry", "label",
-     elm_widget_style_get(obj));
+      (obj, sd->label, "multibuttonentry", PART_NAME_LABEL,
+       elm_widget_style_get(obj));
 
    // ACCESS
    if (_elm_config->access_mode == ELM_ACCESS_MODE_ON)
@@ -1507,8 +1471,8 @@ _view_init(Evas_Object *obj, Elm_Multibuttonentry_Data *sd)
         sd->end = edje_object_add(evas_object_evas_get(obj));
         if (!sd->end) return;
         elm_widget_theme_object_set
-          (obj, sd->end, "multibuttonentry", "closedbutton",
-          elm_widget_style_get(obj));
+           (obj, sd->end, "multibuttonentry", PART_NAME_CLOSED_BUTTON,
+            elm_widget_style_get(obj));
 
         edje_object_size_min_calc(sd->end, &button_min_width, &button_min_height);
         elm_coords_finger_size_adjust(1, &button_min_width, 1, &button_min_height);
@@ -1517,25 +1481,19 @@ _view_init(Evas_Object *obj, Elm_Multibuttonentry_Data *sd)
      }
 }
 
-EOLIAN static Eina_Bool
+static void
 _elm_multibuttonentry_text_set(Eo *obj, Elm_Multibuttonentry_Data *sd EINA_UNUSED, const char *part, const char *label)
 {
-   Eina_Bool int_ret = EINA_TRUE;
-
-   if (!part || !strcmp(part, "default") || !strcmp(part, "elm.text"))
+   if (!part || !strcmp(part, "elm.text"))
      {
         if (label) _label_set(obj, label);
-        int_ret = EINA_TRUE;
      }
    else if (!strcmp(part, "guide"))
      {
         if (label) _guide_text_set(obj, label);
-        int_ret = EINA_TRUE;
      }
    else
-     efl_text_set(efl_part(efl_super(obj, MY_CLASS), part), label);
-
-   return int_ret;
+     elm_object_part_text_set(obj, part, label);
 }
 
 EOLIAN static const char*
@@ -1543,7 +1501,7 @@ _elm_multibuttonentry_text_get(Eo *obj, Elm_Multibuttonentry_Data *sd, const cha
 {
    const char *text = NULL;
 
-   if (!part || !strcmp(part, "default"))
+   if (!part || !strcmp(part, "elm.text"))
      {
         text = sd->label_str;
      }
@@ -1552,7 +1510,7 @@ _elm_multibuttonentry_text_get(Eo *obj, Elm_Multibuttonentry_Data *sd, const cha
         text = sd->guide_text_str;
      }
    else
-     text = efl_text_get(efl_part(efl_super(obj, MY_CLASS), part));
+     text = elm_object_part_text_get(obj, part);
 
    return text;
 }
@@ -1601,19 +1559,23 @@ _elm_multibuttonentry_efl_canvas_group_group_add(Eo *obj, Elm_Multibuttonentry_D
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
+   if (!elm_widget_theme_klass_get(obj))
+     elm_widget_theme_klass_set(obj, "multibuttonentry");
    efl_canvas_group_add(efl_super(obj, MY_CLASS));
    elm_widget_sub_object_parent_add(obj);
 
-   if (!elm_layout_theme_set
-       (obj, "multibuttonentry", "base", elm_widget_style_get(obj)))
+   if (!elm_widget_theme_object_set(obj, wd->resize_obj,
+                                       elm_widget_theme_klass_get(obj),
+                                       elm_widget_theme_element_get(obj),
+                                       elm_widget_theme_style_get(obj)))
      CRI("Failed to set layout!");
 
-   elm_widget_can_focus_set(obj, EINA_TRUE);
+   elm_widget_can_focus_set(obj, EINA_FALSE);
 
    priv->last_it_select = EINA_TRUE;
    priv->editable = EINA_TRUE;
    priv->parent = obj;
-   priv->format_func = _format_count;
+	   priv->format_func = _format_count;
 
    _view_init(obj, priv);
    _callbacks_register(obj);
@@ -1639,6 +1601,7 @@ _elm_multibuttonentry_efl_canvas_group_group_del(Eo *obj, Elm_Multibuttonentry_D
    sd->items = eina_list_free(sd->items);
 
    sd->selected_it = NULL;
+   sd->focused_it = NULL;
 
    eina_stringshare_del(sd->label_str);
    eina_stringshare_del(sd->guide_text_str);
@@ -1654,84 +1617,6 @@ _elm_multibuttonentry_efl_canvas_group_group_del(Eo *obj, Elm_Multibuttonentry_D
    efl_canvas_group_del(efl_super(obj, MY_CLASS));
 }
 
-EOLIAN static Eina_Bool
-_elm_multibuttonentry_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd EINA_UNUSED)
-{
-   return _elm_multibuttonentry_smart_focus_direction_enable;
-}
-
-EOLIAN static Eina_Bool
-_elm_multibuttonentry_elm_widget_focus_direction(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Eina_Bool ret;
-   Eina_List *items = NULL;
-
-   items = eina_list_append(items, sd->box);
-
-   ret = elm_widget_focus_list_direction_get
-      (obj, base, items, eina_list_data_get, degree, direction, direction_item, weight);
-   eina_list_free(items);
-
-   return ret;
-}
-
-EOLIAN static Eina_Bool
-_elm_multibuttonentry_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd EINA_UNUSED)
-{
-   return _elm_multibuttonentry_smart_focus_next_enable;
-}
-
-EOLIAN static Eina_Bool
-_elm_multibuttonentry_elm_widget_focus_next(Eo *obj, Elm_Multibuttonentry_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Eina_Bool int_ret = EINA_FALSE;
-
-   Eina_List *items = NULL;
-   Eina_List *l = NULL;
-   Elm_Object_Item *eo_item;
-   Evas_Object *ao;
-   Evas_Object *po;
-
-   if (!elm_widget_focus_get(obj))
-     {
-        *next = (Evas_Object *)obj;
-        return EINA_TRUE;
-     }
-
-   if (sd->label)
-     {
-        po = (Evas_Object *)edje_object_part_object_get(sd->label, "elm.text");
-        ao = evas_object_data_get(po, "_part_access_obj");
-        int_ret = elm_widget_focus_get(ao);
-        items = eina_list_append(items, ao);
-     }
-
-   EINA_LIST_FOREACH (sd->items, l, eo_item)
-     {
-        ELM_MULTIBUTTONENTRY_ITEM_DATA_GET(eo_item, item);
-        po = (Evas_Object *)edje_object_part_object_get
-                           (elm_layout_edje_get(VIEW(item)), "elm.btn.text");
-        ao = evas_object_data_get(po, "_part_access_obj");
-        int_ret = int_ret || elm_widget_focus_get(ao);
-        items = eina_list_append(items, ao);
-     }
-
-   if (sd->entry)
-     {
-        int_ret = int_ret || elm_widget_focus_get(sd->entry);
-        /* elm_widget_list_focus_liset_next_get() check parent of item
-           because parent sd->entry is not multibuttnentry but sd->box
-           so append sd->box instead of sd->entry, is this proper? */
-        items = eina_list_append(items, sd->box);
-     }
-
-   if (int_ret)
-     return elm_widget_focus_list_next_get
-              (obj, items, eina_list_data_get, dir, next, next_item);
-
-   return EINA_FALSE;
-}
-
 static void
 _access_obj_process(Evas_Object *obj, Eina_Bool is_access)
 {
@@ -1749,7 +1634,7 @@ _access_obj_process(Evas_Object *obj, Eina_Bool is_access)
 }
 
 EOLIAN static void
-_elm_multibuttonentry_elm_widget_access(Eo *obj, Elm_Multibuttonentry_Data *sd EINA_UNUSED, Eina_Bool acs)
+_elm_multibuttonentry_efl_ui_widget_on_access_update(Eo *obj, Elm_Multibuttonentry_Data *sd EINA_UNUSED, Eina_Bool acs)
 {
    _elm_multibuttonentry_smart_focus_next_enable = acs;
    _access_obj_process(obj, _elm_multibuttonentry_smart_focus_next_enable);
@@ -1759,7 +1644,44 @@ EAPI Evas_Object *
 elm_multibuttonentry_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
+}
+
+static void
+_legacy_focused(void *data, const Efl_Event *ev)
+{
+   Efl_Ui_Focus_Object *new_focus;
+   Eina_Bool meaningful_focus_in = EINA_FALSE, meaningful_focus_out = EINA_FALSE;
+   ELM_MULTIBUTTONENTRY_DATA_GET(data, pd);
+
+   new_focus = efl_ui_focus_manager_focus_get(ev->object);
+
+   if (efl_isa(ev->info, EFL_UI_WIDGET_CLASS) && elm_widget_parent_get(ev->info) == pd->box)
+     {
+        meaningful_focus_out = EINA_TRUE;
+     }
+
+   if (efl_isa(new_focus, EFL_UI_WIDGET_CLASS) && elm_widget_parent_get(new_focus) == pd->box)
+     {
+        meaningful_focus_in = EINA_TRUE;
+     }
+
+   if (meaningful_focus_in && !meaningful_focus_out)
+     {
+        evas_object_smart_callback_call(data, "focused", NULL);
+     }
+
+   if (!meaningful_focus_in && meaningful_focus_out)
+     {
+        evas_object_smart_callback_call(data, "unfocused", NULL);
+     }
+}
+
+static void
+_legacy_manager_changed_cb(void *data EINA_UNUSED, const Efl_Event *ev)
+{
+   efl_event_callback_del(ev->info, EFL_UI_FOCUS_MANAGER_EVENT_FOCUSED, _legacy_focused, ev->object);
+   efl_event_callback_add(efl_ui_focus_object_focus_manager_get(ev->object), EFL_UI_FOCUS_MANAGER_EVENT_FOCUSED, _legacy_focused, ev->object);
 }
 
 EOLIAN static Eo *
@@ -1768,19 +1690,22 @@ _elm_multibuttonentry_efl_object_constructor(Eo *obj, Elm_Multibuttonentry_Data
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_PANEL);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_PANEL);
+
+   //listen to manager changes here
+   efl_event_callback_add(obj, EFL_UI_FOCUS_OBJECT_EVENT_MANAGER_CHANGED, _legacy_manager_changed_cb, NULL);
 
    return obj;
 }
 
 EOLIAN static Evas_Object*
-_elm_multibuttonentry_entry_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_entry_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    return sd->entry;
 }
 
 EOLIAN static Eina_Bool
-_elm_multibuttonentry_expanded_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_expanded_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    return sd->view_state == MULTIBUTTONENTRY_VIEW_SHRINK ?
           EINA_FALSE : EINA_TRUE;
@@ -1829,7 +1754,7 @@ _elm_multibuttonentry_editable_set(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Dat
 }
 
 EOLIAN static Eina_Bool
-_elm_multibuttonentry_editable_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_editable_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    return sd->editable;
 }
@@ -1859,25 +1784,25 @@ _elm_multibuttonentry_item_insert_after(Eo *obj EINA_UNUSED, Elm_Multibuttonentr
 }
 
 EOLIAN static const Eina_List*
-_elm_multibuttonentry_items_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_items_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    return sd->items;
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_multibuttonentry_first_item_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_first_item_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    return eina_list_data_get(sd->items);
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_multibuttonentry_last_item_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_last_item_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    return eina_list_data_get(eina_list_last(sd->items));
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_multibuttonentry_selected_item_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_selected_item_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    return EO_OBJ(sd->selected_it);
 }
@@ -1892,7 +1817,7 @@ _elm_multibuttonentry_item_selected_set(Eo *eo_item EINA_UNUSED,
 }
 
 EOLIAN static Eina_Bool
-_elm_multibuttonentry_item_selected_get(Eo *eo_item,
+_elm_multibuttonentry_item_selected_get(const Eo *eo_item,
                                         Elm_Multibuttonentry_Item_Data *item)
 {
    ELM_MULTIBUTTONENTRY_DATA_GET_OR_RETURN_VAL(WIDGET(item), sd, EINA_FALSE);
@@ -1907,7 +1832,7 @@ EOLIAN static void
 _elm_multibuttonentry_clear(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Data *sd)
 {
    while (sd->items)
-     elm_wdg_item_del(eina_list_data_get(sd->items));
+     elm_object_item_del(eina_list_data_get(sd->items));
 
    sd->selected_it = NULL;
    _view_update(sd);
@@ -2059,38 +1984,38 @@ _elm_multibuttonentry_class_constructor(Efl_Class *klass)
 }
 
 EOLIAN static Eina_List*
-_elm_multibuttonentry_elm_interface_atspi_accessible_children_get(Eo *obj, Elm_Multibuttonentry_Data *sd)
+_elm_multibuttonentry_efl_access_object_access_children_get(const Eo *obj, Elm_Multibuttonentry_Data *sd)
 {
    Eina_List *ret;
-   ret = elm_interface_atspi_accessible_children_get(efl_super(obj, ELM_MULTIBUTTONENTRY_CLASS));
+   ret = efl_access_object_access_children_get(efl_super(obj, ELM_MULTIBUTTONENTRY_CLASS));
    return eina_list_merge(eina_list_clone(sd->items), ret);
 }
 
 EOLIAN static const char*
-_elm_multibuttonentry_item_elm_interface_atspi_accessible_name_get(Eo *obj, Elm_Multibuttonentry_Item_Data *item)
+_elm_multibuttonentry_item_efl_access_object_i18n_name_get(const Eo *eo_it, Elm_Multibuttonentry_Item_Data *item)
 {
    const char *ret;
-   ret = elm_interface_atspi_accessible_name_get(efl_super(obj, ELM_MULTIBUTTONENTRY_ITEM_CLASS));
+   ret = efl_access_object_i18n_name_get(efl_super(eo_it, ELM_MULTIBUTTONENTRY_ITEM_CLASS));
    if (ret) return ret;
 
-   const char *txt = elm_object_part_text_get(VIEW(item), "elm.btn.text");
-   return txt;
+   ret = elm_object_part_text_get(VIEW(item), "elm.btn.text");
+   return _elm_widget_item_accessible_plain_name_get(eo_it, ret);
 }
 
-EOLIAN static Elm_Atspi_State_Set
-_elm_multibuttonentry_item_elm_interface_atspi_accessible_state_set_get(Eo *eo_it, Elm_Multibuttonentry_Item_Data *sd EINA_UNUSED)
+EOLIAN static Efl_Access_State_Set
+_elm_multibuttonentry_item_efl_access_object_state_set_get(const Eo *eo_it, Elm_Multibuttonentry_Item_Data *sd EINA_UNUSED)
 {
-   Elm_Atspi_State_Set ret;
+   Efl_Access_State_Set ret;
    Eina_Bool sel;
 
-   ret = elm_interface_atspi_accessible_state_set_get(efl_super(eo_it, ELM_MULTIBUTTONENTRY_ITEM_CLASS));
+   ret = efl_access_object_state_set_get(efl_super(eo_it, ELM_MULTIBUTTONENTRY_ITEM_CLASS));
 
    sel = elm_obj_multibuttonentry_item_selected_get(eo_it);
 
-   STATE_TYPE_SET(ret, ELM_ATSPI_STATE_EDITABLE);
+   STATE_TYPE_SET(ret, EFL_ACCESS_STATE_EDITABLE);
 
    if (sel)
-     STATE_TYPE_SET(ret, ELM_ATSPI_STATE_CHECKED);
+     STATE_TYPE_SET(ret, EFL_ACCESS_STATE_CHECKED);
 
    return ret;
 }
@@ -2120,10 +2045,10 @@ _key_action_longpress(Eo *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_multibuttonentry_item_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Item_Data *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_multibuttonentry_item_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Multibuttonentry_Item_Data *pd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "activate", NULL, NULL, _key_action_activate },
           { "delete", NULL, NULL, _key_action_delete},
           { "longpress", NULL, NULL, _key_action_longpress},
@@ -2134,15 +2059,16 @@ _elm_multibuttonentry_item_elm_interface_atspi_widget_action_elm_actions_get(Eo
 
 /* Efl.Part begin */
 
-ELM_PART_OVERRIDE(elm_multibuttonentry, ELM_MULTIBUTTONENTRY, ELM_LAYOUT, Elm_Multibuttonentry_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_SET(elm_multibuttonentry, ELM_MULTIBUTTONENTRY, ELM_LAYOUT, Elm_Multibuttonentry_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_GET(elm_multibuttonentry, ELM_MULTIBUTTONENTRY, ELM_LAYOUT, Elm_Multibuttonentry_Data, Elm_Part_Data)
-#include "elm_multibuttonentry_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_multibuttonentry, ELM_MULTIBUTTONENTRY, Elm_Multibuttonentry_Data)
+ELM_PART_OVERRIDE_TEXT_SET(elm_multibuttonentry, ELM_MULTIBUTTONENTRY, Elm_Multibuttonentry_Data)
+ELM_PART_OVERRIDE_TEXT_GET(elm_multibuttonentry, ELM_MULTIBUTTONENTRY, Elm_Multibuttonentry_Data)
+#include "elm_multibuttonentry_part.eo.c"
 
 /* Efl.Part end */
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_MULTIBUTTONENTRY_EXTRA_OPS \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_multibuttonentry), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_multibuttonentry)
 
 #include "elm_multibuttonentry_item.eo.c"
