@@ -2,9 +2,12 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
 #define ELM_WIDGET_ITEM_PROTECTED
+#define ELM_WIDGET_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
@@ -13,7 +16,7 @@
 #include "elm_widget_naviframe.h"
 #include "elm_widget_container.h"
 
-#include "elm_naviframe_internal_part.eo.h"
+#include "elm_naviframe_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_NAVIFRAME_CLASS
@@ -57,12 +60,30 @@ static const Elm_Action key_actions[] = {
    {NULL, NULL}
 };
 
+EOLIAN static void
+_elm_naviframe_efl_ui_widget_resize_object_set(Eo *obj, Elm_Naviframe_Data *pd EINA_UNUSED,
+                                            Efl_Canvas_Object *sobj)
+{
+   if (!sobj || !efl_finalized_get(obj)) goto super;
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+
+   if (wd->resize_obj == sobj) return;
+
+   // Detach the previous page as resize object to avoid any modifications to
+   // it by the widget implementation. This preserves clip, smart membership,
+   // focus, etc...
+   wd->resize_obj = NULL;
+
+super:
+   efl_ui_widget_resize_object_set(efl_super(obj, MY_CLASS), sobj);
+}
+
 static void
 _resize_object_reset(Evas_Object *obj, Elm_Naviframe_Item_Data *it)
 {
    if (it)
      {
-        elm_widget_resize_object_set(obj, VIEW(it), EINA_FALSE);
+        elm_widget_resize_object_set(obj, VIEW(it));
         evas_object_raise(VIEW(it));
      }
 }
@@ -70,32 +91,20 @@ _resize_object_reset(Evas_Object *obj, Elm_Naviframe_Item_Data *it)
 static void
 _prev_page_focus_recover(Elm_Naviframe_Item_Data *it)
 {
-   Evas_Object *newest;
-   unsigned int order = 0;
+   Elm_Naviframe *n = it->base->widget;
 
-   newest = elm_widget_newest_focus_order_get(VIEW(it), &order, EINA_TRUE);
-   if (newest)
-     elm_object_focus_set(newest, EINA_TRUE);
-   else
-     {
-        if (elm_object_focus_allow_get(VIEW(it)))
-          elm_object_focus_set(VIEW(it), EINA_TRUE);
-        else
-          elm_object_focus_set(WIDGET(it), EINA_TRUE);
-     }
+   efl_ui_focus_manager_focus_set(efl_ui_focus_object_focus_manager_get(n), n);
 }
 
-EOLIAN static Eina_Bool
-_elm_naviframe_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
+EOLIAN static void
+_elm_naviframe_efl_ui_translatable_translation_update(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 {
    Elm_Naviframe_Item_Data *it;
 
    EINA_INLIST_FOREACH(sd->stack, it)
      elm_wdg_item_translate(EO_OBJ(it));
 
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-
-   return EINA_TRUE;
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
 }
 
 static void
@@ -168,45 +177,17 @@ static void
 _item_free(Elm_Naviframe_Item_Data *it)
 {
    Eina_Inlist *l;
-   Elm_Naviframe_Content_Item_Pair *content_pair;
    Elm_Naviframe_Text_Item_Pair *text_pair;
 
-   ELM_NAVIFRAME_DATA_GET(WIDGET(it), sd);
-
-   eina_stringshare_del(it->style);
    eina_stringshare_del(it->title_label);
    eina_stringshare_del(it->subtitle_label);
 
-   EINA_INLIST_FOREACH_SAFE(it->content_list, l, content_pair)
-     {
-        if (content_pair->content)
-          {
-             evas_object_event_callback_del(content_pair->content,
-                                            EVAS_CALLBACK_DEL,
-                                            _title_content_del);
-             evas_object_del(content_pair->content);
-          }
-        eina_stringshare_del(content_pair->part);
-        free(content_pair);
-     }
+
    EINA_INLIST_FOREACH_SAFE(it->text_list, l, text_pair)
      {
         eina_stringshare_del(text_pair->part);
         free(text_pair);
      }
-
-   if (it->content)
-     {
-        if ((sd->preserve) && (!sd->on_deletion))
-          {
-             /* so that elm does not delete the contents with the item's
-              * view after the destructor */
-             elm_object_part_content_unset(VIEW(it), CONTENT_PART);
-             evas_object_event_callback_del
-                (it->content, EVAS_CALLBACK_DEL, _item_content_del_cb);
-             evas_object_hide(it->content);
-          }
-     }
 }
 
 static void
@@ -276,10 +257,12 @@ _item_text_signals_emit(Elm_Naviframe_Item_Data *it)
 static Evas_Object *
 _access_object_get(Elm_Naviframe_Item_Data *it, const char* part)
 {
-   Evas_Object *po, *ao;
+   Evas_Object *po, *ao, *o;
 
-   po = (Evas_Object *)edje_object_part_object_get
-          (elm_layout_edje_get(VIEW(it)), part);
+   o = elm_layout_edje_get(VIEW(it));
+   edje_object_freeze(o);
+   po = (Evas_Object *)edje_object_part_object_get(o, part);
+   edje_object_thaw(o);
    ao = evas_object_data_get(po, "_part_access_obj");
 
    return ao;
@@ -326,17 +309,25 @@ _item_style_set(Elm_Naviframe_Item_Data *it,
    if (!item_style)
      {
         strcpy(buf, "item/basic");
-        eina_stringshare_replace(&it->style, "basic");
+        elm_wdg_item_style_set(efl_super(EO_OBJ(it), ELM_NAVIFRAME_ITEM_CLASS), "basic");
      }
    else
      {
         snprintf(buf, sizeof(buf), "item/%s", item_style);
-        eina_stringshare_replace(&it->style, item_style);
+        elm_wdg_item_style_set(efl_super(EO_OBJ(it), ELM_NAVIFRAME_ITEM_CLASS),  item_style);
      }
 
    if (!elm_layout_theme_set(VIEW(it), "naviframe", buf,
                              elm_widget_style_get(WIDGET(it))))
-     CRI("Failed to set layout!");
+     {
+        /* Naviframe item theme name is combined with item style name and widget
+         * style name.
+         * Therefore, if the item theme name is not found, then set "item/basic"
+         * item style name as a default item style name. */
+        if (!elm_layout_theme_set(VIEW(it), "naviframe", "item/basic",
+                                  elm_widget_style_get(WIDGET(it))))
+          CRI("Failed to set layout!");
+     }
 
    if (sd->freeze_events)
      evas_object_freeze_events_set(VIEW(it), EINA_FALSE);
@@ -375,25 +366,25 @@ _item_title_enabled_update(Elm_Naviframe_Item_Data *nit, Eina_Bool transition)
    edje_object_message_signal_process(elm_layout_edje_get(VIEW(nit)));
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_naviframe_elm_widget_theme_apply(Eo *obj, Elm_Naviframe_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_naviframe_efl_ui_widget_theme_apply(Eo *obj, Elm_Naviframe_Data *sd)
 {
    Elm_Naviframe_Item_Data *it;
    const char *style = NULL, *sstyle = NULL;
 
-   style = elm_obj_widget_style_get(obj);
+   style = efl_ui_widget_style_get(obj);
 
    EINA_INLIST_FOREACH(sd->stack, it)
      {
-        sstyle = elm_obj_widget_style_get(VIEW(it));
+        sstyle = efl_ui_widget_style_get(VIEW(it));
         if ((style && sstyle) && strcmp(style, sstyle))
-          _item_style_set(it, it->style);
+          _item_style_set(it, elm_wdg_item_style_get(EO_OBJ(it)));
         _item_signals_emit(it);
         _item_title_enabled_update(it, EINA_FALSE);
      }
 
    elm_layout_sizing_eval(obj);
-   return ELM_THEME_APPLY_SUCCESS;
+   return EFL_UI_THEME_APPLY_SUCCESS;
 }
 
 static char *
@@ -414,11 +405,14 @@ _access_info_cb(void *data, Evas_Object *obj EINA_UNUSED)
 
    buf = eina_strbuf_new();
    eina_strbuf_append(buf, info);
+   eina_strbuf_append_printf(buf, ", %s", N_("Title"));
 
    info = elm_object_part_text_get(layout, SUBTITLE_PART);
    if (!info) goto end;
+   if (!strcmp(info, "")) goto end;
 
    eina_strbuf_append_printf(buf, ", %s", info);
+   eina_strbuf_append_printf(buf, ", %s", N_("Subtitle"));
 
 end:
    ret = eina_strbuf_string_steal(buf);
@@ -526,13 +520,13 @@ _elm_naviframe_item_elm_widget_item_part_text_set(Eo *eo_it,
         if (nit->title_label) strncat(buf, " ", 1);
         strncat(buf, nit->subtitle_label, sizeof(buf) - strlen(buf) - 2);
      }
-   elm_interface_atspi_accessible_name_set(eo_it, buf);
+   efl_access_object_i18n_name_set(eo_it, buf);
 
    elm_layout_sizing_eval(WIDGET(nit));
 }
 
 EOLIAN static const char *
-_elm_naviframe_item_elm_widget_item_part_text_get(Eo *nit EINA_UNUSED,
+_elm_naviframe_item_elm_widget_item_part_text_get(const Eo *nit EINA_UNUSED,
                                              Elm_Naviframe_Item_Data *it,
                                              const char *part)
 {
@@ -553,52 +547,33 @@ _elm_naviframe_item_efl_object_destructor(Eo *eo_item, Elm_Naviframe_Item_Data *
 {
    Eina_List *l;
    Elm_Naviframe_Op *nfo;
-   Elm_Naviframe_Item_Data *nit = it, *prev_it = NULL;
-   Eina_Bool top;
+   Elm_Naviframe_Item_Data *nit = it;
 
    ELM_NAVIFRAME_DATA_GET(WIDGET(nit), sd);
 
    nit->delete_me = EINA_TRUE;
 
-   top = (eo_item == elm_naviframe_top_item_get(WIDGET(nit)));
-   if (evas_object_data_get(VIEW(nit), "out_of_list"))
-     goto end;
-
-   sd->stack = eina_inlist_remove(sd->stack, EINA_INLIST_GET(nit));
-
-   if (top && !sd->on_deletion) /* must raise another one */
-     {
-        if (sd->stack && sd->stack->last)
-          prev_it = EINA_INLIST_CONTAINER_GET(sd->stack->last,
-                                              Elm_Naviframe_Item_Data);
-        if (!prev_it)
-          {
-             elm_widget_tree_unfocusable_set(VIEW(nit), EINA_TRUE);
-             goto end;
-          }
-
-        elm_widget_tree_unfocusable_set(VIEW(prev_it), EINA_FALSE);
-        elm_widget_tree_unfocusable_set(VIEW(nit), EINA_TRUE);
-
-        if (sd->freeze_events)
-          evas_object_freeze_events_set(VIEW(prev_it), EINA_FALSE);
-        _resize_object_reset(WIDGET(prev_it), prev_it);
-        evas_object_show(VIEW(prev_it));
-
-        _prev_page_focus_recover(prev_it);
-
-        elm_object_signal_emit(VIEW(prev_it), "elm,state,visible", "elm");
-
-        efl_event_callback_legacy_call(WIDGET(prev_it), ELM_NAVIFRAME_EVENT_ITEM_ACTIVATED, EO_OBJ(prev_it));
-     }
-
-end:
    // This should not happen, but just in case and by security
    // make sure there is no more reference to this item.
    EINA_LIST_FOREACH(sd->ops, l, nfo)
      {
-        if (nfo->related == nit) nfo->related = NULL;
-        if (nfo->self == nit) nfo->self = NULL;
+        /* If an item is newly pushed and then deleted by elm_object_item_del()
+         * before item push transition is not started, then the item push
+         * transitions for both new item and current item should be cancelled.
+         * Otherwise, the current item becomes invisible due to the item push
+         * transition. */
+        if ((nit->pushing) && (nfo->self == nit))
+          {
+             nfo->self = NULL;
+             nfo->related = NULL;
+          }
+        else
+          {
+             if (nfo->self == nit)
+               nfo->self = NULL;
+             if (nfo->related == nit)
+               nfo->related = NULL;
+          }
      }
 
    _item_free(nit);
@@ -846,7 +821,7 @@ _elm_naviframe_item_elm_widget_item_part_content_set(Eo *eo_nit EINA_UNUSED,
 }
 
 EOLIAN static Evas_Object *
-_elm_naviframe_item_elm_widget_item_part_content_get(Eo *eo_nit EINA_UNUSED,
+_elm_naviframe_item_elm_widget_item_part_content_get(const Eo *eo_nit EINA_UNUSED,
                                                      Elm_Naviframe_Item_Data *nit,
                                                      const char *part)
 {
@@ -1014,7 +989,7 @@ _back_btn_new(Evas_Object *obj, const char *title_label)
 }
 
 EOLIAN static void
-_elm_naviframe_elm_layout_signal_emit(Eo *obj, Elm_Naviframe_Data *sd EINA_UNUSED, const char *emission, const char *source)
+_elm_naviframe_efl_layout_signal_signal_emit(Eo *obj, Elm_Naviframe_Data *sd EINA_UNUSED, const char *emission, const char *source)
 {
    Elm_Object_Item *eo_top_it;
 
@@ -1022,7 +997,7 @@ _elm_naviframe_elm_layout_signal_emit(Eo *obj, Elm_Naviframe_Data *sd EINA_UNUSE
    if (!eo_top_it) return;
    ELM_NAVIFRAME_ITEM_DATA_GET(eo_top_it, top_it);
 
-   elm_obj_layout_signal_emit(VIEW(top_it), emission, source);
+   efl_layout_signal_emit(VIEW(top_it), emission, source);
 }
 
 /* content/text smart functions proxying things to the top item, which
@@ -1148,7 +1123,7 @@ _on_item_pop_finished(void *data,
      elm_widget_tree_unfocusable_set(VIEW(it), EINA_FALSE);
    sd->popping = eina_list_remove(sd->popping, it);
 
-   elm_wdg_item_del(EO_OBJ(it));
+   efl_del(EO_OBJ(it));
 }
 
 /* "elm,state,new,pushed",
@@ -1211,6 +1186,78 @@ _access_prev_btn_info_cb(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED)
    return strdup(E_("Back"));
 }
 
+EOLIAN static void
+_elm_naviframe_item_efl_object_invalidate(Eo *eo_item, Elm_Naviframe_Item_Data *it)
+{
+   Elm_Naviframe_Item_Data *prev_it = NULL;
+   Elm_Naviframe_Content_Item_Pair *content_pair;
+   Eina_Inlist *l;
+
+   ELM_NAVIFRAME_DATA_GET(WIDGET(it), sd);
+   if (it->title_prev_btn)
+     evas_object_event_callback_del(it->title_prev_btn, EVAS_CALLBACK_DEL, _item_title_prev_btn_del_cb);
+   if (it->title_next_btn)
+     evas_object_event_callback_del(it->title_next_btn, EVAS_CALLBACK_DEL, _item_title_next_btn_del_cb);
+   if (it->title_icon)
+     evas_object_event_callback_del(it->title_icon, EVAS_CALLBACK_DEL, _item_title_icon_del_cb);
+   EINA_INLIST_FOREACH_SAFE(it->content_list, l, content_pair)
+     {
+        if (content_pair->content)
+          {
+             /* content object will be destroyed naturally */
+             evas_object_event_callback_del(content_pair->content,
+                                            EVAS_CALLBACK_DEL,
+                                            _title_content_del);
+             evas_object_del(content_pair->content);
+          }
+        eina_stringshare_del(content_pair->part);
+        free(content_pair);
+     }
+   if (it->content)
+     {
+        evas_object_event_callback_del(it->content, EVAS_CALLBACK_DEL, _item_content_del_cb);
+        if ((sd->preserve) && (!sd->on_deletion))
+          {
+             /* so that elm does not delete the contents with the item's
+              * view after the destructor */
+             elm_object_part_content_unset(VIEW(it), CONTENT_PART);
+             evas_object_hide(it->content);
+          }
+     }
+   if (evas_object_data_get(VIEW(it), "out_of_list"))
+     goto end;
+
+   sd->stack = eina_inlist_remove(sd->stack, EINA_INLIST_GET(it));
+
+   if ((elm_naviframe_top_item_get(WIDGET(it)) == eo_item) && !sd->on_deletion) /* must raise another one */
+     {
+        if (sd->stack && sd->stack->last)
+          prev_it = EINA_INLIST_CONTAINER_GET(sd->stack->last,
+                                              Elm_Naviframe_Item_Data);
+        if (!prev_it)
+          {
+             elm_widget_tree_unfocusable_set(VIEW(it), EINA_TRUE);
+             goto end;
+          }
+
+        elm_widget_tree_unfocusable_set(VIEW(prev_it), EINA_FALSE);
+        elm_widget_tree_unfocusable_set(VIEW(it), EINA_TRUE);
+
+        if (sd->freeze_events)
+          evas_object_freeze_events_set(VIEW(prev_it), EINA_FALSE);
+        _resize_object_reset(WIDGET(prev_it), prev_it);
+        evas_object_show(VIEW(prev_it));
+
+        _prev_page_focus_recover(prev_it);
+
+        elm_object_signal_emit(VIEW(prev_it), "elm,state,visible", "elm");
+
+        efl_event_callback_legacy_call(WIDGET(prev_it), ELM_NAVIFRAME_EVENT_ITEM_ACTIVATED, EO_OBJ(prev_it));
+     }
+end:
+   efl_invalidate(efl_super(eo_item, ELM_NAVIFRAME_ITEM_CLASS));
+}
+
 EOLIAN static Eo *
 _elm_naviframe_item_efl_object_constructor(Eo *eo_item, Elm_Naviframe_Item_Data *it)
 {
@@ -1234,8 +1281,8 @@ _item_new(Evas_Object *obj,
    ELM_NAVIFRAME_DATA_GET(obj, sd);
 
    eo_item = efl_add(ELM_NAVIFRAME_ITEM_CLASS, obj);
-   elm_interface_atspi_accessible_role_set(eo_item, ELM_ATSPI_ROLE_PAGE_TAB);
-   elm_interface_atspi_accessible_name_set(eo_item, (char*)title_label);
+   efl_access_object_role_set(eo_item, EFL_ACCESS_ROLE_PAGE_TAB);
+   efl_access_object_i18n_name_set(eo_item, (char*)title_label);
 
    if (!eo_item)
      {
@@ -1246,7 +1293,7 @@ _item_new(Evas_Object *obj,
    ELM_NAVIFRAME_ITEM_DATA_GET(eo_item, it);
 
    //item base layout
-   VIEW(it) = elm_layout_add(obj);
+   VIEW_SET(it, elm_layout_add(obj));
    evas_object_smart_member_add(VIEW(it), obj);
 
    if (!elm_widget_sub_object_add(obj, VIEW(it)))
@@ -1337,76 +1384,6 @@ _on_obj_size_hints_changed(void *data EINA_UNUSED, Evas *e EINA_UNUSED,
      _item_dispmode_set(it, dispmode);
 }
 
-EOLIAN static Eina_Bool
-_elm_naviframe_elm_widget_focus_next(Eo *obj, Elm_Naviframe_Data *sd EINA_UNUSED, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Evas_Object *ao;
-
-   Eina_List *l = NULL;
-   Elm_Object_Item *eo_top_it;
-   void *(*list_data_get)(const Eina_List *list);
-
-   Eina_Bool int_ret = EINA_FALSE;
-
-   eo_top_it = elm_naviframe_top_item_get(obj);
-   if (!eo_top_it) goto end;
-
-   list_data_get = eina_list_data_get;
-
-   ELM_NAVIFRAME_ITEM_DATA_GET(eo_top_it, top_it);
-   l = eina_list_append(l, VIEW(top_it));
-
-   /* access */
-   if (_elm_config->access_mode)
-     {
-        ao = _access_object_get(top_it, TITLE_ACCESS_PART);
-        if (ao) l = eina_list_append(l, ao);
-     }
-
-   int_ret = elm_widget_focus_list_next_get(obj, l, list_data_get, dir, next, next_item);
-   eina_list_free(l);
-
-end:
-   if (!int_ret)
-     {
-        *next = obj;
-        int_ret = !elm_widget_focus_get(obj);
-     }
-
-   return int_ret;
-}
-
-EOLIAN static Eina_Bool
-_elm_naviframe_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_naviframe_elm_widget_focus_direction(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd EINA_UNUSED, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Eina_Bool int_ret;
-
-   Eina_List *l = NULL;
-   Elm_Object_Item *eo_top_it;
-   void *(*list_data_get)(const Eina_List *list);
-
-   eo_top_it = elm_naviframe_top_item_get(obj);
-   if (!eo_top_it) return EINA_FALSE;
-
-   list_data_get = eina_list_data_get;
-
-   ELM_NAVIFRAME_ITEM_DATA_GET(eo_top_it, top_it);
-   l = eina_list_append(l, VIEW(top_it));
-
-   int_ret = elm_widget_focus_list_direction_get
-            (obj, base, l, list_data_get, degree, direction, direction_item, weight);
-
-   eina_list_free(l);
-
-   return int_ret;
-}
-
 EOLIAN static void
 _elm_naviframe_efl_canvas_group_group_add(Eo *obj, Elm_Naviframe_Data *priv)
 {
@@ -1477,14 +1454,14 @@ _elm_naviframe_efl_canvas_group_group_del(Eo *obj, Elm_Naviframe_Data *sd)
      {
         it = EINA_INLIST_CONTAINER_GET(l, Elm_Naviframe_Item_Data);
         l = l->prev;
-        elm_wdg_item_del(EO_OBJ(it));
+        efl_del(EO_OBJ(it));
      }
 
    // No need to cleanup animator as it is an event on myself
    EINA_LIST_FREE(sd->ops, nfo)
      free(nfo);
    EINA_LIST_FREE(sd->popping, it)
-     elm_wdg_item_del(EO_OBJ(it));
+     efl_del(EO_OBJ(it));
 
    evas_object_del(sd->dummy_edje);
 
@@ -1493,14 +1470,14 @@ _elm_naviframe_efl_canvas_group_group_del(Eo *obj, Elm_Naviframe_Data *sd)
 
 //Show only the top item view
 EOLIAN static void
-_elm_naviframe_efl_gfx_visible_set(Eo *obj, Elm_Naviframe_Data *sd EINA_UNUSED, Eina_Bool vis)
+_elm_naviframe_efl_gfx_entity_visible_set(Eo *obj, Elm_Naviframe_Data *sd EINA_UNUSED, Eina_Bool vis)
 {
    Elm_Object_Item *eo_top;
 
    if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_VISIBLE, 0, vis))
      return;
 
-   efl_gfx_visible_set(efl_super(obj, MY_CLASS), vis);
+   efl_gfx_entity_visible_set(efl_super(obj, MY_CLASS), vis);
    if (!vis) return;
 
    eo_top = elm_naviframe_top_item_get(obj);
@@ -1542,22 +1519,8 @@ _key_action_item_pop(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
-EOLIAN static Eina_Bool
-_elm_naviframe_elm_widget_widget_event(Eo *obj, Elm_Naviframe_Data *sd EINA_UNUSED, Evas_Object *src, Evas_Callback_Type type, void *event_info)
-{
-   (void)src;
-   Evas_Event_Key_Down *ev = event_info;
-
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions)) return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
-}
-
 EOLIAN static void
-_elm_naviframe_elm_widget_access(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd, Eina_Bool is_access)
+_elm_naviframe_efl_ui_widget_on_access_update(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd, Eina_Bool is_access)
 {
    Elm_Naviframe_Item_Data *it;
 
@@ -1584,7 +1547,6 @@ _item_push_helper(Elm_Naviframe_Item_Data *item)
    evas_object_show(VIEW(item));
 
    ELM_NAVIFRAME_ITEM_DATA_GET(eo_top_item, top_item);
-   if (top_item) elm_widget_focused_object_clear(VIEW(top_item));
    _resize_object_reset(obj, item);
    if (top_item)
      {
@@ -1635,7 +1597,7 @@ EAPI Evas_Object *
 elm_naviframe_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -1645,7 +1607,7 @@ _elm_naviframe_efl_object_constructor(Eo *obj, Elm_Naviframe_Data *sd)
    sd->obj = obj;
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_PAGE_TAB_LIST);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_PAGE_TAB_LIST);
 
    return obj;
 }
@@ -1725,7 +1687,6 @@ _elm_naviframe_item_insert_after(Eo *obj, Elm_Naviframe_Data *sd, Elm_Object_Ite
 
    if (top_inserted)
      {
-        elm_widget_focused_object_clear(VIEW(after));
         elm_widget_tree_unfocusable_set(VIEW(after), EINA_TRUE);
         _resize_object_reset(obj, it);
         evas_object_show(VIEW(it));
@@ -1771,7 +1732,7 @@ _elm_naviframe_item_pop(Eo *obj, Elm_Naviframe_Data *sd)
           {
              efl_unref(eo_item);
              if (it->delete_me)
-               elm_wdg_item_del(eo_item);
+               efl_del(eo_item);
              else
                {
                   /* To avoid multiple item pops, the auto pushed button deletes
@@ -1813,7 +1774,7 @@ _elm_naviframe_item_pop(Eo *obj, Elm_Naviframe_Data *sd)
              evas_object_freeze_events_set(VIEW(prev_it), EINA_TRUE);
           }
 
-        elm_widget_resize_object_set(obj, VIEW(prev_it), EINA_FALSE);
+        elm_widget_resize_object_set(obj, VIEW(prev_it));
 
         /* these 2 signals MUST take place simultaneously */
         elm_object_signal_emit(VIEW(it), "elm,state,cur,popped", "elm");
@@ -1835,7 +1796,7 @@ _elm_naviframe_item_pop(Eo *obj, Elm_Naviframe_Data *sd)
         _schedule_deferred(nfo, sd);
      }
    else
-     elm_wdg_item_del(eo_item);
+     efl_del(eo_item);
 
  on_error:
    return content;
@@ -1863,7 +1824,7 @@ _elm_naviframe_item_pop_to(Eo *eo_it, Elm_Naviframe_Item_Data *it)
 
         l = l->prev;
 
-        elm_wdg_item_del(EO_OBJ(iit));
+        efl_del(EO_OBJ(iit));
      }
 
    sd->on_deletion = EINA_FALSE;
@@ -1908,13 +1869,13 @@ _elm_naviframe_content_preserve_on_pop_set(Eo *obj EINA_UNUSED, Elm_Naviframe_Da
 }
 
 EOLIAN static Eina_Bool
-_elm_naviframe_content_preserve_on_pop_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
+_elm_naviframe_content_preserve_on_pop_get(const Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 {
    return sd->preserve;
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_naviframe_top_item_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
+_elm_naviframe_top_item_get(const Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 {
    if (!sd->stack) return NULL;
    Elm_Naviframe_Item_Data *ret_it = EINA_INLIST_CONTAINER_GET
@@ -1923,7 +1884,7 @@ _elm_naviframe_top_item_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_naviframe_bottom_item_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
+_elm_naviframe_bottom_item_get(const Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 {
    if (!sd->stack) return NULL;
    Elm_Naviframe_Item_Data *ret_it = EINA_INLIST_CONTAINER_GET
@@ -1932,25 +1893,30 @@ _elm_naviframe_bottom_item_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 }
 
 EOLIAN static void
-_elm_naviframe_item_style_set(Eo *eo_item EINA_UNUSED,
+_elm_naviframe_item_elm_widget_item_style_set(Eo *eo_item EINA_UNUSED,
                               Elm_Naviframe_Item_Data *nit,
                               const char *item_style)
 {
-   if (item_style && !strcmp(item_style, nit->style)) return;
+   if (item_style && eina_streq(item_style, elm_wdg_item_style_get(EO_OBJ(nit)))) return;
 
    if (!item_style)
-     if (!strcmp("basic", nit->style)) return;
+     if (eina_streq("basic", elm_wdg_item_style_get(EO_OBJ(nit)))) return;
 
    _item_style_set(nit, item_style);
    _item_signals_emit(nit);
    _item_title_enabled_update(nit, EINA_FALSE);
 }
 
-EOLIAN static const char *
-_elm_naviframe_item_style_get(Eo *eo_item EINA_UNUSED,
-                              Elm_Naviframe_Item_Data *nit)
+EAPI void
+elm_naviframe_item_style_set(Elm_Object_Item *obj, const char *style)
 {
-   return nit->style;
+   elm_wdg_item_style_set(obj, style);
+}
+
+EAPI const char *
+elm_naviframe_item_style_get(const Elm_Object_Item *obj)
+{
+   return elm_wdg_item_style_get(obj);
 }
 
 EINA_DEPRECATED EAPI void
@@ -1998,7 +1964,7 @@ _elm_naviframe_item_pop_cb_set(Eo *eo_item EINA_UNUSED,
 }
 
 EOLIAN static Eina_List*
-_elm_naviframe_item_elm_interface_atspi_accessible_children_get(Eo *eo_item EINA_UNUSED, Elm_Naviframe_Item_Data *nit)
+_elm_naviframe_item_efl_access_object_access_children_get(const Eo *eo_item EINA_UNUSED, Elm_Naviframe_Item_Data *nit)
 {
    Eina_List *ret = NULL;
 
@@ -2013,13 +1979,13 @@ _elm_naviframe_prev_btn_auto_pushed_set(Eo *obj EINA_UNUSED, Elm_Naviframe_Data
 }
 
 EOLIAN static Eina_Bool
-_elm_naviframe_prev_btn_auto_pushed_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
+_elm_naviframe_prev_btn_auto_pushed_get(const Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 {
    return sd->auto_pushed;
 }
 
 EOLIAN static Eina_List*
-_elm_naviframe_items_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
+_elm_naviframe_items_get(const Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 {
    Eina_List *ret = NULL;
    Elm_Naviframe_Item_Data *itr;
@@ -2039,27 +2005,21 @@ _elm_naviframe_event_enabled_set(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd, Ei
 }
 
 EOLIAN static Eina_Bool
-_elm_naviframe_event_enabled_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
+_elm_naviframe_event_enabled_get(const Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd)
 {
    return !sd->freeze_events;
 }
 
-EOLIAN static Eina_Bool
-_elm_naviframe_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *sd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
 static void
 _elm_naviframe_class_constructor(Efl_Class *klass)
 {
    evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_naviframe_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Naviframe_Data *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_naviframe_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Naviframe_Data *pd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "top_item_get", "top_item_get", NULL, _key_action_top_item_get },
           { "item_pop", "item_pop", NULL, _key_action_item_pop },
           { NULL, NULL, NULL, NULL }
@@ -2067,21 +2027,26 @@ _elm_naviframe_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UN
    return &atspi_actions[0];
 }
 
+/* Standard widget overrides */
+
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(elm_naviframe, Elm_Naviframe_Data)
+
 /* Efl.Part begin */
 
-ELM_PART_OVERRIDE(elm_naviframe, ELM_NAVIFRAME, ELM_LAYOUT, Elm_Naviframe_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_SET(elm_naviframe, ELM_NAVIFRAME, ELM_LAYOUT, Elm_Naviframe_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_GET(elm_naviframe, ELM_NAVIFRAME, ELM_LAYOUT, Elm_Naviframe_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_UNSET(elm_naviframe, ELM_NAVIFRAME, ELM_LAYOUT, Elm_Naviframe_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_SET(elm_naviframe, ELM_NAVIFRAME, ELM_LAYOUT, Elm_Naviframe_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_GET(elm_naviframe, ELM_NAVIFRAME, ELM_LAYOUT, Elm_Naviframe_Data, Elm_Part_Data)
-#include "elm_naviframe_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_naviframe, ELM_NAVIFRAME, Elm_Naviframe_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_naviframe, ELM_NAVIFRAME, Elm_Naviframe_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(elm_naviframe, ELM_NAVIFRAME, Elm_Naviframe_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_naviframe, ELM_NAVIFRAME, Elm_Naviframe_Data)
+ELM_PART_OVERRIDE_TEXT_SET(elm_naviframe, ELM_NAVIFRAME, Elm_Naviframe_Data)
+ELM_PART_OVERRIDE_TEXT_GET(elm_naviframe, ELM_NAVIFRAME, Elm_Naviframe_Data)
+#include "elm_naviframe_part.eo.c"
 
 /* Efl.Part end */
 
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_NAVIFRAME_EXTRA_OPS \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_naviframe), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_naviframe)
 
 #include "elm_naviframe_item.eo.c"
