@@ -2,17 +2,18 @@
 # include "elementary_config.h"
 #endif
 
-#include <Emotion.h>
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define EFL_PART_PROTECTED
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#include <Emotion.h>
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_widget_layout.h"
 #include "elm_widget_player.h"
 
-#include "elm_player_internal_part.eo.h"
+#include "elm_player_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_PLAYER_CLASS
@@ -98,6 +99,7 @@ _key_action_move(Evas_Object *obj, const char *params)
    ELM_PLAYER_DATA_GET(obj, sd);
    const char *dir = params;
 
+   if (!sd->video) return EINA_FALSE;
    _elm_widget_focus_auto_show(obj);
    if (!strcmp(dir, "left"))
      {
@@ -136,6 +138,7 @@ _key_action_play(Evas_Object *obj, const char *params EINA_UNUSED)
 {
    ELM_PLAYER_DATA_GET(obj, sd);
 
+   if (!sd->video) return EINA_FALSE;
    if (elm_video_is_playing_get(sd->video))
      elm_video_pause(sd->video);
    else
@@ -144,23 +147,6 @@ _key_action_play(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
-EOLIAN static Eina_Bool
-_elm_player_elm_widget_widget_event(Eo *obj, Elm_Player_Data *sd, Evas_Object *src, Evas_Callback_Type type, void *event_info)
-{
-   Evas_Event_Key_Down *ev = event_info;
-   (void) src;
-
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-   if (!sd->video) return EINA_FALSE;
-
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions))
-     return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
-}
-
 static void
 _update_theme_button(Evas_Object *obj, Evas_Object *bt, const char *name)
 {
@@ -199,12 +185,12 @@ _update_theme_slider(Evas_Object *obj, Evas_Object *sl, const char *name, const
    elm_object_disabled_set(sl, elm_widget_disabled_get(obj));
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_player_elm_widget_theme_apply(Eo *obj, Elm_Player_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_player_efl_ui_widget_theme_apply(Eo *obj, Elm_Player_Data *sd)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    _update_theme_button(obj, sd->forward, "forward");
    _update_theme_button(obj, sd->info, "info");
@@ -673,7 +659,7 @@ EAPI Evas_Object *
 elm_player_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -682,7 +668,7 @@ _elm_player_efl_object_constructor(Eo *obj, Elm_Player_Data *sd EINA_UNUSED)
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_ANIMATION);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_ANIMATION);
 
    return obj;
 }
@@ -693,10 +679,10 @@ _elm_player_class_constructor(Efl_Class *klass)
    evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_player_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Player_Data *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_player_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Player_Data *pd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "move,left", "move", "left", _key_action_move},
           { "move,right", "move", "right", _key_action_move},
           { "play", "play", NULL, _key_action_play},
@@ -705,12 +691,16 @@ _elm_player_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSE
    return &atspi_actions[0];
 }
 
+/* Standard widget overrides */
+
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(elm_player, Elm_Player_Data)
+
 /* Efl.Part implementation */
 
-ELM_PART_OVERRIDE(elm_player, ELM_PLAYER, ELM_LAYOUT, Elm_Player_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_SET(elm_player, ELM_PLAYER, ELM_LAYOUT, Elm_Player_Data, Elm_Part_Data)
-ELM_PART_CONTENT_DEFAULT_SET(elm_player, "video")
-#include "elm_player_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_player, ELM_PLAYER, Elm_Player_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_player, ELM_PLAYER, Elm_Player_Data)
+ELM_PART_CONTENT_DEFAULT_GET(elm_player, "video")
+#include "elm_player_part.eo.c"
 
 /* End of Efl.Part */
 
@@ -718,6 +708,7 @@ ELM_PART_CONTENT_DEFAULT_SET(elm_player, "video")
 
 #define ELM_PLAYER_EXTRA_OPS \
    ELM_PART_CONTENT_DEFAULT_OPS(elm_player), \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_player), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_player)
 
 #include "elm_player.eo.c"
