@@ -2,18 +2,18 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
 #define ELM_WIDGET_PROTECTED
 #define ELM_WIDGET_ITEM_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_widget_popup.h"
 
-#include "elm_popup_item.eo.h"
-
-#include "elm_popup_internal_part.eo.h"
+#include "elm_popup_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_POPUP_CLASS
@@ -44,7 +44,6 @@ static const Evas_Smart_Cb_Description _smart_callbacks[] = {
    {NULL, NULL}
 };
 
-static Eina_Bool _key_action_move(Evas_Object *obj, const char *params);
 static Eina_Bool _key_action_escape(Evas_Object *obj, const char *params);
 static void _parent_geom_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj, void *event_info EINA_UNUSED);
 static void _block_clicked_cb(void *data, const Efl_Event *event);
@@ -53,7 +52,6 @@ static void _timeout_cb(void *data, const Efl_Event *event);
 static void _hide_effect_finished_cb(void *data, const Efl_Event *event);
 
 static const Elm_Action key_actions[] = {
-   {"move", _key_action_move},
    {"escape", _key_action_escape},
    {NULL, NULL}
 };
@@ -66,8 +64,8 @@ EFL_CALLBACKS_ARRAY_DEFINE(_notify_cb,
 
 static void  _on_content_del(void *data, Evas *e, Evas_Object *obj, void *event_info);
 
-EOLIAN static Eina_Bool
-_elm_popup_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
+EOLIAN static void
+_elm_popup_efl_ui_translatable_translation_update(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
 {
    Elm_Popup_Item_Data *it;
    Eina_List *l;
@@ -75,10 +73,8 @@ _elm_popup_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
    EINA_LIST_FOREACH(sd->items, l, it)
       elm_wdg_item_translate(EO_OBJ(it));
 
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-   elm_obj_widget_translate(sd->main_layout);
-
-   return EINA_TRUE;
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
+   efl_ui_translatable_translation_update(sd->main_layout);
 }
 
 static void
@@ -118,7 +114,7 @@ _timeout_cb(void *data, const Efl_Event *event EINA_UNUSED)
 static void
 _hide_effect_finished_cb(void *data, const Efl_Event *event EINA_UNUSED)
 {
-   efl_gfx_visible_set(data, EINA_FALSE);
+   efl_gfx_entity_visible_set(data, EINA_FALSE);
    efl_event_callback_legacy_call(data, ELM_POPUP_EVENT_DISMISSED, NULL);
 }
 
@@ -126,11 +122,13 @@ _hide_effect_finished_cb(void *data, const Efl_Event *event EINA_UNUSED)
 static Evas_Object *
 _access_object_get(const Evas_Object *obj, const char* part)
 {
-   Evas_Object *po, *ao;
+   Evas_Object *po, *ao, *o;
    ELM_POPUP_DATA_GET(obj, sd);
 
-   po = (Evas_Object *)edje_object_part_object_get
-      (elm_layout_edje_get(sd->main_layout), part);
+   o = elm_layout_edje_get(sd->main_layout);
+   edje_object_freeze(o);
+   po = (Evas_Object *)edje_object_part_object_get(o, part);
+   edje_object_thaw(o);
    ao = evas_object_data_get(po, "_part_access_obj");
 
    return ao;
@@ -221,11 +219,22 @@ _items_remove(Elm_Popup_Data *sd)
    if (!sd->items) return;
 
    EINA_LIST_FREE(sd->items, it)
-     elm_wdg_item_del(EO_OBJ(it));
+     efl_del(EO_OBJ(it));
 
    sd->items = NULL;
 }
 
+static void
+_focus_changed_popup(void *data, const Efl_Event *ev)
+{
+   //mirror property
+   efl_ui_focus_object_focus_set(data, efl_ui_focus_object_focus_get(ev->object));
+}
+
+EFL_CALLBACKS_ARRAY_DEFINE(composition_cb,
+   { EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED, _focus_changed_popup },
+)
+
 EOLIAN static void
 _elm_popup_efl_canvas_group_group_del(Eo *obj, Elm_Popup_Data *sd)
 {
@@ -239,6 +248,7 @@ _elm_popup_efl_canvas_group_group_del(Eo *obj, Elm_Popup_Data *sd)
    evas_object_event_callback_del
      (sd->content, EVAS_CALLBACK_DEL, _on_content_del);
    evas_object_event_callback_del(obj, EVAS_CALLBACK_SHOW, _on_show);
+   efl_event_callback_array_del(sd->notify, composition_cb(), obj);
 
    sd->last_button_number = 0;
 
@@ -257,17 +267,17 @@ _elm_popup_efl_canvas_group_group_del(Eo *obj, Elm_Popup_Data *sd)
      }
 
    // XXX? delete other objects? just to be sure.
-   ELM_SAFE_FREE(sd->main_layout, evas_object_del);
    ELM_SAFE_FREE(sd->notify, evas_object_del);
    ELM_SAFE_FREE(sd->title_icon, evas_object_del);
-   ELM_SAFE_FREE(sd->content_area, evas_object_del);
    ELM_SAFE_FREE(sd->text_content_obj, evas_object_del);
-   ELM_SAFE_FREE(sd->action_area, evas_object_del);
    ELM_SAFE_FREE(sd->box, evas_object_del);
    ELM_SAFE_FREE(sd->tbl, evas_object_del);
    ELM_SAFE_FREE(sd->spacer, evas_object_del);
    ELM_SAFE_FREE(sd->scr, evas_object_del);
    ELM_SAFE_FREE(sd->content, evas_object_del);
+   ELM_SAFE_FREE(sd->main_layout, evas_object_del);
+   ELM_SAFE_FREE(sd->content_area, evas_object_del);
+   ELM_SAFE_FREE(sd->action_area, evas_object_del);
    ELM_SAFE_FREE(sd->title_text, eina_stringshare_del);
 
    efl_canvas_group_del(efl_super(obj, MY_CLASS));
@@ -355,8 +365,8 @@ _populate_theme_scroll(Elm_Popup_Data *sd)
    sd->theme_scroll = EINA_FALSE;
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_popup_elm_widget_theme_apply(Eo *obj, Elm_Popup_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_popup_efl_ui_widget_theme_apply(Eo *obj, Elm_Popup_Data *sd)
 {
    Elm_Popup_Item_Data *it;
    Eina_List *elist;
@@ -429,7 +439,7 @@ _elm_popup_elm_widget_theme_apply(Eo *obj, Elm_Popup_Data *sd)
    /* access */
    if (_elm_config->access_mode) _access_obj_process(obj, EINA_TRUE);
 
-   return ELM_THEME_APPLY_SUCCESS;
+   return EFL_UI_THEME_APPLY_SUCCESS;
 }
 
 static void
@@ -459,14 +469,14 @@ _elm_popup_elm_layout_sizing_eval(Eo *obj, Elm_Popup_Data *sd)
         EINA_LIST_FOREACH(sd->items, elist, it)
           {
              _item_sizing_eval(it);
-             efl_gfx_size_hint_combined_min_get(elm_layout_edje_get(VIEW(it)),
+             evas_object_size_hint_combined_min_get(elm_layout_edje_get(VIEW(it)),
                                            NULL, &minh_box);
              if (minh_box != -1) h_box += minh_box;
           }
         evas_object_size_hint_min_set(sd->spacer, 0, MIN(h_box, sd->max_sc_h));
         evas_object_size_hint_max_set(sd->spacer, -1, sd->max_sc_h);
 
-        efl_gfx_size_hint_combined_min_get(sd->scr, &minw, &minh);
+        evas_object_size_hint_combined_min_get(sd->scr, &minw, &minh);
         evas_object_size_hint_max_get(sd->scr, &minw, &minh);
      }
    else if (sd->scroll)
@@ -493,28 +503,38 @@ _elm_popup_elm_layout_sizing_eval(Eo *obj, Elm_Popup_Data *sd)
         else
           evas_object_size_hint_min_set(sd->spacer, minw, minh);
 
+        if (sd->main_layout)
+          {
+             Evas *ev = evas_object_evas_get(sd->main_layout);
+             if (evas_smart_objects_calculating_get(ev))
+               evas_object_smart_calculate(sd->main_layout);
+             else
+               evas_object_smart_need_recalculate_set(sd->main_layout, EINA_TRUE);
+          }
        return;
      }
 
-   edje_object_size_min_calc(elm_layout_edje_get(sd->main_layout), &minw, &minh);
-
-   evas_object_size_hint_min_set(obj, minw, minh);
-   evas_object_size_hint_max_set(obj, -1, -1);
+   if (sd->main_layout)
+     {
+        edje_object_size_min_calc(elm_layout_edje_get(sd->main_layout), &minw, &minh);
+        evas_object_size_hint_min_set(obj, minw, minh);
+        evas_object_size_hint_max_set(obj, -1, -1);
+     }
 }
 
 EOLIAN static void
-_elm_popup_elm_layout_signal_emit(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, const char *emission, const char *source)
+_elm_popup_efl_layout_signal_signal_emit(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, const char *emission, const char *source)
 {
    elm_layout_signal_emit(sd->main_layout, emission, source);
 }
 
 EOLIAN static Eina_Bool
-_elm_popup_elm_widget_sub_object_del(Eo *obj, Elm_Popup_Data *sd, Evas_Object *sobj)
+_elm_popup_efl_ui_widget_widget_sub_object_del(Eo *obj, Elm_Popup_Data *sd, Evas_Object *sobj)
 {
    Elm_Popup_Item_Data *it;
    Eina_Bool int_ret = EINA_FALSE;
 
-   int_ret = elm_obj_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
+   int_ret = elm_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
    if (!int_ret) return EINA_FALSE;
 
    if (sobj == sd->title_icon)
@@ -768,7 +788,7 @@ _elm_popup_item_elm_widget_item_part_text_set(Eo *eo_it EINA_UNUSED, Elm_Popup_I
 }
 
 EOLIAN static const char *
-_elm_popup_item_elm_widget_item_part_text_get(Eo *eo_it EINA_UNUSED, Elm_Popup_Item_Data *it,
+_elm_popup_item_elm_widget_item_part_text_get(const Eo *eo_it EINA_UNUSED, Elm_Popup_Item_Data *it,
                     const char *part)
 {
    ELM_POPUP_ITEM_CHECK_OR_RETURN(it, NULL);
@@ -816,7 +836,7 @@ _elm_popup_item_elm_widget_item_part_content_set(Eo *eo_it EINA_UNUSED, Elm_Popu
 }
 
 EOLIAN static Evas_Object *
-_elm_popup_item_elm_widget_item_part_content_get(Eo *eo_it EINA_UNUSED, Elm_Popup_Item_Data *it,
+_elm_popup_item_elm_widget_item_part_content_get(const Eo *eo_it EINA_UNUSED, Elm_Popup_Item_Data *it,
                        const char *part)
 {
    ELM_POPUP_ITEM_CHECK_OR_RETURN(it, NULL);
@@ -897,19 +917,18 @@ _elm_popup_item_elm_widget_item_signal_emit(Eo *eo_it EINA_UNUSED, Elm_Popup_Ite
 }
 
 static void
-_item_focused_cb(void *data, const Efl_Event *event EINA_UNUSED)
+_item_focus_change(void *data, const Efl_Event *event EINA_UNUSED)
 {
    Elm_Popup_Item_Data *it = data;
 
-   efl_event_callback_legacy_call(WIDGET(it), ELM_POPUP_EVENT_ITEM_FOCUSED, EO_OBJ(it));
-}
-
-static void
-_item_unfocused_cb(void *data, const Efl_Event *event EINA_UNUSED)
-{
-   Elm_Popup_Item_Data *it = data;
-
-   efl_event_callback_legacy_call(WIDGET(it), ELM_POPUP_EVENT_ITEM_UNFOCUSED, EO_OBJ(it));
+   if (efl_ui_focus_object_focus_get(event->object))
+     {
+        efl_event_callback_legacy_call(WIDGET(it), ELM_POPUP_EVENT_ITEM_FOCUSED, EO_OBJ(it));
+     }
+   else
+     {
+        efl_event_callback_legacy_call(WIDGET(it), ELM_POPUP_EVENT_ITEM_UNFOCUSED, EO_OBJ(it));
+     }
 }
 
 EOLIAN static Eo *
@@ -926,7 +945,7 @@ _item_new(Elm_Popup_Item_Data *it)
 {
    char style[1024];
 
-   VIEW(it) = elm_layout_add(WIDGET(it));
+   VIEW_SET(it, elm_layout_add(WIDGET(it)));
    elm_object_focus_allow_set(VIEW(it), EINA_TRUE);
    efl_ui_mirrored_automatic_set(VIEW(it), EINA_FALSE);
    elm_object_mirrored_set(VIEW(it), elm_object_mirrored_get(WIDGET(it)));
@@ -940,9 +959,7 @@ _item_new(Elm_Popup_Item_Data *it)
                                        _item_select_cb, it);
         evas_object_size_hint_align_set(VIEW(it), EVAS_HINT_FILL, EVAS_HINT_FILL);
         efl_event_callback_add
-              (VIEW(it), ELM_WIDGET_EVENT_FOCUSED, _item_focused_cb, it);
-        efl_event_callback_add
-              (VIEW(it), ELM_WIDGET_EVENT_UNFOCUSED, _item_unfocused_cb, it);
+              (VIEW(it), EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED, _item_focus_change, it);
         evas_object_show(VIEW(it));
      }
 }
@@ -1240,7 +1257,7 @@ _elm_popup_content_set(Eo *obj, Elm_Popup_Data *_pd EINA_UNUSED, const char *par
    unsigned int i;
    Eina_Bool ret = EINA_TRUE;
 
-   if (!part || !strcmp(part, "default"))
+   if (!part || !strcmp(part, "elm.swallow.content"))
      ret = _content_set(obj, content);
    else if (!strcmp(part, "title,icon"))
      ret = _title_icon_set(obj, content);
@@ -1301,7 +1318,7 @@ _elm_popup_content_get(Eo *obj, Elm_Popup_Data *_pd, const char *part)
    Evas_Object *content = NULL;
    unsigned int i;
 
-   if (!part || !strcmp(part, "default"))
+   if (!part || !strcmp(part, "elm.swallow.content"))
      content = _content_get(_pd);
    else if (!strcmp(part, "title,text"))
      content = _title_icon_get(_pd);
@@ -1369,7 +1386,7 @@ _elm_popup_content_unset(Eo *obj, Elm_Popup_Data *_pd EINA_UNUSED, const char *p
    Evas_Object *content = NULL;
    unsigned int i;
 
-   if (!part || !strcmp(part, "default"))
+   if (!part || !strcmp(part, "elm.swallow.content"))
      content = _content_unset(obj);
    else if (!strcmp(part, "title,icon"))
      content = _title_icon_unset(obj);
@@ -1393,106 +1410,6 @@ err:
    return NULL;
 }
 
-EOLIAN static Eina_Bool
-_elm_popup_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Popup_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_popup_elm_widget_focus_next(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Evas_Object *ao;
-   Eina_List *items = NULL;
-   Eina_Iterator *base_it;
-
-   /* access */
-   if (_elm_config->access_mode)
-     {
-        if (sd->title_text)
-          {
-             ao = _access_object_get(obj, ACCESS_TITLE_PART);
-             items = eina_list_append(items, ao);
-          }
-
-        ao = _access_object_get(obj, ACCESS_BODY_PART);
-        if (ao) items = eina_list_append(items, ao);
-     }
-
-   base_it = efl_content_iterate(sd->main_layout);
-   EINA_ITERATOR_FOREACH(base_it, ao)
-     if (ao) items = eina_list_append(items, ao);
-   eina_iterator_free(base_it);
-
-   if (!elm_widget_focus_list_next_get(sd->main_layout, items, eina_list_data_get, dir, next, next_item))
-     *next = sd->main_layout;
-   eina_list_free(items);
-
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_popup_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Popup_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_popup_elm_widget_focus_direction(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Evas_Object *ao;
-   Eina_List *items = NULL;
-   Eina_Iterator *base_it;
-
-   /* access */
-   if (_elm_config->access_mode)
-     {
-        if (sd->title_text)
-          {
-             ao = _access_object_get(obj, ACCESS_TITLE_PART);
-             items = eina_list_append(items, ao);
-          }
-
-        ao = _access_object_get(obj, ACCESS_BODY_PART);
-        if (ao) items = eina_list_append(items, ao);
-     }
-
-   base_it = efl_content_iterate(sd->main_layout);
-   EINA_ITERATOR_FOREACH(base_it, ao)
-     if (ao) items = eina_list_append(items, ao);
-   eina_iterator_free(base_it);
-
-   elm_widget_focus_list_direction_get
-     (sd->main_layout, base, items, eina_list_data_get, degree, direction, direction_item, weight);
-   eina_list_free(items);
-
-   return EINA_TRUE;
-}
-
-static Eina_Bool
-_key_action_move(Evas_Object *obj, const char *params)
-{
-   const char *dir = params;
-
-   _elm_widget_focus_auto_show(obj);
-   if (!strcmp(dir, "previous"))
-     elm_widget_focus_cycle(obj, ELM_FOCUS_PREVIOUS);
-   else if (!strcmp(dir, "next"))
-     elm_widget_focus_cycle(obj, ELM_FOCUS_NEXT);
-   else if (!strcmp(dir, "left"))
-     elm_widget_focus_cycle(obj, ELM_FOCUS_LEFT);
-   else if (!strcmp(dir, "right"))
-     elm_widget_focus_cycle(obj, ELM_FOCUS_RIGHT);
-   else if (!strcmp(dir, "up"))
-     elm_widget_focus_cycle(obj, ELM_FOCUS_UP);
-   else if (!strcmp(dir, "down"))
-     elm_widget_focus_cycle(obj, ELM_FOCUS_DOWN);
-   else return EINA_FALSE;
-
-   return EINA_TRUE;
-
-}
-
 static Eina_Bool
 _key_action_escape(Evas_Object *obj, const char *params EINA_UNUSED)
 {
@@ -1502,22 +1419,6 @@ _key_action_escape(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
-EOLIAN static Eina_Bool
-_elm_popup_elm_widget_widget_event(Eo *obj, Elm_Popup_Data *_pd EINA_UNUSED, Evas_Object *src, Evas_Callback_Type type, void *event_info)
-{
-   (void)src;
-   Evas_Event_Key_Down *ev = event_info;
-
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions))
-     return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
-}
-
 EOLIAN static void
 _elm_popup_efl_canvas_group_group_add(Eo *obj, Elm_Popup_Data *priv)
 {
@@ -1544,6 +1445,7 @@ _elm_popup_efl_canvas_group_group_add(Eo *obj, Elm_Popup_Data *priv)
    elm_object_mirrored_set(priv->notify, elm_object_mirrored_get(obj));
 
    evas_object_event_callback_add(priv->notify, EVAS_CALLBACK_RESIZE, _notify_resize_cb, obj);
+   efl_event_callback_array_add(priv->notify, composition_cb(), obj);
 
    priv->main_layout = elm_layout_add(obj);
    if (!elm_layout_theme_set(priv->main_layout, "popup", "base",
@@ -1576,9 +1478,6 @@ _elm_popup_efl_canvas_group_group_add(Eo *obj, Elm_Popup_Data *priv)
    priv->content_text_wrap_type = ELM_WRAP_MIXED;
    efl_event_callback_array_add(priv->notify, _notify_cb(), obj);
 
-   elm_widget_can_focus_set(obj, EINA_TRUE);
-   elm_widget_can_focus_set(priv->main_layout, EINA_TRUE);
-
    _populate_theme_scroll(priv);
 
    _visuals_set(obj);
@@ -1606,7 +1505,7 @@ _parent_geom_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj, void *event_i
 }
 
 EOLIAN static void
-_elm_popup_elm_widget_widget_parent_set(Eo *obj, Elm_Popup_Data *sd, Evas_Object *parent)
+_elm_popup_efl_ui_widget_widget_parent_set(Eo *obj, Elm_Popup_Data *sd, Evas_Object *parent)
 {
    Evas_Coord x, y, w, h;
    evas_object_geometry_get(parent, &x, &y, &w, &h);
@@ -1625,7 +1524,7 @@ _elm_popup_elm_widget_widget_parent_set(Eo *obj, Elm_Popup_Data *sd, Evas_Object
 }
 
 EOLIAN static void
-_elm_popup_elm_widget_access(Eo *obj, Elm_Popup_Data *_pd EINA_UNUSED, Eina_Bool is_access)
+_elm_popup_efl_ui_widget_on_access_update(Eo *obj, Elm_Popup_Data *_pd EINA_UNUSED, Eina_Bool is_access)
 {
    _access_obj_process(obj, is_access);
 }
@@ -1634,7 +1533,7 @@ EAPI Evas_Object *
 elm_popup_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   Evas_Object *obj = efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   Evas_Object *obj = elm_legacy_add(MY_CLASS, parent);
 
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, NULL);
    wd->highlight_root = EINA_TRUE;
@@ -1648,7 +1547,7 @@ _elm_popup_efl_object_constructor(Eo *obj, Elm_Popup_Data *_pd EINA_UNUSED)
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_NOTIFICATION);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_DIALOG);
 
    return obj;
 }
@@ -1665,7 +1564,7 @@ _elm_popup_content_text_wrap_type_set(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, E
 }
 
 EOLIAN static Elm_Wrap_Type
-_elm_popup_content_text_wrap_type_get(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
+_elm_popup_content_text_wrap_type_get(const Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
 {
    return sd->content_text_wrap_type;
 }
@@ -1763,7 +1662,7 @@ _elm_popup_orient_set(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, Elm_Popup_Orient
 }
 
 EOLIAN static Elm_Popup_Orient
-_elm_popup_orient_get(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
+_elm_popup_orient_get(const Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
 {
    return (Elm_Popup_Orient)_elm_notify_orient_get(sd->notify);
 }
@@ -1775,7 +1674,7 @@ _elm_popup_align_set(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, double horizontal,
 }
 
 EOLIAN static void
-_elm_popup_align_get(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, double *horizontal, double *vertical)
+_elm_popup_align_get(const Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, double *horizontal, double *vertical)
 {
    elm_notify_align_get(sd->notify, horizontal, vertical);
 }
@@ -1787,7 +1686,7 @@ _elm_popup_timeout_set(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, double timeout)
 }
 
 EOLIAN static double
-_elm_popup_timeout_get(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
+_elm_popup_timeout_get(const Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
 {
    return elm_notify_timeout_get(sd->notify);
 }
@@ -1801,7 +1700,7 @@ _elm_popup_allow_events_set(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd, Eina_Bool a
 }
 
 EOLIAN static Eina_Bool
-_elm_popup_allow_events_get(Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
+_elm_popup_allow_events_get(const Eo *obj EINA_UNUSED, Elm_Popup_Data *sd)
 {
    return elm_notify_allow_events_get(sd->notify);
 }
@@ -1881,7 +1780,7 @@ _elm_popup_scrollable_set(Eo *obj, Elm_Popup_Data *pd, Eina_Bool scroll)
 }
 
 EOLIAN Eina_Bool
-_elm_popup_scrollable_get(Eo *obj EINA_UNUSED, Elm_Popup_Data *pd)
+_elm_popup_scrollable_get(const Eo *obj EINA_UNUSED, Elm_Popup_Data *pd)
 {
    return pd->scroll;
 }
@@ -1906,44 +1805,73 @@ _action_dismiss(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_popup_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Popup_Data *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_popup_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Popup_Data *pd)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "dismiss", NULL, NULL, _action_dismiss},
           { NULL, NULL, NULL, NULL }
    };
+   if (pd->action_area)
+     return NULL;
    return &atspi_actions[0];
 }
 
-EOLIAN static Elm_Atspi_State_Set
-_elm_popup_elm_interface_atspi_accessible_state_set_get(Eo *obj, Elm_Popup_Data *sd EINA_UNUSED)
+EOLIAN static Efl_Access_State_Set
+_elm_popup_efl_access_object_state_set_get(const Eo *obj, Elm_Popup_Data *sd EINA_UNUSED)
 {
-   Elm_Atspi_State_Set ret;
-   ret = elm_interface_atspi_accessible_state_set_get(efl_super(obj, MY_CLASS));
+   Efl_Access_State_Set ret;
+   ret = efl_access_object_state_set_get(efl_super(obj, MY_CLASS));
 
-   STATE_TYPE_SET(ret, ELM_ATSPI_STATE_MODAL);
+   STATE_TYPE_SET(ret, EFL_ACCESS_STATE_MODAL);
 
    return ret;
 }
 
+EOLIAN static const char*
+_elm_popup_efl_access_object_i18n_name_get(const Eo *obj, Elm_Popup_Data *sd)
+{
+   const char *name = NULL;
+   Eina_Strbuf *buf;
+
+   name = efl_access_object_i18n_name_get(efl_super(obj, ELM_POPUP_CLASS));
+   if (name) return name;
+
+   buf = eina_strbuf_new();
+   eina_strbuf_append_printf(buf, "%s", E_("Alert"));
+   if (sd->title_text)
+     eina_strbuf_append_printf(buf, ", %s", sd->title_text);
+   else if (sd->text_content_obj)
+     eina_strbuf_append_printf(buf, ", %s", elm_object_text_get(sd->text_content_obj));
+   else if (elm_object_part_text_get(obj, "elm.text"))
+     eina_strbuf_append_printf(buf, ", %s", elm_object_part_text_get(obj, "elm.text"));
+
+   name = _elm_widget_accessible_plain_name_get(obj, eina_strbuf_string_get(buf));
+   eina_strbuf_free(buf);
+
+   return name;
+}
+
+/* Standard widget overrides */
+
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(elm_popup, Elm_Popup_Data)
+
 /* Efl.Part begin */
 
-ELM_PART_OVERRIDE(elm_popup, ELM_POPUP, ELM_LAYOUT, Elm_Popup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_SET(elm_popup, ELM_POPUP, ELM_LAYOUT, Elm_Popup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_GET(elm_popup, ELM_POPUP, ELM_LAYOUT, Elm_Popup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_UNSET(elm_popup, ELM_POPUP, ELM_LAYOUT, Elm_Popup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_SET(elm_popup, ELM_POPUP, ELM_LAYOUT, Elm_Popup_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_TEXT_GET(elm_popup, ELM_POPUP, ELM_LAYOUT, Elm_Popup_Data, Elm_Part_Data)
-ELM_PART_CONTENT_DEFAULT_SET(elm_popup, "default")
-#include "elm_popup_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_popup, ELM_POPUP, Elm_Popup_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_popup, ELM_POPUP, Elm_Popup_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(elm_popup, ELM_POPUP, Elm_Popup_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_popup, ELM_POPUP, Elm_Popup_Data)
+ELM_PART_OVERRIDE_TEXT_SET(elm_popup, ELM_POPUP, Elm_Popup_Data)
+ELM_PART_OVERRIDE_TEXT_GET(elm_popup, ELM_POPUP, Elm_Popup_Data)
+#include "elm_popup_part.eo.c"
 
 /* Efl.Part end */
 
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_POPUP_EXTRA_OPS \
-   ELM_PART_CONTENT_DEFAULT_OPS(elm_popup), \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_popup), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_popup)
 
 #include "elm_popup.eo.c"
