@@ -2,8 +2,8 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
@@ -84,7 +84,7 @@ _access_action_callback_call(Evas_Object *obj,
 }
 
 EOLIAN static Eina_Bool
-_elm_access_elm_widget_activate(Eo *obj, void *_pd EINA_UNUSED, Elm_Activate act)
+_elm_access_efl_ui_widget_on_access_activate(Eo *obj, void *_pd EINA_UNUSED, Efl_Ui_Activate act)
 {
    int type = ELM_ACCESS_ACTION_FIRST;
 
@@ -93,25 +93,25 @@ _elm_access_elm_widget_activate(Eo *obj, void *_pd EINA_UNUSED, Elm_Activate act
 
    switch (act)
      {
-      case ELM_ACTIVATE_DEFAULT:
+      case EFL_UI_ACTIVATE_DEFAULT:
         type = ELM_ACCESS_ACTION_ACTIVATE;
         break;
 
-      case ELM_ACTIVATE_UP:
+      case EFL_UI_ACTIVATE_UP:
         type = ELM_ACCESS_ACTION_UP;
         break;
 
-      case ELM_ACTIVATE_DOWN:
+      case EFL_UI_ACTIVATE_DOWN:
         type = ELM_ACCESS_ACTION_DOWN;
         break;
 
-      case ELM_ACTIVATE_RIGHT:
+      case EFL_UI_ACTIVATE_RIGHT:
         break;
 
-      case ELM_ACTIVATE_LEFT:
+      case EFL_UI_ACTIVATE_LEFT:
         break;
 
-      case ELM_ACTIVATE_BACK:
+      case EFL_UI_ACTIVATE_BACK:
         type = ELM_ACCESS_ACTION_BACK;
         break;
 
@@ -132,7 +132,7 @@ _elm_access_elm_widget_activate(Eo *obj, void *_pd EINA_UNUSED, Elm_Activate act
      }
 
    /* TODO: deprecate below? */
-   if (act != ELM_ACTIVATE_DEFAULT) return EINA_FALSE;
+   if (act != EFL_UI_ACTIVATE_DEFAULT) return EINA_FALSE;
 
    Elm_Access_Info *ac = evas_object_data_get(obj, "_elm_access");
    if (!ac) return EINA_FALSE;
@@ -145,9 +145,9 @@ _elm_access_elm_widget_activate(Eo *obj, void *_pd EINA_UNUSED, Elm_Activate act
 }
 
 EOLIAN static Eina_Bool
-_elm_access_elm_widget_on_focus(Eo *obj, void *_pd EINA_UNUSED, Elm_Object_Item *item EINA_UNUSED)
+_elm_access_efl_ui_focus_object_on_focus_update(Eo *obj, void *_pd EINA_UNUSED)
 {
-   evas_object_focus_set(obj, elm_widget_focus_get(obj));
+   evas_object_focus_set(obj, efl_ui_focus_object_focus_get(obj));
 
    return EINA_TRUE;
 }
@@ -535,9 +535,19 @@ _access_highlight_next_get(Evas_Object *obj, Elm_Focus_Direction dir)
           }
         else
           {
-             ret = elm_widget_focus_next_get(obj, dir, &target, NULL);
-             if (ret && target)
-               _elm_access_highlight_set(target);
+             Efl_Ui_Focus_Relations *rel;
+
+             rel = efl_ui_focus_manager_fetch(efl_ui_focus_object_focus_manager_get(obj), obj);
+
+             if (rel)
+               {
+                  if (dir == ELM_FOCUS_NEXT)
+                    _elm_access_highlight_set(rel->next);
+                  else
+                    _elm_access_highlight_set(rel->prev);
+
+                  free(rel);
+               }
           }
      }
 
@@ -622,7 +632,7 @@ _elm_access_activate_callback_set(Elm_Access_Info           *ac,
 }
 
 EAPI void
-_elm_access_highlight_object_activate(Evas_Object *obj, Elm_Activate act)
+_elm_access_highlight_object_activate(Evas_Object *obj, Efl_Ui_Activate act)
 {
    Evas_Object *highlight;
 
@@ -690,7 +700,10 @@ _elm_access_highlight_cycle(Evas_Object *obj, Elm_Focus_Direction dir)
              elm_widget_focus_region_show(comming);
           }
         else
-          elm_widget_focus_cycle(obj, dir);
+          {
+             efl_ui_focus_util_focus(EFL_UI_FOCUS_UTIL_CLASS, obj);
+             efl_ui_focus_manager_move(elm_widget_top_get(obj), dir);
+          }
      }
 
    action_by = ELM_ACCESS_ACTION_FIRST;
@@ -1000,7 +1013,9 @@ _elm_access_edje_object_part_object_register(Evas_Object* obj,
 {
    Evas_Object *ao, *po;
 
+   edje_object_freeze((Evas_Object *)eobj);
    po = (Evas_Object *)edje_object_part_object_get(eobj, part);
+   edje_object_thaw((Evas_Object *)eobj);
    if (!obj || !po) return NULL;
 
    /* check previous access object */
@@ -1021,7 +1036,9 @@ _elm_access_edje_object_part_object_unregister(Evas_Object* obj EINA_UNUSED,
 {
    Evas_Object *po;
 
+   edje_object_freeze((Evas_Object *)eobj);
    po = (Evas_Object *)edje_object_part_object_get(eobj, part);
+   edje_object_thaw((Evas_Object *)eobj);
    if (!po) return;
 
    _access_object_unregister(po);
@@ -1247,7 +1264,7 @@ static Evas_Object *
 _elm_access_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -1370,15 +1387,15 @@ elm_access_action(Evas_Object *obj, const Elm_Access_Action_Type type, Elm_Acces
         break;
 
       case ELM_ACCESS_ACTION_ACTIVATE:
-        _elm_access_highlight_object_activate(obj, ELM_ACTIVATE_DEFAULT);
+        _elm_access_highlight_object_activate(obj, EFL_UI_ACTIVATE_DEFAULT);
         break;
 
       case ELM_ACCESS_ACTION_UP:
-        _elm_access_highlight_object_activate(obj, ELM_ACTIVATE_UP);
+        _elm_access_highlight_object_activate(obj, EFL_UI_ACTIVATE_UP);
         break;
 
       case ELM_ACCESS_ACTION_DOWN:
-        _elm_access_highlight_object_activate(obj, ELM_ACTIVATE_DOWN);
+        _elm_access_highlight_object_activate(obj, EFL_UI_ACTIVATE_DOWN);
         break;
 
       case ELM_ACCESS_ACTION_SCROLL:
@@ -1491,10 +1508,10 @@ _access_atspi_action_do(Evas_Object *obj, const char *params)
    return ret;
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_access_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, void *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_access_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, void *pd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "highlight", NULL, "highlight", _access_atspi_action_do},
           { "unhighlight", NULL, "unhighlight", _access_atspi_action_do},
           { "highlight,next", NULL, "highlight,next", _access_atspi_action_do},
@@ -1508,17 +1525,17 @@ _elm_access_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSE
    return &atspi_actions[0];
 }
 
-EOLIAN static Elm_Atspi_State_Set
-_elm_access_elm_interface_atspi_accessible_state_set_get(Eo *obj, void *pd EINA_UNUSED)
+EOLIAN static Efl_Access_State_Set
+_elm_access_efl_access_object_state_set_get(const Eo *obj, void *pd EINA_UNUSED)
 {
-   Elm_Atspi_State_Set ret;
-   ret = elm_interface_atspi_accessible_state_set_get(efl_super(obj, ELM_ACCESS_CLASS));
+   Efl_Access_State_Set ret;
+   ret = efl_access_object_state_set_get(efl_super(obj, ELM_ACCESS_CLASS));
 
    Elm_Access_Info *info = _elm_access_info_get(obj);
    if (info && !evas_object_visible_get(info->part_object))
      {
-        STATE_TYPE_UNSET(ret, ELM_ATSPI_STATE_VISIBLE);
-        STATE_TYPE_UNSET(ret, ELM_ATSPI_STATE_SHOWING);
+        STATE_TYPE_UNSET(ret, EFL_ACCESS_STATE_VISIBLE);
+        STATE_TYPE_UNSET(ret, EFL_ACCESS_STATE_SHOWING);
      }
 
    return ret;
