@@ -2,7 +2,8 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_UI_FOCUS_COMPOSITION_PROTECTED
 
 #include <Elementary.h>
 #include <elm_box.eo.h>
@@ -23,19 +24,21 @@ static const Evas_Smart_Cb_Description _smart_callbacks[] = {
 };
 
 static void
-_focus_order_flush(Eo *obj, Elm_Box_Data *pd EINA_UNUSED)
+_elm_box_efl_ui_focus_composition_prepare(Eo *obj, Elm_Box_Data *pd EINA_UNUSED)
 {
-   Elm_Widget_Smart_Data *wpd = efl_data_scope_get(obj, ELM_WIDGET_CLASS);
+   Eina_List *n, *nn;
+   Efl_Ui_Widget *elem;
+
+   Elm_Widget_Smart_Data *wpd = efl_data_scope_get(obj, EFL_UI_WIDGET_CLASS);
    Eina_List *order = evas_object_box_children_get(wpd->resize_obj);
 
-   efl_ui_focus_manager_update_order(wpd->focus.manager, obj, order);
-}
+   EINA_LIST_FOREACH_SAFE(order, n, nn, elem)
+     {
+        if (!efl_isa(elem, EFL_UI_WIDGET_CLASS))
+          order = eina_list_remove(order, elem);
+     }
 
-static void *
-_elm_box_list_data_get(const Eina_List *list)
-{
-   Evas_Object_Box_Option *opt = eina_list_data_get(list);
-   return opt->obj;
+   efl_ui_focus_composition_elements_set(obj, order);
 }
 
 static void
@@ -54,75 +57,15 @@ _child_removed_cb_proxy(void *data, const Efl_Event *event)
    efl_event_callback_legacy_call(box, ELM_BOX_EVENT_CHILD_REMOVED, child);
 }
 
-EOLIAN static Eina_Bool
-_elm_box_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Box_Data *_pd EINA_UNUSED)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_box_efl_ui_widget_theme_apply(Eo *obj, Elm_Box_Data *sd EINA_UNUSED)
 {
-   return EINA_TRUE;
-}
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
 
-EOLIAN static Eina_Bool
-_elm_box_elm_widget_focus_next(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   const Eina_List *items;
-   void *(*list_data_get)(const Eina_List *list);
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
-   /* Focus chain */
-   /* TODO: Change this to use other chain */
-   if ((items = elm_widget_focus_custom_chain_get(obj)))
-     list_data_get = eina_list_data_get;
-   else
-     {
-        ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EINA_FALSE);
-        Evas_Object_Box_Data *bd =
-          evas_object_smart_data_get(wd->resize_obj);
-
-        items = bd->children;
-        list_data_get = _elm_box_list_data_get;
-
-        if (!items) return EINA_FALSE;
-     }
-
-   return elm_widget_focus_list_next_get(obj, items, list_data_get, dir, next, next_item);
-}
-
-EOLIAN static Eina_Bool
-_elm_box_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Box_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_box_elm_widget_focus_direction(Eo *obj EINA_UNUSED, Elm_Box_Data *_pd EINA_UNUSED, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   const Eina_List *items;
-   void *(*list_data_get)(const Eina_List *list);
-
-   if ((items = elm_widget_focus_custom_chain_get(obj)))
-     list_data_get = eina_list_data_get;
-   else
-     {
-        ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EINA_FALSE);
-        Evas_Object_Box_Data *bd =
-          evas_object_smart_data_get(wd->resize_obj);
-
-        items = bd->children;
-        list_data_get = _elm_box_list_data_get;
-
-        if (!items) return EINA_FALSE;
-     }
-   return elm_widget_focus_list_direction_get
-            (obj, base, items, list_data_get, degree, direction, direction_item, weight);
-}
-
-EOLIAN static Elm_Theme_Apply
-_elm_box_elm_widget_theme_apply(Eo *obj, Elm_Box_Data *sd EINA_UNUSED)
-{
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
-
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
-
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, ELM_THEME_APPLY_FAILED);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EFL_UI_THEME_APPLY_FAILED);
    evas_object_smart_calculate(wd->resize_obj);
 
    return int_ret;
@@ -138,7 +81,7 @@ _sizing_eval(Evas_Object *obj)
 
    if (sd->delete_me) return;
 
-   efl_gfx_size_hint_combined_min_get(wd->resize_obj, &minw, &minh);
+   evas_object_size_hint_combined_min_get(wd->resize_obj, &minw, &minh);
    evas_object_size_hint_max_get(wd->resize_obj, &maxw, &maxh);
    evas_object_size_hint_min_set(obj, minw, minh);
    evas_object_size_hint_max_set(obj, maxw, maxh);
@@ -154,11 +97,11 @@ _on_size_hints_changed(void *data,
 }
 
 EOLIAN static Eina_Bool
-_elm_box_elm_widget_sub_object_del(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, Evas_Object *child)
+_elm_box_efl_ui_widget_widget_sub_object_del(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, Evas_Object *child)
 {
    Eina_Bool int_ret = EINA_FALSE;
 
-   int_ret = elm_obj_widget_sub_object_del(efl_super(obj, MY_CLASS), child);
+   int_ret = elm_widget_sub_object_del(efl_super(obj, MY_CLASS), child);
    if (!int_ret) return EINA_FALSE;
 
    _sizing_eval(obj);
@@ -370,9 +313,7 @@ EOLIAN static void
 _elm_box_efl_canvas_group_group_add(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
-   elm_widget_resize_object_set(obj,
-                                evas_object_box_add(evas_object_evas_get(obj)),
-                                EINA_TRUE);
+   elm_widget_resize_object_set(obj, evas_object_box_add(evas_object_evas_get(obj)));
 
    evas_object_box_layout_set(wd->resize_obj, _elm_box_custom_layout,
                               obj, NULL);
@@ -425,17 +366,17 @@ EAPI Evas_Object *
 elm_box_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
 _elm_box_efl_object_constructor(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED)
 {
-   elm_interface_atspi_accessible_type_set(obj, ELM_ATSPI_TYPE_SKIPPED);
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_FILLER);
+   efl_access_object_access_type_set(obj, EFL_ACCESS_TYPE_SKIPPED);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_FILLER);
 
    return obj;
 }
@@ -450,7 +391,7 @@ _elm_box_horizontal_set(Eo *obj, Elm_Box_Data *sd, Eina_Bool horizontal)
 }
 
 EOLIAN static Eina_Bool
-_elm_box_horizontal_get(Eo *obj EINA_UNUSED, Elm_Box_Data *sd)
+_elm_box_horizontal_get(const Eo *obj EINA_UNUSED, Elm_Box_Data *sd)
 {
    return sd->horizontal;
 }
@@ -465,33 +406,33 @@ _elm_box_homogeneous_set(Eo *obj, Elm_Box_Data *sd, Eina_Bool homogeneous)
 }
 
 EOLIAN static Eina_Bool
-_elm_box_homogeneous_get(Eo *obj EINA_UNUSED, Elm_Box_Data *sd)
+_elm_box_homogeneous_get(const Eo *obj EINA_UNUSED, Elm_Box_Data *sd)
 {
    return sd->homogeneous;
 }
 
 EOLIAN static void
-_elm_box_pack_start(Eo *obj, Elm_Box_Data *pd, Evas_Object *subobj)
+_elm_box_pack_start(Eo *obj, Elm_Box_Data *pd EINA_UNUSED, Evas_Object *subobj)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    elm_widget_sub_object_add(obj, subobj);
    evas_object_box_prepend(wd->resize_obj, subobj);
-   _focus_order_flush(obj, pd);
+   efl_ui_focus_composition_dirty(obj);
 }
 
 EOLIAN static void
-_elm_box_pack_end(Eo *obj, Elm_Box_Data *pd, Evas_Object *subobj)
+_elm_box_pack_end(Eo *obj, Elm_Box_Data *pd EINA_UNUSED, Evas_Object *subobj)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    elm_widget_sub_object_add(obj, subobj);
    evas_object_box_append(wd->resize_obj, subobj);
-   _focus_order_flush(obj, pd);
+   efl_ui_focus_composition_dirty(obj);
 }
 
 EOLIAN static void
-_elm_box_pack_before(Eo *obj, Elm_Box_Data *pd, Evas_Object *subobj, Evas_Object *before)
+_elm_box_pack_before(Eo *obj, Elm_Box_Data *pd EINA_UNUSED, Evas_Object *subobj, Evas_Object *before)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
@@ -499,41 +440,41 @@ _elm_box_pack_before(Eo *obj, Elm_Box_Data *pd, Evas_Object *subobj, Evas_Object
 
    evas_object_box_insert_before
      (wd->resize_obj, subobj, before);
-   _focus_order_flush(obj, pd);
+   efl_ui_focus_composition_dirty(obj);
 }
 
 EOLIAN static void
-_elm_box_pack_after(Eo *obj, Elm_Box_Data *pd, Evas_Object *subobj, Evas_Object *after)
+_elm_box_pack_after(Eo *obj, Elm_Box_Data *pd EINA_UNUSED, Evas_Object *subobj, Evas_Object *after)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    elm_widget_sub_object_add(obj, subobj);
    evas_object_box_insert_after
      (wd->resize_obj, subobj, after);
-   _focus_order_flush(obj, pd);
+   efl_ui_focus_composition_dirty(obj);
 }
 
 EOLIAN static void
-_elm_box_clear(Eo *obj, Elm_Box_Data *pd)
+_elm_box_clear(Eo *obj, Elm_Box_Data *pd EINA_UNUSED)
 {
    /* EINA_TRUE means to delete objects as well */
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
    evas_object_box_remove_all(wd->resize_obj, EINA_TRUE);
-   _focus_order_flush(obj, pd);
+   efl_ui_focus_composition_dirty(obj);
 }
 
 EOLIAN static void
-_elm_box_unpack(Eo *obj, Elm_Box_Data *pd, Evas_Object *subobj)
+_elm_box_unpack(Eo *obj, Elm_Box_Data *pd EINA_UNUSED, Evas_Object *subobj)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    if (evas_object_box_remove(wd->resize_obj, subobj))
      _elm_widget_sub_object_redirect_to_top(obj, subobj);
-   _focus_order_flush(obj, pd);
+   efl_ui_focus_composition_dirty(obj);
 }
 
 EOLIAN static void
-_elm_box_unpack_all(Eo *obj, Elm_Box_Data *pd)
+_elm_box_unpack_all(Eo *obj, Elm_Box_Data *pd EINA_UNUSED)
 {
    Evas_Object_Box_Data *bd;
    Evas_Object_Box_Option *opt;
@@ -557,7 +498,7 @@ _elm_box_unpack_all(Eo *obj, Elm_Box_Data *pd)
      _elm_widget_sub_object_redirect_to_top(obj, c);
    /* update size hints */
    _sizing_eval(obj);
-   _focus_order_flush(obj, pd);
+   efl_ui_focus_composition_dirty(obj);
 }
 
 EAPI void
@@ -663,7 +604,7 @@ elm_box_transition_free(void *data)
 }
 
 EOLIAN static Eina_List*
-_elm_box_children_get(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED)
+_elm_box_children_get(const Eo *obj, Elm_Box_Data *_pd EINA_UNUSED)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, NULL);
    return evas_object_box_children_get(wd->resize_obj);
@@ -679,7 +620,7 @@ _elm_box_padding_set(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, Evas_Coord horizont
 }
 
 EOLIAN static void
-_elm_box_padding_get(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, Evas_Coord *horizontal, Evas_Coord *vertical)
+_elm_box_padding_get(const Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, Evas_Coord *horizontal, Evas_Coord *vertical)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
    evas_object_box_padding_get
@@ -695,7 +636,7 @@ _elm_box_align_set(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, double horizontal, do
 }
 
 EOLIAN static void
-_elm_box_align_get(Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, double *horizontal, double *vertical)
+_elm_box_align_get(const Eo *obj, Elm_Box_Data *_pd EINA_UNUSED, double *horizontal, double *vertical)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
@@ -720,17 +661,6 @@ _elm_box_class_constructor(Efl_Class *klass)
 {
    evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
-EOLIAN Eina_Bool
-_elm_box_elm_widget_focus_register(Eo *obj, Elm_Box_Data *pd, Efl_Ui_Focus_Manager *manager, Efl_Ui_Focus_Object *logical, Eina_Bool *logical_flag)
-{
-   Eina_Bool result = elm_obj_widget_focus_register(efl_super(obj, MY_CLASS), manager, logical, logical_flag);
-
-   //later registering children are automatically set into the order of the internal table
-   _focus_order_flush(obj, pd);
-
-   return result;
-}
-
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_BOX_EXTRA_OPS \
