@@ -5,6 +5,7 @@
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_color_class.h"
+#include "elm_colorselector.eo.h"
 
 //static Eldbus_Proxy *cc_proxy;
 //static Ecore_Event_Handler *h1;
@@ -216,6 +217,8 @@ _colorclass_activate(void *data, const Efl_Event *event)
    else
      {
         cc->current = calloc(1, sizeof(Colorclass)); //actually Elm_Color_Overlay
+        if (!cc->current) return;
+
         memcpy(cc->current, ecc, sizeof(Elm_Color_Overlay));
         cc->current->name = eina_stringshare_ref(ecc->name);
      }
@@ -687,6 +690,8 @@ elm_color_class_editor_add(Evas_Object *obj)
              Colorclass *lcc;
 
              ecc2 = malloc(sizeof(Edje_Color_Class));
+             if (!ecc2) continue;
+
              memcpy(ecc2, ecc, sizeof(Edje_Color_Class));
              ecc2->name = eina_stringshare_add(ecc->name);
              if (tl_cb)
@@ -815,6 +820,8 @@ elm_color_class_util_edje_file_list(Eina_File *f)
    EINA_ITERATOR_FOREACH(it, ecc)
      {
         ecc2 = malloc(sizeof(Edje_Color_Class));
+        if (!ecc2) continue;
+
         memcpy(ecc2, ecc, sizeof(Edje_Color_Class));
         ecc2->name = eina_stringshare_add(ecc->name);
         if (tl_cb)
