@@ -2,13 +2,16 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_COMPONENT_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_COMPONENT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define EFL_UI_FOCUS_COMPOSITION_PROTECTED
+#define EFL_UI_FOCUS_OBJECT_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_widget_colorselector.h"
+#include "elm_widget_spinner.h"
 
 #define MY_CLASS ELM_COLORSELECTOR_CLASS
 
@@ -192,6 +195,28 @@ static const Elm_Action key_actions[] = {
    {NULL, NULL}
 };
 
+static void
+_flush_color_children(Eo *obj, Elm_Colorselector_Data *pd)
+{
+   Eina_List *items = NULL;
+
+   if (pd->mode == ELM_COLORSELECTOR_ALL) {
+      items = eina_list_append(items, pd->picker);
+      items = eina_list_merge(items, eina_list_clone(pd->items));
+      items = eina_list_append(items, pd->col_bars_area);
+   } else if (pd->mode == ELM_COLORSELECTOR_BOTH) {
+      items = eina_list_merge(items, eina_list_clone(pd->items));
+      items = eina_list_append(items, pd->col_bars_area);
+   } else if (pd->mode == ELM_COLORSELECTOR_COMPONENTS) {
+      items = eina_list_append(items, pd->col_bars_area);
+   } else if (pd->mode == ELM_COLORSELECTOR_PALETTE) {
+      items = eina_list_merge(items, eina_list_clone(pd->items));
+   } else if (pd->mode == ELM_COLORSELECTOR_PICKER) {
+      items = eina_list_append(items, pd->picker);
+   }
+   efl_ui_focus_composition_elements_set(obj, items);
+}
+
 enum Palette_Box_Direction
 {
    PALETTE_BOX_UP,
@@ -947,7 +972,7 @@ _create_colorpicker(Evas_Object *obj)
 
         sd->spinners[i] = spinner;
      }
-     
+
    elm_layout_content_set(sd->picker, "elm.swallow.red", sd->spinners[0]);
    elm_layout_text_set(sd->picker, "elm.label.red", E_("R:"));
    elm_layout_content_set(sd->picker, "elm.swallow.green", sd->spinners[1]);
@@ -1292,8 +1317,8 @@ _color_bars_add(Evas_Object *obj)
      }
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_colorselector_elm_widget_theme_apply(Eo *obj, Elm_Colorselector_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_colorselector_efl_ui_widget_theme_apply(Eo *obj, Elm_Colorselector_Data *sd)
 {
    int i;
    Eina_List *elist;
@@ -1303,11 +1328,11 @@ _elm_colorselector_elm_widget_theme_apply(Eo *obj, Elm_Colorselector_Data *sd)
    unsigned int h_pad = DEFAULT_HOR_PAD;
    unsigned int v_pad = DEFAULT_VER_PAD;
 
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, ELM_THEME_APPLY_FAILED);
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EFL_UI_THEME_APPLY_FAILED);
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    if ((sd->mode == ELM_COLORSELECTOR_PALETTE) ||
        (sd->mode == ELM_COLORSELECTOR_ALL) ||
@@ -1322,7 +1347,7 @@ _elm_colorselector_elm_widget_theme_apply(Eo *obj, Elm_Colorselector_Data *sd)
             (wd->resize_obj, "vertical_pad");
         if (vpadstr) v_pad = atoi(vpadstr);
 
-        scale = efl_ui_scale_get(obj) * elm_config_scale_get() / edje_object_base_scale_get(wd->resize_obj);
+        scale = efl_gfx_entity_scale_get(obj) * elm_config_scale_get() / edje_object_base_scale_get(wd->resize_obj);
         efl_pack_padding_set(sd->palette_box, h_pad * scale, v_pad * scale, 0);
 
         EINA_LIST_FOREACH(sd->items, elist, eo_item)
@@ -1394,8 +1419,8 @@ _sub_obj_size_hints_set(Evas_Object *sobj,
    Evas_Coord minw = -1, minh = -1;
 
    elm_coords_finger_size_adjust(timesw, &minw, timesh, &minh);
-   if (sobj && efl_isa(sobj, EDJE_OBJECT_CLASS))
-     edje_object_size_min_restricted_calc(sobj, &minw, &minh, minw, minh);
+   if (!efl_isa(sobj, EFL_CANVAS_LAYOUT_CLASS)) return;
+   edje_object_size_min_restricted_calc(sobj, &minw, &minh, minw, minh);
    evas_object_size_hint_min_set(sobj, minw, minh);
    evas_object_size_hint_max_set(sobj, -1, -1);
 }
@@ -1468,7 +1493,7 @@ _picker_sizing_eval(Evas_Object *obj)
 
    ELM_COLORSELECTOR_DATA_GET(obj, sd);
 
-   efl_gfx_size_hint_combined_min_get(sd->picker, &minw, &minh);
+   evas_object_size_hint_combined_min_get(sd->picker, &minw, &minh);
    evas_object_size_hint_min_set(obj, minw, minh);
 }
 
@@ -1478,6 +1503,7 @@ _elm_colorselector_elm_layout_sizing_eval(Eo *obj, Elm_Colorselector_Data *sd)
    Evas_Coord minw = -1, minh = -1;
 
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
+   if (!efl_finalized_get(obj)) return; //not constructed yet
 
    elm_coords_finger_size_adjust(1, &minw, 1, &minh);
 
@@ -1523,7 +1549,7 @@ _on_resize(void *data EINA_UNUSED, Evas *e EINA_UNUSED,
      {
         Evas_Coord w = 0, h = 0, minw = -1;
 
-        efl_gfx_size_hint_combined_min_get(obj, &minw, NULL);
+        evas_object_size_hint_combined_min_get(obj, &minw, NULL);
         evas_object_geometry_get(obj, NULL, NULL, &w, &h);
         if ((w != sd->_w) && (w < minw))
           elm_layout_sizing_eval(obj);
@@ -1712,8 +1738,8 @@ _item_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
 
    elm_object_signal_emit(VIEW(item), "elm,state,selected", "elm");
    if (_elm_config->atspi_mode)
-     elm_interface_atspi_accessible_state_changed_signal_emit(obj,
-                                                              ELM_ATSPI_STATE_CHECKED,
+     efl_access_state_changed_signal_emit(obj,
+                                                              EFL_ACCESS_STATE_CHECKED,
                                                               EINA_TRUE);
    elm_colorselector_color_set(WIDGET(item), item->color->r, item->color->g,
                                item->color->b, item->color->a);
@@ -1746,7 +1772,7 @@ _elm_color_item_efl_object_constructor(Eo *eo_item, Elm_Color_Item_Data *item)
    Evas_Object *obj;
    obj = efl_parent_get(eo_item);
 
-   VIEW(item) = elm_layout_add(obj);
+   VIEW_SET(item, elm_layout_add(obj));
    if (!elm_layout_theme_set
        (VIEW(item), "colorselector", "item", elm_widget_style_get(obj)))
      CRI("Failed to set layout!");
@@ -1770,7 +1796,8 @@ _elm_color_item_efl_object_constructor(Eo *eo_item, Elm_Color_Item_Data *item)
      (item->color_obj, EVAS_CALLBACK_MOUSE_MOVE, _on_color_moved, item);
    evas_object_event_callback_add
      (item->color_obj, EVAS_CALLBACK_MOUSE_UP, _on_color_released, item);
-   elm_object_part_content_set(VIEW(item), "color_obj", item->color_obj);
+   if (!elm_layout_content_set(VIEW(item), "elm.swallow.color_obj", item->color_obj))
+     elm_layout_content_set(VIEW(item), "color_obj", item->color_obj);
 
    _item_sizing_eval(item);
    evas_object_show(VIEW(item));
@@ -1779,7 +1806,7 @@ _elm_color_item_efl_object_constructor(Eo *eo_item, Elm_Color_Item_Data *item)
    if (_elm_config->access_mode == ELM_ACCESS_MODE_ON)
      elm_wdg_item_access_register(eo_item);
 
-   elm_interface_atspi_accessible_role_set(eo_item, ELM_ATSPI_ROLE_RADIO_BUTTON);
+   efl_access_object_role_set(eo_item, EFL_ACCESS_ROLE_RADIO_BUTTON);
 
    return eo_item;
 }
@@ -1857,6 +1884,15 @@ _palette_colors_load(Evas_Object *obj)
    sd->config_load = EINA_TRUE;
 }
 
+static inline void
+_palette_box_prepare(Eo *o)
+{
+   efl_ui_direction_set(o, EFL_UI_DIR_HORIZONTAL);
+   efl_gfx_size_hint_weight_set(o, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND);
+   efl_gfx_size_hint_align_set(o, EVAS_HINT_FILL, EVAS_HINT_FILL);
+   efl_gfx_entity_visible_set(o, EINA_FALSE);
+}
+
 static void
 _create_colorpalette(Evas_Object *obj)
 {
@@ -1869,18 +1905,22 @@ _create_colorpalette(Evas_Object *obj)
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
 
    if (sd->palette_box) return;
-   sd->palette_box = efl_add(EFL_UI_BOX_FLOW_CLASS, obj,
-                             efl_orientation_set(efl_added, EFL_ORIENT_HORIZONTAL),
-                             efl_gfx_size_hint_weight_set(efl_added, EVAS_HINT_EXPAND, EVAS_HINT_EXPAND),
-                             efl_gfx_size_hint_align_set(efl_added, EVAS_HINT_FILL, EVAS_HINT_FILL),
-                             efl_gfx_visible_set(efl_added, EINA_FALSE));
+   if (elm_widget_is_legacy(obj))
+     {
+        sd->palette_box = elm_legacy_add(EFL_UI_BOX_FLOW_CLASS, obj);
+     }
+   else
+     {
+        sd->palette_box = efl_add(EFL_UI_BOX_FLOW_CLASS, obj);
+     }
+   _palette_box_prepare(sd->palette_box);
 
    hpadstr = edje_object_data_get(wd->resize_obj, "horizontal_pad");
    if (hpadstr) h_pad = atoi(hpadstr);
    vpadstr = edje_object_data_get(wd->resize_obj, "vertical_pad");
    if (vpadstr) v_pad = atoi(vpadstr);
 
-   scale = efl_ui_scale_get(obj) * elm_config_scale_get() / edje_object_base_scale_get(wd->resize_obj);
+   scale = efl_gfx_entity_scale_get(obj) * elm_config_scale_get() / edje_object_base_scale_get(wd->resize_obj);
    efl_pack_padding_set(sd->palette_box, h_pad * scale, v_pad * scale, 0);
    efl_pack_align_set(sd->palette_box, 0.0, 0.0);
    if (!elm_layout_content_set(obj, "elm.palette", sd->palette_box))
@@ -1942,9 +1982,10 @@ _elm_colorselector_efl_canvas_group_group_add(Eo *obj, Elm_Colorselector_Data *p
    priv->grab.xroot = -1;
 #endif
    priv->grab.in = EINA_TRUE;
-
    elm_layout_sizing_eval(obj);
    elm_widget_can_focus_set(obj, EINA_TRUE);
+
+   _flush_color_children(obj, priv);
 }
 
 EOLIAN static void
@@ -1965,7 +2006,11 @@ _elm_colorselector_efl_canvas_group_group_del(Eo *obj, Elm_Colorselector_Data *s
    ecore_event_handler_del(sd->grab.key_up);
 #endif
 
-   _items_del(sd);
+   // We created the items with efl_add, they will be dead after this.
+   sd->items = eina_list_free(sd->items);
+   sd->selected = NULL;
+   sd->focus_items = NULL;
+
    /* This cb_data are used during the destruction process of base.del */
    for (i = 0; i < 4; i++)
      tmp[i] = sd->cb_data[i];
@@ -2043,6 +2088,8 @@ _key_action_move(Evas_Object *obj, const char *params)
    char colorbar_s[128];
    const char *dir = params;
 
+   if (!sd->selected) sd->selected = sd->items;
+   if (!sd->focus_items) sd->focus_items = sd->items;
    _elm_widget_focus_auto_show(obj);
    if (!strcmp(dir, "left"))
      {
@@ -2144,6 +2191,8 @@ _key_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
 {
    ELM_COLORSELECTOR_DATA_GET(obj, sd);
 
+   if (!sd->selected) sd->selected = sd->items;
+   if (!sd->focus_items) sd->focus_items = sd->items;
    if (sd->focused == ELM_COLORSELECTOR_PALETTE)
      {
         Elm_Object_Item *eo_item = NULL;
@@ -2156,76 +2205,8 @@ _key_action_activate(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_FALSE;
 }
 
-EOLIAN static Eina_Bool
-_elm_colorselector_elm_widget_widget_event(Eo *obj, Elm_Colorselector_Data *sd, Evas_Object *src, Evas_Callback_Type type, void *event_info)
-{
-   Evas_Event_Key_Down *ev = event_info;
-   (void) src;
-
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-   if (!sd) return EINA_FALSE;
-   if (!sd->selected) sd->selected = sd->items;
-   if (!sd->focus_items) sd->focus_items = sd->items;
-
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions))
-     return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
-}
-
 static Eina_Bool _elm_colorselector_smart_focus_next_enable = EINA_FALSE;
 
-EOLIAN static Eina_Bool
-_elm_colorselector_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *_pd EINA_UNUSED)
-{
-   return EINA_FALSE;
-}
-
-EOLIAN static Eina_Bool
-_elm_colorselector_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *_pd EINA_UNUSED)
-{
-   return _elm_colorselector_smart_focus_next_enable;
-}
-
-EOLIAN static Eina_Bool
-_elm_colorselector_elm_widget_focus_next(Eo *obj, Elm_Colorselector_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Eina_List *items = NULL;
-   Eina_List *l;
-   Elm_Object_Item *eo_item;
-   int i = 0;
-
-   if (!sd) return EINA_FALSE;
-
-   if ((sd->mode == ELM_COLORSELECTOR_PALETTE) ||
-       (sd->mode == ELM_COLORSELECTOR_ALL)||
-       (sd->mode == ELM_COLORSELECTOR_BOTH))
-     {
-        if (!sd->items) return EINA_FALSE;
-        EINA_LIST_FOREACH(sd->items, l, eo_item)
-          {
-             Elm_Widget_Item_Data *witem = efl_data_scope_get(eo_item, ELM_WIDGET_ITEM_CLASS);
-             items = eina_list_append(items, witem->access_obj);
-          }
-     }
-   if ((sd->mode == ELM_COLORSELECTOR_COMPONENTS) ||
-       (sd->mode == ELM_COLORSELECTOR_ALL) ||
-       (sd->mode == ELM_COLORSELECTOR_BOTH))
-     {
-        for (i = 0; i < 4; i++)
-          {
-             items = eina_list_append(items, sd->cb_data[i]->lbt);
-             items = eina_list_append(items, sd->cb_data[i]->access_obj);
-             items = eina_list_append(items, sd->cb_data[i]->rbt);
-          }
-     }
-
-   return elm_widget_focus_list_next_get
-            (obj, items, eina_list_data_get, dir, next, next_item);
-}
-
 static void
 _access_obj_process(Evas_Object *obj, Eina_Bool is_access)
 {
@@ -2266,22 +2247,22 @@ _access_obj_process(Evas_Object *obj, Eina_Bool is_access)
      }
 }
 
-EOLIAN static void
-_elm_colorselector_elm_widget_focus_highlight_geometry_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h)
+EOLIAN static Eina_Rect
+_elm_colorselector_efl_ui_widget_focus_highlight_geometry_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
 {
    if (sd->focused_item && (sd->focused == ELM_COLORSELECTOR_PALETTE))
      {
        ELM_COLOR_ITEM_DATA_GET(sd->focused_item, focus_it);
-       evas_object_geometry_get(VIEW(focus_it), x, y, w, h);
+       return efl_gfx_entity_geometry_get(VIEW(focus_it));
      }
    else if(sd->focused == ELM_COLORSELECTOR_COMPONENTS)
-     evas_object_geometry_get(sd->cb_data[sd->sel_color_type]->colorbar, x, y, w, h);
-   else
-     evas_object_geometry_get(obj, x, y, w, h);
+     return efl_gfx_entity_geometry_get(sd->cb_data[sd->sel_color_type]->colorbar);
+
+   return efl_gfx_entity_geometry_get(obj);
 }
 
 EOLIAN static void
-_elm_colorselector_elm_widget_access(Eo *obj, Elm_Colorselector_Data *_pd EINA_UNUSED, Eina_Bool acs)
+_elm_colorselector_efl_ui_widget_on_access_update(Eo *obj, Elm_Colorselector_Data *_pd EINA_UNUSED, Eina_Bool acs)
 {
    _elm_colorselector_smart_focus_next_enable = acs;
    _access_obj_process(obj, _elm_colorselector_smart_focus_next_enable);
@@ -2291,7 +2272,7 @@ EAPI Evas_Object *
 elm_colorselector_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -2300,19 +2281,19 @@ _elm_colorselector_efl_object_constructor(Eo *obj, Elm_Colorselector_Data *_pd E
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_COLOR_CHOOSER);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_COLOR_CHOOSER);
 
    return obj;
 }
 
 EOLIAN static void
-_elm_colorselector_color_set(Eo *obj, Elm_Colorselector_Data *_pd EINA_UNUSED, int r, int g, int b, int a)
+_elm_colorselector_picked_color_set(Eo *obj, Elm_Colorselector_Data *_pd EINA_UNUSED, int r, int g, int b, int a)
 {
    _colors_set(obj, r, g, b, a, EINA_FALSE);
 }
 
 EOLIAN static void
-_elm_colorselector_color_get(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd, int *r, int *g, int *b, int *a)
+_elm_colorselector_picked_color_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd, int *r, int *g, int *b, int *a)
 {
    if (r) *r = sd->r;
    if (g) *g = sd->g;
@@ -2397,10 +2378,11 @@ _elm_colorselector_mode_set(Eo *obj, Elm_Colorselector_Data *sd, Elm_Colorselect
 
    _colors_set(obj, sd->r, sd->g, sd->b, sd->a, EINA_TRUE);
    elm_layout_sizing_eval(obj);
+   _flush_color_children(obj, sd);
 }
 
 EOLIAN static Elm_Colorselector_Mode
-_elm_colorselector_mode_get(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
+_elm_colorselector_mode_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
 {
    return sd->mode;
 }
@@ -2416,7 +2398,7 @@ elm_colorselector_palette_item_color_get(const Elm_Object_Item *it,
 }
 
 EOLIAN static void
-_elm_color_item_color_get(Eo *eo_item EINA_UNUSED,
+_elm_color_item_color_get(const Eo *eo_item EINA_UNUSED,
                           Elm_Color_Item_Data *item,
                           int *r,
                           int *g,
@@ -2505,7 +2487,7 @@ _elm_colorselector_palette_clear(Eo *obj, Elm_Colorselector_Data *sd)
 }
 
 EOLIAN static const Eina_List*
-_elm_colorselector_palette_items_get(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
+_elm_colorselector_palette_items_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
 {
    return sd->items;
 }
@@ -2566,7 +2548,7 @@ elm_colorselector_palette_item_selected_get(const Elm_Object_Item *it)
 }
 
 EOLIAN static Eina_Bool
-_elm_color_item_selected_get(Eo *eo_item EINA_UNUSED, Elm_Color_Item_Data *item)
+_elm_color_item_selected_get(const Eo *eo_item EINA_UNUSED, Elm_Color_Item_Data *item)
 {
    Eo *eo_temp_item;
 
@@ -2578,7 +2560,7 @@ _elm_color_item_selected_get(Eo *eo_item EINA_UNUSED, Elm_Color_Item_Data *item)
 }
 
 EOLIAN static Elm_Object_Item*
-_elm_colorselector_palette_selected_item_get(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
+_elm_colorselector_palette_selected_item_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
 {
    return eina_list_data_get(sd->selected);
 }
@@ -2596,7 +2578,7 @@ _elm_colorselector_palette_name_set(Eo *obj, Elm_Colorselector_Data *sd, const c
 }
 
 EOLIAN static const char*
-_elm_colorselector_palette_name_get(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
+_elm_colorselector_palette_name_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
 {
    return sd->palette_name;
 }
@@ -2610,10 +2592,10 @@ _elm_colorselector_class_constructor(Efl_Class *klass)
       _elm_colorselector_smart_focus_next_enable = EINA_TRUE;
 }
 
-EOLIAN static const Elm_Atspi_Action*
-_elm_colorselector_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd EINA_UNUSED)
+EOLIAN static const Efl_Access_Action_Data*
+_elm_colorselector_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "move,left", "move", "left", _key_action_move},
           { "move,right", "move", "right", _key_action_move},
           { "move,up", "move", "up", _key_action_move},
@@ -2624,11 +2606,11 @@ _elm_colorselector_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EIN
 }
 
 EOLIAN static Eina_List*
-_elm_colorselector_elm_interface_atspi_accessible_children_get(Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
+_elm_colorselector_efl_access_object_access_children_get(const Eo *obj EINA_UNUSED, Elm_Colorselector_Data *sd)
 {
    Eina_List *ret = NULL;
 
-   ret = elm_interface_atspi_accessible_children_get(efl_super(obj, ELM_COLORSELECTOR_CLASS));
+   ret = efl_access_object_access_children_get(efl_super(obj, ELM_COLORSELECTOR_CLASS));
    // filter - out box contiainer
    ret = eina_list_remove(ret, sd->palette_box);
    // append items as colorselector children
@@ -2637,24 +2619,24 @@ _elm_colorselector_elm_interface_atspi_accessible_children_get(Eo *obj EINA_UNUS
    return ret;
 }
 
-EOLIAN static Elm_Atspi_State_Set
-_elm_color_item_elm_interface_atspi_accessible_state_set_get(Eo *obj, Elm_Color_Item_Data *sd EINA_UNUSED)
+EOLIAN static Efl_Access_State_Set
+_elm_color_item_efl_access_object_state_set_get(const Eo *obj, Elm_Color_Item_Data *sd EINA_UNUSED)
 {
-   Elm_Atspi_State_Set ret;
+   Efl_Access_State_Set ret;
    Eina_Bool sel;
 
-   ret = elm_interface_atspi_accessible_state_set_get(efl_super(obj, ELM_COLOR_ITEM_CLASS));
+   ret = efl_access_object_state_set_get(efl_super(obj, ELM_COLOR_ITEM_CLASS));
 
    sel = elm_obj_color_item_selected_get(obj);
 
    if (sel)
-     STATE_TYPE_SET(ret, ELM_ATSPI_STATE_CHECKED);
+     STATE_TYPE_SET(ret, EFL_ACCESS_STATE_CHECKED);
 
    return ret;
 }
 
 EOLIAN static void
-_elm_color_item_elm_widget_item_focus_set(Eo *eo_it, Elm_Color_Item_Data *it, Eina_Bool focused)
+_elm_color_item_elm_widget_item_item_focus_set(Eo *eo_it, Elm_Color_Item_Data *it, Eina_Bool focused)
 {
    Evas_Object *obj = WIDGET(it);
    ELM_COLORSELECTOR_DATA_GET(obj, sd);
@@ -2671,7 +2653,7 @@ _elm_color_item_elm_widget_item_focus_set(Eo *eo_it, Elm_Color_Item_Data *it, Ei
      }
    else
      {
-        if (!elm_widget_focus_get(obj))
+        if (!efl_ui_focus_object_focus_get(obj))
           return;
         sd->focused_item = NULL;
      }
@@ -2680,7 +2662,7 @@ _elm_color_item_elm_widget_item_focus_set(Eo *eo_it, Elm_Color_Item_Data *it, Ei
 }
 
 EOLIAN static Eina_Bool
-_elm_color_item_elm_widget_item_focus_get(Eo *eo_it, Elm_Color_Item_Data *it)
+_elm_color_item_elm_widget_item_item_focus_get(const Eo *eo_it, Elm_Color_Item_Data *it)
 {
    Evas_Object *obj = WIDGET(it);
    ELM_COLORSELECTOR_DATA_GET(obj, sd);
@@ -2690,10 +2672,10 @@ _elm_color_item_elm_widget_item_focus_get(Eo *eo_it, Elm_Color_Item_Data *it)
    return EINA_FALSE;
 }
 
-EOLIAN static const Elm_Atspi_Action*
-_elm_color_item_elm_interface_atspi_widget_action_elm_actions_get(Eo *eo_it EINA_UNUSED, Elm_Color_Item_Data *it EINA_UNUSED)
+EOLIAN static const Efl_Access_Action_Data*
+_elm_color_item_efl_access_widget_action_elm_actions_get(const Eo *eo_it EINA_UNUSED, Elm_Color_Item_Data *it EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "activate", "activate", NULL, _item_action_activate},
           { NULL, NULL, NULL, NULL }
    };
@@ -2701,14 +2683,14 @@ _elm_color_item_elm_interface_atspi_widget_action_elm_actions_get(Eo *eo_it EINA
 }
 
 EOLIAN static const char*
-_elm_color_item_elm_interface_atspi_accessible_name_get(Eo *eo_it, Elm_Color_Item_Data *it)
+_elm_color_item_efl_access_object_i18n_name_get(const Eo *eo_it, Elm_Color_Item_Data *it)
 {
    Eina_Strbuf *buf;
    const char *color_name = NULL;
    const char *name;
    char *accessible_name;
 
-   name = elm_interface_atspi_accessible_name_get(efl_super(eo_it, ELM_COLOR_ITEM_CLASS));
+   name = efl_access_object_i18n_name_get(efl_super(eo_it, ELM_COLOR_ITEM_CLASS));
    if (name) return name;
 
    buf = eina_strbuf_new();
@@ -2727,11 +2709,29 @@ _elm_color_item_elm_interface_atspi_accessible_name_get(Eo *eo_it, Elm_Color_Ite
    return it->base->accessible_name;
 }
 
+EOLIAN static Eina_Rect
+_elm_color_item_efl_ui_focus_object_focus_geometry_get(const Eo *obj EINA_UNUSED, Elm_Color_Item_Data *pd)
+{
+   return efl_gfx_entity_geometry_get(pd->color_obj);
+}
+
+EOLIAN static void
+_elm_color_item_efl_ui_focus_object_focus_set(Eo *obj, Elm_Color_Item_Data *pd, Eina_Bool focus)
+{
+   efl_ui_focus_object_focus_set(efl_super(obj, ELM_COLOR_ITEM_CLASS), focus);
+   evas_object_focus_set(pd->color_obj, focus);
+   elm_object_item_focus_set(obj, focus);
+}
+
+/* Standard widget overrides */
+
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(elm_colorselector, Elm_Colorselector_Data)
+
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_COLORSELECTOR_EXTRA_OPS \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_colorselector), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_colorselector)
 
 #include "elm_colorselector.eo.c"
 #include "elm_color_item.eo.c"
-
