@@ -3,16 +3,20 @@
 #endif
 
 #define ELM_WIDGET_PROTECTED
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
 #define ELM_LAYOUT_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_widget_conform.h"
 #include "elm_widget_layout.h"
+#include "elm_widget_plug.h"
+#include "elm_scroller.eo.h"
+#include "elm_genlist.eo.h"
+#include "elm_conformant.eo.h"
 
 #define MY_CLASS ELM_CONFORMANT_CLASS
-
+#define MY_CLASS_PFX elm_conformant
 #define MY_CLASS_NAME "Elm_Conformant"
 #define MY_CLASS_NAME_LEGACY "elm_conformant"
 
@@ -338,7 +342,7 @@ _land_indicator_connect_cb(void *data)
      }
    if (strchr(indicator_serv_name, '/'))
      {
-        sd->port_indi_timer = NULL;
+        sd->land_indi_timer = NULL;
         return ECORE_CALLBACK_CANCEL;
      }
    if (elm_plug_connect(sd->landscape_indicator, indicator_serv_name, 0, EINA_FALSE))
@@ -569,13 +573,13 @@ _on_rotation_changed(void *data, const Efl_Event *event EINA_UNUSED)
      }
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_conformant_elm_widget_theme_apply(Eo *obj, Elm_Conformant_Data *_pd EINA_UNUSED)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_conformant_efl_ui_widget_theme_apply(Eo *obj, Elm_Conformant_Data *_pd EINA_UNUSED)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    _conformant_parts_swallow(obj);
 
@@ -660,17 +664,15 @@ _show_region_job(void *data)
 
    ELM_CONFORMANT_DATA_GET(data, sd);
 
-   focus_obj = elm_widget_focused_object_get(data);
+   focus_obj = elm_object_focused_object_get(data);
    if (focus_obj)
      {
-        Evas_Coord x, y, w, h;
+        Eina_Rect r = elm_widget_focus_region_get(focus_obj);
 
-        elm_widget_focus_region_get(focus_obj, &x, &y, &w, &h);
+        if (r.h < _elm_config->finger_size)
+          r.h = _elm_config->finger_size;
 
-        if (h < _elm_config->finger_size)
-          h = _elm_config->finger_size;
-
-        elm_widget_show_region_set(focus_obj, x, y, w, h, EINA_TRUE);
+        elm_widget_show_region_set(focus_obj, r, EINA_TRUE);
      }
 
    sd->show_region_job = NULL;
@@ -712,7 +714,7 @@ _autoscroll_objects_update(void *data)
 
    ELM_CONFORMANT_DATA_GET(data, sd);
 
-   sub = elm_widget_focused_object_get(data);
+   sub = elm_object_focused_object_get(data);
    //Look up for top most scroller in the focus object hierarchy
    //inside Conformant.
 
@@ -964,7 +966,7 @@ _elm_conformant_efl_canvas_group_group_del(Eo *obj, Elm_Conformant_Data *sd)
 }
 
 EOLIAN static void
-_elm_conformant_elm_widget_widget_parent_set(Eo *obj, Elm_Conformant_Data *sd, Evas_Object *parent)
+_elm_conformant_efl_ui_widget_widget_parent_set(Eo *obj, Elm_Conformant_Data *sd, Evas_Object *parent)
 {
 #ifdef HAVE_ELEMENTARY_X
    Evas_Object *top = elm_widget_top_get(parent);
@@ -986,17 +988,11 @@ _elm_conformant_elm_widget_widget_parent_set(Eo *obj, Elm_Conformant_Data *sd, E
 #endif
 }
 
-EOLIAN static const Elm_Layout_Part_Alias_Description*
-_elm_conformant_elm_layout_content_aliases_get(Eo *obj EINA_UNUSED, Elm_Conformant_Data *_pd EINA_UNUSED)
-{
-   return _content_aliases;
-}
-
 EAPI Evas_Object *
 elm_conformant_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -1005,7 +1001,7 @@ _elm_conformant_efl_object_constructor(Eo *obj, Elm_Conformant_Data *sd)
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_FILLER);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_FILLER);
 
    Efl_Event event = {};
    event.object = sd->win;
@@ -1032,7 +1028,10 @@ _elm_conformant_class_constructor(Efl_Class *klass)
 
 /* Internal EO APIs and hidden overrides */
 
+ELM_LAYOUT_CONTENT_ALIASES_IMPLEMENT(MY_CLASS_PFX)
+
 #define ELM_CONFORMANT_EXTRA_OPS \
+   ELM_LAYOUT_CONTENT_ALIASES_OPS(MY_CLASS_PFX), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_conformant)
 
 #include "elm_conformant.eo.c"
