@@ -2,14 +2,16 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_UI_TRANSLATABLE_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 #include "elm_priv.h"
 #include "elm_widget_dayselector.h"
 #include "elm_widget_container.h"
 
-#include "elm_dayselector_internal_part.eo.h"
+#include "elm_dayselector_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_DAYSELECTOR_CLASS
@@ -55,8 +57,8 @@ _dayselector_resize(void *data,
    elm_layout_sizing_eval(data);
 }
 
-EOLIAN static Eina_Bool
-_elm_dayselector_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
+EOLIAN static void
+_elm_dayselector_efl_ui_translatable_translation_update(Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
 {
    time_t t;
    Eina_List *l;
@@ -65,7 +67,7 @@ _elm_dayselector_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Dayselector_Data
    Elm_Dayselector_Item_Data *it;
 
    if (sd->weekdays_names_set)
-     return EINA_TRUE;
+     return;
 
    t = time(NULL);
    localtime_r(&t, &time_daysel);
@@ -76,9 +78,7 @@ _elm_dayselector_elm_widget_translate(Eo *obj EINA_UNUSED, Elm_Dayselector_Data
         elm_object_text_set(VIEW(it), buf);
      }
 
-   elm_obj_widget_translate(efl_super(obj, MY_CLASS));
-
-   return EINA_TRUE;
+   efl_ui_translatable_translation_update(efl_super(obj, MY_CLASS));
 }
 
 static void
@@ -123,17 +123,17 @@ _item_location_get(Elm_Dayselector_Data *sd,
           ELM_DAYSELECTOR_MAX;
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_dayselector_elm_widget_theme_apply(Eo *obj, Elm_Dayselector_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_dayselector_efl_ui_widget_theme_apply(Eo *obj, Elm_Dayselector_Data *sd)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
 
    Eina_List *l;
    char buf[1024];
    Elm_Dayselector_Item_Data *it;
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    EINA_LIST_FOREACH(sd->items, l, it)
      {
@@ -141,9 +141,14 @@ _elm_dayselector_elm_widget_theme_apply(Eo *obj, Elm_Dayselector_Data *sd)
           (buf, sizeof(buf), "dayselector/%s", elm_object_style_get(obj));
         elm_object_style_set(VIEW(it), buf);
 
+        /* XXX kept for legacy compatibility, remove eventually */
         snprintf
           (buf, sizeof(buf), "day%d,visible", _item_location_get(sd, it));
         elm_layout_signal_emit(obj, buf, "elm");
+        /* XXX */
+        snprintf
+          (buf, sizeof(buf), "elm,day%d,visible", _item_location_get(sd, it));
+        elm_layout_signal_emit(obj, buf, "elm");
      }
 
    _update_items(obj);
@@ -170,12 +175,16 @@ _item_del_cb(void *data,
           {
              sd->items = eina_list_remove(sd->items, it);
              eina_stringshare_del(it->day_style);
+             /* XXX kept for legacy compatibility, remove eventually */
              snprintf(buf, sizeof(buf), "day%d,default",
                       _item_location_get(sd, it));
              elm_layout_signal_emit(obj, buf, "elm");
+             /* XXX */
+             snprintf(buf, sizeof(buf), "elm,day%d,default",
+                      _item_location_get(sd, it));
+             elm_layout_signal_emit(obj, buf, "elm");
 
-             VIEW(it) = NULL;
-             efl_del(EO_OBJ(it));
+             // The object is already being deleted, there is no point in calling efl_del on it nore setting it to NULL.
 
              elm_layout_sizing_eval(obj);
              break;
@@ -235,15 +244,23 @@ _elm_dayselector_content_set(Eo *obj, Elm_Dayselector_Data *sd, const char *item
    it = _item_find(obj, day);
    if (it)
      {
-        snprintf(buf, sizeof(buf), "day%d", _item_location_get(sd, it));
+        snprintf(buf, sizeof(buf), "elm.swallow.day%d", _item_location_get(sd, it));
 
         int_ret = efl_content_set(efl_part(efl_super(obj, MY_CLASS), buf), content);
+        if (!int_ret)
+          {
+             /* XXX kept for legacy compatibility, remove eventually */
+             snprintf(buf, sizeof(buf), "day%d", _item_location_get(sd, it));
+
+             int_ret = efl_content_set(efl_part(efl_super(obj, MY_CLASS), buf), content);
+             /* XXX */
+          }
         if (!int_ret) return EINA_FALSE;
 
         if (!content) return EINA_TRUE; /* item deletion already handled */
 
         evas_object_del(VIEW(it));
-        VIEW(it) = content;
+        VIEW_SET(it, content);
      }
    else
      {
@@ -251,9 +268,17 @@ _elm_dayselector_content_set(Eo *obj, Elm_Dayselector_Data *sd, const char *item
         it = efl_data_scope_get(eo_it, ELM_DAYSELECTOR_ITEM_CLASS);
         it->day = day;
 
-        snprintf(buf, sizeof(buf), "day%d", _item_location_get(sd, it));
+        snprintf(buf, sizeof(buf), "elm.swallow.day%d", _item_location_get(sd, it));
 
         int_ret = efl_content_set(efl_part(efl_super(obj, MY_CLASS), buf), content);
+        if (!int_ret)
+          {
+             /* XXX kept for legacy compatibility, remove eventually */
+             snprintf(buf, sizeof(buf), "day%d", _item_location_get(sd, it));
+
+             int_ret = efl_content_set(efl_part(efl_super(obj, MY_CLASS), buf), content);
+             /* XXX */
+          }
         if (!int_ret)
           {
              efl_del(eo_it);
@@ -261,9 +286,12 @@ _elm_dayselector_content_set(Eo *obj, Elm_Dayselector_Data *sd, const char *item
           }
 
         sd->items = eina_list_append(sd->items, it);
-        VIEW(it) = content;
+        VIEW_SET(it, content);
      }
 
+   snprintf(buf, sizeof(buf), "elm,day%d,visible", _item_location_get(sd, it));
+   elm_layout_signal_emit(obj, buf, "elm");
+   /* XXX kept for legacy compatibility, remove eventually */
    snprintf(buf, sizeof(buf), "day%d,visible", _item_location_get(sd, it));
    elm_layout_signal_emit(obj, buf, "elm");
 
@@ -326,10 +354,12 @@ _elm_dayselector_content_unset(Eo *obj, Elm_Dayselector_Data *sd, const char *it
    elm_object_signal_callback_del
      (content, ITEM_TYPE_WEEKEND_STYLE1, "*", _item_signal_emit_cb);
 
+   snprintf(buf, sizeof(buf), "elm,day%d,default", _item_location_get(sd, it));
+   elm_layout_signal_emit(obj, buf, "elm");
+   /* XXX kept for legacy compatibility, remove eventually */
    snprintf(buf, sizeof(buf), "day%d,default", _item_location_get(sd, it));
    elm_layout_signal_emit(obj, buf, "elm");
 
-   VIEW(it) = NULL;
    efl_del(EO_OBJ(it));
 
    elm_layout_sizing_eval(obj);
@@ -395,8 +425,12 @@ _items_create(Evas_Object *obj)
         strftime(buf, sizeof(buf), "%a", &time_daysel);
         elm_object_text_set(chk, buf);
 
-        snprintf(buf, sizeof(buf), "day%u", idx);
-        elm_layout_content_set(obj, buf, chk);
+        snprintf(buf, sizeof(buf), "elm.swallow.day%u", idx);
+        if (!elm_layout_content_set(obj, buf, chk))
+          {
+             snprintf(buf, sizeof(buf), "day%u", idx);
+             elm_layout_content_set(obj, buf, chk);
+          }
 
         // XXX: ACCESS
         _elm_access_text_set(_elm_access_info_get(chk),
@@ -437,7 +471,7 @@ _elm_dayselector_efl_canvas_group_group_del(Eo *obj, Elm_Dayselector_Data *sd)
      {
         sd->items = eina_list_remove(sd->items, it);
         eina_stringshare_del(it->day_style);
-        efl_del(EO_OBJ(it));
+        // No need to efl_del the object as they have been created by efl_add and are dead by now.
      }
 
    /* handles freeing sd */
@@ -448,7 +482,7 @@ EAPI Evas_Object *
 elm_dayselector_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -457,7 +491,7 @@ _elm_dayselector_efl_object_constructor(Eo *obj, Elm_Dayselector_Data *_pd EINA_
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_PANEL);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_PANEL);
 
    return obj;
 }
@@ -498,16 +532,19 @@ _elm_dayselector_week_start_set(Eo *obj, Elm_Dayselector_Data *sd, Elm_Dayselect
    sd->week_start = day;
    EINA_LIST_FOREACH(sd->items, l, it)
      {
-        snprintf(buf, sizeof(buf), "day%d", _item_location_get(sd, it));
-        edje_object_part_swallow
-          (wd->resize_obj, buf, VIEW(it));
+        snprintf(buf, sizeof(buf), "elm.swallow.day%d", _item_location_get(sd, it));
+        if (!edje_object_part_swallow(wd->resize_obj, buf, VIEW(it)))
+          {
+             snprintf(buf, sizeof(buf), "day%d", _item_location_get(sd, it));
+             edje_object_part_swallow(wd->resize_obj, buf, VIEW(it));
+          }
      }
 
    _update_items(obj);
 }
 
 EOLIAN static Elm_Dayselector_Day
-_elm_dayselector_week_start_get(Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
+_elm_dayselector_week_start_get(const Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
 {
    return sd->week_start;
 }
@@ -522,7 +559,7 @@ _elm_dayselector_weekend_start_set(Eo *obj, Elm_Dayselector_Data *sd, Elm_Daysel
 }
 
 EOLIAN static Elm_Dayselector_Day
-_elm_dayselector_weekend_start_get(Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
+_elm_dayselector_weekend_start_get(const Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
 {
    return sd->weekend_start;
 }
@@ -537,7 +574,7 @@ _elm_dayselector_weekend_length_set(Eo *obj, Elm_Dayselector_Data *sd, unsigned
 }
 
 EOLIAN static unsigned int
-_elm_dayselector_weekend_length_get(Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
+_elm_dayselector_weekend_length_get(const Eo *obj EINA_UNUSED, Elm_Dayselector_Data *sd)
 {
    return sd->weekend_len;
 }
@@ -595,12 +632,6 @@ _elm_dayselector_weekdays_names_get(const Eo *obj, Elm_Dayselector_Data *sd EINA
    return weekdays;
 }
 
-EOLIAN static Eina_Bool
-_elm_dayselector_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Dayselector_Data *_pd EINA_UNUSED)
-{
-   return EINA_FALSE;
-}
-
 static void
 _elm_dayselector_class_constructor(Efl_Class *klass)
 {
@@ -609,16 +640,17 @@ _elm_dayselector_class_constructor(Efl_Class *klass)
 
 /* Efl.Part begin */
 
-ELM_PART_OVERRIDE(elm_dayselector, ELM_DAYSELECTOR, ELM_LAYOUT, Elm_Dayselector_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_SET(elm_dayselector, ELM_DAYSELECTOR, ELM_LAYOUT, Elm_Dayselector_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_UNSET(elm_dayselector, ELM_DAYSELECTOR, ELM_LAYOUT, Elm_Dayselector_Data, Elm_Part_Data)
-#include "elm_dayselector_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_dayselector, ELM_DAYSELECTOR, Elm_Dayselector_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_dayselector, ELM_DAYSELECTOR, Elm_Dayselector_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_dayselector, ELM_DAYSELECTOR, Elm_Dayselector_Data)
+#include "elm_dayselector_part.eo.c"
 
 /* Efl.Part end */
 
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_DAYSELECTOR_EXTRA_OPS \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_dayselector), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_dayselector)
 
 #include "elm_dayselector.eo.c"
