@@ -333,8 +333,7 @@ _root_layout_build(Elm_DBus_Menu *dbus_menu, Eina_List *property_list,
 {
    char *property;
    Eldbus_Message_Iter *layout, *array, *pair, *variant;
-   Eina_List *l;
-   Eina_Iterator *it = NULL;
+   const Eina_List *l, *it;
    Elm_Object_Item *obj_item;
 
    layout = eldbus_message_iter_container_new(iter, 'r', NULL);
@@ -360,8 +359,8 @@ _root_layout_build(Elm_DBus_Menu *dbus_menu, Eina_List *property_list,
 
    if (recursion_depth > 0)
      {
-        it = efl_ui_menu_items_get(dbus_menu->menu);
-        EINA_ITERATOR_FOREACH (it, obj_item)
+        it = elm_menu_items_get(dbus_menu->menu);
+        EINA_LIST_FOREACH (it, l, obj_item)
           {
              variant = eldbus_message_iter_container_new(array, 'v',
                                                          "(ia{sv}av)");
@@ -370,7 +369,6 @@ _root_layout_build(Elm_DBus_Menu *dbus_menu, Eina_List *property_list,
                                      recursion_depth - 1, variant);
              eldbus_message_iter_container_close(array, variant);
           }
-        eina_iterator_free(it);
      }
 
    eldbus_message_iter_container_close(layout, array);
@@ -423,7 +421,7 @@ _elm_dbus_menu_add(Eo *menu)
 {
    Elm_DBus_Menu *dbus_menu;
    Elm_Object_Item *obj_item;
-   Eina_Iterator *it = NULL;
+   const Eina_List *it, *l;
 
    ELM_MENU_CHECK(menu) NULL;
 
@@ -443,8 +441,8 @@ _elm_dbus_menu_add(Eo *menu)
 
    dbus_menu->menu = menu;
 
-   it = efl_ui_menu_items_get(menu);
-   EINA_ITERATOR_FOREACH(it, obj_item)
+   it = elm_menu_items_get(menu);
+   EINA_LIST_FOREACH(it, l, obj_item)
      {
         ELM_MENU_ITEM_DATA_GET(obj_item, item);
         if (!_menu_add_recursive(dbus_menu, item))
@@ -453,12 +451,10 @@ _elm_dbus_menu_add(Eo *menu)
              goto error_hash;
           }
      }
-   eina_iterator_free(it);
 
    return dbus_menu;
 
 error_hash:
-   eina_iterator_free(it);
    eina_hash_free(dbus_menu->elements);
 error_menu:
    free(dbus_menu);
@@ -953,6 +949,8 @@ _elm_dbus_menu_app_menu_register(Ecore_X_Window xid, Eo *obj,
      }
 
    sd->dbus_menu->app_menu_data = malloc(sizeof(Callback_Data));
+   if (!sd->dbus_menu->app_menu_data) return;
+
    cd = sd->dbus_menu->app_menu_data;
    cd->result_cb = result_cb;
    cd->data = data;
