@@ -2,7 +2,7 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
 
 #include <Elementary.h>
 
@@ -27,15 +27,15 @@ static const Evas_Smart_Cb_Description _smart_callbacks[] = {
 };
 
 EOLIAN static Eina_Bool
-_elm_glview_elm_widget_on_focus(Eo *obj, Elm_Glview_Data *_pd EINA_UNUSED, Elm_Object_Item *item EINA_UNUSED)
+_elm_glview_efl_ui_focus_object_on_focus_update(Eo *obj, Elm_Glview_Data *_pd EINA_UNUSED)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EINA_FALSE);
    Eina_Bool int_ret = EINA_FALSE;
 
-   int_ret = elm_obj_widget_on_focus(efl_super(obj, MY_CLASS), NULL);
+   int_ret = efl_ui_focus_object_on_focus_update(efl_super(obj, MY_CLASS));
    if (!int_ret) return EINA_FALSE;
 
-   if (elm_widget_focus_get(obj))
+   if (efl_ui_focus_object_focus_get(obj))
      evas_object_focus_set(wd->resize_obj, EINA_TRUE);
    else
      evas_object_focus_set(wd->resize_obj, EINA_FALSE);
@@ -86,25 +86,22 @@ _glview_update_surface(Evas_Object *obj)
 }
 
 EOLIAN static void
-_elm_glview_efl_gfx_size_set(Eo *obj, Elm_Glview_Data *sd, Evas_Coord w, Evas_Coord h)
+_elm_glview_efl_gfx_entity_size_set(Eo *obj, Elm_Glview_Data *sd, Eina_Size2D sz)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
-   efl_gfx_size_set(efl_super(obj, MY_CLASS), w, h);
+   efl_gfx_entity_size_set(efl_super(obj, MY_CLASS), sz);
 
    sd->resized = EINA_TRUE;
 
    if (sd->scale_policy == ELM_GLVIEW_RESIZE_POLICY_RECREATE)
      {
-        if ((w == 0) || (h == 0))
-          {
-             w = 64;
-             h = 64;
-          }
+        if ((sz.w == 0) || (sz.h == 0))
+          sz = EINA_SIZE2D(64, 64);
 
-        sd->w = w;
-        sd->h = h;
+        sd->w = sz.w;
+        sd->h = sz.h;
 
         _glview_update_surface(obj);
      }
@@ -121,7 +118,7 @@ _render_cb(void *obj, const Efl_Event *event EINA_UNUSED)
    // Do a make current
    if (!evas_gl_make_current(sd->evasgl, sd->surface, sd->context))
      {
-        ERR("Failed doing make current.\n");
+        ERR("Failed doing make current.");
         goto on_error;
      }
 
@@ -161,14 +158,14 @@ _render_cb(void *obj, const Efl_Event *event EINA_UNUSED)
      }
    else
      {
-        ERR("Invalid Render Policy.\n");
+        ERR("Invalid Render Policy.");
         goto on_error;
      }
 
    return;
 
  on_error:
-   efl_event_callback_del(ecore_main_loop_get(),
+   efl_event_callback_del(efl_main_loop_get(),
                          EFL_LOOP_EVENT_IDLE_ENTER,
                          _render_cb,
                          obj);
@@ -190,7 +187,7 @@ _set_render_policy_callback(Evas_Object *obj)
               evas_object_image_data_update_add(wd->resize_obj, 0, 0, sd->w, sd->h);
            }
          // Delete idle_enterer if it for some reason is around
-         efl_event_callback_del(ecore_main_loop_get(),
+         efl_event_callback_del(efl_main_loop_get(),
                                EFL_LOOP_EVENT_IDLE_ENTER,
                                _render_cb,
                                obj);
@@ -204,8 +201,8 @@ _set_render_policy_callback(Evas_Object *obj)
         break;
 
       case ELM_GLVIEW_RENDER_POLICY_ALWAYS:
-        if (evas_object_image_pixels_dirty_get(wd->resize_obj))
-          sd->render_idle_enterer = efl_event_callback_priority_add(ecore_main_loop_get(),
+        if (evas_object_image_pixels_dirty_get(wd->resize_obj) && !sd->render_idle_enterer)
+          sd->render_idle_enterer = efl_event_callback_priority_add(efl_main_loop_get(),
                                                                    EFL_LOOP_EVENT_IDLE_ENTER,
                                                                    EFL_CALLBACK_PRIORITY_BEFORE,
                                                                    _render_cb,
@@ -217,7 +214,7 @@ _set_render_policy_callback(Evas_Object *obj)
         break;
 
       default:
-        ERR("Invalid Render Policy.\n");
+        ERR("Invalid Render Policy.");
         return;
      }
 }
@@ -231,7 +228,7 @@ _elm_glview_efl_canvas_group_group_add(Eo *obj, Elm_Glview_Data *priv EINA_UNUSE
 
    // Create image to render Evas_GL Surface
    img = evas_object_image_filled_add(evas_object_evas_get(obj));
-   elm_widget_resize_object_set(obj, img, EINA_TRUE);
+   elm_widget_resize_object_set(obj, img);
    evas_object_image_size_set(img, 1, 1);
 
    efl_canvas_group_add(efl_super(obj, MY_CLASS));
@@ -244,8 +241,7 @@ _elm_glview_constructor(Eo *obj, Elm_Glview_Data *priv)
    priv->evasgl = evas_gl_new(evas_object_evas_get(obj));
    if (!priv->evasgl)
      {
-        ERR("Failed Creating an Evas GL Object.\n");
-
+        ERR("Failed Creating an Evas GL Object.");
         return;
      }
 
@@ -253,8 +249,7 @@ _elm_glview_constructor(Eo *obj, Elm_Glview_Data *priv)
    priv->config = evas_gl_config_new();
    if (!priv->config)
      {
-        ERR("Failed Creating a Config Object.\n");
-
+        ERR("Failed Creating a Config Object.");
         evas_gl_free(priv->evasgl);
         priv->evasgl = NULL;
         return;
@@ -281,8 +276,7 @@ _elm_glview_constructor(Eo *obj, Elm_Glview_Data *priv)
      priv->context = evas_gl_context_version_create(priv->evasgl, NULL, priv->gles_version);
    if (!priv->context)
      {
-        ERR("Error Creating an Evas_GL Context.\n");
-
+        ERR("Error Creating an Evas_GL Context.");
         ELM_SAFE_FREE(priv->config, evas_gl_config_free);
         ELM_SAFE_FREE(priv->evasgl, evas_gl_free);
         return;
@@ -303,7 +297,7 @@ _elm_glview_efl_canvas_group_group_del(Eo *obj, Elm_Glview_Data *sd)
    //TODO:will be optimised
    efl_event_callback_legacy_call(obj, ELM_GLVIEW_EVENT_DESTROYED, NULL);
 
-   efl_event_callback_del(ecore_main_loop_get(),
+   efl_event_callback_del(efl_main_loop_get(),
                          EFL_LOOP_EVENT_IDLE_ENTER,
                          _render_cb,
                          obj);
@@ -342,18 +336,16 @@ EAPI Evas_Object *
 elm_glview_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent,
-                  elm_obj_glview_version_constructor(efl_added, EVAS_GL_GLES_2_X),
-                  efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent,
+                         elm_obj_glview_version_constructor(efl_added, EVAS_GL_GLES_2_X));
 }
 
 EAPI Evas_Object *
 elm_glview_version_add(Evas_Object *parent, Evas_GL_Context_Version version)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent,
-                  elm_obj_glview_version_constructor(efl_added, version),
-                  efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent,
+                         elm_obj_glview_version_constructor(efl_added, version));
 }
 
 EOLIAN static void
@@ -366,7 +358,7 @@ _elm_glview_version_constructor(Eo *obj, Elm_Glview_Data *sd,
 
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_ANIMATION);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_ANIMATION);
    efl_event_callback_add(obj, EFL_EVENT_CALLBACK_ADD, _cb_added, NULL);
 }
 
@@ -383,7 +375,7 @@ _elm_glview_efl_object_finalize(Eo *obj, Elm_Glview_Data *sd)
 }
 
 EOLIAN static Evas_GL_API*
-_elm_glview_gl_api_get(Eo *obj EINA_UNUSED, Elm_Glview_Data *sd)
+_elm_glview_gl_api_get(const Eo *obj EINA_UNUSED, Elm_Glview_Data *sd)
 {
    return evas_gl_context_api_get(sd->evasgl, sd->context);
 }
@@ -484,7 +476,7 @@ _elm_glview_resize_policy_set(Eo *obj, Elm_Glview_Data *sd, Elm_GLView_Resize_Po
         return EINA_TRUE;
 
       default:
-        ERR("Invalid Scale Policy.\n");
+        ERR("Invalid Scale Policy.");
         return EINA_FALSE;
      }
 
@@ -497,7 +489,7 @@ _elm_glview_render_policy_set(Eo *obj, Elm_Glview_Data *sd, Elm_GLView_Render_Po
    if ((policy != ELM_GLVIEW_RENDER_POLICY_ON_DEMAND) &&
        (policy != ELM_GLVIEW_RENDER_POLICY_ALWAYS))
      {
-        ERR("Invalid Render Policy.\n");
+        ERR("Invalid Render Policy.");
         return EINA_FALSE;
      }
 
@@ -511,22 +503,21 @@ _elm_glview_render_policy_set(Eo *obj, Elm_Glview_Data *sd, Elm_GLView_Render_Po
 }
 
 EOLIAN static void
-_elm_glview_efl_gfx_view_view_size_set(Eo *obj, Elm_Glview_Data *sd, int w, int h)
+_elm_glview_efl_gfx_view_view_size_set(Eo *obj, Elm_Glview_Data *sd, Eina_Size2D sz)
 {
-   if ((w == sd->w) && (h == sd->h)) return;
+   if ((sz.w == sd->w) && (sz.h == sd->h)) return;
 
-   sd->w = w;
-   sd->h = h;
+   sd->w = sz.w;
+   sd->h = sz.h;
 
    _glview_update_surface(obj);
    elm_obj_glview_draw_request(obj);
 }
 
-EOLIAN static void
-_elm_glview_efl_gfx_view_view_size_get(Eo *obj EINA_UNUSED, Elm_Glview_Data *sd, int *w, int *h)
+EOLIAN static Eina_Size2D
+_elm_glview_efl_gfx_view_view_size_get(const Eo *obj EINA_UNUSED, Elm_Glview_Data *sd)
 {
-   if (w) *w = sd->w;
-   if (h) *h = sd->h;
+   return EINA_SIZE2D(sd->w, sd->h);
 }
 
 EOLIAN static void
@@ -538,20 +529,20 @@ _elm_glview_draw_request(Eo *obj, Elm_Glview_Data *sd)
    evas_object_image_data_update_add(wd->resize_obj, 0, 0, sd->w, sd->h);
    if (sd->render_policy == ELM_GLVIEW_RENDER_POLICY_ALWAYS &&
        !sd->render_idle_enterer)
-     sd->render_idle_enterer = efl_event_callback_priority_add(ecore_main_loop_get(),
+     sd->render_idle_enterer = efl_event_callback_priority_add(efl_main_loop_get(),
                                                               EFL_LOOP_EVENT_IDLE_ENTER,
                                                               EFL_CALLBACK_PRIORITY_BEFORE,
                                                               _render_cb, obj);
 }
 
 EOLIAN static Evas_GL *
-_elm_glview_evas_gl_get(Eo *obj EINA_UNUSED, Elm_Glview_Data *sd)
+_elm_glview_evas_gl_get(const Eo *obj EINA_UNUSED, Elm_Glview_Data *sd)
 {
    return sd->evasgl;
 }
 
 EOLIAN static int
-_elm_glview_rotation_get(Eo *obj EINA_UNUSED, Elm_Glview_Data *sd)
+_elm_glview_rotation_get(const Eo *obj EINA_UNUSED, Elm_Glview_Data *sd)
 {
    return evas_gl_rotation_get(sd->evasgl);
 }
@@ -574,13 +565,16 @@ elm_glview_changed_set(Evas_Object *obj)
 EAPI void
 elm_glview_size_get(const Elm_Glview *obj, int *w, int *h)
 {
-   efl_gfx_view_size_get(obj, w, h);
+   Eina_Size2D sz;
+   sz = efl_gfx_view_size_get(obj);
+   if (w) *w = sz.w;
+   if (h) *h = sz.h;
 }
 
 EAPI void
 elm_glview_size_set(Elm_Glview *obj, int w, int h)
 {
-   efl_gfx_view_size_set(obj, w, h);
+   efl_gfx_view_size_set(obj, EINA_SIZE2D(w, h));
 }
 
 EAPI void
