@@ -3,7 +3,8 @@
 #endif
 
 #define ELM_WIDGET_PROTECTED
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 
@@ -11,7 +12,7 @@
 #include "elm_widget_notify.h"
 #include "elm_widget_container.h"
 
-#include "elm_notify_internal_part.eo.h"
+#include "elm_notify_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_NOTIFY_CLASS
@@ -19,7 +20,7 @@
 #define MY_CLASS_NAME "Elm_Notify"
 #define MY_CLASS_NAME_LEGACY "elm_notify"
 
-static Elm_Theme_Apply
+static Efl_Ui_Theme_Apply
 _notify_theme_apply(Evas_Object *obj)
 {
    const char *style = elm_widget_style_get(obj);
@@ -140,12 +141,12 @@ _sizing_eval(Evas_Object *obj)
    evas_object_resize(obj, w, h);
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_notify_elm_widget_theme_apply(Eo *obj, Elm_Notify_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_notify_efl_ui_widget_theme_apply(Eo *obj, Elm_Notify_Data *sd)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    _mirrored_set(obj, efl_ui_mirrored_get(obj));
 
@@ -153,21 +154,23 @@ _elm_notify_elm_widget_theme_apply(Eo *obj, Elm_Notify_Data *sd)
    if (sd->block_events) _block_events_theme_apply(obj);
 
    edje_object_scale_set
-     (sd->notify, efl_ui_scale_get(obj) * elm_config_scale_get());
+     (sd->notify, efl_gfx_entity_scale_get(obj) * elm_config_scale_get());
 
    _sizing_eval(obj);
 
    return int_ret;
 }
 
-EOLIAN static void
-_elm_notify_elm_widget_part_text_set(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, const char *part, const char *label)
+/* Legacy compat. Note that notify has no text parts in the default theme... */
+static void
+_elm_notify_text_set(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, const char *part, const char *label)
 {
    edje_object_part_text_set(sd->notify, part, label);
 }
 
-EOLIAN static const char*
-_elm_notify_elm_widget_part_text_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, const char *part)
+/* Legacy compat. Note that notify has no text parts in the default theme... */
+static const char*
+_elm_notify_text_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, const char *part)
 {
    return edje_object_part_text_get(sd->notify, part);
 }
@@ -199,10 +202,10 @@ _changed_size_hints_cb(void *data,
 }
 
 EOLIAN static Eina_Bool
-_elm_notify_elm_widget_sub_object_del(Eo *obj, Elm_Notify_Data *sd, Evas_Object *sobj)
+_elm_notify_efl_ui_widget_widget_sub_object_del(Eo *obj, Elm_Notify_Data *sd, Evas_Object *sobj)
 {
    Eina_Bool int_ret = EINA_FALSE;
-   int_ret = elm_obj_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
+   int_ret = elm_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
    if (!int_ret) return EINA_FALSE;
 
    if (sobj == sd->content)
@@ -226,36 +229,36 @@ _block_area_clicked_cb(void *data,
 }
 
 EOLIAN static void
-_elm_notify_efl_gfx_size_set(Eo *obj, Elm_Notify_Data *sd, Evas_Coord w, Evas_Coord h)
+_elm_notify_efl_gfx_entity_size_set(Eo *obj, Elm_Notify_Data *sd, Eina_Size2D sz)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
-   efl_gfx_size_set(efl_super(obj, MY_CLASS), w, h);
+   efl_gfx_entity_size_set(efl_super(obj, MY_CLASS), sz);
 
    if (!sd->parent && sd->content)
      {
-        Evas_Coord x, y;
+        Eina_Position2D pos;
 
-        efl_gfx_position_get(obj, &x, &y);
-        _notify_move_to_orientation(obj, x, y, w, h);
+        pos = efl_gfx_entity_position_get(obj);
+        _notify_move_to_orientation(obj, pos.x, pos.y, sz.w, sz.h);
      }
 }
 
 EOLIAN static void
-_elm_notify_efl_gfx_position_set(Eo *obj, Elm_Notify_Data *sd, Evas_Coord x, Evas_Coord y)
+_elm_notify_efl_gfx_entity_position_set(Eo *obj, Elm_Notify_Data *sd, Eina_Position2D pos)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, x, y))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, pos.x, pos.y))
      return;
 
-   efl_gfx_position_set(efl_super(obj, MY_CLASS), x, y);
+   efl_gfx_entity_position_set(efl_super(obj, MY_CLASS), pos);
 
    if (!sd->parent && sd->content)
      {
         Evas_Coord w, h;
 
         evas_object_geometry_get(obj, NULL, NULL, &w, &h);
-        _notify_move_to_orientation(obj, x, y, w, h);
+        _notify_move_to_orientation(obj, pos.x, pos.y, w, h);
      }
 }
 
@@ -293,7 +296,7 @@ _elm_notify_show(Eo *obj, Elm_Notify_Data *sd)
 {
    sd->had_hidden = EINA_FALSE;
    sd->in_timeout = EINA_FALSE;
-   efl_gfx_visible_set(efl_super(obj, MY_CLASS), EINA_TRUE);
+   efl_gfx_entity_visible_set(efl_super(obj, MY_CLASS), EINA_TRUE);
 
    evas_object_show(sd->notify);
    if (!sd->allow_events) evas_object_show(sd->block_events);
@@ -320,7 +323,7 @@ _elm_notify_hide(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
      }
    else //for backport supporting: edc without emitting hide finished signal
      {
-        efl_gfx_visible_set(efl_super(obj, MY_CLASS), EINA_FALSE);
+        efl_gfx_entity_visible_set(efl_super(obj, MY_CLASS), EINA_FALSE);
         evas_object_hide(sd->notify);
         if (sd->allow_events) evas_object_hide(sd->block_events);
      }
@@ -328,7 +331,7 @@ _elm_notify_hide(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
 }
 
 EOLIAN static void
-_elm_notify_efl_gfx_visible_set(Eo *obj, Elm_Notify_Data *sd, Eina_Bool vis)
+_elm_notify_efl_gfx_entity_visible_set(Eo *obj, Elm_Notify_Data *sd, Eina_Bool vis)
 {
    if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_VISIBLE, 0, vis))
      return;
@@ -356,43 +359,6 @@ _parent_hide_cb(void *data,
    evas_object_hide(data);
 }
 
-EOLIAN static Eina_Bool
-_elm_notify_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_notify_elm_widget_focus_next(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Evas_Object *cur;
-
-   if (!sd->content) return EINA_FALSE;
-
-   cur = sd->content;
-
-   /* Try to cycle focus on content */
-   return elm_widget_focus_next_get(cur, dir, next, next_item);
-}
-
-EOLIAN static Eina_Bool
-_elm_notify_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_notify_elm_widget_focus_direction(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Evas_Object *cur;
-
-   if (!sd->content) return EINA_FALSE;
-
-   cur = sd->content;
-
-   return elm_widget_focus_direction_get(cur, base, degree, direction, direction_item, weight);
-}
-
 static Eina_Bool
 _elm_notify_content_set(Eo *obj, Elm_Notify_Data *sd, const char *part, Evas_Object *content)
 {
@@ -417,7 +383,7 @@ _elm_notify_content_set(Eo *obj, Elm_Notify_Data *sd, const char *part, Evas_Obj
 }
 
 static Evas_Object*
-_elm_notify_content_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, const char *part)
+_elm_notify_content_get(const Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, const char *part)
 {
    if (part && strcmp(part, "default")) return NULL;
 
@@ -440,21 +406,21 @@ _elm_notify_content_unset(Eo *obj, Elm_Notify_Data *sd, const char *part)
 }
 
 EOLIAN static Eina_Bool
-_elm_notify_efl_container_content_set(Eo *obj, Elm_Notify_Data *sd, Evas_Object *content)
+_elm_notify_efl_content_content_set(Eo *obj, Elm_Notify_Data *sd, Evas_Object *content)
 {
-   return _elm_notify_content_set(obj, sd, NULL, content);
+   return _elm_notify_content_set(obj, sd, "default", content);
 }
 
 EOLIAN static Evas_Object*
-_elm_notify_efl_container_content_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
+_elm_notify_efl_content_content_get(const Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
 {
-   return _elm_notify_content_get(obj, sd, NULL);
+   return _elm_notify_content_get(obj, sd, "default");
 }
 
 EOLIAN static Evas_Object*
-_elm_notify_efl_container_content_unset(Eo *obj, Elm_Notify_Data *sd)
+_elm_notify_efl_content_content_unset(Eo *obj, Elm_Notify_Data *sd)
 {
-   return _elm_notify_content_unset(obj, sd, NULL);
+   return _elm_notify_content_unset(obj, sd, "default");
 }
 
 static void
@@ -467,7 +433,7 @@ _hide_finished_cb(void *data,
    sd->had_hidden = EINA_TRUE;
    evas_object_hide(sd->notify);
    if (!sd->allow_events) evas_object_hide(sd->block_events);
-   efl_gfx_visible_set(efl_super(data, MY_CLASS), EINA_FALSE);
+   efl_gfx_entity_visible_set(efl_super(data, MY_CLASS), EINA_FALSE);
    efl_event_callback_legacy_call(data, ELM_NOTIFY_EVENT_DISMISSED, NULL);
 }
 
@@ -495,7 +461,6 @@ _elm_notify_efl_canvas_group_group_del(Eo *obj, Elm_Notify_Data *sd)
    edje_object_signal_callback_del_full
       (sd->notify, "elm,action,hide,finished", "elm", _hide_finished_cb, obj);
    elm_notify_parent_set(obj, NULL);
-   elm_notify_allow_events_set(obj, EINA_FALSE);
    ecore_timer_del(sd->timer);
 
    ELM_SAFE_FREE(sd->notify, evas_object_del);
@@ -506,7 +471,7 @@ EAPI Evas_Object *
 elm_notify_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EOLIAN static Eo *
@@ -514,7 +479,7 @@ _elm_notify_efl_object_constructor(Eo *obj, Elm_Notify_Data *sd EINA_UNUSED)
 {
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_NOTIFICATION);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_NOTIFICATION);
 
    return obj;
 }
@@ -524,11 +489,11 @@ elm_notify_parent_set(Evas_Object *obj,
                       Evas_Object *parent)
 {
    ELM_NOTIFY_CHECK(obj);
-   elm_obj_widget_parent_set(obj, parent);
+   efl_ui_widget_parent_set(obj, parent);
 }
 
 EOLIAN static void
-_elm_notify_elm_widget_widget_parent_set(Eo *obj, Elm_Notify_Data *sd, Evas_Object *parent)
+_elm_notify_efl_ui_widget_widget_parent_set(Eo *obj, Elm_Notify_Data *sd, Evas_Object *parent)
 {
    if (sd->parent)
      {
@@ -570,12 +535,12 @@ elm_notify_parent_get(const Evas_Object *obj)
 {
    ELM_NOTIFY_CHECK(obj) NULL;
    Evas_Object *ret = NULL;
-   ret = elm_obj_widget_parent_get((Eo *) obj);
+   ret = efl_ui_widget_parent_get((Eo *) obj);
    return ret;
 }
 
 EOLIAN static Evas_Object*
-_elm_notify_elm_widget_widget_parent_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
+_elm_notify_efl_ui_widget_widget_parent_get(const Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
 {
    return sd->parent;
 }
@@ -670,7 +635,7 @@ _elm_notify_timeout_set(Eo *obj, Elm_Notify_Data *sd, double timeout)
 }
 
 EOLIAN static double
-_elm_notify_timeout_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
+_elm_notify_timeout_get(const Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
 {
    return sd->timeout;
 }
@@ -684,7 +649,7 @@ _elm_notify_allow_events_set(Eo *obj, Elm_Notify_Data *sd, Eina_Bool allow)
      {
         sd->block_events = elm_layout_add(obj);
         _block_events_theme_apply(obj);
-        elm_widget_resize_object_set(obj, sd->block_events, EINA_TRUE);
+        elm_widget_resize_object_set(obj, sd->block_events);
         evas_object_stack_above(sd->notify, sd->block_events);
         elm_layout_signal_callback_add
           (sd->block_events, "elm,action,click", "elm",
@@ -698,7 +663,7 @@ _elm_notify_allow_events_set(Eo *obj, Elm_Notify_Data *sd, Eina_Bool allow)
 }
 
 EOLIAN static Eina_Bool
-_elm_notify_allow_events_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
+_elm_notify_allow_events_get(const Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
 {
    return sd->allow_events;
 }
@@ -722,7 +687,7 @@ _elm_notify_dismiss(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd)
 
 
 EOLIAN static void
-_elm_notify_align_get(Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, double *horizontal, double *vertical)
+_elm_notify_align_get(const Eo *obj EINA_UNUSED, Elm_Notify_Data *sd, double *horizontal, double *vertical)
 {
    if (horizontal)
      *horizontal = sd->horizontal_align;
@@ -738,12 +703,29 @@ _elm_notify_class_constructor(Efl_Class *klass)
 
 /* Efl.Part begin */
 
-ELM_PART_IMPLEMENT(elm_notify, ELM_NOTIFY, Elm_Notify_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_SET(elm_notify, ELM_NOTIFY, Elm_Notify_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_GET(elm_notify, ELM_NOTIFY, Elm_Notify_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_UNSET(elm_notify, ELM_NOTIFY, Elm_Notify_Data, Elm_Part_Data)
-ELM_PART_CONTENT_DEFAULT_SET(elm_notify, "default")
-#include "elm_notify_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_notify, ELM_NOTIFY, Elm_Notify_Data)
+ELM_PART_OVERRIDE_TEXT_SET(elm_notify, ELM_NOTIFY, Elm_Notify_Data)
+ELM_PART_OVERRIDE_TEXT_GET(elm_notify, ELM_NOTIFY, Elm_Notify_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_notify, ELM_NOTIFY, Elm_Notify_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(elm_notify, ELM_NOTIFY, Elm_Notify_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_notify, ELM_NOTIFY, Elm_Notify_Data)
+ELM_PART_CONTENT_DEFAULT_GET(elm_notify, "default")
+
+EOLIAN static const char *
+_elm_notify_part_efl_ui_translatable_translatable_text_get(const Eo *obj, void *_pd EINA_UNUSED, const char **domain)
+{
+   Elm_Part_Data *pd = efl_data_scope_get(obj, EFL_UI_WIDGET_PART_CLASS);
+   return elm_widget_part_translatable_text_get(pd->obj, pd->part, domain);
+}
+
+EOLIAN static void
+_elm_notify_part_efl_ui_translatable_translatable_text_set(Eo *obj, void *_pd EINA_UNUSED, const char *label, const char *domain)
+{
+   Elm_Part_Data *pd = efl_data_scope_get(obj, EFL_UI_WIDGET_PART_CLASS);
+   elm_widget_part_translatable_text_set(pd->obj, pd->part, label, domain);
+}
+
+#include "elm_notify_part.eo.c"
 
 /* Efl.Part end */
 
