@@ -2,8 +2,10 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define EFL_UI_FOCUS_LAYER_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 
@@ -12,7 +14,7 @@
 
 #include "els_box.h"
 
-#include "elm_panel_internal_part.eo.h"
+#include "elm_panel_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_PANEL_CLASS
@@ -48,7 +50,7 @@ _mirrored_set(Evas_Object *obj,
 {
    ELM_PANEL_DATA_GET(obj, sd);
 
-   if ((sd->content) && (efl_isa(sd->content, ELM_WIDGET_CLASS)))
+   if ((sd->content) && (efl_isa(sd->content, EFL_UI_WIDGET_CLASS)))
      efl_ui_mirrored_set(sd->content, rtl);
    elm_panel_orient_set(obj, elm_panel_orient_get(obj));
 }
@@ -64,11 +66,8 @@ _elm_panel_elm_layout_sizing_eval(Eo *obj, Elm_Panel_Data *sd)
 
    if (sd->scrollable)
      {
-        int w, h;
-        evas_object_geometry_get(obj, NULL, NULL, &w, &h);
-
-        if (sd->hidden) _drawer_close(obj, w, h, EINA_FALSE);
-        else _drawer_open(obj, w, h, EINA_FALSE);
+        if (sd->hidden) _drawer_close(obj, wd->w, wd->h, EINA_FALSE);
+        else _drawer_open(obj, wd->w, wd->h, EINA_FALSE);
      }
 
    evas_object_smart_calculate(sd->bx);
@@ -91,11 +90,13 @@ _access_state_cb(void *data, Evas_Object *obj EINA_UNUSED)
 static Evas_Object *
 _access_object_get(const Evas_Object *obj, const char *part)
 {
-   Evas_Object *po, *ao;
+   Evas_Object *po, *ao, *o;
    ELM_PANEL_DATA_GET(obj, sd);
 
-   po = (Evas_Object *)edje_object_part_object_get
-      (elm_layout_edje_get(sd->scr_ly), part);
+   o = elm_layout_edje_get(sd->scr_ly);
+   edje_object_freeze(o);
+   po = (Evas_Object *)edje_object_part_object_get(o, part);
+   edje_object_thaw(o);
    ao = evas_object_data_get(po, "_part_access_obj");
 
    return ao;
@@ -215,18 +216,18 @@ _scrollable_layout_theme_set(Eo *obj, Elm_Panel_Data *sd)
      _access_obj_process(obj, EINA_TRUE);
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_panel_elm_widget_theme_apply(Eo *obj, Elm_Panel_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_panel_efl_ui_widget_theme_apply(Eo *obj, Elm_Panel_Data *sd)
 {
    const char *str;
    Evas_Coord minw = 0, minh = 0;
 
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
 
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, ELM_THEME_APPLY_FAILED);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EFL_UI_THEME_APPLY_FAILED);
 
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    _mirrored_set(obj, efl_ui_mirrored_get(obj));
 
@@ -259,68 +260,12 @@ _elm_panel_elm_widget_theme_apply(Eo *obj, Elm_Panel_Data *sd)
           efl_content_set(efl_part(efl_super(obj, MY_CLASS), "elm.swallow.event"), sd->event);
      }
 
-   elm_layout_sizing_eval(obj);
+   if (efl_finalized_get(obj))
+     elm_layout_sizing_eval(obj);
 
    return int_ret;
 }
 
-EOLIAN static Eina_Bool
-_elm_panel_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Panel_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_panel_elm_widget_focus_next(Eo *obj, Elm_Panel_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Evas_Object *cur;
-   Eina_List *items = NULL;
-   Eina_Bool ret = EINA_FALSE;
-
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EINA_FALSE);
-
-   if (!sd->content) return EINA_FALSE;
-
-   if (sd->scrollable)
-     {
-        if (sd->hidden) return EINA_FALSE;
-
-        if (_elm_config->access_mode == ELM_ACCESS_MODE_ON)
-          {
-             Evas_Object *ao = _access_object_get(obj, ACCESS_OUTLINE_PART);
-             if (ao) items = eina_list_append(items, ao);
-             items = eina_list_append(items, sd->content);
-
-             ret = elm_widget_focus_list_next_get
-                (obj, items, eina_list_data_get, dir, next, next_item);
-             eina_list_free(items);
-
-             return ret;
-          }
-
-        return elm_widget_focus_next_get(sd->content, dir, next, next_item);
-     }
-
-   cur = sd->content;
-
-   /* Try to Focus cycle in subitem */
-   if (!sd->hidden) return elm_widget_focus_next_get(cur, dir, next, next_item);
-
-   /* access */
-   if (_elm_config->access_mode != ELM_ACCESS_MODE_OFF)
-     {
-        Evas_Object *ao, *po;
-        po = (Evas_Object *)edje_object_part_object_get
-               (wd->resize_obj, "btn_icon");
-        ao = evas_object_data_get(po, "_part_access_obj");
-        _elm_access_highlight_set(ao);
-     }
-
-   /* Return */
-   *next = (Evas_Object *)obj;
-   return !elm_widget_focus_get(obj);
-}
-
 static void
 _box_layout_cb(Evas_Object *o,
                Evas_Object_Box_Data *priv,
@@ -366,7 +311,7 @@ _drawer_open(Evas_Object *obj, Evas_Coord w, Evas_Coord h, Eina_Bool anim)
    if (sd->freeze)
      {
         elm_interface_scrollable_movement_block_set
-              (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+              (obj, EFL_UI_SCROLL_BLOCK_NONE);
         sd->freeze = EINA_FALSE;
         elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
      }
@@ -402,7 +347,7 @@ static void
 _drawer_close(Evas_Object *obj, Evas_Coord w, Evas_Coord h, Eina_Bool anim)
 {
    ELM_PANEL_DATA_GET(obj, sd);
-   int x = 0, y = 0;
+   int x = 0, y = 0, cx, cy;
    Eina_Bool horizontal = EINA_FALSE;
 
    elm_widget_tree_unfocusable_set(obj, EINA_TRUE);
@@ -428,12 +373,31 @@ _drawer_close(Evas_Object *obj, Evas_Coord w, Evas_Coord h, Eina_Bool anim)
          break;
      }
 
+   elm_interface_scrollable_content_pos_get(obj, &cx, &cy);
+
+   if ((x == cx) && (y == cy))
+     {
+        if (!sd->freeze)
+          {
+             if (horizontal)
+               elm_interface_scrollable_movement_block_set
+                  (obj, EFL_UI_SCROLL_BLOCK_HORIZONTAL);
+             else
+               elm_interface_scrollable_movement_block_set
+                  (obj, EFL_UI_SCROLL_BLOCK_VERTICAL);
+             sd->freeze = EINA_TRUE;
+             elm_layout_signal_emit(sd->scr_ly, "elm,state,content,hidden", "elm");
+          }
+
+        return;
+     }
+
    if (anim)
      {
         if (sd->freeze)
           {
              elm_interface_scrollable_movement_block_set
-                   (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+                   (obj, EFL_UI_SCROLL_BLOCK_NONE);
              sd->freeze = EINA_FALSE;
              elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
           }
@@ -446,10 +410,10 @@ _drawer_close(Evas_Object *obj, Evas_Coord w, Evas_Coord h, Eina_Bool anim)
           {
              if (horizontal)
                elm_interface_scrollable_movement_block_set
-                     (obj, ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL);
+                     (obj, EFL_UI_SCROLL_BLOCK_HORIZONTAL);
              else
                elm_interface_scrollable_movement_block_set
-                     (obj, ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL);
+                     (obj, EFL_UI_SCROLL_BLOCK_VERTICAL);
              sd->freeze = EINA_TRUE;
              elm_layout_signal_emit(sd->scr_ly, "elm,state,content,hidden", "elm");
           }
@@ -495,16 +459,14 @@ _panel_toggle(void *data EINA_UNUSED,
              elm_layout_signal_emit(obj, "elm,action,hide", "elm");
              sd->hidden = EINA_TRUE;
              evas_object_repeat_events_set(obj, EINA_TRUE);
-             if (sd->content && elm_widget_focus_get(sd->content))
-               {
-                  elm_widget_focused_object_clear(obj);
-                  elm_widget_focus_steal(obj, NULL);
-               }
           }
 
+        //if the panel is hidden, make this thing unfocusable
+        elm_widget_tree_unfocusable_set(obj, sd->hidden);
         edje_object_message_signal_process(wd->resize_obj);
      }
 
+   efl_ui_focus_layer_enable_set(obj, !sd->hidden);
    efl_event_callback_legacy_call(obj, ELM_PANEL_EVENT_TOGGLED, NULL);
 }
 
@@ -577,7 +539,7 @@ _timer_cb(void *data)
    if (sd->freeze)
      {
         elm_interface_scrollable_movement_block_set
-              (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+              (obj, EFL_UI_SCROLL_BLOCK_NONE);
         sd->freeze = EINA_FALSE;
         elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
         evas_object_geometry_get(obj, NULL, NULL, &w, &h);
@@ -685,7 +647,7 @@ _on_mouse_move(void *data,
          if (sd->timer && ((cur_y - sd->down_y) > finger_size))
            {
               elm_interface_scrollable_movement_block_set
-                 (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+                 (obj, EFL_UI_SCROLL_BLOCK_NONE);
               sd->freeze = EINA_FALSE;
               elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
            }
@@ -694,7 +656,7 @@ _on_mouse_move(void *data,
          if (sd->timer && ((sd->down_y - cur_y) > finger_size))
            {
               elm_interface_scrollable_movement_block_set
-                 (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+                 (obj, EFL_UI_SCROLL_BLOCK_NONE);
               sd->freeze = EINA_FALSE;
               elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
            }
@@ -704,7 +666,7 @@ _on_mouse_move(void *data,
               ((is_mirrored) && (sd->timer) && ((sd->down_x - cur_x) > finger_size)))
            {
               elm_interface_scrollable_movement_block_set
-                 (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+                 (obj, EFL_UI_SCROLL_BLOCK_NONE);
               sd->freeze = EINA_FALSE;
               elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
            }
@@ -714,7 +676,7 @@ _on_mouse_move(void *data,
               (!is_mirrored && (sd->timer) && ((sd->down_x - cur_x) > finger_size)))
            {
               elm_interface_scrollable_movement_block_set
-                 (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+                 (obj, EFL_UI_SCROLL_BLOCK_NONE);
               sd->freeze = EINA_FALSE;
               elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
            }
@@ -760,18 +722,14 @@ _key_action_toggle(Evas_Object *obj, const char *params EINA_UNUSED)
    return EINA_TRUE;
 }
 
+// _panel_elm_widget_widget_event
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(panel, Elm_Panel_Data)
+
 EOLIAN static Eina_Bool
-_elm_panel_elm_widget_widget_event(Eo *obj, Elm_Panel_Data *_pd EINA_UNUSED, Evas_Object *src, Evas_Callback_Type type, void *event_info)
+_elm_panel_efl_ui_widget_widget_event(Eo *obj, Elm_Panel_Data *pd, const Efl_Event *eo_event, Evas_Object *src)
 {
-   Evas_Event_Key_Down *ev = event_info;
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
    if (src != obj) return EINA_FALSE;
-
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions)) return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
+   return _panel_efl_ui_widget_widget_event(obj, pd, eo_event, src);
 }
 
 static Eina_Bool
@@ -785,7 +743,7 @@ _elm_panel_content_set(Eo *obj, Elm_Panel_Data *sd, const char *part, Evas_Objec
              ERR("elm.swallow.event is being used for panel internally. Don't touch this part!");
              return EINA_FALSE;
           }
-        if (strcmp(part, "default"))
+        if (strcmp(part, "elm.swallow.content") || (content == sd->bx))
           {
              Eina_Bool int_ret = EINA_TRUE;
              int_ret = efl_content_set(efl_part(efl_super(obj, MY_CLASS), part), content);
@@ -803,9 +761,12 @@ _elm_panel_content_set(Eo *obj, Elm_Panel_Data *sd, const char *part, Evas_Objec
         evas_object_show(sd->content);
         if (sd->scrollable)
           elm_widget_sub_object_add(sd->scr_ly, sd->content);
+        else
+          elm_widget_sub_object_add(obj, sd->content);
      }
 
-   elm_layout_sizing_eval(obj);
+   if (efl_finalized_get(obj))
+     elm_layout_sizing_eval(obj);
 
    return EINA_TRUE;
 }
@@ -821,7 +782,7 @@ _elm_panel_content_get(Eo *obj, Elm_Panel_Data *sd, const char *part)
              ERR("elm.swallow.event is being used for panel internally. Don't touch this part!");
              return NULL;
           }
-        if (strcmp(part, "default"))
+        if (strcmp(part, "elm.swallow.content"))
           {
              Evas_Object *ret = NULL;
              ret = efl_content_get(efl_part(efl_super(obj, MY_CLASS), part));
@@ -845,7 +806,7 @@ _elm_panel_content_unset(Eo *obj, Elm_Panel_Data *sd, const char *part)
              ERR("elm.swallow.event is being used for panel internally. Don't touch this part!");
              return NULL;
           }
-        if (strcmp(part, "default"))
+        if (strcmp(part, "elm.swallow.content"))
           {
              ret = efl_content_unset(efl_part(efl_super(obj, MY_CLASS), part));
              return ret;
@@ -874,7 +835,7 @@ _elm_panel_efl_canvas_group_group_add(Eo *obj, Elm_Panel_Data *priv)
 
    priv->panel_edje = wd->resize_obj;
 
-   elm_obj_widget_theme_apply(obj);
+   efl_ui_widget_theme_apply(obj);
 
    priv->bx = evas_object_box_add(evas_object_evas_get(obj));
    evas_object_box_layout_set(priv->bx, _box_layout_cb, priv, NULL);
@@ -907,8 +868,6 @@ _elm_panel_efl_canvas_group_group_add(Eo *obj, Elm_Panel_Data *priv)
              efl_content_set(efl_part(efl_super(obj, MY_CLASS), "elm.swallow.event"), priv->event);
           }
      }
-
-   elm_layout_sizing_eval(obj);
 }
 
 EOLIAN static void
@@ -939,14 +898,13 @@ _elm_panel_efl_canvas_group_group_del(Eo *obj, Elm_Panel_Data *sd)
 }
 
 EOLIAN static void
-_elm_panel_efl_gfx_position_set(Eo *obj, Elm_Panel_Data *sd, Evas_Coord x, Evas_Coord y)
+_elm_panel_efl_gfx_entity_position_set(Eo *obj, Elm_Panel_Data *sd, Eina_Position2D pos)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, x, y))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, pos.x, pos.y))
      return;
 
-   efl_gfx_position_set(efl_super(obj, MY_CLASS), x, y);
-
-   evas_object_move(sd->hit_rect, x, y);
+   efl_gfx_entity_position_set(efl_super(obj, MY_CLASS), pos);
+   efl_gfx_entity_position_set(sd->hit_rect, pos);
 }
 
 static void
@@ -969,23 +927,22 @@ _scrollable_layout_resize(Eo *obj, Elm_Panel_Data *sd, Evas_Coord w, Evas_Coord
          evas_object_size_hint_min_set(sd->scr_event, w, h);
          break;
      }
-
-   elm_layout_sizing_eval(obj);
+   if (efl_finalized_get(obj))
+     elm_layout_sizing_eval(obj);
 }
 
 EOLIAN static void
-_elm_panel_efl_gfx_size_set(Eo *obj, Elm_Panel_Data *sd, Evas_Coord w, Evas_Coord h)
+_elm_panel_efl_gfx_entity_size_set(Eo *obj, Elm_Panel_Data *sd, Eina_Size2D sz)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
-   efl_gfx_size_set(efl_super(obj, MY_CLASS), w, h);
+   efl_gfx_entity_size_set(efl_super(obj, MY_CLASS), sz);
 
    if (!sd->scrollable) return;
 
-   evas_object_resize(sd->hit_rect, w, h);
-
-   _scrollable_layout_resize(obj, sd, w, h);
+   efl_gfx_entity_size_set(sd->hit_rect, sz);
+   _scrollable_layout_resize(obj, sd, sz.w, sz.h);
 }
 
 EOLIAN static void
@@ -997,7 +954,7 @@ _elm_panel_efl_canvas_group_group_member_add(Eo *obj, Elm_Panel_Data *sd, Evas_O
 }
 
 EOLIAN static void
-_elm_panel_elm_widget_access(Eo *obj, Elm_Panel_Data *_pd, Eina_Bool is_access)
+_elm_panel_efl_ui_widget_on_access_update(Eo *obj, Elm_Panel_Data *_pd, Eina_Bool is_access)
 {
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd);
    Elm_Panel_Data *sd = _pd;
@@ -1020,7 +977,7 @@ EAPI Evas_Object *
 elm_panel_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   Evas_Object *obj = efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   Evas_Object *obj = elm_legacy_add(MY_CLASS, parent);
 
    ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, NULL);
    wd->highlight_root = EINA_TRUE;
@@ -1034,7 +991,9 @@ _elm_panel_efl_object_constructor(Eo *obj, Elm_Panel_Data *_pd EINA_UNUSED)
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_PANEL);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_PANEL);
+
+   efl_ui_focus_layer_behaviour_set(obj, EINA_FALSE, EINA_FALSE);
 
    return obj;
 }
@@ -1056,12 +1015,12 @@ _elm_panel_orient_set(Eo *obj, Elm_Panel_Data *sd, Elm_Panel_Orient orient)
                   case ELM_PANEL_ORIENT_TOP:
                   case ELM_PANEL_ORIENT_BOTTOM:
                      elm_interface_scrollable_movement_block_set
-                           (obj, ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL);
+                           (obj, EFL_UI_SCROLL_BLOCK_VERTICAL);
                      break;
                   case ELM_PANEL_ORIENT_LEFT:
                   case ELM_PANEL_ORIENT_RIGHT:
                      elm_interface_scrollable_movement_block_set
-                           (obj, ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL);
+                           (obj, EFL_UI_SCROLL_BLOCK_HORIZONTAL);
                      break;
                }
 
@@ -1074,11 +1033,12 @@ _elm_panel_orient_set(Eo *obj, Elm_Panel_Data *sd, Elm_Panel_Orient orient)
    else
      _orient_set_do(obj);
 
-   elm_layout_sizing_eval(obj);
+   if (efl_finalized_get(obj))
+     elm_layout_sizing_eval(obj);
 }
 
 EOLIAN static Elm_Panel_Orient
-_elm_panel_orient_get(Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
+_elm_panel_orient_get(const Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
 {
    return sd->orient;
 }
@@ -1101,7 +1061,7 @@ _elm_panel_hidden_set(Eo *obj, Elm_Panel_Data *sd, Eina_Bool hidden)
 }
 
 EOLIAN static Eina_Bool
-_elm_panel_hidden_get(Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
+_elm_panel_hidden_get(const Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
 {
    return sd->hidden;
 }
@@ -1112,28 +1072,28 @@ _elm_panel_toggle(Eo *obj, Elm_Panel_Data *_pd EINA_UNUSED)
    _panel_toggle(NULL, obj, NULL, NULL);
 }
 
-EOLIAN static Eina_Bool
-_elm_panel_elm_widget_on_focus_region(Eo *obj,
-                                      Elm_Panel_Data *sd,
-                                      Evas_Coord *x,
-                                      Evas_Coord *y,
-                                      Evas_Coord *w,
-                                      Evas_Coord *h)
+EOLIAN static Eina_Rect
+_elm_panel_efl_ui_widget_interest_region_get(const Eo *obj, Elm_Panel_Data *sd)
 {
-   elm_interface_scrollable_content_pos_get(obj, x, y);
-   evas_object_geometry_get(obj, NULL, NULL, w, h);
+   Eina_Rect r = {};
+
+   elm_interface_scrollable_content_pos_get(obj, &r.x, &r.y);
+   evas_object_geometry_get(obj, NULL, NULL, &r.w, &r.h);
    switch (sd->orient)
      {
       case ELM_PANEL_ORIENT_TOP:
       case ELM_PANEL_ORIENT_BOTTOM:
-         *h = *h * sd->content_size_ratio;
+         r.h *= sd->content_size_ratio;
          break;
       case ELM_PANEL_ORIENT_LEFT:
       case ELM_PANEL_ORIENT_RIGHT:
-         *w = *w * sd->content_size_ratio;
+         r.w *= sd->content_size_ratio;
          break;
      }
-   return EINA_TRUE;
+   if (r.w < 1) r.w = 1;
+   if (r.h < 1) r.h = 1;
+
+   return r;
 }
 
 static void
@@ -1202,10 +1162,10 @@ _anim_stop_cb(Evas_Object *obj, void *data EINA_UNUSED)
      {
         if (horizontal)
           elm_interface_scrollable_movement_block_set
-                (obj, ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL);
+                (obj, EFL_UI_SCROLL_BLOCK_HORIZONTAL);
         else
           elm_interface_scrollable_movement_block_set
-                (obj, ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL);
+                (obj, EFL_UI_SCROLL_BLOCK_VERTICAL);
         sd->freeze = EINA_TRUE;
         elm_layout_signal_emit(sd->scr_ly, "elm,state,content,hidden", "elm");
 
@@ -1235,7 +1195,7 @@ _scroll_cb(Evas_Object *obj, void *data EINA_UNUSED)
    if (sd->freeze)
      {
         elm_interface_scrollable_movement_block_set
-              (obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
+              (obj, EFL_UI_SCROLL_BLOCK_NONE);
         sd->freeze = EINA_FALSE;
         elm_layout_signal_emit(sd->scr_ly, "elm,state,content,visible", "elm");
      }
@@ -1283,15 +1243,14 @@ _scroll_cb(Evas_Object *obj, void *data EINA_UNUSED)
 }
 
 EOLIAN static Eina_Bool
-_elm_panel_elm_widget_disable(Eo *obj, Elm_Panel_Data *sd)
+_elm_panel_efl_ui_widget_on_disabled_update(Eo *obj, Elm_Panel_Data *sd, Eina_Bool disabled)
 {
-   Eina_Bool int_ret = EINA_FALSE;
-   int_ret = elm_obj_widget_disable(efl_super(obj, MY_CLASS));
-   if (!int_ret) return EINA_FALSE;
+   if (!efl_ui_widget_on_disabled_update(efl_super(obj, MY_CLASS), disabled))
+     return EINA_FALSE;
 
    if (sd->scrollable)
      {
-        if (elm_widget_disabled_get(obj))
+        if (disabled && sd->callback_added)
           {
              evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_DOWN,
                                             _on_mouse_down);
@@ -1301,8 +1260,10 @@ _elm_panel_elm_widget_disable(Eo *obj, Elm_Panel_Data *sd)
                                             _on_mouse_up);
              evas_object_event_callback_del(sd->scr_event, EVAS_CALLBACK_MOUSE_UP,
                                             _event_mouse_up);
+
+             sd->callback_added = EINA_FALSE;
           }
-        else
+        else if (!disabled && !sd->callback_added)
           {
              evas_object_event_callback_add(obj, EVAS_CALLBACK_MOUSE_DOWN,
                                             _on_mouse_down, sd);
@@ -1312,6 +1273,8 @@ _elm_panel_elm_widget_disable(Eo *obj, Elm_Panel_Data *sd)
                                             _on_mouse_up, sd);
              evas_object_event_callback_add(sd->scr_event, EVAS_CALLBACK_MOUSE_UP,
                                             _event_mouse_up, obj);
+
+             sd->callback_added = EINA_TRUE;
           }
      }
 
@@ -1319,7 +1282,7 @@ _elm_panel_elm_widget_disable(Eo *obj, Elm_Panel_Data *sd)
 }
 
 EOLIAN static double
-_elm_panel_scrollable_content_size_get(Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
+_elm_panel_scrollable_content_size_get(const Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
 {
    return sd->content_size_ratio;
 }
@@ -1342,7 +1305,7 @@ _elm_panel_scrollable_content_size_set(Eo *obj, Elm_Panel_Data *sd, double ratio
 }
 
 EOLIAN static Eina_Bool
-_elm_panel_scrollable_get(Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
+_elm_panel_scrollable_get(const Eo *obj EINA_UNUSED, Elm_Panel_Data *sd)
 {
    return sd->scrollable;
 }
@@ -1358,7 +1321,7 @@ _elm_panel_scrollable_set(Eo *obj, Elm_Panel_Data *sd, Eina_Bool scrollable)
      {
         elm_layout_content_unset(obj, "elm.swallow.content");
 
-        elm_widget_resize_object_set(obj, NULL, EINA_TRUE);
+        elm_widget_resize_object_set(obj, NULL);
         elm_widget_sub_object_add(obj, sd->panel_edje);
 
         if (!sd->scr_edje)
@@ -1378,7 +1341,7 @@ _elm_panel_scrollable_set(Eo *obj, Elm_Panel_Data *sd, Eina_Bool scrollable)
                sd->handler_size = (int) (elm_object_scale_get(obj)) * (atoi(handler_size));
           }
 
-        elm_widget_resize_object_set(obj, sd->scr_edje, EINA_TRUE);
+        elm_widget_resize_object_set(obj, sd->scr_edje);
 
         if (!sd->hit_rect)
           {
@@ -1404,12 +1367,14 @@ _elm_panel_scrollable_set(Eo *obj, Elm_Panel_Data *sd, Eina_Bool scrollable)
              sd->scr_panel = evas_object_rectangle_add(evas_object_evas_get(obj));
              evas_object_color_set(sd->scr_panel, 0, 0, 0, 0);
              elm_widget_sub_object_add(obj, sd->scr_panel);
-             elm_layout_content_set(sd->scr_ly, "panel_area", sd->scr_panel);
+             if (!elm_layout_content_set(sd->scr_ly, "elm.panel_area", sd->scr_panel))
+               elm_layout_content_set(sd->scr_ly, "panel_area", sd->scr_panel);
 
              sd->scr_event = evas_object_rectangle_add(evas_object_evas_get(obj));
              evas_object_color_set(sd->scr_event, 0, 0, 0, 0);
              elm_widget_sub_object_add(obj, sd->scr_event);
-             elm_layout_content_set(sd->scr_ly, "event_area", sd->scr_event);
+             if (!elm_layout_content_set(sd->scr_ly, "elm.event_area", sd->scr_event))
+               elm_layout_content_set(sd->scr_ly, "event_area", sd->scr_event);
           }
 
         elm_interface_scrollable_content_set(obj, sd->scr_ly);
@@ -1422,19 +1387,19 @@ _elm_panel_scrollable_set(Eo *obj, Elm_Panel_Data *sd, Eina_Bool scrollable)
            case ELM_PANEL_ORIENT_TOP:
            case ELM_PANEL_ORIENT_BOTTOM:
               elm_interface_scrollable_movement_block_set
-                    (obj, ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL);
+                    (obj, EFL_UI_SCROLL_BLOCK_VERTICAL);
               break;
            case ELM_PANEL_ORIENT_LEFT:
            case ELM_PANEL_ORIENT_RIGHT:
               elm_interface_scrollable_movement_block_set
-                    (obj, ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL);
+                    (obj, EFL_UI_SCROLL_BLOCK_HORIZONTAL);
               break;
           }
 
         elm_interface_scrollable_single_direction_set
               (obj, ELM_SCROLLER_SINGLE_DIRECTION_NONE);
 
-        if (!elm_widget_disabled_get(obj))
+        if (!elm_widget_disabled_get(obj) && !sd->callback_added)
           {
              evas_object_event_callback_add(obj, EVAS_CALLBACK_MOUSE_DOWN,
                                             _on_mouse_down, sd);
@@ -1444,6 +1409,8 @@ _elm_panel_scrollable_set(Eo *obj, Elm_Panel_Data *sd, Eina_Bool scrollable)
                                             _on_mouse_up, sd);
              evas_object_event_callback_add(sd->scr_event, EVAS_CALLBACK_MOUSE_UP,
                                             _event_mouse_up, obj);
+
+             sd->callback_added = EINA_TRUE;
           }
 
      }
@@ -1451,20 +1418,25 @@ _elm_panel_scrollable_set(Eo *obj, Elm_Panel_Data *sd, Eina_Bool scrollable)
      {
         elm_interface_scrollable_content_set(obj, NULL);
 
-        evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_DOWN, _on_mouse_down);
-        evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_MOVE, _on_mouse_move);
-        evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_UP, _on_mouse_up);
-        evas_object_event_callback_del(sd->scr_event, EVAS_CALLBACK_MOUSE_UP,
-                                       _event_mouse_up);
+        if (sd->callback_added)
+          {
+             evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_DOWN, _on_mouse_down);
+             evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_MOVE, _on_mouse_move);
+             evas_object_event_callback_del(obj, EVAS_CALLBACK_MOUSE_UP, _on_mouse_up);
+             evas_object_event_callback_del(sd->scr_event, EVAS_CALLBACK_MOUSE_UP,
+                                            _event_mouse_up);
 
-        elm_widget_resize_object_set(obj, NULL, EINA_TRUE);
+             sd->callback_added = EINA_FALSE;
+          }
+
+        elm_widget_resize_object_set(obj, NULL);
         elm_widget_sub_object_add(obj, sd->scr_edje);
 
-        elm_widget_resize_object_set(obj, sd->panel_edje, EINA_TRUE);
+        elm_widget_resize_object_set(obj, sd->panel_edje);
 
         elm_layout_content_unset(sd->scr_ly, "elm.swallow.content");
         elm_layout_content_set(obj, "elm.swallow.content", sd->bx);
-        if (sd->content) elm_widget_sub_object_add(sd->bx, sd->content);
+        if (sd->content) elm_widget_sub_object_add(obj, sd->content);
      }
 }
 
@@ -1474,10 +1446,10 @@ _elm_panel_class_constructor(Efl_Class *klass)
    evas_smart_legacy_type_register(MY_CLASS_NAME_LEGACY, klass);
 }
 
-EOLIAN const Elm_Atspi_Action *
-_elm_panel_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Panel_Data *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_panel_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Panel_Data *pd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "toggle", "toggle", NULL, _key_action_toggle},
           { NULL, NULL, NULL, NULL }
    };
@@ -1486,17 +1458,18 @@ _elm_panel_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED
 
 /* Efl.Part begin */
 
-ELM_PART_IMPLEMENT(elm_panel, ELM_PANEL, Elm_Panel_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_SET(elm_panel, ELM_PANEL, Elm_Panel_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_GET(elm_panel, ELM_PANEL, Elm_Panel_Data, Elm_Part_Data)
-ELM_PART_IMPLEMENT_CONTENT_UNSET(elm_panel, ELM_PANEL, Elm_Panel_Data, Elm_Part_Data)
-#include "elm_panel_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_panel, ELM_PANEL, Elm_Panel_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_panel, ELM_PANEL, Elm_Panel_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(elm_panel, ELM_PANEL, Elm_Panel_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_panel, ELM_PANEL, Elm_Panel_Data)
+#include "elm_panel_part.eo.c"
 
 /* Efl.Part end */
 
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_PANEL_EXTRA_OPS \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_panel), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_panel)
 
 #include "elm_panel.eo.c"
