@@ -2,8 +2,9 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define EFL_PART_PROTECTED
 
 #include <Elementary.h>
 
@@ -12,7 +13,8 @@
 #include "elm_widget_layout.h"
 #include "elm_widget_scroller.h"
 
-#include "elm_scroller_internal_part.eo.h"
+#include "elm_scroller.eo.h"
+#include "elm_scroller_part.eo.h"
 #include "elm_part_helper.h"
 
 #define MY_CLASS ELM_SCROLLER_CLASS
@@ -134,7 +136,7 @@ _key_action_move(Evas_Object *obj, const char *params)
       Efl_Ui_Focus_Object *focused;
       Eina_Rectangle focused_geom, viewport;
 
-      focused = efl_ui_focus_manager_focused(obj);
+      focused = efl_ui_focus_manager_focus_get(obj);
 
       if (focused &&
           (!strcmp(dir, "next") ||
@@ -261,23 +263,7 @@ _key_action_move(Evas_Object *obj, const char *params)
 }
 
 EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_widget_event(Eo *obj, Elm_Scroller_Data *sd EINA_UNUSED, Evas_Object *src, Evas_Callback_Type type, void *event_info)
-{
-   (void) src;
-   Evas_Event_Key_Down *ev = event_info;
-
-   if (type != EVAS_CALLBACK_KEY_DOWN) return EINA_FALSE;
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
-
-   if (!_elm_config_key_binding_call(obj, MY_CLASS_NAME, ev, key_actions))
-     return EINA_FALSE;
-
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_activate(Eo *obj, Elm_Scroller_Data *_pd EINA_UNUSED, Elm_Activate act)
+_elm_scroller_efl_ui_widget_on_access_activate(Eo *obj, Elm_Scroller_Data *_pd EINA_UNUSED, Efl_Ui_Activate act)
 {
    Evas_Coord x = 0;
    Evas_Coord y = 0;
@@ -287,35 +273,35 @@ _elm_scroller_elm_widget_activate(Eo *obj, Elm_Scroller_Data *_pd EINA_UNUSED, E
    Evas_Coord page_y = 0;
 
    if (elm_widget_disabled_get(obj)) return EINA_FALSE;
-   if (act == ELM_ACTIVATE_DEFAULT) return EINA_FALSE;
+   if (act == EFL_UI_ACTIVATE_DEFAULT) return EINA_FALSE;
 
    elm_interface_scrollable_content_pos_get(obj, &x, &y);
    elm_interface_scrollable_page_size_get(obj, &page_x, &page_y);
    elm_interface_scrollable_content_viewport_geometry_get
          (obj, NULL, NULL, &v_w, &v_h);
 
-   if (act == ELM_ACTIVATE_UP)
+   if (act == EFL_UI_ACTIVATE_UP)
      {
         if (page_y < 0)
           y -= -(page_y * v_h) / 100;
         else
           y -= page_y;
      }
-   else if (act == ELM_ACTIVATE_DOWN)
+   else if (act == EFL_UI_ACTIVATE_DOWN)
      {
         if (page_y < 0)
           y += -(page_y * v_h) / 100;
         else
           y += page_y;
      }
-   else if (act == ELM_ACTIVATE_LEFT)
+   else if (act == EFL_UI_ACTIVATE_LEFT)
      {
         if (page_x < 0)
           x -= -(page_x * v_w) / 100;
         else
           x -= page_x;
      }
-   else if (act == ELM_ACTIVATE_RIGHT)
+   else if (act == EFL_UI_ACTIVATE_RIGHT)
      {
         if (page_x < 0)
           x += -(page_x * v_w) / 100;
@@ -341,7 +327,7 @@ _elm_scroller_elm_layout_sizing_eval(Eo *obj, Elm_Scroller_Data *sd)
 
    if (sd->content)
      {
-        efl_gfx_size_hint_combined_min_get(sd->content, &minw, &minh);
+        evas_object_size_hint_combined_min_get(sd->content, &minw, &minh);
         evas_object_size_hint_max_get(sd->content, &maxw, &maxh);
         evas_object_size_hint_weight_get(sd->content, &xw, &yw);
      }
@@ -399,15 +385,15 @@ static void
 _mirrored_set(Evas_Object *obj,
               Eina_Bool mirrored)
 {
-   elm_interface_scrollable_mirrored_set(obj, mirrored);
+   efl_ui_mirrored_set(obj, mirrored);
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_scroller_elm_widget_theme_apply(Eo *obj, Elm_Scroller_Data *sd EINA_UNUSED)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_scroller_efl_ui_widget_theme_apply(Eo *obj, Elm_Scroller_Data *sd EINA_UNUSED)
 {
-   Elm_Theme_Apply int_ret = ELM_THEME_APPLY_FAILED;
-   int_ret = elm_obj_widget_theme_apply(efl_super(obj, MY_CLASS));
-   if (!int_ret) return ELM_THEME_APPLY_FAILED;
+   Efl_Ui_Theme_Apply int_ret = EFL_UI_THEME_APPLY_FAILED;
+   int_ret = efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS));
+   if (!int_ret) return EFL_UI_THEME_APPLY_FAILED;
 
    _mirrored_set(obj, efl_ui_mirrored_get(obj));
 
@@ -416,145 +402,10 @@ _elm_scroller_elm_widget_theme_apply(Eo *obj, Elm_Scroller_Data *sd EINA_UNUSED)
    return int_ret;
 }
 
-EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Scroller_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_focus_next(Eo *obj EINA_UNUSED, Elm_Scroller_Data *sd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Evas_Object *cur;
-
-   if (!sd->content) return EINA_FALSE;
-
-   cur = sd->content;
-
-   /* access */
-   if (_elm_config->access_mode)
-     {
-        if ((elm_widget_can_focus_get(cur)) ||
-            (elm_widget_child_can_focus_get(cur)))
-          {
-             return elm_widget_focus_next_get(cur, dir, next, next_item);
-          }
-
-        return EINA_FALSE;
-     }
-
-   /* Try focus cycle in subitem */
-   if ((elm_widget_can_focus_get(cur)) ||
-       (elm_widget_child_can_focus_get(cur)))
-     {
-        Eina_Bool ret = EINA_FALSE;
-
-        ret =  elm_widget_focus_next_get(cur, dir, next, next_item);
-        if (*next)
-          {
-             Evas_Coord x = 0, y = 0;
-             Evas_Coord v_w = 0, v_h = 0;
-             Evas_Coord c_x = 0, c_y = 0;
-             Evas_Coord f_x = 0, f_y = 0, f_w = 0, f_h = 0;
-             Evas_Coord l_x = 0, l_y = 0, l_w = 0, l_h = 0;
-             Evas_Coord step_x = 0, step_y = 0;
-
-             elm_interface_scrollable_content_pos_get(obj, &x, &y);
-             elm_interface_scrollable_step_size_get(obj, &step_x, &step_y);
-             elm_interface_scrollable_content_viewport_geometry_get
-                (obj, NULL, NULL, &v_w, &v_h);
-             evas_object_geometry_get(sd->content, &c_x, &c_y, NULL, NULL);
-             evas_object_geometry_get(*next, &f_x, &f_y, &f_w, &f_h);
-             l_x = f_x - c_x - step_x;
-             l_y = f_y - c_y - step_y;
-             l_w = f_w + (step_x * 2);
-             l_h = f_h + (step_y * 2);
-
-             if (!ret || ELM_RECTS_INTERSECT(x, y, v_w, v_h, l_x, l_y, l_w, l_h))
-               return ret;
-          }
-     }
-
-   if (!(elm_widget_can_focus_get(obj)) &&
-       !(elm_widget_can_focus_get(cur)))
-      return EINA_FALSE;
-
-   /* Return */
-   *next = (Evas_Object *)obj;
-
-   return !elm_widget_focus_get(obj);
-}
-
-EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Scroller_Data *_pd EINA_UNUSED)
-{
-   return EINA_TRUE;
-}
-
-EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_focus_direction(Eo *obj, Elm_Scroller_Data *sd, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Evas_Object *cur;
-
-   if (!sd->content) return EINA_FALSE;
-
-   cur = sd->content;
-
-   /* access */
-   if (_elm_config->access_mode)
-     {
-        if ((elm_widget_can_focus_get(cur)) ||
-            (elm_widget_child_can_focus_get(cur)))
-          {
-             return elm_widget_focus_direction_get(cur, base, degree, direction, direction_item, weight);
-          }
-
-        return EINA_FALSE;
-     }
-
-   /* Try focus cycle in subitem */
-   if ((elm_widget_can_focus_get(cur)) ||
-       (elm_widget_child_can_focus_get(cur)))
-     {
-        Eina_Bool ret = EINA_FALSE;
-        Evas_Coord x = 0, y = 0;
-        Evas_Coord v_w = 0, v_h = 0;
-        Evas_Coord c_x = 0, c_y = 0;
-        Evas_Coord f_x = 0, f_y = 0, f_w = 0, f_h = 0;
-        Evas_Coord l_x = 0, l_y = 0, l_w = 0, l_h = 0;
-        Evas_Coord step_x = 0, step_y = 0;
-
-        ret = elm_widget_focus_direction_get(cur, base, degree, direction, direction_item, weight);
-
-        elm_interface_scrollable_content_pos_get(obj, &x, &y);
-        elm_interface_scrollable_step_size_get(obj, &step_x, &step_y);
-        elm_interface_scrollable_content_viewport_geometry_get
-              (obj, NULL, NULL, &v_w, &v_h);
-        evas_object_geometry_get(sd->content, &c_x, &c_y, NULL, NULL);
-        evas_object_geometry_get(*direction, &f_x, &f_y, &f_w, &f_h);
-        l_x = f_x - c_x - step_x;
-        l_y = f_y - c_y - step_y;
-        l_w = f_w + (step_x * 2);
-        l_h = f_h + (step_y * 2);
-
-        if (!ret || ELM_RECTS_INTERSECT(x, y, v_w, v_h, l_x, l_y, l_w, l_h))
-          return ret;
-     }
-
-   /* Return */
-   *direction = (Evas_Object *)obj;
-
-   return !elm_widget_focus_get(obj);
-}
-
 static void
-_show_region_hook(void *data,
-                  Evas_Object *content_obj)
+_show_region_hook(void *data, Evas_Object *content_obj EINA_UNUSED, Eina_Rect r)
 {
-   Evas_Coord x, y, w, h;
-
-   elm_widget_show_region_get(content_obj, &x, &y, &w, &h);
-   elm_interface_scrollable_content_region_show(data, x, y, w, h);
+   elm_interface_scrollable_content_region_show(data, r.x, r.y, r.w, r.h);
 }
 
 static void
@@ -567,16 +418,16 @@ _changed_size_hints_cb(void *data,
 }
 
 EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_sub_object_del(Eo *obj, Elm_Scroller_Data *sd, Evas_Object *sobj)
+_elm_scroller_efl_ui_widget_widget_sub_object_del(Eo *obj, Elm_Scroller_Data *sd, Evas_Object *sobj)
 {
    Eina_Bool int_ret = EINA_FALSE;
-   int_ret = elm_obj_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
+   int_ret = elm_widget_sub_object_del(efl_super(obj, MY_CLASS), sobj);
    if (!int_ret) return EINA_FALSE;
 
    if (sobj == sd->content)
      {
         if (elm_widget_is(sobj))
-          elm_widget_on_show_region_hook_set(sd->content, NULL, NULL);
+          elm_widget_on_show_region_hook_set(sd->content, NULL, NULL, NULL);
 
         sd->content = NULL;
      }
@@ -753,7 +604,7 @@ _loop_content_set(Evas_Object *obj, Elm_Scroller_Data *sd, Evas_Object *content)
         evas_object_size_hint_align_set(sd->contents, EVAS_HINT_FILL, EVAS_HINT_FILL);
 
         elm_widget_sub_object_add(obj, sd->contents);
-        elm_widget_on_show_region_hook_set(sd->contents, _show_region_hook, obj);
+        elm_widget_on_show_region_hook_set(sd->contents, obj, _show_region_hook, NULL);
 
         efl_ui_mirrored_automatic_set(sd->contents, EINA_FALSE);
         efl_ui_mirrored_set(sd->contents, EINA_FALSE);
@@ -795,7 +646,7 @@ _loop_content_set(Evas_Object *obj, Elm_Scroller_Data *sd, Evas_Object *content)
 static Eina_Bool
 _elm_scroller_content_set(Eo *obj, Elm_Scroller_Data *sd, const char *part, Evas_Object *content)
 {
-   if (part && strcmp(part, "default"))
+   if (part && strcmp(part, "elm.swallow.content"))
      {
         return efl_content_set(efl_part(efl_super(obj, MY_CLASS), part), content);
      }
@@ -808,7 +659,7 @@ _elm_scroller_content_set(Eo *obj, Elm_Scroller_Data *sd, const char *part, Evas
    if (content)
      {
         if (elm_widget_is(content))
-          elm_widget_on_show_region_hook_set(content, _show_region_hook, obj);
+          elm_widget_on_show_region_hook_set(content, obj, _show_region_hook, NULL);
         elm_widget_sub_object_add(obj, content);
 
         if (sd->loop_h || sd->loop_v)
@@ -836,9 +687,9 @@ _elm_scroller_content_set(Eo *obj, Elm_Scroller_Data *sd, const char *part, Evas
 }
 
 static Evas_Object*
-_elm_scroller_content_get(Eo *obj, Elm_Scroller_Data *sd, const char *part)
+_elm_scroller_content_get(const Eo *obj, Elm_Scroller_Data *sd, const char *part)
 {
-   if (part && strcmp(part, "default"))
+   if (part && strcmp(part, "elm.swallow.content"))
      {
         return efl_content_get(efl_part(efl_super(obj, MY_CLASS), part));
      }
@@ -850,7 +701,7 @@ static Evas_Object*
 _elm_scroller_content_unset(Eo *obj, Elm_Scroller_Data *sd, const char *part)
 {
    Evas_Object *ret = NULL;
-   if (part && strcmp(part, "default"))
+   if (part && strcmp(part, "elm.swallow.content"))
      {
         return efl_content_unset(efl_part(efl_super(obj, MY_CLASS), part));
      }
@@ -868,6 +719,24 @@ _elm_scroller_content_unset(Eo *obj, Elm_Scroller_Data *sd, const char *part)
    return ret;
 }
 
+EOLIAN static Eina_Bool
+_elm_scroller_efl_content_content_set(Eo *obj, Elm_Scroller_Data *sd, Eo *content)
+{
+   return _elm_scroller_content_set(obj, sd, "elm.swallow.content", content);
+}
+
+EOLIAN static Eo *
+_elm_scroller_efl_content_content_get(const Eo *obj, Elm_Scroller_Data *sd)
+{
+   return _elm_scroller_content_get(obj, sd, "elm.swallow.content");
+}
+
+EOLIAN static Eo *
+_elm_scroller_efl_content_content_unset(Eo *obj, Elm_Scroller_Data *sd)
+{
+   return _elm_scroller_content_unset(obj, sd, "elm.swallow.content");
+}
+
 static void
 _elm_scroller_content_min_limit_cb(Evas_Object *obj,
                                    Eina_Bool w,
@@ -949,25 +818,23 @@ _elm_scroller_efl_canvas_group_group_add(Eo *obj, Elm_Scroller_Data *priv)
 }
 
 EOLIAN static void
-_elm_scroller_efl_gfx_position_set(Eo *obj, Elm_Scroller_Data *sd, Evas_Coord x, Evas_Coord y)
+_elm_scroller_efl_gfx_entity_position_set(Eo *obj, Elm_Scroller_Data *sd, Eina_Position2D pos)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, x, y))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, pos.x, pos.y))
      return;
 
-   efl_gfx_position_set(efl_super(obj, MY_CLASS), x, y);
-
-   evas_object_move(sd->hit_rect, x, y);
+   efl_gfx_entity_position_set(efl_super(obj, MY_CLASS), pos);
+   efl_gfx_entity_position_set(sd->hit_rect, pos);
 }
 
 EOLIAN static void
-_elm_scroller_efl_gfx_size_set(Eo *obj, Elm_Scroller_Data *sd, Evas_Coord w, Evas_Coord h)
+_elm_scroller_efl_gfx_entity_size_set(Eo *obj, Elm_Scroller_Data *sd, Eina_Size2D sz)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
-   efl_gfx_size_set(efl_super(obj, MY_CLASS), w, h);
-
-   evas_object_resize(sd->hit_rect, w, h);
+   efl_gfx_entity_size_set(efl_super(obj, MY_CLASS), sz);
+   efl_gfx_entity_size_set(sd->hit_rect, sz);
 }
 
 EOLIAN static void
@@ -983,7 +850,35 @@ EAPI Evas_Object *
 elm_scroller_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
+}
+
+static void
+_focused_element(void *data, const Efl_Event *event)
+{
+   Eina_Rect geom;
+   Efl_Ui_Focus_Object *obj = data;
+   Efl_Ui_Focus_Object *focus = efl_ui_focus_manager_focus_get(event->object);
+   Elm_Scrollable_Smart_Interface_Data *pd;
+   Eina_Position2D pos;
+   int pan_x, pan_y;
+
+   pd = efl_data_scope_get(obj, ELM_INTERFACE_SCROLLABLE_MIXIN);
+
+   if (!focus) return;
+
+   geom = efl_ui_focus_object_focus_geometry_get(focus);
+   pos = efl_gfx_entity_position_get(obj);
+   elm_obj_pan_pos_get(pd->pan_obj, &pan_x, &pan_y);
+   geom.x = geom.x + pan_x - pos.x;
+   geom.y = geom.y + pan_y - pos.y;
+
+   elm_interface_scrollable_region_bring_in(obj, geom.x, geom.y, geom.w, geom.h);
+
+   geom = efl_gfx_entity_geometry_get(obj);
+   geom.x = geom.y = 0;
+   elm_widget_show_region_set(obj, geom, EINA_TRUE);
+
 }
 
 EOLIAN static Eo *
@@ -992,8 +887,8 @@ _elm_scroller_efl_object_constructor(Eo *obj, Elm_Scroller_Data *_pd EINA_UNUSED
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_SCROLL_PANE);
-
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_SCROLL_PANE);
+   efl_event_callback_add(obj, EFL_UI_FOCUS_MANAGER_EVENT_FOCUSED, _focused_element, obj);
    return obj;
 }
 
@@ -1001,14 +896,12 @@ _elm_scroller_efl_object_constructor(Eo *obj, Elm_Scroller_Data *_pd EINA_UNUSED
 EOLIAN static void
 _elm_scroller_custom_widget_base_theme_set(Eo *obj, Elm_Scroller_Data *_pd EINA_UNUSED, const char *klass, const char *group)
 {
-   ELM_LAYOUT_DATA_GET(obj, ld);
-
    EINA_SAFETY_ON_NULL_RETURN(klass);
    EINA_SAFETY_ON_NULL_RETURN(group);
 
-   if (eina_stringshare_replace(&(ld->klass), klass) ||
-       eina_stringshare_replace(&(ld->group), group))
-      elm_obj_widget_theme_apply(obj);
+   if (elm_widget_theme_klass_set(obj, klass) ||
+       elm_widget_theme_element_set(obj, group))
+       efl_ui_widget_theme_apply(obj);
 }
 
 EAPI void
@@ -1090,7 +983,7 @@ elm_scroller_single_direction_get(const Evas_Object *obj)
 }
 
 EOLIAN static Elm_Scroller_Single_Direction
-_elm_scroller_elm_interface_scrollable_single_direction_get(Eo *obj, Elm_Scroller_Data *sd EINA_UNUSED)
+_elm_scroller_elm_interface_scrollable_single_direction_get(const Eo *obj, Elm_Scroller_Data *sd EINA_UNUSED)
 {
    return elm_interface_scrollable_single_direction_get(efl_super(obj, MY_CLASS));
 }
@@ -1303,20 +1196,33 @@ elm_scroller_movement_block_set(Evas_Object *obj,
                                 Elm_Scroller_Movement_Block block)
 {
    ELM_SCROLLABLE_CHECK(obj);
+   Efl_Ui_Scroll_Block mode = EFL_UI_SCROLL_BLOCK_NONE;
 
-   elm_interface_scrollable_movement_block_set(obj, block);
+   // legacy -> eo
+   if (block == ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL)
+     mode = EFL_UI_SCROLL_BLOCK_HORIZONTAL;
+   else if (block == ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL)
+     mode = EFL_UI_SCROLL_BLOCK_VERTICAL;
+
+   elm_interface_scrollable_movement_block_set(obj, mode);
 }
 
 EAPI Elm_Scroller_Movement_Block
 elm_scroller_movement_block_get(const Evas_Object *obj)
 {
-   Elm_Scroller_Movement_Block block = ELM_SCROLLER_MOVEMENT_NO_BLOCK;
+   Efl_Ui_Scroll_Block mode;
 
    ELM_SCROLLABLE_CHECK(obj, ELM_SCROLLER_MOVEMENT_NO_BLOCK);
 
-   block = elm_interface_scrollable_movement_block_get((Eo *) obj);
+   mode = elm_interface_scrollable_movement_block_get(obj);
 
-   return block;
+   // eo -> legacy
+   if (mode == EFL_UI_SCROLL_BLOCK_HORIZONTAL)
+     return ELM_SCROLLER_MOVEMENT_BLOCK_HORIZONTAL;
+   else if (mode == EFL_UI_SCROLL_BLOCK_VERTICAL)
+     return ELM_SCROLLER_MOVEMENT_BLOCK_VERTICAL;
+
+   return ELM_SCROLLER_MOVEMENT_NO_BLOCK;
 }
 
 EAPI void
@@ -1354,7 +1260,7 @@ elm_scroller_loop_set(Evas_Object *obj,
    sd->loop_h = loop_h;
    sd->loop_v = loop_v;
 
-   elm_interface_scrollable_loop_set(obj, loop_h, loop_v);
+   elm_interface_scrollable_content_loop_set(obj, loop_h, loop_v);
 
    if (sd->content)
      {
@@ -1367,7 +1273,7 @@ elm_scroller_loop_set(Evas_Object *obj,
                {
                   elm_interface_scrollable_content_set(obj, sd->contents);
                   elm_widget_sub_object_add(obj, sd->contents);
-                  elm_widget_on_show_region_hook_set(sd->contents, _show_region_hook, obj);
+                  elm_widget_on_show_region_hook_set(sd->contents, obj, _show_region_hook, NULL);
                }
           }
         else
@@ -1392,7 +1298,7 @@ elm_scroller_loop_get(const Evas_Object *obj,
 {
    ELM_SCROLLABLE_CHECK(obj);
 
-   elm_interface_scrollable_loop_get(obj, loop_h, loop_v);
+   elm_interface_scrollable_content_loop_get(obj, loop_h, loop_v);
 }
 
 EAPI void
@@ -1430,18 +1336,18 @@ _elm_scroller_class_constructor(Efl_Class *klass)
 }
 
 EOLIAN static Eina_Bool
-_elm_scroller_elm_widget_focus_register(Eo *obj, Elm_Scroller_Data *pd EINA_UNUSED, Efl_Ui_Focus_Manager *manager, Efl_Ui_Focus_Object *logical, Eina_Bool *logical_flag)
+_elm_scroller_efl_ui_widget_focus_state_apply(Eo *obj, Elm_Scroller_Data *pd EINA_UNUSED, Efl_Ui_Widget_Focus_State current_state, Efl_Ui_Widget_Focus_State *configured_state, Efl_Ui_Widget *redirect EINA_UNUSED)
 {
    //undepended from logical or not we always reigster as full with ourself as redirect
-   *logical_flag = EINA_TRUE;
-   return efl_ui_focus_manager_register_logical(manager, obj, logical, obj);
+   configured_state->logical = EINA_TRUE;
+   return efl_ui_widget_focus_state_apply(efl_super(obj, MY_CLASS), current_state, configured_state, obj);
 }
 
 
-EOLIAN const Elm_Atspi_Action *
-_elm_scroller_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Scroller_Data *pd EINA_UNUSED)
+EOLIAN const Efl_Access_Action_Data *
+_elm_scroller_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Scroller_Data *pd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
           { "move,prior", "move", "prior", _key_action_move},
           { "move,next", "move", "next", _key_action_move},
           { "move,left", "move", "left", _key_action_move},
@@ -1455,21 +1361,24 @@ _elm_scroller_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNU
    return &atspi_actions[0];
 }
 
+/* Standard widget overrides */
+
+ELM_WIDGET_KEY_DOWN_DEFAULT_IMPLEMENT(elm_scroller, Elm_Scroller_Data)
+
 /* Efl.Part begin */
 
-ELM_PART_OVERRIDE(elm_scroller, ELM_SCROLLER, ELM_LAYOUT, Elm_Scroller_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_SET(elm_scroller, ELM_SCROLLER, ELM_LAYOUT, Elm_Scroller_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_GET(elm_scroller, ELM_SCROLLER, ELM_LAYOUT, Elm_Scroller_Data, Elm_Part_Data)
-ELM_PART_OVERRIDE_CONTENT_UNSET(elm_scroller, ELM_SCROLLER, ELM_LAYOUT, Elm_Scroller_Data, Elm_Part_Data)
-ELM_PART_CONTENT_DEFAULT_SET(elm_scroller, "default")
-#include "elm_scroller_internal_part.eo.c"
+ELM_PART_OVERRIDE(elm_scroller, ELM_SCROLLER, Elm_Scroller_Data)
+ELM_PART_OVERRIDE_CONTENT_SET(elm_scroller, ELM_SCROLLER, Elm_Scroller_Data)
+ELM_PART_OVERRIDE_CONTENT_GET(elm_scroller, ELM_SCROLLER, Elm_Scroller_Data)
+ELM_PART_OVERRIDE_CONTENT_UNSET(elm_scroller, ELM_SCROLLER, Elm_Scroller_Data)
+#include "elm_scroller_part.eo.c"
 
 /* Efl.Part end */
 
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_SCROLLER_EXTRA_OPS \
-   ELM_PART_CONTENT_DEFAULT_OPS(elm_scroller), \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_scroller), \
    EFL_CANVAS_GROUP_ADD_OPS(elm_scroller)
 
 #include "elm_scroller.eo.c"
