@@ -2,15 +2,17 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
-#define ELM_INTERFACE_ATSPI_VALUE_PROTECTED
-#define ELM_INTERFACE_ATSPI_WIDGET_ACTION_PROTECTED
+#define EFL_ACCESS_OBJECT_PROTECTED
+#define EFL_ACCESS_VALUE_PROTECTED
+#define EFL_ACCESS_WIDGET_ACTION_PROTECTED
+#define EFL_UI_FOCUS_COMPOSITION_PROTECTED
 
 #include <Elementary.h>
 #include <ctype.h>
 
 #include "elm_priv.h"
 #include "elm_widget_spinner.h"
+#include "elm_entry.eo.h"
 
 #include "Eo.h"
 
@@ -53,9 +55,7 @@ _inc_dec_button_unpressed_cb(void *data, const Efl_Event *event);
 static void
 _inc_dec_button_mouse_move_cb(void *data, const Efl_Event *event);
 static void
-_text_button_focused_cb(void *data, const Efl_Event *event);
-static void
-_entry_unfocused_cb(void *data, const Efl_Event *event);
+_entry_focus_change(void *data, const Efl_Event *event);
 static void
 _entry_activated_cb(void *data, const Efl_Event *event);
 
@@ -69,13 +69,6 @@ EFL_CALLBACKS_ARRAY_DEFINE(_inc_dec_button_cb,
 static void _access_increment_decrement_info_say(Evas_Object *obj,
                                                  Eina_Bool is_incremented);
 
-typedef enum _Elm_Spinner_Format_Type
-{
-   SPINNER_FORMAT_FLOAT,
-   SPINNER_FORMAT_INT,
-   SPINNER_FORMAT_INVALID
-} Elm_Spinner_Format_Type;
-
 static Eina_Bool
 _is_valid_digit(char x)
 {
@@ -226,7 +219,7 @@ apply:
    else
      elm_layout_text_set(obj, "elm.text", buf);
 
-   elm_interface_atspi_accessible_name_changed_signal_emit(obj);
+   efl_access_i18n_name_changed_signal_emit(obj);
    if (sd->entry_visible) _entry_show(sd);
 }
 
@@ -243,13 +236,24 @@ _delay_change_timer_cb(void *data)
 
 static Eina_Bool
 _value_set(Evas_Object *obj,
-           double new_val)
+           double val, double changed)
 {
+   double new_val;
+
    ELM_SPINNER_DATA_GET(obj, sd);
 
    if (sd->round > 0)
-     new_val = sd->val_base +
-       (double)((((int)(new_val - sd->val_base)) / sd->round) * sd->round);
+     {
+        //Spin value changed by entry input.
+        if (changed != 0)
+          new_val = sd->val_base +
+            (double)((((int)((val + changed) - sd->val_base)) / sd->round) * sd->round);
+        else
+          new_val = sd->val_base +
+            (double)((((int)(val - sd->val_base + (sd->round / 2))) / sd->round) * sd->round);
+     }
+   else
+     new_val = val + changed;
 
    if (sd->wrap)
      {
@@ -275,7 +279,7 @@ _value_set(Evas_Object *obj,
      efl_event_callback_legacy_call(obj, ELM_SPINNER_EVENT_MAX_REACHED, NULL);
 
    efl_event_callback_legacy_call(obj, ELM_SPINNER_EVENT_CHANGED, NULL);
-   elm_interface_atspi_accessible_value_changed_signal_emit(obj);
+   efl_access_value_changed_signal_emit(obj);
    ecore_timer_del(sd->delay_change_timer);
    sd->delay_change_timer = ecore_timer_add(ELM_SPINNER_DELAY_CHANGE_TIME,
                                             _delay_change_timer_cb, obj);
@@ -343,7 +347,7 @@ _drag_cb(void *data,
    if (!strncmp(style, "vertical", 8)) delta *= -1;
    /* If we are on rtl mode, change the delta to be negative on such changes */
    if (efl_ui_mirrored_get(obj)) delta *= -1;
-   if (_value_set(data, sd->val + delta)) _label_write(data);
+   if (_value_set(data, sd->val, delta)) _label_write(data);
    sd->dragging = 1;
 }
 
@@ -414,19 +418,15 @@ _entry_value_apply(Evas_Object *obj)
    if (!sd->entry_visible) return;
 
    efl_event_callback_del
-    (sd->ent, ELM_WIDGET_EVENT_UNFOCUSED, _entry_unfocused_cb, obj);
+    (sd->ent, EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED, _entry_focus_change, obj);
    _entry_hide(obj);
    str = elm_object_text_get(sd->ent);
    if (!str) return;
 
    val = strtod(str, &end);
    if (((*end != '\0') && (!isspace(*end))) || (fabs(val - sd->val) < DBL_EPSILON)) return;
-   elm_spinner_value_set(obj, val);
 
-   efl_event_callback_legacy_call(obj, ELM_SPINNER_EVENT_CHANGED, NULL);
-   ecore_timer_del(sd->delay_change_timer);
-   sd->delay_change_timer = ecore_timer_add(ELM_SPINNER_DELAY_CHANGE_TIME,
-                                            _delay_change_timer_cb, obj);
+   if (_value_set(obj, val, 0.0)) _label_write(obj);
 }
 
 static int
@@ -547,8 +547,8 @@ _text_insert(const char *text, const char *input, int pos)
 static void
 _min_max_validity_filter(void *data, Evas_Object *obj, char **text)
 {
-   const char *str, *new_str;
-   char *insert;
+   const char *str, *point;
+   char *insert, *new_str = NULL;
    double val;
    int max_len, len;
 
@@ -564,20 +564,32 @@ _min_max_validity_filter(void *data, Evas_Object *obj, char **text)
    insert = *text;
    new_str = _text_insert(str, insert, elm_entry_cursor_pos_get(obj));
    if (!new_str) return;
-
    max_len = log10(fabs(sd->val_max)) + 1;
-   len = evas_string_char_len_get(new_str);
-   if (len < max_len)
+
+   if (sd->format_type == SPINNER_FORMAT_INT)
      {
-        ELM_SAFE_FREE(new_str, free);
-        return;
+        len = strlen(new_str);
+        if (len < max_len) goto end;
+     }
+   else if (sd->format_type == SPINNER_FORMAT_FLOAT)
+     {
+        point = strchr(new_str, '.');
+        if (point)
+          {
+             if ((int) strlen(point + 1) > sd->decimal_points)
+               {
+                  *insert = 0;
+                  goto end;
+               }
+          }
      }
 
    val = strtod(new_str, NULL);
-   ELM_SAFE_FREE(new_str, free);
-
    if ((val < sd->val_min) || (val > sd->val_max))
      *insert = 0;
+
+end:
+   free(new_str);
 }
 
 static void
@@ -589,11 +601,11 @@ _entry_show_cb(void *data,
    ELM_SPINNER_DATA_GET(data, sd);
 
    _entry_show(sd);
+   elm_layout_signal_emit(data, "elm,state,button,inactive", "elm");
+   evas_object_hide(sd->text_button);
    elm_object_focus_set(obj, EINA_TRUE);
    elm_entry_select_all(obj);
    sd->entry_visible = EINA_TRUE;
-   elm_layout_signal_emit(data, "elm,state,button,inactive", "elm");
-   evas_object_hide(sd->text_button);
 }
 
 static void
@@ -637,15 +649,25 @@ _toggle_entry(Evas_Object *obj)
              elm_layout_signal_emit(obj, "elm,state,active", "elm");
              _entry_show(sd);
              elm_entry_select_all(sd->ent);
-             elm_widget_focus_set(sd->ent, EINA_TRUE);
              sd->entry_visible = EINA_TRUE;
           }
 
         efl_event_callback_add
-           (sd->ent, ELM_WIDGET_EVENT_UNFOCUSED, _entry_unfocused_cb, obj);
+           (sd->ent, EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED, _entry_focus_change, obj);
         sd->entry_visible = EINA_TRUE;
         elm_layout_signal_emit(obj, "elm,state,entry,active", "elm");
         evas_object_show(sd->ent);
+        {
+           Eina_List *items = NULL;
+
+           items = eina_list_append(items, sd->dec_button);
+           items = eina_list_append(items, sd->text_button);
+           items = eina_list_append(items, sd->ent);
+           items = eina_list_append(items, sd->inc_button);
+
+           efl_ui_focus_composition_elements_set(obj, items);
+        }
+        efl_ui_focus_manager_focus_set(efl_ui_focus_object_focus_manager_get(obj), sd->ent);
      }
 }
 
@@ -676,7 +698,7 @@ _spin_value(void *data)
    // spin_timer does not exist when _spin_value() is called from wheel event
    if (sd->spin_timer)
      ecore_timer_interval_set(sd->spin_timer, sd->interval);
-   if (_value_set(data, sd->val + real_speed)) _label_write(data);
+   if (_value_set(data, sd->val, real_speed)) _label_write(data);
 
    return ECORE_CALLBACK_RENEW;
 }
@@ -722,30 +744,25 @@ _key_action_toggle(Evas_Object *obj, const char *params EINA_UNUSED)
 }
 
 EOLIAN static Eina_Bool
-_elm_spinner_elm_widget_widget_event(Eo *obj, Elm_Spinner_Data *sd EINA_UNUSED, Evas_Object *src EINA_UNUSED, Evas_Callback_Type type, void *event_info)
+_elm_spinner_efl_ui_widget_widget_event(Eo *obj, Elm_Spinner_Data *sd EINA_UNUSED, const Efl_Event *eo_event, Evas_Object *src EINA_UNUSED)
 {
-   Evas_Event_Key_Down *ev = event_info;
-   Evas_Event_Mouse_Wheel *mev = event_info;
+   Eo *ev = eo_event->info;
 
-   if (type == EVAS_CALLBACK_KEY_DOWN)
+   if (efl_input_processed_get(ev)) return EINA_FALSE;
+   if (eo_event->desc == EFL_EVENT_KEY_DOWN)
      {
-        if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
         if (sd->spin_timer) _spin_stop(obj);
         else return EINA_FALSE;
-        ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
      }
-   else if (type == EVAS_CALLBACK_KEY_UP)
+   else if (eo_event->desc == EFL_EVENT_KEY_UP)
      {
-        if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
         if (sd->spin_timer) _spin_stop(obj);
         else return EINA_FALSE;
-        ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
      }
-   else if (type == EVAS_CALLBACK_MOUSE_WHEEL)
+   else if (eo_event->desc == EFL_EVENT_POINTER_WHEEL)
      {
-        if (mev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return EINA_FALSE;
         sd->interval = sd->first_interval;
-        if (mev->z < 0)
+        if (efl_input_pointer_wheel_delta_get(ev) < 0)
           {
              sd->spin_speed = sd->step;
              elm_layout_signal_emit(obj, "elm,right,anim,activate", "elm");
@@ -756,10 +773,10 @@ _elm_spinner_elm_widget_widget_event(Eo *obj, Elm_Spinner_Data *sd EINA_UNUSED,
              elm_layout_signal_emit(obj, "elm,left,anim,activate", "elm");
           }
         _spin_value(obj);
-        mev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
      }
    else return EINA_FALSE;
 
+   efl_input_processed_set(ev, EINA_TRUE);
    return EINA_TRUE;
 }
 
@@ -864,9 +881,10 @@ _inc_dec_button_unpressed_cb(void *data, const Efl_Event *event EINA_UNUSED)
 }
 
 static void
-_text_button_focused_cb(void *data, const Efl_Event *event EINA_UNUSED)
+_text_button_focus_change(void *data, const Efl_Event *event)
 {
-   _toggle_entry(data);
+   if (efl_ui_focus_object_focus_get(event->object))
+     _toggle_entry(data);
 }
 
 static void
@@ -875,11 +893,11 @@ _entry_activated_cb(void *data, const Efl_Event *event EINA_UNUSED)
    _toggle_entry(data);
 }
 
-
 static void
-_entry_unfocused_cb(void *data, const Efl_Event *event EINA_UNUSED)
+_entry_focus_change(void *data, const Efl_Event *event)
 {
-   _toggle_entry(data);
+   if (!efl_ui_focus_object_focus_get(event->object))
+     _toggle_entry(data);
 }
 
 static void
@@ -919,17 +937,18 @@ _elm_spinner_elm_layout_sizing_eval(Eo *obj, Elm_Spinner_Data *_pd EINA_UNUSED)
 }
 
 EOLIAN static Eina_Bool
-_elm_spinner_elm_widget_on_focus(Eo *obj, Elm_Spinner_Data *sd, Elm_Object_Item *item EINA_UNUSED)
+_elm_spinner_efl_ui_focus_object_on_focus_update(Eo *obj, Elm_Spinner_Data *sd)
 {
    Eina_Bool int_ret = EINA_FALSE;
 
-   int_ret = elm_obj_widget_on_focus(efl_super(obj, MY_CLASS), NULL);
+   int_ret = efl_ui_focus_object_on_focus_update(efl_super(obj, MY_CLASS));
    if (!int_ret) return EINA_FALSE;
 
-   if (!elm_widget_focus_get(obj))
+   if (!efl_ui_focus_object_focus_get(obj))
      {
         ELM_SAFE_FREE(sd->delay_change_timer, ecore_timer_del);
         ELM_SAFE_FREE(sd->spin_timer, ecore_timer_del);
+        ELM_SAFE_FREE(sd->longpress_timer, ecore_timer_del);
      }
    else
      {
@@ -961,7 +980,9 @@ _access_activate_cb(void *data,
      increment_part = "right_bt";
 
    eo = elm_layout_edje_get(data);
+   edje_object_freeze(eo);
    inc_btn = (Evas_Object *)edje_object_part_object_get(eo, increment_part);
+   edje_object_thaw(eo);
 
    if (part_obj != inc_btn)
      {
@@ -1199,11 +1220,13 @@ _elm_spinner_efl_canvas_group_group_add(Eo *obj, Elm_Spinner_Data *priv)
 
         priv->text_button = elm_button_add(obj);
         elm_object_style_set(priv->text_button, "spinner/default");
+        elm_widget_can_focus_set(priv->text_button, _elm_config->access_mode);
 
         efl_event_callback_add
           (priv->text_button, EFL_UI_EVENT_CLICKED, _text_button_clicked_cb, obj);
+
         efl_event_callback_add
-          (priv->text_button, ELM_WIDGET_EVENT_FOCUSED, _text_button_focused_cb, obj);
+          (priv->text_button, EFL_UI_FOCUS_OBJECT_EVENT_FOCUS_CHANGED, _text_button_focus_change, obj);
 
         elm_layout_content_set(obj, "elm.swallow.text_button", priv->text_button);
         elm_widget_sub_object_add(obj, priv->text_button);
@@ -1215,6 +1238,16 @@ _elm_spinner_efl_canvas_group_group_add(Eo *obj, Elm_Spinner_Data *priv)
 
         elm_layout_content_set(obj, "elm.swallow.dec_button", priv->dec_button);
         elm_widget_sub_object_add(obj, priv->dec_button);
+
+        {
+           Eina_List *items = NULL;
+
+           items = eina_list_append(items, priv->dec_button);
+           items = eina_list_append(items, priv->text_button);
+           items = eina_list_append(items, priv->inc_button);
+
+           efl_ui_focus_composition_elements_set(obj, items);
+        }
      }
    else
      {
@@ -1266,13 +1299,16 @@ _elm_spinner_efl_canvas_group_group_del(Eo *obj, Elm_Spinner_Data *sd)
    efl_canvas_group_del(efl_super(obj, MY_CLASS));
 }
 
-EOLIAN static Elm_Theme_Apply
-_elm_spinner_elm_widget_theme_apply(Eo *obj, Elm_Spinner_Data *sd)
+EOLIAN static Efl_Ui_Theme_Apply
+_elm_spinner_efl_ui_widget_theme_apply(Eo *obj, Elm_Spinner_Data *sd)
 {
-   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, ELM_THEME_APPLY_FAILED);
+   ELM_WIDGET_DATA_GET_OR_RETURN(obj, wd, EFL_UI_THEME_APPLY_FAILED);
 
-   if (!elm_layout_theme_set(obj, "spinner", "base", elm_widget_style_get(obj)))
-     CRI("Failed to set layout!");
+   if (!efl_ui_widget_theme_apply(efl_super(obj, MY_CLASS)))
+     {
+        CRI("Failed to set layout!");
+        return EFL_UI_THEME_APPLY_FAILED;
+     }
 
    if (edje_object_part_exists(wd->resize_obj, "elm.swallow.dec_button"))
      sd->button_layout = EINA_TRUE;
@@ -1315,96 +1351,13 @@ _elm_spinner_elm_widget_theme_apply(Eo *obj, Elm_Spinner_Data *sd)
      _access_spinner_register(obj, EINA_TRUE);
 
    elm_layout_sizing_eval(obj);
-   return ELM_THEME_APPLY_SUCCESS;
+   return EFL_UI_THEME_APPLY_SUCCESS;
 }
 
 static Eina_Bool _elm_spinner_smart_focus_next_enable = EINA_FALSE;
 
-EOLIAN static Eina_Bool
-_elm_spinner_elm_widget_focus_next_manager_is(Eo *obj EINA_UNUSED, Elm_Spinner_Data *_pd EINA_UNUSED)
-{
-   ELM_SPINNER_DATA_GET(obj, sd);
-
-   return _elm_spinner_smart_focus_next_enable | sd->button_layout;
-}
-
-EOLIAN static Eina_Bool
-_elm_spinner_elm_widget_focus_direction_manager_is(Eo *obj EINA_UNUSED, Elm_Spinner_Data *_pd EINA_UNUSED)
-{
-   ELM_SPINNER_DATA_GET(obj, sd);
-
-   if (sd->button_layout) return EINA_TRUE;
-   return EINA_FALSE;
-}
-
-EOLIAN static Eina_Bool
-_elm_spinner_elm_widget_focus_direction(Eo *obj, Elm_Spinner_Data *_pd, const Evas_Object *base, double degree, Evas_Object **direction, Elm_Object_Item **direction_item, double *weight)
-{
-   Eina_Bool ret;
-   Eina_List *items = NULL;
-   void *(*list_data_get)(const Eina_List *list);
-
-   ELM_SPINNER_CHECK(obj) EINA_FALSE;
-
-   if (!_pd)
-     return EINA_FALSE;
-
-   list_data_get = eina_list_data_get;
-
-   items = eina_list_append(items, _pd->inc_button);
-   items = eina_list_append(items, _pd->text_button);
-   items = eina_list_append(items, _pd->dec_button);
-
-   ret = elm_widget_focus_list_direction_get
-      (obj, base, items, list_data_get, degree, direction, direction_item, weight);
-   eina_list_free(items);
-
-   return ret;
-}
-
-static Evas_Object *
-_access_object_get(const Evas_Object *obj, const char* part)
-{
-   Evas_Object *eo, *po, *ao;
-
-   eo = elm_layout_edje_get(obj);
-
-   po = (Evas_Object *)edje_object_part_object_get(eo, part);
-   ao = evas_object_data_get(po, "_part_access_obj");
-
-   return ao;
-}
-
-EOLIAN static Eina_Bool
-_elm_spinner_elm_widget_focus_next(Eo *obj, Elm_Spinner_Data *_pd, Elm_Focus_Direction dir, Evas_Object **next, Elm_Object_Item **next_item)
-{
-   Evas_Object *ao;
-   Eina_List *items = NULL;
-   int ret;
-
-   ELM_SPINNER_CHECK(obj) EINA_FALSE;
-
-   if (_elm_config->access_mode)
-     {
-        ao = _access_object_get(obj, "access");
-        items = eina_list_append(items, ao);
-     }
-   if (!elm_widget_disabled_get(obj))
-     {
-        items = eina_list_append(items, _pd->dec_button);
-        items = eina_list_append(items, _pd->text_button);
-        items = eina_list_append(items, _pd->inc_button);
-     }
-
-   ret = elm_widget_focus_list_next_get
-      (obj, items, eina_list_data_get, dir, next, next_item);
-   eina_list_free(items);
-
-   return ret;
-}
-
 EOLIAN static void
-_elm_spinner_elm_widget_access(Eo *obj, Elm_Spinner_Data *_pd EINA_UNUSED, Eina_Bool acs)
+_elm_spinner_efl_ui_widget_on_access_update(Eo *obj, Elm_Spinner_Data *_pd EINA_UNUSED, Eina_Bool acs)
 {
    _elm_spinner_smart_focus_next_enable = acs;
    _access_spinner_register(obj, _elm_spinner_smart_focus_next_enable);
@@ -1414,55 +1367,43 @@ EAPI Evas_Object *
 elm_spinner_add(Evas_Object *parent)
 {
    EINA_SAFETY_ON_NULL_RETURN_VAL(parent, NULL);
-   return efl_add(MY_CLASS, parent, efl_canvas_object_legacy_ctor(efl_added));
+   return elm_legacy_add(MY_CLASS, parent);
 }
 
 EAPI void
 elm_spinner_min_max_set(Evas_Object *obj, double min, double max)
 {
-   efl_ui_spin_min_max_set(obj, min, max);
+   efl_ui_range_min_max_set(obj, min, max);
 }
 
 EAPI void
 elm_spinner_min_max_get(const Evas_Object *obj, double *min, double *max)
 {
-   efl_ui_spin_min_max_get(obj, min, max);
+   efl_ui_range_min_max_get(obj, min, max);
 }
 
 EAPI void
 elm_spinner_step_set(Evas_Object *obj, double step)
 {
-   efl_ui_spin_step_set(obj, step);
+   efl_ui_range_step_set(obj, step);
 }
 
 EAPI double
 elm_spinner_step_get(const Evas_Object *obj)
 {
-   return efl_ui_spin_step_get(obj);
-}
-
-EAPI void
-elm_spinner_interval_set(Evas_Object *obj, double interval)
-{
-   efl_ui_spin_interval_set(obj, interval);
-}
-
-EAPI double
-elm_spinner_interval_get(const Evas_Object *obj)
-{
-   return efl_ui_spin_interval_get(obj);
+   return efl_ui_range_step_get(obj);
 }
 
 EAPI void
 elm_spinner_value_set(Evas_Object *obj, double val)
 {
-   efl_ui_spin_value_set(obj, val);
+   efl_ui_range_value_set(obj, val);
 }
 
 EAPI double
 elm_spinner_value_get(const Evas_Object *obj)
 {
-   return efl_ui_spin_value_get(obj);
+   return efl_ui_range_value_get(obj);
 }
 
 EOLIAN static Eo *
@@ -1471,7 +1412,7 @@ _elm_spinner_efl_object_constructor(Eo *obj, Elm_Spinner_Data *_pd EINA_UNUSED)
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
    evas_object_smart_callbacks_descriptions_set(obj, _smart_callbacks);
-   elm_interface_atspi_accessible_role_set(obj, ELM_ATSPI_ROLE_SPIN_BUTTON);
+   efl_access_object_role_set(obj, EFL_ACCESS_ROLE_SPIN_BUTTON);
 
    return obj;
 }
@@ -1480,35 +1421,35 @@ EOLIAN static void
 _elm_spinner_label_format_set(Eo *obj, Elm_Spinner_Data *sd, const char *fmt)
 {
    Elm_Spinner_Format_Type type;
-   if (fmt)
+
+   if (!fmt) fmt = "%.0f";
+   type = _is_label_format_integer(fmt);
+   if (type == SPINNER_FORMAT_INVALID)
      {
-        type = _is_label_format_integer(fmt);
-        if (type == SPINNER_FORMAT_INVALID)
-          {
-             ERR("format:\"%s\" is Invalid, cannot be set", fmt);
-             return;
-          }
-        else if (type == SPINNER_FORMAT_FLOAT)
-          {
-             sd->decimal_points = _decimal_points_get(fmt);
-          }
+        ERR("format:\"%s\" is invalid, cannot be set", fmt);
+        return;
+     }
+   else if (type == SPINNER_FORMAT_FLOAT)
+     {
+        sd->decimal_points = _decimal_points_get(fmt);
      }
 
    eina_stringshare_replace(&sd->label, fmt);
 
+   sd->format_type = type;
    _label_write(obj);
    elm_layout_sizing_eval(obj);
    _entry_accept_filter_add(obj);
 }
 
 EOLIAN static const char*
-_elm_spinner_label_format_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_label_format_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->label;
 }
 
 EOLIAN static void
-_elm_spinner_efl_ui_spin_min_max_set(Eo *obj, Elm_Spinner_Data *sd, double min, double max)
+_elm_spinner_efl_ui_range_range_min_max_set(Eo *obj, Elm_Spinner_Data *sd, double min, double max)
 {
    if ((sd->val_min == min) && (sd->val_max == max)) return;
 
@@ -1523,30 +1464,32 @@ _elm_spinner_efl_ui_spin_min_max_set(Eo *obj, Elm_Spinner_Data *sd, double min,
 }
 
 EOLIAN static void
-_elm_spinner_efl_ui_spin_min_max_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double *min, double *max)
+_elm_spinner_efl_ui_range_range_min_max_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double *min, double *max)
 {
    if (min) *min = sd->val_min;
    if (max) *max = sd->val_max;
 }
 
 EOLIAN static void
-_elm_spinner_efl_ui_spin_step_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double step)
+_elm_spinner_efl_ui_range_range_step_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double step)
 {
    sd->step = step;
 }
 
 EOLIAN static double
-_elm_spinner_efl_ui_spin_step_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_efl_ui_range_range_step_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->step;
 }
 
 EOLIAN static void
-_elm_spinner_efl_ui_spin_value_set(Eo *obj, Elm_Spinner_Data *sd, double val)
+_elm_spinner_efl_ui_range_range_value_set(Eo *obj, Elm_Spinner_Data *sd, double val)
 {
    if (sd->val == val) return;
 
-   sd->val = val;
+   sd->val = (sd->round <= 0) ? val : sd->val_base +
+      (double)((((int)(val - sd->val_base + (sd->round / 2))) / sd->round) * sd->round);
+
    sd->val_updated = EINA_FALSE;
 
    if (sd->val < sd->val_min)
@@ -1565,7 +1508,7 @@ _elm_spinner_efl_ui_spin_value_set(Eo *obj, Elm_Spinner_Data *sd, double val)
 }
 
 EOLIAN static double
-_elm_spinner_efl_ui_spin_value_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_efl_ui_range_range_value_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->val;
 }
@@ -1577,7 +1520,7 @@ _elm_spinner_wrap_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, Eina_Bool wrap)
 }
 
 EOLIAN static Eina_Bool
-_elm_spinner_wrap_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_wrap_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->wrap;
 }
@@ -1653,22 +1596,23 @@ EOLIAN static void
 _elm_spinner_editable_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, Eina_Bool editable)
 {
    sd->editable = editable;
+   elm_widget_can_focus_set(sd->text_button, editable | _elm_config->access_mode);
 }
 
 EOLIAN static Eina_Bool
-_elm_spinner_editable_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_editable_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->editable;
 }
 
 EOLIAN static void
-_elm_spinner_efl_ui_spin_interval_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double interval)
+_elm_spinner_interval_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double interval)
 {
    sd->first_interval = interval;
 }
 
 EOLIAN static double
-_elm_spinner_efl_ui_spin_interval_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_interval_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->first_interval;
 }
@@ -1680,7 +1624,7 @@ _elm_spinner_base_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double base)
 }
 
 EOLIAN static double
-_elm_spinner_base_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_base_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->val_base;
 }
@@ -1692,7 +1636,7 @@ _elm_spinner_round_set(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, int rnd)
 }
 
 EOLIAN static int
-_elm_spinner_round_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_round_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->round;
 }
@@ -1706,10 +1650,10 @@ _elm_spinner_class_constructor(Efl_Class *klass)
       _elm_spinner_smart_focus_next_enable = EINA_TRUE;
 }
 
-EOLIAN static const Elm_Atspi_Action *
-_elm_spinner_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd EINA_UNUSED)
+EOLIAN static const Efl_Access_Action_Data *
+_elm_spinner_efl_access_widget_action_elm_actions_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd EINA_UNUSED)
 {
-   static Elm_Atspi_Action atspi_actions[] = {
+   static Efl_Access_Action_Data atspi_actions[] = {
       { "toggle", "toggle", NULL, _key_action_toggle},
       { NULL, NULL, NULL, NULL }
    };
@@ -1719,14 +1663,14 @@ _elm_spinner_elm_interface_atspi_widget_action_elm_actions_get(Eo *obj EINA_UNUS
 // A11Y Accessibility
 
 EOLIAN static void
-_elm_spinner_elm_interface_atspi_value_value_and_text_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double *value, const char **text)
+_elm_spinner_efl_access_value_value_and_text_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double *value, const char **text)
 {
    if (value) *value = sd->val;
    if (text) *text = NULL;
 }
 
 EOLIAN static Eina_Bool
-_elm_spinner_elm_interface_atspi_value_value_and_text_set(Eo *obj, Elm_Spinner_Data *sd, double value, const char *text EINA_UNUSED)
+_elm_spinner_efl_access_value_value_and_text_set(Eo *obj, Elm_Spinner_Data *sd, double value, const char *text EINA_UNUSED)
 {
    if (sd->val_min > value) return EINA_FALSE;
    if (sd->val_max < value) return EINA_FALSE;
@@ -1738,7 +1682,7 @@ _elm_spinner_elm_interface_atspi_value_value_and_text_set(Eo *obj, Elm_Spinner_D
 }
 
 EOLIAN static void
-_elm_spinner_elm_interface_atspi_value_range_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double *lower, double *upper, const char **descr)
+_elm_spinner_efl_access_value_range_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd, double *lower, double *upper, const char **descr)
 {
    if (lower) *lower = sd->val_min;
    if (upper) *upper = sd->val_max;
@@ -1746,18 +1690,26 @@ _elm_spinner_elm_interface_atspi_value_range_get(Eo *obj EINA_UNUSED, Elm_Spinne
 }
 
 EOLIAN static double
-_elm_spinner_elm_interface_atspi_value_increment_get(Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
+_elm_spinner_efl_access_value_increment_get(const Eo *obj EINA_UNUSED, Elm_Spinner_Data *sd)
 {
    return sd->step;
 }
 
 EOLIAN static const char*
-_elm_spinner_elm_interface_atspi_accessible_name_get(Eo *obj, Elm_Spinner_Data *sd EINA_UNUSED)
+_elm_spinner_efl_access_object_i18n_name_get(const Eo *obj, Elm_Spinner_Data *sd)
 {
-   const char *name;
-   name = elm_interface_atspi_accessible_name_get(efl_super(obj, ELM_SPINNER_CLASS));
+   const char *name, *ret;
+   name = efl_access_object_i18n_name_get(efl_super(obj, ELM_SPINNER_CLASS));
    if (name) return name;
-   const char *ret = elm_layout_text_get(obj, "elm.text");
+   if (sd->button_layout)
+     {
+        if (sd->entry_visible)
+          ret = elm_object_text_get(sd->ent);
+        else
+          ret = elm_object_text_get(sd->text_button);
+     }
+   else
+     ret = elm_layout_text_get(obj, "elm.text");
    return ret;
 }
 
@@ -1766,6 +1718,7 @@ _elm_spinner_elm_interface_atspi_accessible_name_get(Eo *obj, Elm_Spinner_Data *
 /* Internal EO APIs and hidden overrides */
 
 #define ELM_SPINNER_EXTRA_OPS \
+   ELM_LAYOUT_SIZING_EVAL_OPS(elm_spinner), \
    EFL_CANVAS_GROUP_ADD_DEL_OPS(elm_spinner)
 
 #include "elm_spinner.eo.c"
