@@ -480,7 +480,6 @@ _recover_image_uv(Evas_Object *obj, Evas_Map *map, Eina_Bool revert, Eina_Bool b
    //Need to handle uvs only for image objects
    int iw, ih;
    int x, y, w, h;
-   int fill_x, fill_y, fill_w, fill_h;
 
    const char *type = evas_object_type_get(obj);
    if ((!type) || (strcmp(type, "image"))) return EINA_FALSE;
@@ -507,16 +506,22 @@ _recover_image_uv(Evas_Object *obj, Evas_Map *map, Eina_Bool revert, Eina_Bool b
         //Zooming image fill area.
         else
           {
-             efl_gfx_fill_get(obj, &fill_x, &fill_y, &fill_w, &fill_h);
-             efl_gfx_size_get(obj, &w, &h);
+             Eina_Rect fill;
+             Eina_Size2D sz;
 
-             double rate_x = (double) w / (double) fill_w;
-             double rate_y = (double) h / (double) fill_h;
-             double rate_x2 = (double) iw / (double) fill_w;
-             double rate_y2 = (double) ih / (double) fill_h;
+             fill = efl_gfx_fill_get(obj);
+             sz = efl_gfx_entity_size_get(obj);
+             w = sz.w;
+             h = sz.h;
 
-             x = -(int)((double) fill_x * rate_x2);
-             y = -(int)((double) fill_y * rate_y2);
+             EINA_SAFETY_ON_FALSE_RETURN_VAL(eina_rectangle_is_valid(&fill.rect), EINA_FALSE);
+             double rate_x = (double) w / (double) fill.w;
+             double rate_y = (double) h / (double) fill.h;
+             double rate_x2 = (double) iw / (double) fill.w;
+             double rate_y2 = (double) ih / (double) fill.h;
+
+             x = -(int)((double) fill.x * rate_x2);
+             y = -(int)((double) fill.y * rate_y2);
              w = (int)(((double) iw) * rate_x) + x;
              h = (int)(((double) ih) * rate_y) + y;
           }
@@ -584,7 +589,7 @@ elm_transit_effect_add(Elm_Transit *transit, Elm_Transit_Effect_Transition_Cb tr
    EINA_INLIST_FOREACH(transit->effect_list, effect_module)
      if ((effect_module->transition_cb == transition_cb) && (effect_module->effect == effect))
        {
-          WRN("elm_transit does not allow to add the duplicated effect! : transit=%p", transit);
+          WRN("elm_transit does not allow one to add the duplicated effect! : transit=%p", transit);
           return;
        }
 
@@ -787,7 +792,7 @@ elm_transit_duration_set(Elm_Transit *transit, double duration)
    ELM_TRANSIT_CHECK_OR_RETURN(transit);
    if (transit->animator)
      {
-        WRN("elm_transit does not allow to set the duration time in operating! : transit=%p", transit);
+        WRN("elm_transit does not allow one to set the duration time in operating! : transit=%p", transit);
         return;
      }
    transit->time.duration = duration;
@@ -913,7 +918,7 @@ elm_transit_objects_final_state_keep_set(Elm_Transit *transit, Eina_Bool state_k
    if (transit->state_keep == state_keep) return;
    if (transit->animator)
      {
-        WRN("elm_transit does not allow to change final state keep mode in operating! : transit=%p", transit);
+        WRN("elm_transit does not allow one to change final state keep mode in operating! : transit=%p", transit);
         return;
      }
    transit->state_keep = !!state_keep;
