@@ -34,6 +34,23 @@ static const char _tooltip_key[] = "_elm_tooltip";
     }                                                   \
   while (0)
 
+#define ELM_TOOLTIP_GET_OR_CREATE(tt, obj, ...)         \
+  Elm_Tooltip *tt;                                      \
+  do                                                    \
+    {                                                   \
+       if (!(obj))                                      \
+         {                                              \
+            CRI("Null pointer: " #obj);            \
+            return __VA_ARGS__;                         \
+         }                                              \
+       tt = evas_object_data_get((obj), _tooltip_key);  \
+       if (!tt)                                         \
+         {                                              \
+            tt = _elm_tooltip_create((obj));     \
+         }                                              \
+    }                                                   \
+  while (0)
+
 struct _Elm_Tooltip
 {
    Elm_Tooltip_Content_Cb   func;
@@ -263,7 +280,11 @@ _elm_tooltip_hide_anim_start(Elm_Tooltip *tt)
    TTDBG("HIDE START\n");
    /* hide slightly faster when in window mode to look less stupid */
    if ((tt->hide_timeout > 0) && tt->tt_win) extra = 0.1;
-   edje_object_signal_emit(tt->tooltip, "elm,action,hide", "elm");
+
+   if (elm_widget_is_legacy(tt->owner))
+     edje_object_signal_emit(tt->tooltip, "elm,action,hide", "elm");
+   else
+     edje_object_signal_emit(tt->tooltip, "efl,action,hide", "efl");
    tt->hide_timer = ecore_timer_add
      (tt->hide_timeout - extra, _elm_tooltip_hide_anim_cb, tt);
 }
@@ -273,7 +294,12 @@ _elm_tooltip_hide_anim_stop(Elm_Tooltip *tt)
 {
    if (!tt->hide_timer) return;
    if (tt->tooltip)
-     edje_object_signal_emit(tt->tooltip, "elm,action,show", "elm");
+     {
+        if (elm_widget_is_legacy(tt->owner))
+          edje_object_signal_emit(tt->tooltip, "elm,action,show", "elm");
+        else
+          edje_object_signal_emit(tt->tooltip, "efl,action,show", "efl");
+     }
 
    ELM_SAFE_FREE(tt->hide_timer, ecore_timer_del);
 }
@@ -409,6 +435,7 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
    Evas_Coord eminw, eminh, ominw, ominh;
    double rel_x = 0.0, rel_y = 0.0;
    Eina_Bool inside_eventarea;
+   Eina_Bool new_content = EINA_FALSE;
 
    _elm_tooltip_reconfigure_job_stop(tt);
 
@@ -418,8 +445,8 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
      {
         const char *style = tt->style ? tt->style : "default";
         const char *str;
-        if (!_elm_theme_object_set(tt->tt_win ? NULL : tt->owner, tt->tooltip,
-                                  "tooltip", "base", style))
+        if (!_elm_theme_object_set(tt->tt_win ? : tt->owner, tt->tooltip,
+                                  "tooltip", NULL, style))
           {
              ERR("Could not apply the theme to the tooltip! style=%s", style);
              if (tt->tt_win) evas_object_del(tt->tt_win);
@@ -473,10 +500,19 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
 
         tt->changed_style = EINA_FALSE;
         if (tt->tooltip)
-          edje_object_part_swallow(tt->tooltip, "elm.swallow.content",
-                                   tt->content);
+          {
+             if (elm_widget_is_legacy(tt->owner))
+               edje_object_part_swallow(tt->tooltip, "elm.swallow.content",
+                                        tt->content);
+             else
+               edje_object_part_swallow(tt->tooltip, "efl.content",
+                                        tt->content);
+          }
 
-        edje_object_signal_emit(tt->tooltip, "elm,action,show", "elm");
+        if (elm_widget_is_legacy(tt->owner))
+          edje_object_signal_emit(tt->tooltip, "elm,action,show", "elm");
+        else
+          edje_object_signal_emit(tt->tooltip, "efl,action,show", "efl");
      }
 
    if (!tt->content)
@@ -501,10 +537,14 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
              tt->tooltip = NULL;
              return;
           }
-        edje_object_part_swallow
-          (tt->tooltip, "elm.swallow.content", tt->content);
-        evas_object_event_callback_add(tt->content, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
-           _elm_tooltip_content_changed_hints_cb, tt);
+
+        if (elm_widget_is_legacy(tt->owner))
+          edje_object_part_swallow
+             (tt->tooltip, "elm.swallow.content", tt->content);
+        else
+          edje_object_part_swallow
+             (tt->tooltip, "efl.content", tt->content);
+        new_content = EINA_TRUE;
         evas_object_event_callback_add(tt->content, EVAS_CALLBACK_DEL,
            _elm_tooltip_content_del_cb, tt);
 
@@ -512,7 +552,17 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
         evas_object_layer_set(tt->tooltip, ELM_OBJECT_LAYER_TOOLTIP);
      }
    TTDBG("*******RECALC\n");
-   efl_gfx_size_hint_combined_min_get(tt->content, &ominw, &ominh);
+   evas_object_size_hint_combined_min_get(tt->content, &ominw, &ominh);
+   /* force size hints to update */
+   if ((!ominw) || (!ominh))
+     {
+        evas_object_smart_need_recalculate_set(tt->content, 1);
+        evas_object_smart_calculate(tt->content);
+        evas_object_size_hint_combined_min_get(tt->content, &ominw, &ominh);
+     }
+   if (new_content)
+     evas_object_event_callback_add(tt->content, EVAS_CALLBACK_CHANGED_SIZE_HINTS,
+           _elm_tooltip_content_changed_hints_cb, tt);
    edje_object_size_min_get(tt->tooltip, &eminw, &eminh);
 
    if (eminw && (ominw < eminw)) ominw = eminw;
@@ -527,14 +577,14 @@ _elm_tooltip_reconfigure(Elm_Tooltip *tt)
                                 &basex, &basey, &cw, &ch);
         elm_win_screen_position_get(elm_widget_top_get(tt->owner),
                                     &cx, &cy);
-        evas_canvas_pointer_canvas_xy_get(tt->evas, &px, &py);
+        evas_pointer_canvas_xy_get(tt->evas, &px, &py);
         cx -= basex;
         cy -= basey;
      }
    else
      {
         evas_output_size_get(tt->evas, &cw, &ch);
-        evas_canvas_pointer_canvas_xy_get(tt->evas, &px, &py);
+        evas_pointer_canvas_xy_get(tt->evas, &px, &py);
      }
    TTDBG("SCREEN:  cw=%d,ch=%d\n", cw, ch);
 
@@ -734,6 +784,28 @@ _elm_tooltip_obj_free_cb(void *data, Evas *e  EINA_UNUSED, Evas_Object *obj, voi
    _elm_tooltip_unset(tt);
 }
 
+static Elm_Tooltip *
+_elm_tooltip_create(Evas_Object *eventarea)
+{
+   Elm_Tooltip *tt = NULL;
+
+   tt = ELM_NEW(Elm_Tooltip);
+   if (!tt) return NULL;
+
+   tt->eventarea = eventarea;
+   tt->evas = evas_object_evas_get(eventarea);
+   evas_object_data_set(eventarea, _tooltip_key, tt);
+
+   evas_object_event_callback_add(eventarea, EVAS_CALLBACK_MOUSE_IN,
+      _elm_tooltip_obj_mouse_in_cb, tt);
+   evas_object_event_callback_add(eventarea, EVAS_CALLBACK_MOUSE_OUT,
+      (Evas_Object_Event_Cb)_elm_tooltip_obj_mouse_out_cb, tt);
+   evas_object_event_callback_add(eventarea, EVAS_CALLBACK_FREE,
+      _elm_tooltip_obj_free_cb, tt);
+
+   return tt;
+}
+
 static void
 _tooltip_label_style_set(Evas_Object *obj, Evas_Object *label)
 {
@@ -826,7 +898,7 @@ elm_object_tooltip_move_freeze_get(const Evas_Object *obj)
 EAPI void
 elm_object_tooltip_orient_set(Evas_Object *obj, Elm_Tooltip_Orient orient)
 {
-   ELM_TOOLTIP_GET_OR_RETURN(tt, obj);
+   ELM_TOOLTIP_GET_OR_CREATE(tt, obj);
 
    if ((orient > ELM_TOOLTIP_ORIENT_NONE) && (orient < ELM_TOOLTIP_ORIENT_LAST))
      tt->orient = orient;
@@ -893,7 +965,7 @@ void
 elm_object_sub_tooltip_content_cb_set(Evas_Object *eventarea, Evas_Object *owner, Elm_Tooltip_Content_Cb func, const void *data, Evas_Smart_Cb del_cb)
 {
    Elm_Tooltip *tt = NULL;
-   Eina_Bool just_created;
+   Eina_Bool just_created = EINA_TRUE;
 
    EINA_SAFETY_ON_NULL_GOTO(owner, error);
    EINA_SAFETY_ON_NULL_GOTO(eventarea, error);
@@ -905,7 +977,7 @@ elm_object_sub_tooltip_content_cb_set(Evas_Object *eventarea, Evas_Object *owner
      }
 
    tt = evas_object_data_get(eventarea, _tooltip_key);
-   if (tt)
+   if (tt && tt->owner)
      {
         if (tt->owner != owner)
           {
@@ -930,23 +1002,13 @@ elm_object_sub_tooltip_content_cb_set(Evas_Object *eventarea, Evas_Object *owner
      }
    else
      {
-        tt = ELM_NEW(Elm_Tooltip);
-        if (!tt) goto error;
+        if (!tt)
+          {
+             tt = _elm_tooltip_create(eventarea);
+             if (!tt) goto error;
+          }
 
         tt->owner = owner;
-        tt->eventarea = eventarea;
-        tt->evas = evas_object_evas_get(eventarea);
-        evas_object_data_set(eventarea, _tooltip_key, tt);
-
-        just_created = EINA_TRUE;
-
-        evas_object_event_callback_add(eventarea, EVAS_CALLBACK_MOUSE_IN,
-           _elm_tooltip_obj_mouse_in_cb, tt);
-        evas_object_event_callback_add(eventarea, EVAS_CALLBACK_MOUSE_OUT,
-           (Evas_Object_Event_Cb)_elm_tooltip_obj_mouse_out_cb, tt);
-        evas_object_event_callback_add(eventarea, EVAS_CALLBACK_FREE,
-           _elm_tooltip_obj_free_cb, tt);
-
         if (owner != eventarea)
           evas_object_event_callback_add
             (owner, EVAS_CALLBACK_FREE, _elm_tooltip_obj_free_cb, tt);
@@ -959,6 +1021,8 @@ elm_object_sub_tooltip_content_cb_set(Evas_Object *eventarea, Evas_Object *owner
    tt->del_cb = del_cb;
 
    if (!just_created) _elm_tooltip_reconfigure_job_start(tt);
+   else if (efl_canvas_pointer_inside_get(eventarea, NULL) && (!tt->tooltip))
+     _elm_tooltip_show(tt);
    return;
 
  error:
@@ -1032,7 +1096,7 @@ elm_object_tooltip_unset(Evas_Object *obj)
 EAPI void
 elm_object_tooltip_style_set(Evas_Object *obj, const char *style)
 {
-   ELM_TOOLTIP_GET_OR_RETURN(tt, obj);
+   ELM_TOOLTIP_GET_OR_CREATE(tt, obj);
    if (!eina_stringshare_replace(&tt->style, style)) return;
    elm_tooltip_theme(tt);
 }
@@ -1047,7 +1111,7 @@ elm_object_tooltip_style_get(const Evas_Object *obj)
 EAPI Eina_Bool
 elm_object_tooltip_window_mode_set(Evas_Object *obj, Eina_Bool disable)
 {
-   ELM_TOOLTIP_GET_OR_RETURN(tt, obj, EINA_FALSE);
+   ELM_TOOLTIP_GET_OR_CREATE(tt, obj, EINA_FALSE);
    return tt->free_size = disable;
 }
 
