@@ -25,7 +25,7 @@
 #include <jpeglib.h>
 #include <jerror.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 #include <Evil.h>
 #endif
 
@@ -680,6 +680,7 @@ _emile_tgv_data(Emile_Image *image,
 
 on_error:
    if (image->compress) eina_binbuf_free(buffer);
+   _emile_image_file_source_unmap(image);
    return r;
 }
 
@@ -1601,7 +1602,7 @@ _emile_jpeg_head(Emile_Image *image,
         RECTS_CLIP_TO_RECT(load_region_x, load_region_y,
                            load_region_w, load_region_h,
                            0, 0, prop->w, prop->h);
-        if ((load_region_w <= 0) || (load_region_h <= 0))
+        if ((load_region_w == 0) || (load_region_h == 0))
           {
              jpeg_destroy_decompress(&cinfo);
              _emile_jpeg_membuf_src_term(&cinfo);
@@ -2325,6 +2326,7 @@ done:
 
    jpeg_destroy_decompress(&cinfo);
    _emile_jpeg_membuf_src_term(&cinfo);
+   _emile_image_file_source_unmap(image);
    return r;
 
 }
@@ -2389,6 +2391,8 @@ _emile_image_bind(Emile_Image *ei,
      return ei;
 
    /* File is not of that format */
+   if (!ei->bin_source)
+     eina_file_close(ei->source.f);
    free(ei);
    return NULL;
 }
