@@ -10,16 +10,14 @@ database_class_del(Eolian_Class *cl)
 {
    Eolian_Function *fid;
    Eolian_Event *ev;
+   Eolian_Part *pt;
    Eolian_Implement *impl;
    Eolian_Constructor *ctor;
-   const char *s;
 
-   if (!cl) return;
+   if (!cl || eolian_object_unref(&cl->base)) return;
 
-   if (cl->base.file) eina_stringshare_del(cl->base.file);
-
-   EINA_LIST_FREE(cl->inherits, s)
-     if (s) eina_stringshare_del(s);
+   eina_stringshare_del(cl->base.file);
+   eina_stringshare_del(cl->base.name);
 
    EINA_LIST_FREE(cl->implements, impl)
      database_implement_del(impl);
@@ -30,9 +28,8 @@ database_class_del(Eolian_Class *cl)
    EINA_LIST_FREE(cl->methods, fid) database_function_del(fid);
    EINA_LIST_FREE(cl->properties, fid) database_function_del(fid);
    EINA_LIST_FREE(cl->events, ev) database_event_del(ev);
+   EINA_LIST_FREE(cl->parts, pt) database_part_del(pt);
 
-   if (cl->name) eina_stringshare_del(cl->name);
-   if (cl->full_name) eina_stringshare_del(cl->full_name);
    if (cl->legacy_prefix) eina_stringshare_del(cl->legacy_prefix);
    if (cl->eo_prefix) eina_stringshare_del(cl->eo_prefix);
    if (cl->ev_prefix) eina_stringshare_del(cl->ev_prefix);
@@ -40,8 +37,5 @@ database_class_del(Eolian_Class *cl)
 
    database_doc_del(cl->doc);
 
-   if (cl->namespaces) EINA_LIST_FREE(cl->namespaces, s)
-      if (s) eina_stringshare_del(s);
-
    free(cl);
 }
