@@ -40,7 +40,6 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <dirent.h>
 #include <ctype.h>
 #include <pwd.h>
 
@@ -52,7 +51,7 @@
 # define PATH_MAX 4096
 #endif
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
@@ -68,6 +67,7 @@
 #include "ethumb_private.h"
 #include "Ethumb_Plugin.h"
 #include "md5.h"
+#include "../../static_libs/buildsystem/buildsystem.h"
 
 static Ethumb_Version _version = { VMAJ, VMIN, VMIC, VREV };
 EAPI Ethumb_Version *ethumb_version = &_version;
@@ -173,9 +173,7 @@ _ethumb_plugins_load(void)
                   const char **itr;
                   for (itr = built_modules; *itr != NULL; itr++)
                     {
-                       snprintf(buf, sizeof(buf),
-                                "%s/src/modules/ethumb/%s/.libs",
-                                PACKAGE_BUILD_DIR, *itr);
+                       bs_mod_get(buf, sizeof(buf), "ethumb", *itr);
                        _plugins = eina_module_list_get(_plugins, buf,
                                                        EINA_FALSE, NULL, NULL);
                     }
