@@ -8,7 +8,7 @@
 #include <sys/stat.h>
 #include <errno.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
