@@ -26,7 +26,7 @@ EAPI Evas_Object *
 evas_object_image_add(Evas *eo_e)
 {
    EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(eo_e, EVAS_CANVAS_CLASS), NULL);
-   return efl_add(EVAS_IMAGE_CLASS, eo_e,
+   return efl_add(EVAS_IMAGE_CLASS, evas_find(eo_e),
                  efl_gfx_fill_auto_set(efl_added, EINA_FALSE),
                  efl_canvas_object_legacy_ctor(efl_added));
 }
@@ -35,7 +35,7 @@ EAPI Evas_Object *
 evas_object_image_filled_add(Evas *eo_e)
 {
    EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(eo_e, EVAS_CANVAS_CLASS), NULL);
-   return efl_add(EVAS_IMAGE_CLASS, eo_e,
+   return efl_add(EVAS_IMAGE_CLASS, evas_find(eo_e),
                  efl_canvas_object_legacy_ctor(efl_added));
 }
 
@@ -90,8 +90,14 @@ evas_object_image_fill_get(const Evas_Object *obj,
                            Evas_Coord *x, Evas_Coord *y,
                            Evas_Coord *w, Evas_Coord *h)
 {
+   Eina_Rect r;
+
    EVAS_IMAGE_API(obj);
-   efl_gfx_fill_get(obj, x, y, w, h);
+   r = efl_gfx_fill_get(obj);
+   if (x) *x = r.x;
+   if (y) *y = r.y;
+   if (w) *w = r.w;
+   if (h) *h = r.h;
 }
 
 EAPI void
@@ -112,49 +118,52 @@ EAPI void
 evas_object_image_border_set(Evas_Object *obj, int l, int r, int t, int b)
 {
    EVAS_IMAGE_API(obj);
-   efl_image_border_set(obj, l, r, t, b);
+   efl_gfx_image_border_set(obj, l, r, t, b);
 }
 
 EAPI void
 evas_object_image_border_get(const Evas_Object *obj, int *l, int *r, int *t, int *b)
 {
    EVAS_IMAGE_API(obj);
-   efl_image_border_get(obj, l, r, t, b);
+   efl_gfx_image_border_get(obj, l, r, t, b);
 }
 
 EAPI void
 evas_object_image_border_scale_set(Evas_Object *obj, double scale)
 {
    EVAS_IMAGE_API(obj);
-   efl_image_border_scale_set(obj, scale);
+   efl_gfx_image_border_scale_set(obj, scale);
 }
 
 EAPI double
 evas_object_image_border_scale_get(const Evas_Object *obj)
 {
-   EVAS_IMAGE_API(obj, 1.0);
-   return efl_image_border_scale_get(obj);
+   EVAS_IMAGE_API(obj, 0.0);
+   return efl_gfx_image_border_scale_get(obj);
 }
 
 EAPI void
 evas_object_image_border_center_fill_set(Evas_Object *obj, Evas_Border_Fill_Mode fill)
 {
    EVAS_IMAGE_API(obj);
-   efl_image_border_center_fill_set(obj, (Efl_Gfx_Border_Fill_Mode) fill);
+   efl_gfx_image_border_center_fill_set(obj, (Efl_Gfx_Border_Fill_Mode) fill);
 }
 
 EAPI Evas_Border_Fill_Mode
 evas_object_image_border_center_fill_get(const Evas_Object *obj)
 {
-   EVAS_IMAGE_API(obj, EVAS_BORDER_FILL_DEFAULT);
-   return (Evas_Border_Fill_Mode) efl_image_border_center_fill_get(obj);
+   EVAS_IMAGE_API(obj, EVAS_BORDER_FILL_NONE);
+   return (Evas_Border_Fill_Mode) efl_gfx_image_border_center_fill_get(obj);
 }
 
 EAPI void
 evas_object_image_size_get(const Evas_Object *obj, int *w, int *h)
 {
+   Eina_Size2D sz;
    EVAS_IMAGE_API(obj);
-   efl_gfx_view_size_get(obj, w, h);
+   sz = efl_gfx_view_size_get(obj);
+   if (w) *w = sz.w;
+   if (h) *h = sz.h;
 }
 
 EAPI Evas_Colorspace
@@ -175,22 +184,25 @@ evas_object_image_stride_get(const Evas_Object *obj)
 EAPI void
 evas_object_image_data_update_add(Evas_Object *obj, int x, int y, int w, int h)
 {
+   Eina_Rect r;
+
    EVAS_IMAGE_API(obj);
-   efl_gfx_buffer_update_add(obj, x, y, w, h);
+   r = EINA_RECT(x, y, w, h);
+   efl_gfx_buffer_update_add(obj, &r);
 }
 
 EAPI void
 evas_object_image_file_set(Evas_Object *obj, const char *file, const char *key)
 {
    EVAS_IMAGE_API(obj);
-   _evas_image_file_set(obj, file, key);
+   efl_file_set(obj, file, key);
 }
 
 EAPI void
 evas_object_image_file_get(const Evas_Object *obj, const char **file, const char **key)
 {
    EVAS_IMAGE_API(obj);
-   _evas_image_file_get(obj, file, key);
+   efl_file_get(obj, file, key);
 }
 
 EAPI void
@@ -358,14 +370,14 @@ EAPI void
 evas_object_image_smooth_scale_set(Evas_Object *obj, Eina_Bool smooth_scale)
 {
    EVAS_IMAGE_API(obj);
-   efl_image_smooth_scale_set(obj, smooth_scale);
+   efl_gfx_image_smooth_scale_set(obj, smooth_scale);
 }
 
 EAPI Eina_Bool
 evas_object_image_smooth_scale_get(const Evas_Object *obj)
 {
    EVAS_IMAGE_API(obj, EINA_FALSE);
-   return efl_image_smooth_scale_get(obj);
+   return efl_gfx_image_smooth_scale_get(obj);
 }
 
 EAPI void
@@ -463,28 +475,28 @@ EAPI void
 evas_object_image_content_hint_set(Evas_Object *obj, Evas_Image_Content_Hint hint)
 {
    EVAS_IMAGE_API(obj);
-   return efl_image_content_hint_set(obj, hint);
+   return efl_gfx_image_content_hint_set(obj, hint);
 }
 
 EAPI Evas_Image_Content_Hint
 evas_object_image_content_hint_get(const Evas_Object *obj)
 {
    EVAS_IMAGE_API(obj, EVAS_IMAGE_CONTENT_HINT_NONE);
-   return efl_image_content_hint_get(obj);
+   return efl_gfx_image_content_hint_get(obj);
 }
 
 EAPI void
 evas_object_image_scale_hint_set(Evas_Object *obj, Evas_Image_Scale_Hint hint)
 {
    EVAS_IMAGE_API(obj);
-   return efl_image_scale_hint_set(obj, (Efl_Image_Scale_Hint) hint);
+   return efl_gfx_image_scale_hint_set(obj, (Efl_Gfx_Image_Scale_Hint) hint);
 }
 
 EAPI Evas_Image_Scale_Hint
 evas_object_image_scale_hint_get(const Evas_Object *obj)
 {
    EVAS_IMAGE_API(obj, EVAS_IMAGE_SCALE_HINT_NONE);
-   return (Evas_Image_Scale_Hint) efl_image_scale_hint_get(obj);
+   return (Evas_Image_Scale_Hint) efl_gfx_image_scale_hint_get(obj);
 }
 
 EAPI void
@@ -580,11 +592,11 @@ evas_object_image_data_set(Eo *eo_obj, void *data)
 
         if (o->engine_data)
           {
-             o->engine_data = ENFN->image_data_put(ENDT, o->engine_data, data);
+             o->engine_data = ENFN->image_data_put(ENC, o->engine_data, data);
           }
         else
           {
-             o->engine_data = ENFN->image_new_from_data(ENDT,
+             o->engine_data = ENFN->image_new_from_data(ENC,
                                                         o->cur->image.w,
                                                         o->cur->image.h,
                                                         data,
@@ -596,13 +608,13 @@ evas_object_image_data_set(Eo *eo_obj, void *data)
              int stride = 0;
 
              if (ENFN->image_scale_hint_set)
-               ENFN->image_scale_hint_set(ENDT, o->engine_data, o->scale_hint);
+               ENFN->image_scale_hint_set(ENC, o->engine_data, o->scale_hint);
 
              if (ENFN->image_content_hint_set)
-               ENFN->image_content_hint_set(ENDT, o->engine_data, o->content_hint);
+               ENFN->image_content_hint_set(ENC, o->engine_data, o->content_hint);
 
              if (ENFN->image_stride_get)
-               ENFN->image_stride_get(ENDT, o->engine_data, &stride);
+               ENFN->image_stride_get(ENC, o->engine_data, &stride);
              else
                stride = o->cur->image.w * 4;
 
@@ -619,7 +631,7 @@ evas_object_image_data_set(Eo *eo_obj, void *data)
      {
         if (o->engine_data)
           {
-             ENFN->image_free(ENDT, o->engine_data);
+             ENFN->image_free(ENC, o->engine_data);
              o->changed = EINA_TRUE;
              evas_object_change(eo_obj, obj);
           }
@@ -636,20 +648,14 @@ evas_object_image_data_set(Eo *eo_obj, void *data)
         EINA_COW_IMAGE_STATE_WRITE_END(o, state_write);
 
         o->engine_data = NULL;
-        if (o->file_obj)
-          {
-             efl_del(o->file_obj);
-             o->file_obj = NULL;
-          }
      }
 /* FIXME - in engine call above
    if (o->engine_data)
-     o->engine_data = ENFN->image_alpha_set(ENDT, o->engine_data, o->cur->has_alpha);
+     o->engine_data = ENFN->image_alpha_set(ENC, o->engine_data, o->cur->has_alpha);
 */
    if (o->pixels_checked_out > 0) o->pixels_checked_out--;
    if (p_data != o->engine_data)
      {
-        EVAS_OBJECT_WRITE_IMAGE_FREE_FILE_AND_KEY(o);
         o->pixels_checked_out = 0;
      }
    if (resize_call) evas_object_inform_call_image_resize(eo_obj);
@@ -663,7 +669,7 @@ _image_to_free_del_cb(void *data)
 
    obj = efl_data_scope_safe_get(px_entry->object, EFL_CANVAS_OBJECT_CLASS);
    EINA_SAFETY_ON_NULL_RETURN(obj);
-   ENFN->image_free(ENDT, px_entry->image);
+   ENFN->image_free(ENC, px_entry->image);
    free(px_entry);
 }
 
@@ -688,10 +694,10 @@ evas_object_image_data_get(const Eo *eo_obj, Eina_Bool for_writing)
 
    data = NULL;
    if (ENFN->image_scale_hint_set)
-     ENFN->image_scale_hint_set(ENDT, o->engine_data, o->scale_hint);
+     ENFN->image_scale_hint_set(ENC, o->engine_data, o->scale_hint);
    if (ENFN->image_content_hint_set)
-     ENFN->image_content_hint_set(ENDT, o->engine_data, o->content_hint);
-   pixels = ENFN->image_data_get(ENDT, o->engine_data, for_writing, &data, &o->load_error, &tofree);
+     ENFN->image_content_hint_set(ENC, o->engine_data, o->content_hint);
+   pixels = ENFN->image_data_get(ENC, o->engine_data, for_writing, &data, &o->load_error, &tofree);
 
    /* if we fail to get engine_data, we have to return NULL */
    if (!pixels || !data) goto error;
@@ -700,7 +706,7 @@ evas_object_image_data_get(const Eo *eo_obj, Eina_Bool for_writing)
      {
         o->engine_data = pixels;
         if (ENFN->image_stride_get)
-          ENFN->image_stride_get(ENDT, o->engine_data, &stride);
+          ENFN->image_stride_get(ENC, o->engine_data, &stride);
         else
            stride = o->cur->image.w * 4;
 
@@ -736,7 +742,6 @@ evas_object_image_data_get(const Eo *eo_obj, Eina_Bool for_writing)
    if (for_writing)
      {
         o->written = EINA_TRUE;
-        EVAS_OBJECT_WRITE_IMAGE_FREE_FILE_AND_KEY(o);
      }
 
    return data;
@@ -744,7 +749,7 @@ evas_object_image_data_get(const Eo *eo_obj, Eina_Bool for_writing)
 error:
    free(px_entry);
    if (tofree && pixels)
-     ENFN->image_free(ENDT, pixels);
+     ENFN->image_free(ENC, pixels);
    return NULL;
 }
 
@@ -762,13 +767,8 @@ evas_object_image_data_copy_set(Eo *eo_obj, void *data)
    if ((o->cur->image.w <= 0) ||
        (o->cur->image.h <= 0)) return;
    if (o->engine_data)
-     ENFN->image_free(ENDT, o->engine_data);
-   if (o->file_obj)
-     {
-        efl_del(o->file_obj);
-        o->file_obj = NULL;
-     }
-   o->engine_data = ENFN->image_new_from_copied_data(ENDT,
+     ENFN->image_free(ENC, o->engine_data);
+   o->engine_data = ENFN->image_new_from_copied_data(ENC,
                                                      o->cur->image.w,
                                                      o->cur->image.h,
                                                      data,
@@ -779,13 +779,13 @@ evas_object_image_data_copy_set(Eo *eo_obj, void *data)
         int stride = 0;
 
         o->engine_data =
-          ENFN->image_alpha_set(ENDT, o->engine_data, o->cur->has_alpha);
+          ENFN->image_alpha_set(ENC, o->engine_data, o->cur->has_alpha);
         if (ENFN->image_scale_hint_set)
-          ENFN->image_scale_hint_set(ENDT, o->engine_data, o->scale_hint);
+          ENFN->image_scale_hint_set(ENC, o->engine_data, o->scale_hint);
         if (ENFN->image_content_hint_set)
-          ENFN->image_content_hint_set(ENDT, o->engine_data, o->content_hint);
+          ENFN->image_content_hint_set(ENC, o->engine_data, o->content_hint);
         if (ENFN->image_stride_get)
-          ENFN->image_stride_get(ENDT, o->engine_data, &stride);
+          ENFN->image_stride_get(ENC, o->engine_data, &stride);
         else
           stride = o->cur->image.w * 4;
 
@@ -798,7 +798,6 @@ evas_object_image_data_copy_set(Eo *eo_obj, void *data)
         o->written = EINA_TRUE;
      }
    o->pixels_checked_out = 0;
-   EVAS_OBJECT_WRITE_IMAGE_FREE_FILE_AND_KEY(o);
 }
 
 /* Evas_Object equivalent: pixels_set(null, w, h, cspace) to (re)allocate an image */
@@ -830,19 +829,19 @@ evas_object_image_size_set(Evas_Object *eo_obj, int w, int h)
    EINA_COW_IMAGE_STATE_WRITE_END(o, state_write);
 
    if (o->engine_data)
-      o->engine_data = ENFN->image_size_set(ENDT, o->engine_data, w, h);
+      o->engine_data = ENFN->image_size_set(ENC, o->engine_data, w, h);
    else
       o->engine_data = ENFN->image_new_from_copied_data
-        (ENDT, w, h, NULL, o->cur->has_alpha, o->cur->cspace);
+        (ENC, w, h, NULL, o->cur->has_alpha, o->cur->cspace);
 
    if (o->engine_data)
      {
         if (ENFN->image_scale_hint_set)
-           ENFN->image_scale_hint_set(ENDT, o->engine_data, o->scale_hint);
+           ENFN->image_scale_hint_set(ENC, o->engine_data, o->scale_hint);
         if (ENFN->image_content_hint_set)
-           ENFN->image_content_hint_set(ENDT, o->engine_data, o->content_hint);
+           ENFN->image_content_hint_set(ENC, o->engine_data, o->content_hint);
         if (ENFN->image_stride_get)
-           ENFN->image_stride_get(ENDT, o->engine_data, &stride);
+           ENFN->image_stride_get(ENC, o->engine_data, &stride);
         else
            stride = w * 4;
      }
@@ -854,7 +853,7 @@ evas_object_image_size_set(Evas_Object *eo_obj, int w, int h)
 
 /* FIXME - in engine call above
    if (o->engine_data)
-     o->engine_data = ENFN->image_alpha_set(ENDT, o->engine_data, o->cur->has_alpha);
+     o->engine_data = ENFN->image_alpha_set(ENC, o->engine_data, o->cur->has_alpha);
 */
         EINA_COW_WRITE_BEGIN(evas_object_image_state_cow, o->prev, Evas_Object_Image_State, prev_write)
           EVAS_OBJECT_IMAGE_FREE_FILE_AND_KEY(cur_write, prev_write);
@@ -885,7 +884,7 @@ evas_object_image_colorspace_set(Evas_Object *eo_obj, Evas_Colorspace cspace)
    EINA_COW_IMAGE_STATE_WRITE_END(o, state_write);
 
    if (o->engine_data)
-     ENFN->image_colorspace_set(ENDT, o->engine_data, cspace);
+     ENFN->image_colorspace_set(ENC, o->engine_data, cspace);
 }
 
 /* old video surfaces */
@@ -1086,17 +1085,17 @@ evas_object_image_data_convert(Evas_Object *eo_obj, Evas_Colorspace to_cspace)
    if ((o->preloading) && (o->engine_data))
      {
         o->preloading = EINA_FALSE;
-        ENFN->image_data_preload_cancel(ENDT, o->engine_data, eo_obj);
+        ENFN->image_data_preload_cancel(ENC, o->engine_data, eo_obj);
      }
    if (!o->engine_data) return NULL;
    if (o->video_surface)
      o->pixels->video.update_pixels(o->pixels->video.data, eo_obj, &o->pixels->video);
    if (o->cur->cspace == to_cspace) return NULL;
    data = NULL;
-   engine_data = ENFN->image_data_get(ENDT, o->engine_data, 0, &data, &o->load_error, NULL);
+   engine_data = ENFN->image_data_get(ENC, o->engine_data, 0, &data, &o->load_error, NULL);
    result = _evas_image_data_convert_internal(o, data, to_cspace);
    if (engine_data)
-     o->engine_data = ENFN->image_data_put(ENDT, engine_data, data);
+     o->engine_data = ENFN->image_data_put(ENC, engine_data, data);
 
    return result;
 }
@@ -1115,20 +1114,23 @@ evas_object_image_reload(Evas_Object *eo_obj)
    if ((o->preloading) && (o->engine_data))
      {
         o->preloading = EINA_FALSE;
-        ENFN->image_data_preload_cancel(ENDT, o->engine_data, eo_obj);
+        ENFN->image_data_preload_cancel(ENC, o->engine_data, eo_obj);
      }
-   if ((!o->cur->u.file) ||
+   if ((!o->cur->f) ||
        (o->pixels_checked_out > 0)) return;
    if (o->engine_data)
-     o->engine_data = ENFN->image_dirty_region(ENDT, o->engine_data, 0, 0, o->cur->image.w, o->cur->image.h);
+     o->engine_data = ENFN->image_dirty_region(ENC, o->engine_data, 0, 0, o->cur->image.w, o->cur->image.h);
+
+   eina_file_refresh(o->cur->f);
    o->written = EINA_FALSE;
+
    _evas_image_unload(eo_obj, obj, 1);
    evas_object_inform_call_image_unloaded(eo_obj);
    _evas_image_load(eo_obj, obj, o);
 
    EINA_COW_WRITE_BEGIN(evas_object_image_state_cow, o->prev, Evas_Object_Image_State, prev_write)
      {
-        prev_write->u.file = NULL;
+        prev_write->f = NULL;
         prev_write->key = NULL;
      }
    EINA_COW_WRITE_END(evas_object_image_state_cow, o->prev, prev_write);
@@ -1168,7 +1170,7 @@ evas_object_image_pixels_import(Evas_Object *eo_obj, Evas_Pixel_Import_Source *p
                   DATA32 *image_pixels = NULL;
 
                   o->engine_data =
-                    ENFN->image_data_get(ENDT,
+                    ENFN->image_data_get(ENC,
                                          o->engine_data,
                                          1,
                                          &image_pixels,
@@ -1177,10 +1179,10 @@ evas_object_image_pixels_import(Evas_Object *eo_obj, Evas_Pixel_Import_Source *p
 /*		  memcpy(image_pixels, pixels->rows, o->cur->image.w * o->cur->image.h * 4);*/
                   if (o->engine_data)
                     o->engine_data =
-                    ENFN->image_data_put(ENDT, o->engine_data, image_pixels);
+                    ENFN->image_data_put(ENC, o->engine_data, image_pixels);
                   if (o->engine_data)
                     o->engine_data =
-                    ENFN->image_alpha_set(ENDT, o->engine_data, o->cur->has_alpha);
+                    ENFN->image_alpha_set(ENC, o->engine_data, o->cur->has_alpha);
                   o->changed = EINA_TRUE;
                   evas_object_change(eo_obj, obj);
                }
@@ -1193,13 +1195,13 @@ evas_object_image_pixels_import(Evas_Object *eo_obj, Evas_Pixel_Import_Source *p
                {
                   DATA32 *image_pixels = NULL;
 
-                  o->engine_data = ENFN->image_data_get(ENDT, o->engine_data, 1, &image_pixels,&o->load_error, NULL);
+                  o->engine_data = ENFN->image_data_get(ENC, o->engine_data, 1, &image_pixels,&o->load_error, NULL);
                   if (image_pixels)
                     evas_common_convert_yuv_422p_601_rgba((DATA8 **) pixels->rows, (DATA8 *) image_pixels, o->cur->image.w, o->cur->image.h);
                   if (o->engine_data)
-                    o->engine_data = ENFN->image_data_put(ENDT, o->engine_data, image_pixels);
+                    o->engine_data = ENFN->image_data_put(ENC, o->engine_data, image_pixels);
                   if (o->engine_data)
-                    o->engine_data = ENFN->image_alpha_set(ENDT, o->engine_data, o->cur->has_alpha);
+                    o->engine_data = ENFN->image_alpha_set(ENC, o->engine_data, o->cur->has_alpha);
                   o->changed = EINA_TRUE;
                   evas_object_change(eo_obj, obj);
                }
@@ -1212,6 +1214,21 @@ evas_object_image_pixels_import(Evas_Object *eo_obj, Evas_Pixel_Import_Source *p
    return EINA_TRUE;
 }
 
+EAPI Eina_Bool
+evas_image_max_size_get(Eo *eo_e, int *w, int *h)
+{
+   Eina_Size2D size;
+   Eina_Bool ret;
+
+   ret = efl_canvas_scene_image_max_size_get(eo_e, &size);
+   if (ret)
+     {
+        if (w) *w = size.w;
+        if (h) *h = size.h;
+     }
+   return ret;
+}
+
 /* deprecated */
 EAPI void
 evas_object_image_alpha_mask_set(Evas_Object *eo_obj EINA_UNUSED, Eina_Bool ismask EINA_UNUSED)
@@ -1220,36 +1237,16 @@ evas_object_image_alpha_mask_set(Evas_Object *eo_obj EINA_UNUSED, Eina_Bool isma
    EVAS_IMAGE_LEGACY_API(eo_obj);
 }
 
-EOLIAN static Eina_Bool
-_evas_image_efl_file_file_set(Eo *obj, void *pd EINA_UNUSED, const char *file, const char *key)
-{
-   WRN("efl_file_set shouldn't be used on Evas.Image. please switch to Efl.Canvas.Image");
-   EVAS_IMAGE_API(obj, EINA_FALSE);
-   return _evas_image_file_set(obj, file, key);
-}
-
-EOLIAN static void
-_evas_image_efl_file_file_get(Eo *obj, void *pd EINA_UNUSED, const char **file, const char **key)
-{
-   WRN("efl_file_get shouldn't be used on Evas.Image. please switch to Efl.Canvas.Image");
-   if (file) *file = NULL;
-   if (key) *key = NULL;
-   EVAS_IMAGE_API(obj);
-   _evas_image_file_get(obj, file, key);
-}
-
 EOLIAN static Eina_Bool
 _evas_image_efl_file_mmap_set(Eo *obj, void *pd EINA_UNUSED, const Eina_File *f, const char *key)
 {
-   WRN("efl_file_mmap_set shouldn't be used on Evas.Image. please switch to Efl.Canvas.Image");
    EVAS_IMAGE_API(obj, EINA_FALSE);
    return _evas_image_mmap_set(obj, f, key);
 }
 
 EOLIAN static void
-_evas_image_efl_file_mmap_get(Eo *obj, void *pd EINA_UNUSED, const Eina_File **f, const char **key)
+_evas_image_efl_file_mmap_get(const Eo *obj, void *pd EINA_UNUSED, const Eina_File **f, const char **key)
 {
-   WRN("efl_file_mmap_get shouldn't be used on Evas.Image. please switch to Efl.Canvas.Image");
    if (f) *f = NULL;
    if (key) *key = NULL;
    EVAS_IMAGE_API(obj);
