@@ -69,7 +69,7 @@ struct _Evas_Object_Image_Pixels
 
 struct _Evas_Object_Image_State
 {
-   Evas_Coord_Rectangle fill;
+   Eina_Rectangle   fill;
    struct {
       short         w, h, stride;
    } image;
@@ -83,10 +83,7 @@ struct _Evas_Object_Image_State
    Evas_Map      *defmap;
    Evas_Canvas3D_Scene *scene;
 
-   union {
-      const char    *file;
-      Eina_File     *f;
-   } u;
+   Eina_File     *f;
    const char    *key;
    int            frame;
 
@@ -97,7 +94,6 @@ struct _Evas_Object_Image_State
    Eina_Bool      has_alpha :1;
    Eina_Bool      opaque_valid : 1;
    Eina_Bool      opaque : 1;
-   Eina_Bool      mmaped_source : 1;
 };
 
 struct _Evas_Image_Data
@@ -109,15 +105,14 @@ struct _Evas_Image_Data
 
    void             *engine_data;
    void             *engine_data_prep;
-   Efl_Vpath_File   *file_obj;
 
    void             *plane;
 
    int               pixels_checked_out;
    int               load_error;
 
-   Efl_Image_Scale_Hint   scale_hint;
-   Efl_Image_Content_Hint content_hint;
+   Efl_Gfx_Image_Scale_Hint   scale_hint;
+   Efl_Gfx_Image_Content_Hint content_hint;
    Efl_Flip               flip_value;
    Efl_Orient             orient_value;
 
@@ -130,7 +125,8 @@ struct _Evas_Image_Data
    Eina_Bool         filled : 1;
    Eina_Bool         filled_set : 1;
    Eina_Bool         proxyrendering : 1;
-   Eina_Bool         preloading : 1;
+   Eina_Bool         preloading : 1;      //on preloading
+   Eina_Bool         preloaded: 1;        //just finsihed preloading
    Eina_Bool         video_surface : 1;
    Eina_Bool         video_visible : 1;
    Eina_Bool         created : 1;
@@ -153,7 +149,7 @@ struct _Evas_Image_Data
 };
 
 /* shared functions between legacy and new eo classes */
-void _evas_image_init_set(const Eina_File *f, const char *file, const char *key, Eo *eo_obj, Evas_Object_Protected_Data *obj, Evas_Image_Data *o, Evas_Image_Load_Opts *lo);
+void _evas_image_init_set(const Eina_File *f, const char *key, Eo *eo_obj, Evas_Object_Protected_Data *obj, Evas_Image_Data *o, Evas_Image_Load_Opts *lo);
 void _evas_image_done_set(Eo *eo_obj, Evas_Object_Protected_Data *obj, Evas_Image_Data *o);
 void _evas_image_cleanup(Evas_Object *eo_obj, Evas_Object_Protected_Data *obj, Evas_Image_Data *o);
 void *_evas_image_pixels_get(Eo *eo_obj, Evas_Object_Protected_Data *obj, void *engine, void *output, void *context, void *surface, int x, int y, int *imagew, int *imageh, int *uvw, int *uvh, Eina_Bool filtered, Eina_Bool needs_post_render);
@@ -168,7 +164,7 @@ Eina_Bool _evas_image_file_set(Eo *eo_obj, const char *file, const char *key);
 void _evas_image_file_get(const Eo *eo_obj, const char **file, const char **key);
 
 /* Efl.Image.Load */
-Efl_Image_Load_Error _evas_image_load_error_get(const Eo *eo_obj);
+Efl_Gfx_Image_Load_Error _evas_image_load_error_get(const Eo *eo_obj);
 void _evas_image_load_post_update(Evas_Object *eo_obj, Evas_Object_Protected_Data *obj);
 void _evas_image_load_async_start(Eo *eo_obj);
 void _evas_image_load_async_cancel(Eo *eo_obj);
@@ -187,10 +183,10 @@ Eina_Bool _evas_image_load_orientation_get(const Eo *eo_obj);
 Eina_Bool _evas_image_load_region_support_get(const Eo *eo_obj);
 void _evas_image_orientation_set(Eo *eo_obj, Evas_Image_Data *o, Evas_Image_Orient orient);
 
-/* Efl.Image.Animated */
+/* Efl.Image_Animation_Controller */
 Eina_Bool _evas_image_animated_get(const Eo *eo_obj);
 int _evas_image_animated_frame_count_get(const Eo *eo_obj);
-Efl_Image_Animated_Loop_Hint _evas_image_animated_loop_type_get(const Eo *eo_obj);
+Efl_Gfx_Image_Animation_Controller_Loop_Hint _evas_image_animated_loop_type_get(const Eo *eo_obj);
 int _evas_image_animated_loop_count_get(const Eo *eo_obj);
 double _evas_image_animated_frame_duration_get(const Eo *eo_obj, int start_frame, int frame_num);
 Eina_Bool _evas_image_animated_frame_set(Eo *eo_obj, int frame_index);
@@ -240,7 +236,7 @@ void _evas_image_load(Evas_Object *eo_obj, Evas_Object_Protected_Data *obj, Evas
   EINA_COW_WRITE_END(evas_object_image_load_opts_cow, Obj->load_opts, Write)
 
 # define EVAS_OBJECT_WRITE_IMAGE_FREE_FILE_AND_KEY(Obj)                 \
-  if ((!Obj->cur->mmaped_source && Obj->cur->u.file) || Obj->cur->key) \
+  if (Obj->cur->key) \
     {                                                                   \
        EINA_COW_IMAGE_STATE_WRITE_BEGIN(Obj, cur_write)                 \
          {                                                              \
