@@ -48,7 +48,7 @@ static void _sizing_eval(Evas_Object *obj);
    EVAS_OBJECT_BOX_DATA_GET(o, ptr);                                    \
 if (!ptr)                                                               \
 {                                                                       \
-   CRI("no widget data for object %p (%s)",                            \
+   ERR("No widget data for object %p (%s)",                            \
         o, evas_object_type_get(o));                                    \
    fflush(stderr);                                                      \
    return;                                                              \
@@ -58,7 +58,7 @@ if (!ptr)                                                               \
    EVAS_OBJECT_BOX_DATA_GET(o, ptr);                                    \
 if (!ptr)                                                               \
 {                                                                       \
-   CRI("no widget data for object %p (%s)",                            \
+   ERR("No widget data for object %p (%s)",                            \
         o, evas_object_type_get(o));                                    \
    fflush(stderr);                                                      \
    return val;                                                          \
@@ -121,7 +121,7 @@ _on_child_resize(void *data, const Efl_Event *event EINA_UNUSED)
 }
 
 static void
-_on_child_del(void *data, const Efl_Event *event)
+_on_child_invalidate(void *data, const Efl_Event *event)
 {
    Evas_Object *box = data;
 
@@ -165,9 +165,9 @@ _evas_object_box_option_new(Evas_Object *o, Evas_Object_Box_Data *priv EINA_UNUS
 }
 
 EFL_CALLBACKS_ARRAY_DEFINE(evas_object_box_callbacks,
-  { EFL_GFX_EVENT_RESIZE, _on_child_resize },
-  { EFL_EVENT_DEL, _on_child_del },
-  { EFL_GFX_EVENT_CHANGE_SIZE_HINTS, _on_child_hints_changed }
+  { EFL_GFX_ENTITY_EVENT_RESIZE, _on_child_resize },
+  { EFL_EVENT_INVALIDATE, _on_child_invalidate },
+  { EFL_GFX_ENTITY_EVENT_CHANGE_SIZE_HINTS, _on_child_hints_changed }
 );
 
 static void
@@ -405,7 +405,7 @@ _evas_box_efl_canvas_group_group_add(Eo *eo_obj, Evas_Object_Box_Data *priv)
 
    // make sure evas box smart data is fully initialized and set (for legacy)
    // this assumes only box and smart clipped access the smart data
-   cso = efl_data_scope_get(eo_obj, EFL_CANVAS_GROUP_CLIPPED_CLASS);
+   cso = evas_object_smart_data_get(eo_obj);
    priv->base = *cso;
    evas_object_smart_data_set(eo_obj, priv);
 }
@@ -432,22 +432,22 @@ _evas_box_efl_canvas_group_group_del(Eo *o, Evas_Object_Box_Data *priv)
 }
 
 EOLIAN static void
-_evas_box_efl_gfx_size_set(Eo *o, Evas_Object_Box_Data *_pd EINA_UNUSED, Evas_Coord w, Evas_Coord h)
+_evas_box_efl_gfx_entity_size_set(Eo *o, Evas_Object_Box_Data *_pd EINA_UNUSED, Eina_Size2D sz)
 {
-   if (_evas_object_intercept_call(o, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call(o, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
-   efl_gfx_size_set(efl_super(o, MY_CLASS), w, h);
+   efl_gfx_entity_size_set(efl_super(o, MY_CLASS), sz);
    evas_object_smart_changed(o);
 }
 
 EOLIAN static void
-_evas_box_efl_gfx_position_set(Eo *o, Evas_Object_Box_Data *_pd EINA_UNUSED, Evas_Coord x, Evas_Coord y)
+_evas_box_efl_gfx_entity_position_set(Eo *o, Evas_Object_Box_Data *_pd EINA_UNUSED, Eina_Position2D pos)
 {
-   if (_evas_object_intercept_call(o, EVAS_OBJECT_INTERCEPT_CB_MOVE , 0, x, y))
+   if (_evas_object_intercept_call(o, EVAS_OBJECT_INTERCEPT_CB_MOVE , 0, pos.x, pos.y))
      return;
 
-   efl_gfx_position_set(efl_super(o, MY_CLASS), x, y);
+   efl_gfx_entity_position_set(efl_super(o, MY_CLASS), pos);
    evas_object_smart_changed(o);
 }
 
@@ -475,15 +475,14 @@ _evas_box_efl_canvas_group_group_calculate(Eo *o, Evas_Object_Box_Data *priv)
 EAPI Evas_Object *
 evas_object_box_add(Evas *evas)
 {
-   MAGIC_CHECK(evas, Evas, MAGIC_EVAS);
-   return NULL;
-   MAGIC_CHECK_END();
-   return efl_add(MY_CLASS, evas, efl_canvas_object_legacy_ctor(efl_added));
+   EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(evas, EVAS_CANVAS_CLASS), NULL);
+   return efl_add(MY_CLASS, evas_find(evas), efl_canvas_object_legacy_ctor(efl_added));
 }
 
 EOLIAN static Eo *
 _evas_box_efl_object_constructor(Eo *obj, Evas_Object_Box_Data *class_data EINA_UNUSED)
 {
+   efl_canvas_group_clipped_set(obj, EINA_TRUE);
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    evas_object_smart_callbacks_descriptions_set(obj, _signals);
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
@@ -607,7 +606,7 @@ _sizing_eval(Evas_Object *obj)
    Evas_Coord minw, minh, maxw, maxh;
    Evas_Coord w, h;
 
-   efl_gfx_size_hint_combined_min_get(obj, &minw, &minh);
+   evas_object_size_hint_combined_min_get(obj, &minw, &minh);
    evas_object_size_hint_max_get(obj, &maxw, &maxh);
    evas_object_geometry_get(obj, NULL, NULL, &w, &h);
 
@@ -637,7 +636,7 @@ _evas_object_box_layout_horizontal_weight_apply(Evas_Object_Box_Data *priv, Evas
           {
              int min_w;
 
-             efl_gfx_size_hint_combined_min_get(o, &min_w, NULL);
+             evas_object_size_hint_combined_min_get(o, &min_w, NULL);
              evas_object_resize(o, min_w, h);
           }
         else
@@ -677,7 +676,7 @@ EOLIAN static void
 _evas_box_layout_horizontal(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Data *boxdata EINA_UNUSED, void *data EINA_UNUSED)
 {
    int pad_inc = 0, sub_pixel = 0;
-   int req_w, global_pad, remaining, top_h = 0;
+   int req_w, global_pad, remaining, top_h = 0, totalminw = 0;
    double weight_total = 0.0;
    int weight_use = 0;
    int x, y, w, h;
@@ -703,11 +702,13 @@ _evas_box_layout_horizontal(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_D
    evas_object_geometry_get(o, &x, &y, &w, &h);
    global_pad = priv->pad.h;
    req_w = global_pad * (n_children - 1);
+   totalminw = req_w;
 
    EINA_LIST_FOREACH(priv->children, l, opt)
      {
         int padding_l, padding_r;
         double weight_x;
+        int minw;
 
         _sizing_eval(opt->obj);
         evas_object_size_hint_weight_get(opt->obj, &weight_x, NULL);
@@ -715,12 +716,11 @@ _evas_box_layout_horizontal(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_D
            (opt->obj, &padding_l, &padding_r, NULL, NULL);
         req_w += padding_l + padding_r;
 
+        evas_object_size_hint_combined_min_get(opt->obj, &minw, NULL);
+        if (minw > 0) totalminw += minw + padding_l + padding_r;
         if (EINA_DBL_EQ(weight_x, 0.0))
           {
-             int child_w;
-
-             evas_object_geometry_get(opt->obj, NULL, NULL, &child_w, NULL);
-             req_w += child_w;
+             if (minw > 0) req_w += minw;
           }
         else
           {
@@ -749,7 +749,7 @@ _evas_box_layout_horizontal(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_D
 
    EINA_LIST_FOREACH(priv->children, l, opt)
      {
-        int child_w, child_h, max_h, new_h, off_x, off_y;
+        int child_w, child_h, max_h, new_h, off_x, off_y, minw, minh;
         int padding_l, padding_r, padding_t, padding_b;
         double align_y;
 
@@ -758,10 +758,11 @@ _evas_box_layout_horizontal(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_D
            (opt->obj, &padding_l, &padding_r, &padding_t, &padding_b);
         evas_object_size_hint_max_get(opt->obj, NULL, &max_h);
 
+        evas_object_size_hint_combined_min_get(opt->obj, &minw, &minh);
         evas_object_geometry_get(opt->obj, NULL, NULL, &child_w, &child_h);
 
         off_x = padding_l;
-        new_h = child_h;
+        new_h = minh;
         if (new_h > top_h) top_h = new_h;
 
         _layout_set_offset_and_expand_dimension_space_max_bounded
@@ -780,7 +781,7 @@ _evas_box_layout_horizontal(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_D
           }
      }
 
-   evas_object_size_hint_min_set(o, req_w, top_h);
+   evas_object_size_hint_min_set(o, totalminw, top_h);
 }
 
 static int
@@ -801,7 +802,7 @@ _evas_object_box_layout_vertical_weight_apply(Evas_Object_Box_Data *priv, Evas_O
           {
              int min_h;
 
-             efl_gfx_size_hint_combined_min_get(o, NULL, &min_h);
+             evas_object_size_hint_combined_min_get(o, NULL, &min_h);
              evas_object_resize(o, w, min_h);
           }
         else
@@ -841,7 +842,7 @@ EOLIAN static void
 _evas_box_layout_vertical(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Data *boxdata EINA_UNUSED, void *data EINA_UNUSED)
 {
    int pad_inc = 0, sub_pixel = 0;
-   int req_h, global_pad, remaining, top_w = 0;
+   int req_h, global_pad, remaining, top_w = 0, totalminh = 0;
    double weight_total = 0.0;
    int weight_use = 0;
    int x, y, w, h;
@@ -867,11 +868,13 @@ _evas_box_layout_vertical(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Dat
    evas_object_geometry_get(o, &x, &y, &w, &h);
    global_pad = priv->pad.v;
    req_h = global_pad * (n_children - 1);
+   totalminh = req_h;
 
    EINA_LIST_FOREACH(priv->children, l, opt)
      {
         int padding_t, padding_b;
         double weight_y;
+        int minh;
 
         _sizing_eval(opt->obj);
         evas_object_size_hint_weight_get(opt->obj, NULL, &weight_y);
@@ -879,12 +882,11 @@ _evas_box_layout_vertical(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Dat
            (opt->obj, NULL, NULL, &padding_t, &padding_b);
         req_h += padding_t + padding_b;
 
+        evas_object_size_hint_combined_min_get(opt->obj, NULL, &minh);
+        if (minh > 0) totalminh += minh + padding_t + padding_b;
         if (EINA_DBL_EQ(weight_y, 0.0))
           {
-             int child_h;
-
-             evas_object_geometry_get(opt->obj, NULL, NULL, NULL, &child_h);
-             req_h += child_h;
+             if (minh > 0) req_h += minh;
           }
         else
           {
@@ -913,7 +915,7 @@ _evas_box_layout_vertical(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Dat
 
    EINA_LIST_FOREACH(priv->children, l, opt)
      {
-        int child_w, child_h, max_w, new_w, off_x, off_y;
+        int child_w, child_h, max_w, new_w, off_x, off_y, minw, minh;
         int padding_l, padding_r, padding_t, padding_b;
         double align_x;
 
@@ -922,10 +924,11 @@ _evas_box_layout_vertical(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Dat
            (opt->obj, &padding_l, &padding_r, &padding_t, &padding_b);
         evas_object_size_hint_max_get(opt->obj, &max_w, NULL);
 
+        evas_object_size_hint_combined_min_get(opt->obj, &minw, &minh);
         evas_object_geometry_get(opt->obj, NULL, NULL, &child_w, &child_h);
 
         off_y = padding_t;
-        new_w = child_w;
+        new_w = minw;
 
         _layout_set_offset_and_expand_dimension_space_max_bounded
            (child_w, &new_w, w, max_w, &off_x, align_x, padding_l, padding_r);
@@ -945,7 +948,7 @@ _evas_box_layout_vertical(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Dat
           }
      }
 
-   evas_object_size_hint_min_set(o, top_w, req_h);
+   evas_object_size_hint_min_set(o, top_w, totalminh);
 }
 
 EOLIAN static void
@@ -981,7 +984,7 @@ _evas_box_layout_homogeneous_horizontal(Eo *o, Evas_Object_Box_Data *priv, Evas_
         evas_object_size_hint_padding_get
            (opt->obj, &padding_l, &padding_r, &padding_t, &padding_b);
         evas_object_size_hint_max_get(opt->obj, &max_w, &max_h);
-        efl_gfx_size_hint_combined_min_get(opt->obj, &min_w, NULL);
+        evas_object_size_hint_combined_min_get(opt->obj, &min_w, NULL);
 
         _sizing_eval(opt->obj);
         evas_object_geometry_get(opt->obj, NULL, NULL, &child_w, &child_h);
@@ -1045,7 +1048,7 @@ _evas_box_layout_homogeneous_vertical(Eo *o, Evas_Object_Box_Data *priv, Evas_Ob
         evas_object_size_hint_padding_get
            (opt->obj, &padding_l, &padding_r, &padding_t, &padding_b);
         evas_object_size_hint_max_get(opt->obj, &max_w, &max_h);
-        efl_gfx_size_hint_combined_min_get(opt->obj, NULL, &min_h);
+        evas_object_size_hint_combined_min_get(opt->obj, NULL, &min_h);
 
         _sizing_eval(opt->obj);
         evas_object_geometry_get(opt->obj, NULL, NULL, &child_w, &child_h);
@@ -1131,7 +1134,7 @@ _evas_box_layout_homogeneous_max_size_horizontal(Eo *o, Evas_Object_Box_Data *pr
         evas_object_size_hint_padding_get
            (opt->obj, &padding_l, &padding_r, &padding_t, &padding_b);
         evas_object_size_hint_max_get(opt->obj, &max_w, &max_h);
-        efl_gfx_size_hint_combined_min_get(opt->obj, &min_w, NULL);
+        evas_object_size_hint_combined_min_get(opt->obj, &min_w, NULL);
 
         evas_object_geometry_get(opt->obj, NULL, NULL, &child_w, &child_h);
 
@@ -1218,7 +1221,7 @@ _evas_box_layout_homogeneous_max_size_vertical(Eo *o, Evas_Object_Box_Data *priv
         evas_object_size_hint_padding_get
            (opt->obj, &padding_l, &padding_r, &padding_t, &padding_b);
         evas_object_size_hint_max_get(opt->obj, &max_w, &max_h);
-        efl_gfx_size_hint_combined_min_get(opt->obj, NULL, &min_h);
+        evas_object_size_hint_combined_min_get(opt->obj, NULL, &min_h);
 
         evas_object_geometry_get(opt->obj, NULL, NULL, &child_w, &child_h);
 
@@ -1629,7 +1632,7 @@ _evas_box_layout_stack(Eo *o, Evas_Object_Box_Data *priv, Evas_Object_Box_Data *
         evas_object_size_hint_padding_get
            (child, &pad_l, &pad_r, &pad_t, &pad_b);
         evas_object_size_hint_max_get(child, &max_w, &max_h);
-        efl_gfx_size_hint_combined_min_get(child, &min_w, &min_h);
+        evas_object_size_hint_combined_min_get(child, &min_w, &min_h);
 
         _sizing_eval(opt->obj);
         evas_object_geometry_get(child, NULL, NULL, &child_w, &child_h);
@@ -1673,7 +1676,7 @@ _evas_box_align_set(Eo *o, Evas_Object_Box_Data *priv, double horizontal, double
 }
 
 EOLIAN static void
-_evas_box_align_get(Eo *o EINA_UNUSED, Evas_Object_Box_Data *priv, double *horizontal, double *vertical)
+_evas_box_align_get(const Eo *o EINA_UNUSED, Evas_Object_Box_Data *priv, double *horizontal, double *vertical)
 {
    if (priv)
      {
@@ -1698,7 +1701,7 @@ _evas_box_padding_set(Eo *o, Evas_Object_Box_Data *priv, Evas_Coord horizontal,
 }
 
 EOLIAN static void
-_evas_box_padding_get(Eo *o EINA_UNUSED, Evas_Object_Box_Data *priv, Evas_Coord *horizontal, Evas_Coord *vertical)
+_evas_box_padding_get(const Eo *o EINA_UNUSED, Evas_Object_Box_Data *priv, Evas_Coord *horizontal, Evas_Coord *vertical)
 {
    if (priv)
      {
