@@ -100,7 +100,15 @@ _evas_object_intercept_call_internal(Evas_Object *eo_obj,
      {
       case EVAS_OBJECT_INTERCEPT_CB_VISIBLE:
         i = !!va_arg(args, int);
-        if (i == obj->cur->visible) return 1;
+        if (!obj->legacy.visible_set) obj->legacy.visible_set = 1;
+        if (i == obj->cur->visible)
+          {
+             /* If show is called during hide animation is running, then the
+              * current hide animation is cancelled and show operation is
+              * proceeded. */
+             if ((!obj->anim_player) || (!efl_player_play_get(obj->anim_player)))
+               return 1;
+          }
         if (!obj->interceptors) return 0;
         if (i) blocked = evas_object_intercept_call_show(eo_obj, obj);
         else blocked = evas_object_intercept_call_hide(eo_obj, obj);
@@ -126,7 +134,7 @@ _evas_object_intercept_call_internal(Evas_Object *eo_obj,
         j = va_arg(args, int);
         if (obj->interceptors)
           blocked = evas_object_intercept_call_resize(eo_obj, obj, i, j);
-        if (!blocked && _efl_canvas_object_efl_gfx_size_set_block(eo_obj, obj, i, j, internal))
+        if (!blocked && _efl_canvas_object_efl_gfx_entity_size_set_block(eo_obj, obj, i, j, internal))
           blocked = 1;
         break;
 
