@@ -74,7 +74,6 @@ static const Evas_Object_Func object_func =
      NULL,
      NULL,
      NULL,
-     NULL,
      NULL, // render_prepare
      NULL
 };
@@ -85,7 +84,8 @@ static const Evas_Object_Func object_func =
 EAPI Evas_Object *
 evas_object_polygon_add(Evas *e)
 {
-   return efl_add(MY_CLASS, e, efl_canvas_object_legacy_ctor(efl_added));
+   EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(e, EVAS_CANVAS_CLASS), NULL);
+   return efl_add(MY_CLASS, evas_find(e), efl_canvas_object_legacy_ctor(efl_added));
 }
 
 EOLIAN static Eo *
@@ -99,7 +99,7 @@ _efl_canvas_polygon_efl_object_constructor(Eo *eo_obj, Efl_Canvas_Polygon_Data *
 }
 
 EOLIAN static void
-_efl_canvas_polygon_point_add(Eo *eo_obj, Efl_Canvas_Polygon_Data *_pd, Evas_Coord x, Evas_Coord y)
+_efl_canvas_polygon_point_add(Eo *eo_obj, Efl_Canvas_Polygon_Data *_pd, Eina_Position2D pos)
 {
    Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
    Efl_Canvas_Polygon_Data *o = _pd;
@@ -135,8 +135,8 @@ _efl_canvas_polygon_point_add(Eo *eo_obj, Efl_Canvas_Polygon_Data *_pd, Evas_Coo
 
    p = malloc(sizeof(Efl_Canvas_Polygon_Point));
    if (!p) return;
-   p->x = x + o->offset.x;
-   p->y = y + o->offset.y;
+   p->x = pos.x + o->offset.x;
+   p->y = pos.y + o->offset.y;
 
    if (!o->points)
      {
@@ -190,7 +190,7 @@ _efl_canvas_polygon_point_add(Eo *eo_obj, Efl_Canvas_Polygon_Data *_pd, Evas_Coo
      _evas_canvas_event_pointer_in_list_mouse_move_feed(obj->layer->evas, was, eo_obj, obj, 1, 1, EINA_TRUE, NULL);
    eina_list_free(was);
    evas_object_inform_call_move(eo_obj, obj);
-   evas_object_inform_call_resize(eo_obj);
+   evas_object_inform_call_resize(eo_obj, obj);
 }
 
 EOLIAN static void
@@ -227,7 +227,7 @@ _efl_canvas_polygon_points_clear(Eo *eo_obj, Efl_Canvas_Polygon_Data *_pd)
      _evas_canvas_event_pointer_in_list_mouse_move_feed(obj->layer->evas, was, eo_obj, obj, 1, 1, EINA_FALSE, NULL);
    eina_list_free(was);
    evas_object_inform_call_move(eo_obj, obj);
-   evas_object_inform_call_resize(eo_obj);
+   evas_object_inform_call_resize(eo_obj, obj);
 }
 
 /* all nice and private */
@@ -530,7 +530,7 @@ evas_object_polygon_was_inside(Evas_Object *eo_obj EINA_UNUSED,
 EAPI void
 evas_object_polygon_point_add(Evas_Object *obj, Evas_Coord x, Evas_Coord y)
 {
-   efl_canvas_polygon_point_add(obj, x, y);
+   efl_canvas_polygon_point_add(obj, EINA_POSITION2D(x, y));
 }
 
 EAPI void
