@@ -82,7 +82,6 @@ static const Evas_Object_Func object_func =
      NULL,
      NULL,
      NULL,
-     NULL,
      NULL, // render_prepare
      evas_object_rectangle_render2_walk
 };
@@ -93,10 +92,8 @@ static const Evas_Object_Func object_func =
 EAPI Evas_Object *
 evas_object_rectangle_add(Evas *e)
 {
-   MAGIC_CHECK(e, Evas, MAGIC_EVAS);
-   return NULL;
-   MAGIC_CHECK_END();
-   return efl_add(EFL_CANVAS_RECTANGLE_CLASS, e, efl_canvas_object_legacy_ctor(efl_added));
+   EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(e, EVAS_CANVAS_CLASS), NULL);
+   return efl_add(EFL_CANVAS_RECTANGLE_CLASS, evas_find(e), efl_canvas_object_legacy_ctor(efl_added));
 }
 
 EOLIAN static Eo *
