@@ -10,8 +10,7 @@
 #define MY_CLASS_NAME_LEGACY "Evas_Object_Smart"
 
 #define EVAS_OBJECT_SMART_GET_OR_RETURN(eo_obj, ...) \
-   Evas_Smart_Data *o = efl_isa(eo_obj, EFL_CANVAS_GROUP_CLASS) ? \
-     efl_data_scope_get(eo_obj, EFL_CANVAS_GROUP_CLASS) : NULL; \
+   Evas_Smart_Data *o = efl_data_scope_safe_get(eo_obj, EFL_CANVAS_GROUP_CLASS); \
    do { if (!o) { MAGIC_CHECK_FAILED(eo_obj,0,MAGIC_SMART) return __VA_ARGS__; } } while (0)
 
 extern Eina_Hash* signals_hash_table;
@@ -21,7 +20,7 @@ static Eina_Hash *_evas_smart_class_names_hash_table = NULL;
 struct _Evas_Smart_Data
 {
    struct {
-      Evas_Coord_Rectangle bounding_box;
+      Eina_Rectangle bounding_box;
    } cur, prev;
    Evas_Object      *object;
    void             *engine_data;
@@ -37,8 +36,7 @@ struct _Evas_Smart_Data
 
    Evas_Smart_Cb_Description_Array callbacks_descriptions;
 
-   Evas_Coord        x, y;
-
+   int               x, y;
    int               walking_list;
    int               member_count; /** number of smart member objects */
 
@@ -50,6 +48,9 @@ struct _Evas_Smart_Data
    Eina_Bool         need_recalculate : 1;
    Eina_Bool         update_boundingbox_needed : 1;
    Eina_Bool         group_del_called : 1;
+   Eina_Bool         clipped : 1; /* If true, smart clipped */
+   Eina_Bool         data_nofree : 1; /* If true, do NOT free the data */
+   Eina_Bool         constructed : 1; /* constructor finished */
 };
 
 typedef struct
@@ -78,7 +79,6 @@ _eo_evas_smart_cb(void *data, const Efl_Event *event)
 }
 
 /* private methods for smart objects */
-static inline void evas_object_smart_init(Evas_Object *eo_obj);
 static void evas_object_smart_render(Evas_Object *eo_obj,
                                      Evas_Object_Protected_Data *obj,
                                      void *type_private_data,
@@ -120,18 +120,30 @@ static const Evas_Object_Func object_func =
    NULL,
    NULL,
    NULL,
-   NULL,
    NULL, // render_prepare
    NULL
 };
 
+/* helpers */
+static inline Evas_Object *
+_smart_clipper_get(Evas_Smart_Data *o)
+{
+   Evas_Object_Smart_Clipped_Data *cso = o->clipped ? o->data : NULL;
+   return cso ? cso->clipper : NULL;
+}
 
 /* public funcs */
 EAPI void
 evas_object_smart_data_set(Evas_Object *eo_obj, void *data)
 {
    EVAS_OBJECT_SMART_GET_OR_RETURN(eo_obj);
-   o->data = data;
+   if (o->data != data)
+     {
+        if (o->data && !o->data_nofree)
+          free(o->data);
+        o->data = data;
+        o->data_nofree = EINA_TRUE;
+     }
 }
 
 EAPI void *
@@ -198,9 +210,6 @@ evas_object_smart_smart_get(const Efl_Canvas_Group *eo_obj)
 EAPI void
 evas_object_smart_member_add(Evas_Object *eo_obj, Evas_Object *smart_obj)
 {
-   MAGIC_CHECK(eo_obj, Evas_Object, MAGIC_OBJ);
-   return;
-   MAGIC_CHECK_END();
    efl_canvas_group_member_add(smart_obj, eo_obj);
 }
 
@@ -208,7 +217,7 @@ EOLIAN static void
 _efl_canvas_group_group_member_add(Eo *smart_obj, Evas_Smart_Data *o, Evas_Object *eo_obj)
 {
 
-   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
+   Evas_Object_Protected_Data *obj = efl_data_scope_safe_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
    Evas_Object_Protected_Data *smart = efl_data_scope_get(smart_obj, EFL_CANVAS_OBJECT_CLASS);
    Evas_Smart_Data *member_o = NULL;
 
@@ -284,6 +293,26 @@ _efl_canvas_group_group_member_add(Eo *smart_obj, Evas_Smart_Data *o, Evas_Objec
    if (!smart->is_frame_top && (smart->is_frame != obj->is_frame))
      efl_canvas_object_is_frame_object_set(eo_obj, smart->is_frame);
 
+   if (o->clipped)
+     {
+        Evas_Object *clipper = _smart_clipper_get(o);
+        Eina_Bool had_clippees = efl_canvas_object_clipees_has(clipper);
+
+        if (EINA_UNLIKELY(!clipper && !o->constructed))
+          {
+             _evas_object_smart_clipped_init(smart_obj);
+             clipper = _smart_clipper_get(o);
+          }
+
+        if (clipper != eo_obj)
+          {
+             EINA_SAFETY_ON_NULL_RETURN(clipper);
+             efl_canvas_object_clip_set(eo_obj, clipper);
+             if (!had_clippees && smart->cur->visible)
+               efl_gfx_entity_visible_set(clipper, 1);
+          }
+     }
+
    evas_object_change(eo_obj, obj);
    evas_object_mapped_clip_across_mark(eo_obj, obj);
    if (smart->smart.smart && smart->smart.smart->smart_class->member_add)
@@ -294,10 +323,10 @@ _efl_canvas_group_group_member_add(Eo *smart_obj, Evas_Smart_Data *o, Evas_Objec
 EAPI void
 evas_object_smart_member_del(Evas_Object *eo_obj)
 {
-   MAGIC_CHECK(eo_obj, Evas_Object, MAGIC_OBJ);
-   return;
-   MAGIC_CHECK_END();
-   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
+   Evas_Object_Protected_Data *obj;
+
+   if (!eo_obj) return ;
+   obj = efl_data_scope_safe_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
    if (!obj) return;
    if (!obj->smart.parent) return;
    Evas_Object *smart_obj = obj->smart.parent;
@@ -307,17 +336,30 @@ evas_object_smart_member_del(Evas_Object *eo_obj)
 EOLIAN static void
 _efl_canvas_group_group_member_del(Eo *smart_obj, Evas_Smart_Data *_pd EINA_UNUSED, Evas_Object *eo_obj)
 {
-   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
-   Evas_Smart_Data *member_o;
+   Evas_Object_Protected_Data *obj = efl_data_scope_safe_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
+   Evas_Object_Protected_Data *smart;
+   Evas_Smart_Data *member_o, *o;
 
-   if (!obj->smart.parent) return;
+   if (!obj || !obj->smart.parent) return;
 
    evas_object_async_block(obj);
-   Evas_Object_Protected_Data *smart = efl_data_scope_get(smart_obj, EFL_CANVAS_OBJECT_CLASS);
+
+   smart = efl_data_scope_get(smart_obj, EFL_CANVAS_OBJECT_CLASS);
    if (smart->smart.smart && smart->smart.smart->smart_class->member_del)
      smart->smart.smart->smart_class->member_del(smart_obj, eo_obj);
 
-   Evas_Smart_Data *o = efl_data_scope_get(smart_obj, MY_CLASS);
+   o = efl_data_scope_get(smart_obj, MY_CLASS);
+
+   if (o->clipped)
+     {
+        Evas_Object *clipper = _smart_clipper_get(o);
+
+        EINA_SAFETY_ON_NULL_RETURN(clipper);
+        efl_canvas_object_clip_set(eo_obj, NULL);
+        if (!efl_canvas_object_clipees_has(clipper))
+          efl_gfx_entity_visible_set(clipper, 0);
+     }
+
    o->contained = eina_inlist_remove(o->contained, EINA_INLIST_GET(obj));
    o->member_count--;
    obj->smart.parent = NULL;
@@ -454,8 +496,9 @@ _efl_canvas_group_group_iterator_free(Evas_Object_Smart_Iterator *it)
 }
 
 // Should we have an efl_children_iterator_new API and just inherit from it ?
+// No, because each hierarchy is different (Eo, Smart, Widget) -- jpeg
 EOLIAN static Eina_Iterator*
-_efl_canvas_group_group_children_iterate(const Eo *eo_obj, Evas_Smart_Data *priv)
+_efl_canvas_group_group_members_iterate(const Eo *eo_obj, Evas_Smart_Data *priv)
 {
    Evas_Object_Smart_Iterator *it;
    Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
@@ -477,6 +520,18 @@ _efl_canvas_group_group_children_iterate(const Eo *eo_obj, Evas_Smart_Data *priv
    return &it->iterator;
 }
 
+EOLIAN static Eina_Bool
+_efl_canvas_group_group_member_is(const Eo *eo_obj, Evas_Smart_Data *pd EINA_UNUSED, const Eo *sub_obj)
+{
+   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
+   Evas_Object_Protected_Data *sub = efl_data_scope_safe_get(sub_obj, EFL_CANVAS_OBJECT_CLASS);
+
+   evas_object_async_block(obj);
+
+   if (!sub) return EINA_FALSE;
+   return (sub->smart.parent == eo_obj);
+}
+
 EAPI Eina_List*
 evas_object_smart_members_get(const Evas_Object *eo_obj)
 {
@@ -524,17 +579,27 @@ evas_object_smart_members_get_direct(const Evas_Object *eo_obj)
    return o->contained;
 }
 
+static void
+_efl_canvas_group_group_members_all_del_internal(Evas_Smart_Data *o)
+{
+   Evas_Object_Smart_Clipped_Data *cso = o->clipped ? o->data : NULL;
+   Evas_Object_Protected_Data *memobj;
+   Eina_Inlist *itrn;
+
+   EINA_INLIST_FOREACH_SAFE(o->contained, itrn, memobj)
+     {
+        if (memobj->object != cso->clipper)
+          _evas_wrap_del(&memobj->object, memobj);
+     }
+   _evas_wrap_del(&cso->clipper, efl_data_scope_get(cso->clipper, EFL_CANVAS_OBJECT_CLASS));
+   o->group_del_called = EINA_TRUE;
+}
+
 void
 _efl_canvas_group_group_members_all_del(Evas_Object *eo_obj)
 {
    Evas_Smart_Data *o = efl_data_scope_get(eo_obj, MY_CLASS);
-   Evas_Object_Protected_Data *memobj;
-   Eina_Inlist *itrn;
-   EINA_INLIST_FOREACH_SAFE(o->contained, itrn, memobj)
-     {
-        evas_object_del((Evas_Object *)((Evas_Object_Protected_Data *)memobj->object));
-     }
-   o->group_del_called = EINA_TRUE;
+   _efl_canvas_group_group_members_all_del_internal(o);
 }
 
 static void
@@ -610,29 +675,34 @@ evas_object_smart_add(Evas *eo_e, Evas_Smart *s)
 {
    Evas_Object *eo_obj;
 
-   MAGIC_CHECK(eo_e, Evas, MAGIC_EVAS);
-   return NULL;
-   MAGIC_CHECK_END();
-   eo_obj = efl_add(EFL_CANVAS_GROUP_CLASS, eo_e, efl_canvas_object_legacy_ctor(efl_added));
+   EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(eo_e, EVAS_CANVAS_CLASS), NULL);
+   eo_obj = efl_add(EFL_CANVAS_GROUP_CLASS, evas_find(eo_e), efl_canvas_object_legacy_ctor(efl_added));
    evas_object_smart_attach(eo_obj, s);
    return eo_obj;
 }
 
 EOLIAN static Eo *
-_efl_canvas_group_efl_object_constructor(Eo *eo_obj, Evas_Smart_Data *class_data EINA_UNUSED)
+_efl_canvas_group_efl_object_constructor(Eo *eo_obj, Evas_Smart_Data *sd)
 {
-   Evas_Smart_Data *smart;
+   Evas_Object_Protected_Data *obj;
 
-   smart = class_data;
-   smart->object = eo_obj;
-   smart->inherit_paragraph_direction = EINA_TRUE;
+   sd->object = eo_obj;
+   sd->inherit_paragraph_direction = EINA_TRUE;
 
    eo_obj = efl_constructor(efl_super(eo_obj, MY_CLASS));
-   evas_object_smart_init(eo_obj);
+   EINA_SAFETY_ON_NULL_RETURN_VAL(eo_obj, NULL);
+
+   obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
+   obj->is_smart = EINA_TRUE;
+   obj->func = &object_func;
+   obj->private_data = efl_data_ref(eo_obj, MY_CLASS);
+   if (sd->clipped && !sd->data)
+     _evas_object_smart_clipped_init(eo_obj);
 
    efl_canvas_object_type_set(eo_obj, MY_CLASS_NAME_LEGACY);
    efl_canvas_group_add(eo_obj);
 
+   sd->constructed = EINA_TRUE;
    return eo_obj;
 }
 
@@ -640,6 +710,8 @@ EOLIAN static void
 _efl_canvas_group_efl_object_destructor(Eo *eo_obj, Evas_Smart_Data *o)
 {
    efl_destructor(efl_super(eo_obj, MY_CLASS));
+   if (o->data && !o->data_nofree)
+     free(o->data);
    if (!o->group_del_called)
      {
         ERR("efl_canvas_group_del() was not called on this object: %p (%s)",
@@ -647,6 +719,27 @@ _efl_canvas_group_efl_object_destructor(Eo *eo_obj, Evas_Smart_Data *o)
      }
 }
 
+EOLIAN static void
+_efl_canvas_group_efl_object_debug_name_override(Eo *eo_obj, Evas_Smart_Data *o, Eina_Strbuf *sb)
+{
+   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
+   const char *smart_class = NULL;
+
+   if (obj->smart.smart && obj->smart.smart->smart_class)
+     smart_class = obj->smart.smart->smart_class->name;
+
+   efl_debug_name_override(efl_super(eo_obj, MY_CLASS), sb);
+   if (smart_class)
+     {
+        eina_strbuf_append_printf(sb, ":children=%d:smart_class=%s",
+                                  eina_inlist_count(o->contained), smart_class);
+     }
+   else
+     {
+        eina_strbuf_append_printf(sb, ":children=%d", eina_inlist_count(o->contained));
+     }
+}
+
 static inline void
 _evas_object_smart_move_relative_internal(Evas_Smart_Data *o, Evas_Coord dx, Evas_Coord dy)
 {
@@ -686,33 +779,144 @@ _evas_object_smart_clipped_smart_move_internal(Evas_Object *eo_obj, Evas_Coord x
    _evas_object_smart_move_relative_internal(o, x - orig_x, y - orig_y);
 }
 
-EOLIAN static void
-_efl_canvas_group_group_add(Eo *eo_obj, Evas_Smart_Data *o EINA_UNUSED)
+void
+_evas_object_smart_clipped_init(Evas_Object *eo_obj)
 {
-   // If this function is reached, so we do nothing except trying to call
-   // the function of the legacy smart class.
-   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
-   Evas_Smart *s = obj->smart.smart;
-   if (s && s->smart_class->add) s->smart_class->add(eo_obj);
+   EVAS_OBJECT_SMART_GET_OR_RETURN(eo_obj);
+   Evas_Object_Smart_Clipped_Data *cso;
+   Evas_Object *clipper;
+
+   // user may realloc this... (legacy only!)
+   cso = o->data;
+   if (!cso)
+     {
+        cso = calloc(1, sizeof(*cso));
+        o->data = cso;
+        o->data_nofree = EINA_FALSE;
+     }
+
+   cso->evas = evas_object_evas_get(eo_obj);
+   clipper = evas_object_rectangle_add(cso->evas);
+   evas_object_static_clip_set(clipper, 1);
+   cso->clipper = clipper;
+   o->clipped = 0;
+   evas_object_smart_member_add(clipper, eo_obj);
+   o->clipped = 1;
+   evas_object_color_set(cso->clipper, 255, 255, 255, 255);
+   evas_object_move(cso->clipper, -100000, -100000);
+   evas_object_resize(cso->clipper, 200000, 200000);
+   evas_object_pass_events_set(cso->clipper, 1);
+   evas_object_hide(cso->clipper); /* show when have something clipped to it */
+   efl_canvas_object_no_render_set(cso->clipper, 1);
 }
 
 EOLIAN static void
-_efl_canvas_group_group_del(Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o EINA_UNUSED)
+_efl_canvas_group_group_add(Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o EINA_UNUSED)
 {
+}
+
+EOLIAN static void
+_efl_canvas_group_group_del(Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o)
+{
+   if (o->clipped)
+     {
+        _efl_canvas_group_group_members_all_del_internal(o);
+     }
    o->group_del_called = EINA_TRUE;
 }
 
 EOLIAN static void
-_efl_canvas_group_efl_canvas_object_no_render_set(Eo *eo_obj, Evas_Smart_Data *o EINA_UNUSED, Eina_Bool enable)
+_efl_canvas_group_efl_canvas_object_no_render_set(Eo *eo_obj, Evas_Smart_Data *o, Eina_Bool enable)
 {
    Evas_Object_Protected_Data *obj2;
+   Eo *clipper;
 
    enable = !!enable;
    if (efl_canvas_object_no_render_get(eo_obj) == enable) return;
+
    efl_canvas_object_no_render_set(efl_super(eo_obj, MY_CLASS), enable);
 
-   EINA_INLIST_FOREACH(evas_object_smart_members_get_direct(eo_obj), obj2)
-     efl_canvas_object_no_render_set(obj2->object, enable);
+   clipper = (o->clipped) ? _smart_clipper_get(o) : NULL;
+   EINA_INLIST_FOREACH(o->contained, obj2)
+     {
+        if (obj2->object != clipper)
+          efl_canvas_object_no_render_set(obj2->object, enable);
+     }
+}
+
+EOLIAN static void
+_efl_canvas_group_efl_gfx_color_color_set(Eo *eo_obj, Evas_Smart_Data *o, int r, int g, int b, int a)
+{
+   if (_evas_object_intercept_call(eo_obj, EVAS_OBJECT_INTERCEPT_CB_COLOR_SET, 0, r, g, b, a))
+     return;
+
+   efl_gfx_color_set(efl_super(eo_obj, MY_CLASS), r, g, b, a);
+
+   if (o->clipped)
+     {
+        Evas_Object *clipper = _smart_clipper_get(o);
+        EINA_SAFETY_ON_NULL_RETURN(clipper);
+
+        efl_gfx_color_set(clipper, r, g, b, a);
+        // Note: Legacy impl (and Widget) didn't call super in this case...
+     }
+}
+
+EOLIAN static void
+_efl_canvas_group_efl_gfx_entity_visible_set(Eo *eo_obj, Evas_Smart_Data *o, Eina_Bool vis)
+{
+   if (_evas_object_intercept_call(eo_obj, EVAS_OBJECT_INTERCEPT_CB_VISIBLE, 0, vis))
+     return;
+
+   efl_gfx_entity_visible_set(efl_super(eo_obj, MY_CLASS), vis);
+
+   if (o->clipped)
+     {
+        Evas_Object *clipper = _smart_clipper_get(o);
+        EINA_SAFETY_ON_NULL_RETURN(clipper);
+
+        // note: maybe this is not necessary with no_render set on the clipper
+        if (vis && !evas_object_clipees_has(clipper))
+          return;
+
+        efl_gfx_entity_visible_set(clipper, vis);
+     }
+}
+
+EOLIAN static void
+_efl_canvas_group_efl_gfx_entity_position_set(Eo *eo_obj, Evas_Smart_Data *o, Eina_Position2D pos)
+{
+   Eina_Bool is_overridden;
+   Evas_Object_Protected_Data *obj = EVAS_OBJ_GET_OR_RETURN(eo_obj);
+
+   if (_evas_object_intercept_call(eo_obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, pos.x, pos.y))
+     return;
+
+   is_overridden = (obj->is_smart && obj->smart.smart &&
+                    obj->smart.smart->smart_class->move !=
+                    (void *)evas_object_smart_clipped_smart_move);
+
+   if (o->clipped && !is_overridden)
+     _evas_object_smart_clipped_smart_move_internal(eo_obj, pos.x, pos.y);
+   efl_gfx_entity_position_set(efl_super(eo_obj, MY_CLASS), pos);
+}
+
+EOLIAN static void
+_efl_canvas_group_efl_canvas_object_clip_set(Eo *eo_obj, Evas_Smart_Data *o, Evas_Object *clip)
+{
+   EINA_SAFETY_ON_FALSE_RETURN(!clip || efl_isa(clip, EFL_CANVAS_OBJECT_CLASS));
+   if (_evas_object_intercept_call(eo_obj, EVAS_OBJECT_INTERCEPT_CB_CLIP_SET, 0, clip))
+     return;
+
+   efl_canvas_object_clip_set(efl_super(eo_obj, MY_CLASS), clip);
+
+   if (o->clipped)
+     {
+        Evas_Object *clipper = _smart_clipper_get(o);
+        EINA_SAFETY_ON_NULL_RETURN(clipper);
+
+        efl_canvas_object_clip_set(clipper, clip);
+     }
 }
 
 void
@@ -721,6 +925,10 @@ evas_object_smart_attach(Evas_Object *eo_obj, Evas_Smart *s)
    Evas_Object_Protected_Data *obj = EVAS_OBJ_GET_OR_RETURN(eo_obj);
    unsigned int i;
 
+   MAGIC_CHECK(s, Evas_Smart, MAGIC_SMART);
+   return;
+   MAGIC_CHECK_END();
+
    obj->smart.smart = s;
    obj->type = s->smart_class->name;
    evas_object_smart_use(s);
@@ -743,7 +951,8 @@ evas_object_smart_attach(Evas_Object *eo_obj, Evas_Smart *s)
           }
      }
 
-   efl_canvas_group_add(eo_obj);
+   //efl_canvas_group_add(eo_obj);
+   if (s->smart_class->add) s->smart_class->add(eo_obj);
 }
 
 EAPI void
@@ -938,7 +1147,7 @@ _efl_canvas_group_group_need_recalculate_set(Eo *eo_obj, Evas_Smart_Data *o, Ein
 }
 
 EOLIAN static Eina_Bool
-_efl_canvas_group_group_need_recalculate_get(Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o)
+_efl_canvas_group_group_need_recalculate_get(const Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o)
 {
    return o->need_recalculate;
 }
@@ -956,24 +1165,6 @@ _efl_canvas_group_group_calculate(Eo *eo_obj, Evas_Smart_Data *o)
    obj->smart.smart->smart_class->calculate(eo_obj);
 }
 
-EOLIAN void
-_evas_canvas_smart_objects_calculate(Eo *eo_e, Evas_Public_Data *o EINA_UNUSED)
-{
-   evas_call_smarts_calculate(eo_e);
-}
-
-EOLIAN Eina_Bool
-_evas_canvas_smart_objects_calculating_get(Eo *eo_e EINA_UNUSED, Evas_Public_Data *e)
-{
-   return !!e->in_smart_calc;
-}
-
-EOLIAN int
-_evas_canvas_smart_objects_calculate_count_get(Eo *eo_e EINA_UNUSED, Evas_Public_Data *e)
-{
-   return e->smart_calc_count;
-}
-
 /**
  * Call calculate() on all smart objects that need_recalculate.
  *
@@ -1095,7 +1286,7 @@ evas_object_smart_del(Evas_Object *eo_obj)
    if (s && s->smart_class->del)
      {
         s->smart_class->del(eo_obj);
-        //this is legacy, this will never be called..., smart things dont have inheitence
+        //this is legacy, this will never be called..., smart things dont have inheritance
         sobj->group_del_called = EINA_TRUE;
      }
    else
@@ -1255,8 +1446,8 @@ evas_object_update_bounding_box(Evas_Object *eo_obj EINA_UNUSED, Evas_Object_Pro
 
 void
 evas_object_smart_bounding_box_get(Evas_Object_Protected_Data *obj,
-                                   Evas_Coord_Rectangle *cur_bounding_box,
-                                   Evas_Coord_Rectangle *prev_bounding_box)
+                                   Eina_Rectangle *cur_bounding_box,
+                                   Eina_Rectangle *prev_bounding_box)
 {
    Evas_Smart_Data *s = obj->private_data;
 
@@ -1294,7 +1485,13 @@ evas_object_smart_cleanup(Evas_Object *eo_obj)
                (Evas_Object_Protected_Data *)o->contained;
              Evas_Object *contained_obj = contained->object;
 
-             if (contained->smart.parent != eo_obj)
+             if (!contained_obj)
+               {
+                  ERR("Found an undefined object %p in %s.", contained, efl_debug_name_get(eo_obj));
+                  o->contained = eina_inlist_remove
+                    (o->contained, EINA_INLIST_GET(contained));
+               }
+             else if (contained->smart.parent != eo_obj)
                {
                   Evas_Layer *lay = obj->layer;
 
@@ -1304,9 +1501,9 @@ evas_object_smart_cleanup(Evas_Object *eo_obj)
                   if (lay)
                     {
                        // this SHOULD be eina_inlist_append() BUT seemingly
-                       // if we call this this objetc gets magicaly added
-                       // back to o->conmtaind above NOt lay->objects. this
-                       // is utterly bizzarre and the only explanation i
+                       // if we call this this object gets magically added
+                       // back to o->contained above NOT lay->objects. this
+                       // is utterly bizarre and the only explanation i
                        // can come up with right now is a compiler bug.
                        lay->objects = (Evas_Object_Protected_Data *)
                          eina_inlist_prepend(EINA_INLIST_GET(lay->objects),
@@ -1507,16 +1704,6 @@ evas_object_smart_bounding_box_update(Evas_Object_Protected_Data *obj)
 }
 
 /* all nice and private */
-static inline void
-evas_object_smart_init(Evas_Object *eo_obj)
-{
-   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
-   obj->is_smart = EINA_TRUE;
-   /* set up methods (compulsory) */
-   obj->func = &object_func;
-   obj->private_data = efl_data_ref(eo_obj, MY_CLASS);
-}
-
 static void
 evas_object_smart_render(Evas_Object *eo_obj EINA_UNUSED, Evas_Object_Protected_Data *obj EINA_UNUSED,  void *type_private_data EINA_UNUSED, void *engine EINA_UNUSED, void *output EINA_UNUSED, void *context EINA_UNUSED, void *surface EINA_UNUSED, int x EINA_UNUSED, int y EINA_UNUSED, Eina_Bool do_async EINA_UNUSED)
 {
@@ -1645,19 +1832,36 @@ _efl_canvas_group_efl_canvas_object_paragraph_direction_set(Eo *eo_obj, Evas_Sma
 }
 
 EOLIAN static Evas_BiDi_Direction
-_efl_canvas_group_efl_canvas_object_paragraph_direction_get(Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o)
+_efl_canvas_group_efl_canvas_object_paragraph_direction_get(const Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o)
 {
    return o->paragraph_direction;
 }
 
+EOLIAN static const Eo *
+_efl_canvas_group_group_clipper_get(const Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *o)
+{
+   // NOTE: This may be NULL until all EO smart objects are clipped!
+   return _smart_clipper_get(o);
+}
+
+/* Internal EO */
+static void
+_efl_canvas_group_group_clipped_set(Eo *eo_obj EINA_UNUSED, Evas_Smart_Data *sd, Eina_Bool clipped)
+{
+   // We must call this function BEFORE the constructor (yes, it's hacky)
+   EINA_SAFETY_ON_FALSE_RETURN(!sd->object);
+   sd->clipped = !!clipped;
+}
+
 /* Internal EO APIs */
 
 EOAPI EFL_VOID_FUNC_BODY(efl_canvas_group_add)
 EOAPI EFL_VOID_FUNC_BODY(efl_canvas_group_del)
+EOAPI EFL_VOID_FUNC_BODYV(efl_canvas_group_clipped_set, EFL_FUNC_CALL(enable), Eina_Bool enable)
 
 #define EFL_CANVAS_GROUP_EXTRA_OPS \
    EFL_OBJECT_OP_FUNC(efl_canvas_group_add, _efl_canvas_group_group_add), \
-   EFL_OBJECT_OP_FUNC(efl_canvas_group_del, _efl_canvas_group_group_del)
-
+   EFL_OBJECT_OP_FUNC(efl_canvas_group_del, _efl_canvas_group_group_del), \
+   EFL_OBJECT_OP_FUNC(efl_canvas_group_clipped_set, _efl_canvas_group_group_clipped_set)
 
 #include "canvas/efl_canvas_group.eo.c"
