@@ -105,7 +105,7 @@ struct _Evas_Object_Table_Accessor
    EVAS_OBJECT_TABLE_DATA_GET(o, ptr);                                  \
 if (!ptr)                                                               \
 {                                                                       \
-   CRI("no widget data for object %p (%s)",                            \
+   ERR("No widget data for object %p (%s)",                            \
         o, evas_object_type_get(o));                                    \
    return;                                                              \
 }
@@ -114,7 +114,7 @@ if (!ptr)                                                               \
    EVAS_OBJECT_TABLE_DATA_GET(o, ptr);                                  \
 if (!ptr)                                                               \
 {                                                                       \
-   CRI("No widget data for object %p (%s)",                            \
+   ERR("No widget data for object %p (%s)",                            \
         o, evas_object_type_get(o));                                    \
    return val;                                                          \
 }
@@ -251,7 +251,7 @@ _evas_object_table_option_del(Evas_Object *o)
 }
 
 static void
-_on_child_del(void *data, const Efl_Event *event)
+_on_child_invalidate(void *data, const Efl_Event *event)
 {
    Evas_Object *table = data;
    evas_object_table_unpack(table, event->object);
@@ -267,8 +267,8 @@ _on_child_hints_changed(void *data, const Efl_Event *event EINA_UNUSED)
 }
 
 EFL_CALLBACKS_ARRAY_DEFINE(evas_object_table_callbacks,
-  { EFL_EVENT_DEL, _on_child_del },
-  { EFL_GFX_EVENT_CHANGE_SIZE_HINTS, _on_child_hints_changed }
+  { EFL_EVENT_INVALIDATE, _on_child_invalidate },
+  { EFL_GFX_ENTITY_EVENT_CHANGE_SIZE_HINTS, _on_child_hints_changed }
 );
 
 static void
@@ -344,7 +344,7 @@ _evas_object_table_calculate_hints_homogeneous(Evas_Object *o, Evas_Table_Data *
         Evas_Coord child_minw, child_minh, cell_minw, cell_minh;
         double weightw, weighth;
 
-        efl_gfx_size_hint_combined_min_get(child, &opt->min.w, &opt->min.h);
+        evas_object_size_hint_combined_min_get(child, &opt->min.w, &opt->min.h);
         evas_object_size_hint_max_get(child, &opt->max.w, &opt->max.h);
         evas_object_size_hint_padding_get
            (child, &opt->pad.l, &opt->pad.r, &opt->pad.t, &opt->pad.b);
@@ -405,13 +405,13 @@ _evas_object_table_calculate_hints_homogeneous(Evas_Object *o, Evas_Table_Data *
         if (o_minw < 1)
           {
              ERR("homogeneous table based on item size but no "
-                 "horizontal mininum size specified! Using expand.");
+                 "horizontal minimum size specified! Using expand.");
              expand_h = 1;
           }
         if (o_minh < 1)
           {
              ERR("homogeneous table based on item size but no "
-                 "vertical mininum size specified! Using expand.");
+                 "vertical minimum size specified! Using expand.");
              expand_v = 1;
           }
      }
@@ -435,7 +435,7 @@ _evas_object_table_calculate_layout_homogeneous_sizes_item(const Evas_Object *o,
    Evas_Coord minw, minh;
    Eina_Bool expand_h, expand_v;
 
-   efl_gfx_size_hint_combined_min_get(o, &minw, &minh);
+   evas_object_size_hint_combined_min_get(o, &minw, &minh);
    expand_h = priv->expand_h;
    expand_v = priv->expand_v;
 
@@ -659,7 +659,7 @@ _evas_object_table_calculate_hints_regular(Evas_Object *o, Evas_Table_Data *priv
         Evas_Object *child = opt->obj;
         double weightw, weighth;
 
-        efl_gfx_size_hint_combined_min_get(child, &opt->min.w, &opt->min.h);
+        evas_object_size_hint_combined_min_get(child, &opt->min.w, &opt->min.h);
         evas_object_size_hint_max_get(child, &opt->max.w, &opt->max.h);
         evas_object_size_hint_padding_get
            (child, &opt->pad.l, &opt->pad.r, &opt->pad.t, &opt->pad.b);
@@ -934,22 +934,22 @@ _evas_table_efl_canvas_group_group_del(Eo *obj, Evas_Table_Data *priv)
 }
 
 EOLIAN static void
-_evas_table_efl_gfx_size_set(Eo *obj, Evas_Table_Data *_pd EINA_UNUSED, Evas_Coord w, Evas_Coord h)
+_evas_table_efl_gfx_entity_size_set(Eo *obj, Evas_Table_Data *_pd EINA_UNUSED, Eina_Size2D sz)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
-   efl_gfx_size_set(efl_super(obj, MY_CLASS), w, h);
+   efl_gfx_entity_size_set(efl_super(obj, MY_CLASS), sz);
    evas_object_smart_changed(obj);
 }
 
 EOLIAN static void
-_evas_table_efl_gfx_position_set(Eo *obj, Evas_Table_Data *_pd EINA_UNUSED, Evas_Coord x, Evas_Coord y)
+_evas_table_efl_gfx_entity_position_set(Eo *obj, Evas_Table_Data *_pd EINA_UNUSED, Eina_Position2D pos)
 {
-   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, x, y))
+   if (_evas_object_intercept_call(obj, EVAS_OBJECT_INTERCEPT_CB_MOVE, 0, pos.x, pos.y))
      return;
 
-   efl_gfx_position_set(efl_super(obj, MY_CLASS), x, y);
+   efl_gfx_entity_position_set(efl_super(obj, MY_CLASS), pos);
    evas_object_smart_changed(obj);
 }
 
@@ -979,15 +979,14 @@ _evas_table_efl_canvas_group_group_calculate(Eo *o, Evas_Table_Data *priv)
 EAPI Evas_Object *
 evas_object_table_add(Evas *evas)
 {
-   MAGIC_CHECK(evas, Evas, MAGIC_EVAS);
-   return NULL;
-   MAGIC_CHECK_END();
-   return efl_add(MY_CLASS, evas, efl_canvas_object_legacy_ctor(efl_added));
+   EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(evas, EVAS_CANVAS_CLASS), NULL);
+   return efl_add(MY_CLASS, evas_find(evas), efl_canvas_object_legacy_ctor(efl_added));
 }
 
 EOLIAN static Eo *
 _evas_table_efl_object_constructor(Eo *obj, Evas_Table_Data *class_data EINA_UNUSED)
 {
+   efl_canvas_group_clipped_set(obj, EINA_TRUE);
    obj = efl_constructor(efl_super(obj, MY_CLASS));
    efl_canvas_object_type_set(obj, MY_CLASS_NAME_LEGACY);
 
@@ -1018,7 +1017,7 @@ _evas_table_homogeneous_set(Eo *o, Evas_Table_Data *priv, Evas_Object_Table_Homo
 }
 
 EOLIAN static Evas_Object_Table_Homogeneous_Mode
-_evas_table_homogeneous_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv)
+_evas_table_homogeneous_get(const Eo *o EINA_UNUSED, Evas_Table_Data *priv)
 {
    return priv->homogeneous;
 }
@@ -1035,7 +1034,7 @@ _evas_table_align_set(Eo *o, Evas_Table_Data *priv, double horizontal, double ve
 }
 
 EOLIAN static void
-_evas_table_align_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv, double *horizontal, double *vertical)
+_evas_table_align_get(const Eo *o EINA_UNUSED, Evas_Table_Data *priv, double *horizontal, double *vertical)
 {
    if (priv)
      {
@@ -1061,7 +1060,7 @@ _evas_table_padding_set(Eo *o, Evas_Table_Data *priv, Evas_Coord horizontal, Eva
 }
 
 EOLIAN static void
-_evas_table_padding_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv, Evas_Coord *horizontal, Evas_Coord *vertical)
+_evas_table_padding_get(const Eo *o EINA_UNUSED, Evas_Table_Data *priv, Evas_Coord *horizontal, Evas_Coord *vertical)
 {
    if (priv)
      {
@@ -1322,7 +1321,7 @@ _evas_table_clear(Eo *o, Evas_Table_Data *priv, Eina_Bool clear)
 }
 
 EOLIAN static void
-_evas_table_col_row_size_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv, int *cols, int *rows)
+_evas_table_col_row_size_get(const Eo *o EINA_UNUSED, Evas_Table_Data *priv, int *cols, int *rows)
 {
    if (priv)
      {
@@ -1387,7 +1386,7 @@ _evas_table_accessor_new(const Eo *o, Evas_Table_Data *priv)
 }
 
 EOLIAN static Eina_List*
-_evas_table_children_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv)
+_evas_table_children_get(const Eo *o EINA_UNUSED, Evas_Table_Data *priv)
 {
    Eina_List *new_list = NULL, *l;
    Evas_Object_Table_Option *opt;
@@ -1405,7 +1404,7 @@ _evas_table_count(Eo *o EINA_UNUSED, Evas_Table_Data *priv)
 }
 
 EOLIAN static Evas_Object *
-_evas_table_child_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv, unsigned short col, unsigned short row)
+_evas_table_child_get(const Eo *o EINA_UNUSED, Evas_Table_Data *priv, unsigned short col, unsigned short row)
 {
    Eina_List *l;
    Evas_Object_Table_Option *opt;
@@ -1417,13 +1416,19 @@ _evas_table_child_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv, unsigned short c
 }
 
 EOLIAN static Eina_Bool
-_evas_table_mirrored_get(Eo *o EINA_UNUSED, Evas_Table_Data *priv)
+_evas_table_efl_ui_base_mirrored_get(const Eo *o EINA_UNUSED, Evas_Table_Data *priv)
 {
    return priv->is_mirrored;
 }
 
+EAPI Eina_Bool
+evas_object_table_mirrored_get(const Eo *obj)
+{
+   return efl_ui_mirrored_get(obj);
+}
+
 EOLIAN static void
-_evas_table_mirrored_set(Eo *o, Evas_Table_Data *priv, Eina_Bool mirrored)
+_evas_table_efl_ui_base_mirrored_set(Eo *o, Evas_Table_Data *priv, Eina_Bool mirrored)
 {
    if (priv->is_mirrored != mirrored)
      {
@@ -1432,6 +1437,12 @@ _evas_table_mirrored_set(Eo *o, Evas_Table_Data *priv, Eina_Bool mirrored)
      }
 }
 
+EAPI void
+evas_object_table_mirrored_set(Eo *obj, Eina_Bool mirrored)
+{
+   efl_ui_mirrored_set(obj, mirrored);
+}
+
 EOLIAN static void
 _evas_table_class_constructor(Efl_Class *klass)
 {
