@@ -48,6 +48,7 @@ struct _Evas_Text_Data
 
       Evas_Font_Size       size;
       Evas_Text_Style_Type style;
+      Efl_Text_Font_Bitmap_Scalable bitmap_scalable;
    } cur, prev;
 
    struct {
@@ -113,9 +114,6 @@ static int evas_object_text_was_opaque(Evas_Object *eo_obj,
 				       Evas_Object_Protected_Data *obj,
 				       void *type_private_data);
 
-static void evas_object_text_scale_update(Evas_Object *eo_obj,
-					  Evas_Object_Protected_Data *obj,
-					  void *type_private_data);
 static void _evas_object_text_recalc(Evas_Object *eo_obj, Eina_Unicode *text);
 
 static const Evas_Object_Func object_func =
@@ -138,7 +136,6 @@ static const Evas_Object_Func object_func =
      NULL,
      NULL,
      NULL,
-     evas_object_text_scale_update,
      NULL,
      NULL,
      NULL,
@@ -163,7 +160,7 @@ _evas_object_text_char_coords_get(const Evas_Object *eo_obj,
               (pos < (it->text_pos + it->text_props.text_len)))
           {
              int ret;
-             ret = ENFN->font_char_coords_get(ENDT, o->font,
+             ret = ENFN->font_char_coords_get(ENC, o->font,
                    &it->text_props, pos - it->text_pos, x, y, w, h);
              if (x) *x += it->x;
              return ret;
@@ -304,7 +301,7 @@ _evas_object_text_last_up_to_pos(const Evas_Object *eo_obj,
           {
              if ((x <= cx) && (cx < x + it->adv))
                {
-                  pos = it->text_pos + ENFN->font_last_up_to_pos(ENDT,
+                  pos = it->text_pos + ENFN->font_last_up_to_pos(ENC,
                         o->font,
                         &it->text_props,
                         cx - x,
@@ -322,7 +319,7 @@ _evas_object_text_last_up_to_pos(const Evas_Object *eo_obj,
           {
              if ((it->x <= cx) && (cx < it->x + it->adv))
                {
-                  return it->text_pos + ENFN->font_last_up_to_pos(ENDT,
+                  return it->text_pos + ENFN->font_last_up_to_pos(ENC,
                         o->font,
                         &it->text_props,
                         cx - it->x,
@@ -345,7 +342,7 @@ _evas_object_text_char_at_coords(const Evas_Object *eo_obj,
      {
         if ((it->x <= cx) && (cx < it->x + it->adv))
           {
-             return it->text_pos + ENFN->font_char_at_coords_get(ENDT,
+             return it->text_pos + ENFN->font_char_at_coords_get(ENC,
                    o->font,
                    &it->text_props,
                    cx - it->x,
@@ -379,10 +376,8 @@ _evas_object_text_vert_advance_get(const Evas_Object *obj EINA_UNUSED,
 EAPI Evas_Object *
 evas_object_text_add(Evas *e)
 {
-   MAGIC_CHECK(e, Evas, MAGIC_EVAS);
-   return NULL;
-   MAGIC_CHECK_END();
-   return efl_add(EVAS_TEXT_CLASS, e, efl_canvas_object_legacy_ctor(efl_added));
+   EINA_SAFETY_ON_FALSE_RETURN_VAL(efl_isa(e, EVAS_CANVAS_CLASS), NULL);
+   return efl_add(EVAS_TEXT_CLASS, evas_find(e), efl_canvas_object_legacy_ctor(efl_added));
 }
 
 EOLIAN static Eo *
@@ -395,7 +390,7 @@ _evas_text_efl_object_constructor(Eo *eo_obj, Evas_Text_Data *o EINA_UNUSED)
 }
 
 EOLIAN static void
-_evas_text_efl_text_properties_font_source_set(Eo *eo_obj, Evas_Text_Data *o, const char *font_source)
+_evas_text_efl_text_font_font_source_set(Eo *eo_obj, Evas_Text_Data *o, const char *font_source)
 {
    Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
    if (((o->cur.source) && (font_source) &&
@@ -412,20 +407,64 @@ _evas_text_efl_text_properties_font_source_set(Eo *eo_obj, Evas_Text_Data *o, co
 }
 
 EOLIAN static const char*
-_evas_text_efl_text_properties_font_source_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_efl_text_font_font_source_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->cur.source;
 }
 
-EOLIAN static void
-_evas_text_efl_text_properties_font_set(Eo *eo_obj, Evas_Text_Data *o, const char *font, Evas_Font_Size size)
+static void
+_evas_text_font_reload(Eo *eo_obj, Evas_Text_Data *o)
 {
    Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
    Eina_Bool pass = EINA_FALSE, freeze = EINA_FALSE;
    Eina_Bool source_invisible = EINA_FALSE;
-   Evas_Font_Description *fdesc;
    Eina_List *was = NULL;
 
+   if (!(obj->layer->evas->is_frozen))
+     {
+        pass = evas_event_passes_through(eo_obj, obj);
+        freeze = evas_event_freezes_through(eo_obj, obj);
+        source_invisible = evas_object_is_source_invisible(eo_obj, obj);
+        if ((!pass) && (!freeze) && (!source_invisible))
+          was = _evas_pointer_list_in_rect_get(obj->layer->evas, eo_obj, obj,
+                                               1, 1);
+     }
+
+   /* DO IT */
+   evas_font_free(o->font);
+   o->font = NULL;
+
+   o->font = evas_font_load(obj->layer->evas->font_path,
+                            obj->layer->evas->hinting,
+                            o->cur.fdesc, o->cur.source,
+                            (int)(((double) o->cur.size) * obj->cur->scale),
+                            o->cur.bitmap_scalable);
+     {
+        o->ascent = 0;
+        o->descent = 0;
+        o->max_ascent = 0;
+        o->max_descent = 0;
+     }
+   _evas_object_text_items_clear(o);
+   _evas_object_text_recalc(eo_obj, o->cur.text);
+   o->changed = 1;
+   if (o->has_filter)
+     evas_filter_changed_set(eo_obj, EINA_TRUE);
+   evas_object_change(eo_obj, obj);
+   evas_object_clip_dirty(eo_obj, obj);
+   evas_object_coords_recalc(eo_obj, obj);
+   if (!obj->layer->evas->is_frozen && !pass && !freeze && obj->cur->visible)
+     _evas_canvas_event_pointer_in_list_mouse_move_feed(obj->layer->evas, was, eo_obj, obj, 1, 1, EINA_TRUE, NULL);
+   eina_list_free(was);
+   evas_object_inform_call_resize(eo_obj, obj);
+}
+
+EOLIAN static void
+_evas_text_efl_text_font_font_set(Eo *eo_obj, Evas_Text_Data *o, const char *font, Evas_Font_Size size)
+{
+   Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
+   Evas_Font_Description *fdesc;
+
    if ((!font) || (size <= 0)) return;
 
    evas_object_async_block(obj);
@@ -455,47 +494,11 @@ _evas_text_efl_text_properties_font_set(Eo *eo_obj, Evas_Text_Data *o, const cha
    eina_stringshare_replace(&o->cur.font, font);
    o->prev.font = NULL;
 
-   if (!(obj->layer->evas->is_frozen))
-     {
-        pass = evas_event_passes_through(eo_obj, obj);
-        freeze = evas_event_freezes_through(eo_obj, obj);
-        source_invisible = evas_object_is_source_invisible(eo_obj, obj);
-        if ((!pass) && (!freeze) && (!source_invisible))
-          was = _evas_pointer_list_in_rect_get(obj->layer->evas, eo_obj, obj,
-                                               1, 1);
-     }
-
-   /* DO IT */
-   if (o->font)
-     {
-        evas_font_free(obj->layer->evas->evas, o->font);
-        o->font = NULL;
-     }
-
-   o->font = evas_font_load(obj->layer->evas->evas, o->cur.fdesc, o->cur.source,
-         (int)(((double) o->cur.size) * obj->cur->scale));
-     {
-        o->ascent = 0;
-        o->descent = 0;
-        o->max_ascent = 0;
-        o->max_descent = 0;
-     }
-   _evas_object_text_items_clear(o);
-   _evas_object_text_recalc(eo_obj, o->cur.text);
-   o->changed = 1;
-   if (o->has_filter)
-     evas_filter_changed_set(eo_obj, EINA_TRUE);
-   evas_object_change(eo_obj, obj);
-   evas_object_clip_dirty(eo_obj, obj);
-   evas_object_coords_recalc(eo_obj, obj);
-   if (!obj->layer->evas->is_frozen && !pass && !freeze && obj->cur->visible)
-     _evas_canvas_event_pointer_in_list_mouse_move_feed(obj->layer->evas, was, eo_obj, obj, 1, 1, EINA_TRUE, NULL);
-   eina_list_free(was);
-   evas_object_inform_call_resize(eo_obj);
+   _evas_text_font_reload(eo_obj, o);
 }
 
 EOLIAN static void
-_evas_text_efl_text_properties_font_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, const char **font, Evas_Font_Size *size)
+_evas_text_efl_text_font_font_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, const char **font, Evas_Font_Size *size)
 {
    if (font) *font = o->cur.font;
    if (size) *size = o->cur.size;
@@ -504,11 +507,11 @@ _evas_text_efl_text_properties_font_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *
 static void
 _evas_object_text_item_update_sizes(Evas_Object_Protected_Data *obj, Evas_Text_Data *o, Evas_Object_Text_Item *it)
 {
-   ENFN->font_string_size_get(ENDT,
+   ENFN->font_string_size_get(ENC,
          o->font,
          &it->text_props,
          &it->w, &it->h);
-   it->adv = ENFN->font_h_advance_get(ENDT, o->font,
+   it->adv = ENFN->font_h_advance_get(ENC, o->font,
          &it->text_props);
 }
 
@@ -538,7 +541,7 @@ _evas_object_text_item_new(Evas_Object_Protected_Data *obj,
 
    if (fi)
      {
-        ENFN->font_text_props_info_create(ENDT,
+        ENFN->font_text_props_info_create(ENC,
               fi, str + pos, &it->text_props,
               o->bidi_par_props, it->text_pos, len, EVAS_TEXT_PROPS_MODE_SHAPE,
               o->cur.fdesc->lang);
@@ -619,7 +622,7 @@ _layout_ellipsis_item_new(Evas_Object_Protected_Data *obj, Evas_Text_Data *o)
 
    if (o->font)
      {
-        (void) ENFN->font_run_end_get(ENDT, o->font, &script_fi, &cur_fi,
+        (void) ENFN->font_run_end_get(ENC, o->font, &script_fi, &cur_fi,
                                       script, _ellip_str, 1);
          ellip_ti = _evas_object_text_item_new(obj, o, cur_fi,
                                                _ellip_str, script, 0, 0, len);
@@ -780,7 +783,7 @@ _evas_object_text_layout(Evas_Object *eo_obj, Evas_Text_Data *o, Eina_Unicode *t
                   if (o->font)
                     {
                        run_len = ENFN->font_run_end_get
-                         (ENDT, o->font, &script_fi, &cur_fi,
+                         (ENC, o->font, &script_fi, &cur_fi,
                           script, text + pos, script_len);
                     }
 #ifdef BIDI_SUPPORT
@@ -887,7 +890,7 @@ _evas_object_text_layout(Evas_Object *eo_obj, Evas_Text_Data *o, Eina_Unicode *t
                }
              if (itr && (itr != start_ellip_it))
                {
-                  int cut = ENFN->font_last_up_to_pos(ENDT,
+                  int cut = ENFN->font_last_up_to_pos(ENC,
                         o->font,
                         &itr->text_props,
                         ellipsis_coord - (advance + l + r),
@@ -942,7 +945,7 @@ _evas_object_text_layout(Evas_Object *eo_obj, Evas_Text_Data *o, Eina_Unicode *t
              int cut = -1;
              if (itr && (itr != end_ellip_it))
                {
-                  cut = ENFN->font_last_up_to_pos(ENDT,
+                  cut = ENFN->font_last_up_to_pos(ENC,
                                                   o->font,
                                                   &itr->text_props,
                                                   ellip_frame - (advance + l + r),
@@ -998,17 +1001,17 @@ _evas_object_text_layout(Evas_Object *eo_obj, Evas_Text_Data *o, Eina_Unicode *t
 }
 
 EOLIAN static void
-_evas_text_efl_gfx_size_set(Eo *eo_obj, Evas_Text_Data *o, int w, int h)
+_evas_text_efl_gfx_entity_size_set(Eo *eo_obj, Evas_Text_Data *o, Eina_Size2D sz)
 {
    Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
 
-   if (_evas_object_intercept_call_evas(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, w, h))
+   if (_evas_object_intercept_call_evas(obj, EVAS_OBJECT_INTERCEPT_CB_RESIZE, 0, sz.w, sz.h))
      return;
 
    EINA_COW_STATE_WRITE_BEGIN(obj, state_write, cur)
      {
-        state_write->geometry.w = w;
-        state_write->geometry.h = h;
+        state_write->geometry.w = sz.w;
+        state_write->geometry.h = sz.h;
      }
    EINA_COW_STATE_WRITE_END(obj, state_write, cur);
 
@@ -1033,7 +1036,7 @@ _evas_text_ellipsis_set(Eo *eo_obj, Evas_Text_Data *o, double ellipsis)
 }
 
 EOLIAN static double
-_evas_text_ellipsis_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_ellipsis_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->cur.ellipsis;
 }
@@ -1046,11 +1049,11 @@ _evas_text_efl_object_dbg_info_get(Eo *eo_obj, Evas_Text_Data *o EINA_UNUSED, Ef
 
    const char *text;
    int size;
-   efl_text_properties_font_get(eo_obj, &text, &size);
+   efl_text_font_get(eo_obj, &text, &size);
    EFL_DBG_INFO_APPEND(group, "Font", EINA_VALUE_TYPE_STRING, text);
    EFL_DBG_INFO_APPEND(group, "Text size", EINA_VALUE_TYPE_INT, size);
 
-   text = efl_text_properties_font_source_get(eo_obj);
+   text = efl_text_font_source_get(eo_obj);
    EFL_DBG_INFO_APPEND(group, "Font source", EINA_VALUE_TYPE_STRING, text);
 
    text = efl_text_get(eo_obj);
@@ -1092,7 +1095,7 @@ _evas_text_efl_text_text_set(Eo *eo_obj, Evas_Text_Data *o, const char *_text)
    if (obj->cur->visible)
      _evas_canvas_event_pointer_in_list_mouse_move_feed(obj->layer->evas, was, eo_obj, obj, 1, 1, EINA_FALSE, NULL);
    eina_list_free(was);
-   evas_object_inform_call_resize(eo_obj);
+   evas_object_inform_call_resize(eo_obj, obj);
 }
 
 EOLIAN static void
@@ -1104,19 +1107,19 @@ _evas_text_bidi_delimiters_set(Eo *eo_obj, Evas_Text_Data *o, const char *delim)
 }
 
 EOLIAN static const char*
-_evas_text_bidi_delimiters_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_bidi_delimiters_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->bidi_delimiters;
 }
 
 EOLIAN static const char*
-_evas_text_efl_text_text_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_efl_text_text_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->cur.utf8_text;
 }
 
 EOLIAN static Evas_BiDi_Direction
-_evas_text_direction_get(Eo *eo_obj, Evas_Text_Data *o)
+_evas_text_direction_get(const Eo *eo_obj, Evas_Text_Data *o)
 {
 #ifdef BIDI_SUPPORT
    Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
@@ -1137,9 +1140,10 @@ _evas_text_direction_get(Eo *eo_obj, Evas_Text_Data *o)
 
    if (o->changed_paragraph_direction)
      {
-        _evas_object_text_recalc(eo_obj, o->cur.text);
+        /* XXX const? */
+        _evas_object_text_recalc((Evas_Object *)eo_obj, o->cur.text);
         evas_object_render_pre_prev_cur_add(&obj->layer->evas->clip_changes,
-                                            eo_obj, obj);
+                                            (Evas_Object *)eo_obj, obj);
      }
 #endif
 
@@ -1147,43 +1151,43 @@ _evas_text_direction_get(Eo *eo_obj, Evas_Text_Data *o)
 }
 
 EOLIAN static Evas_Coord
-_evas_text_ascent_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_ascent_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->ascent;
 }
 
 EOLIAN static Evas_Coord
-_evas_text_descent_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_descent_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->descent;
 }
 
 EOLIAN static Evas_Coord
-_evas_text_max_ascent_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_max_ascent_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->max_ascent;
 }
 
 EOLIAN static Evas_Coord
-_evas_text_max_descent_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_max_descent_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->max_descent;
 }
 
 EOLIAN static Evas_Coord
-_evas_text_inset_get(Eo *eo_obj, Evas_Text_Data *o)
+_evas_text_inset_get(const Eo *eo_obj, Evas_Text_Data *o)
 {
    Evas_Object_Protected_Data *obj = efl_data_scope_get(eo_obj, EFL_CANVAS_OBJECT_CLASS);
    Evas_Coord inset = 0;
    if (!o->font) return inset;
    if (!o->items) return inset;
-   inset = ENFN->font_inset_get(ENDT, o->font, &o->items->text_props);
+   inset = ENFN->font_inset_get(ENC, o->font, &o->items->text_props);
 
    return inset;
 }
 
 EOLIAN static Evas_Coord
-_evas_text_horiz_advance_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_horiz_advance_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    Evas_Coord horiz = 0;
    if (!o->font) return horiz;
@@ -1194,7 +1198,7 @@ _evas_text_horiz_advance_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 }
 
 EOLIAN static Evas_Coord
-_evas_text_vert_advance_get(Eo *eo_obj, Evas_Text_Data *o)
+_evas_text_vert_advance_get(const Eo *eo_obj, Evas_Text_Data *o)
 {
    Evas_Coord vert;
    vert = 0;
@@ -1326,12 +1330,12 @@ _evas_text_style_set(Eo *eo_obj, Evas_Text_Data *o, Evas_Text_Style_Type style)
    if (o->items) w = obj->cur->geometry.w + (l - pl) + (r - pr);
    h = obj->cur->geometry.h + (t - pt) + (b - pb);
 
-   efl_gfx_size_set(efl_super(eo_obj, MY_CLASS), w, h);
+   efl_gfx_entity_size_set(efl_super(eo_obj, MY_CLASS), EINA_SIZE2D(w,  h));
    evas_object_change(eo_obj, obj);
 }
 
 EOLIAN static Evas_Text_Style_Type
-_evas_text_style_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+_evas_text_style_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
 {
    return o->cur.style;
 }
@@ -1353,7 +1357,7 @@ _evas_text_shadow_color_set(Eo *eo_obj, Evas_Text_Data *o, int r, int g, int b,
 }
 
 EOLIAN static void
-_evas_text_shadow_color_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
+_evas_text_shadow_color_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
 {
    if (r) *r = o->cur.shadow.r;
    if (g) *g = o->cur.shadow.g;
@@ -1378,7 +1382,7 @@ _evas_text_glow_color_set(Eo *eo_obj, Evas_Text_Data *o, int r, int g, int b, in
 }
 
 EOLIAN static void
-_evas_text_glow_color_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
+_evas_text_glow_color_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
 {
    if (r) *r = o->cur.glow.r;
    if (g) *g = o->cur.glow.g;
@@ -1403,7 +1407,7 @@ _evas_text_glow2_color_set(Eo *eo_obj, Evas_Text_Data *o, int r, int g, int b, i
 }
 
 EOLIAN static void
-_evas_text_glow2_color_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
+_evas_text_glow2_color_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
 {
    if (r) *r = o->cur.glow2.r;
    if (g) *g = o->cur.glow2.g;
@@ -1428,7 +1432,7 @@ _evas_text_outline_color_set(Eo *eo_obj, Evas_Text_Data *o, int r, int g, int b,
 }
 
 EOLIAN static void
-_evas_text_outline_color_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
+_evas_text_outline_color_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r, int *g, int *b, int *a)
 {
    if (r) *r = o->cur.outline.r;
    if (g) *g = o->cur.outline.g;
@@ -1437,7 +1441,7 @@ _evas_text_outline_color_get(Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o, int *r,
 }
 
 EOLIAN static void
-_evas_text_style_pad_get(Eo *eo_obj, Evas_Text_Data *o, int *l, int *r, int *t, int *b)
+_evas_text_style_pad_get(const Eo *eo_obj, Evas_Text_Data *o, int *l, int *r, int *t, int *b)
 {
    _evas_object_text_pad_get(eo_obj, o, l, r, t, b);
 }
@@ -1618,6 +1622,7 @@ evas_object_text_init(Evas_Object *eo_obj)
    Evas_Text_Data *o = obj->private_data;
    /* alloc obj private data */
    o->prev.ellipsis = o->cur.ellipsis = -1.0;
+   o->prev.bitmap_scalable = o->cur.bitmap_scalable = EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR;
    o->prev = o->cur;
 #ifdef BIDI_SUPPORT
    o->bidi_par_props = evas_bidi_paragraph_props_new();
@@ -1646,8 +1651,8 @@ evas_object_text_free(Evas_Object *eo_obj, Evas_Object_Protected_Data *obj)
    if (o->cur.source) eina_stringshare_del(o->cur.source);
    if (o->bidi_delimiters) eina_stringshare_del(o->bidi_delimiters);
    if (o->cur.text) free(o->cur.text);
-   if (o->font && obj->layer && obj->layer->evas)
-      evas_font_free(obj->layer->evas->evas, o->font);
+   if (obj->layer && obj->layer->evas)
+      evas_font_free(o->font);
    o->font = NULL;
    o->cur.utf8_text = NULL;
    o->cur.font = NULL;
@@ -1833,8 +1838,8 @@ evas_object_text_render(Evas_Object *eo_obj,
                                   obj->cur->geometry.x + x + sl + ox + it->x, \
                                   obj->cur->geometry.y + y + st + oy,   \
                                   it->w, it->h);                        \
-      evas_font_draw_async_check(obj, output,                           \
-                                 engine,                                \
+      evas_font_draw_async_check(obj, engine,                           \
+                                 output,                                \
                                  context,                               \
                                  surface,                               \
                                  o->font,                               \
@@ -2204,15 +2209,16 @@ evas_object_text_was_opaque(Evas_Object *eo_obj EINA_UNUSED,
    return 0;
 }
 
-static void
-evas_object_text_scale_update(Evas_Object *eo_obj,
-                              Evas_Object_Protected_Data *pd EINA_UNUSED,
-                              void *type_private_data)
+EOLIAN static void
+_evas_text_efl_gfx_entity_scale_set(Evas_Object *eo_obj, Evas_Text_Data *o,
+                                 double scale)
 {
-   Evas_Text_Data *o = type_private_data;
    int size;
    const char *font;
 
+   if (EINA_DBL_EQ(efl_gfx_entity_scale_get(eo_obj), scale)) return;
+   efl_gfx_entity_scale_set(efl_super(eo_obj, MY_CLASS), scale);
+
    font = eina_stringshare_add(o->cur.font);
    size = o->cur.size;
    if (o->cur.font) eina_stringshare_del(o->cur.font);
@@ -2231,8 +2237,7 @@ _evas_object_text_rehint(Evas_Object *eo_obj)
    Eina_List *was = NULL;
 
    if (!o->font) return;
-   evas_font_load_hinting_set(obj->layer->evas->evas, o->font,
-                  obj->layer->evas->hinting);
+   evas_font_load_hinting_set(o->font, obj->layer->evas->hinting);
    was = _evas_pointer_list_in_rect_get(obj->layer->evas, eo_obj, obj, 1, 1);
    /* DO II */
    _evas_object_text_recalc(eo_obj, o->cur.text);
@@ -2245,7 +2250,7 @@ _evas_object_text_rehint(Evas_Object *eo_obj)
    if (obj->cur->visible)
      _evas_canvas_event_pointer_in_list_mouse_move_feed(obj->layer->evas, was, eo_obj, obj, 1, 1, EINA_FALSE, NULL);
    eina_list_free(was);
-   evas_object_inform_call_resize(eo_obj);
+   evas_object_inform_call_resize(eo_obj, obj);
 }
 
 static void
@@ -2286,18 +2291,18 @@ _evas_object_text_recalc(Evas_Object *eo_obj, Eina_Unicode *text)
  */
         if (o->font)
           {
-             o->ascent = ENFN->font_ascent_get(ENDT, o->font);
-             o->descent = ENFN->font_descent_get(ENDT, o->font);
-             o->max_ascent = ENFN->font_max_ascent_get(ENDT, o->font);
-             o->max_descent = ENFN->font_max_descent_get(ENDT, o->font);
+             o->ascent = ENFN->font_ascent_get(ENC, o->font);
+             o->descent = ENFN->font_descent_get(ENC, o->font);
+             o->max_ascent = ENFN->font_max_ascent_get(ENC, o->font);
+             o->max_descent = ENFN->font_max_descent_get(ENC, o->font);
           }
      }
    else if (o->font)
      {
-        o->ascent = ENFN->font_ascent_get(ENDT, o->font);
-        o->descent = ENFN->font_descent_get(ENDT, o->font);
-        o->max_ascent = ENFN->font_max_ascent_get(ENDT, o->font);
-        o->max_descent = ENFN->font_max_descent_get(ENDT, o->font);
+        o->ascent = ENFN->font_ascent_get(ENC, o->font);
+        o->descent = ENFN->font_descent_get(ENC, o->font);
+        o->max_ascent = ENFN->font_max_ascent_get(ENC, o->font);
+        o->max_descent = ENFN->font_max_descent_get(ENC, o->font);
      }
 
    if ((o->font) && (o->items))
@@ -2314,11 +2319,11 @@ _evas_object_text_recalc(Evas_Object *eo_obj, Eina_Unicode *text)
              int min;
 
              min = w + l + r < obj->cur->geometry.w || obj->cur->geometry.w == 0 ? w + l + r : obj->cur->geometry.w;
-             efl_gfx_size_set(efl_super(eo_obj, MY_CLASS), min, h + t + b);
+             efl_gfx_entity_size_set(efl_super(eo_obj, MY_CLASS), EINA_SIZE2D(min,  h + t + b));
           }
         else
           {
-             efl_gfx_size_set(efl_super(eo_obj, MY_CLASS), w + l + r, h + t + b);
+             efl_gfx_entity_size_set(efl_super(eo_obj, MY_CLASS), EINA_SIZE2D(w + l + r,  h + t + b));
           }
 ////        obj->cur->cache.geometry.validity = 0;
      }
@@ -2326,7 +2331,7 @@ _evas_object_text_recalc(Evas_Object *eo_obj, Eina_Unicode *text)
      {
         int t = 0, b = 0, l = 0, r = 0;
         _evas_object_text_pad_get(eo_obj, o, &l, &r, &t, &b);
-        efl_gfx_size_set(efl_super(eo_obj, MY_CLASS), 0, o->max_ascent + o->max_descent + t + b);
+        efl_gfx_entity_size_set(efl_super(eo_obj, MY_CLASS), EINA_SIZE2D(0,  o->max_ascent + o->max_descent + t + b));
 ////        obj->cur->cache.geometry.validity = 0;
      }
    o->last_computed.w = obj->cur->geometry.w;
@@ -2339,27 +2344,27 @@ _evas_object_text_recalc(Evas_Object *eo_obj, Eina_Unicode *text)
 EAPI void
 evas_object_text_font_source_set(Eo *obj, const char *font_source)
 {
-   efl_text_properties_font_source_set((Eo *) obj, font_source);
+   efl_text_font_source_set((Eo *) obj, font_source);
 }
 
 EAPI const char *
 evas_object_text_font_source_get(const Eo *obj)
 {
    const char *font_source = 0;
-   font_source = efl_text_properties_font_source_get((Eo *) obj);
+   font_source = efl_text_font_source_get((Eo *) obj);
    return font_source;
 }
 
 EAPI void
 evas_object_text_font_set(Eo *obj, const char *font, Evas_Font_Size size)
 {
-   efl_text_properties_font_set((Eo *) obj, font, size);
+   efl_text_font_set((Eo *) obj, font, size);
 }
 
 EAPI void
 evas_object_text_font_get(const Eo *obj, const char **font, Evas_Font_Size *size)
 {
-   efl_text_properties_font_get((Eo *) obj, font, size);
+   efl_text_font_get((Eo *) obj, font, size);
 }
 
 EAPI void
@@ -2436,12 +2441,27 @@ _evas_text_efl_canvas_object_paragraph_direction_set(Eo *eo_obj, Evas_Text_Data
 }
 
 EOLIAN static Evas_BiDi_Direction
-_evas_text_efl_canvas_object_paragraph_direction_get(Eo *eo_obj EINA_UNUSED,
+_evas_text_efl_canvas_object_paragraph_direction_get(const Eo *eo_obj EINA_UNUSED,
                                                      Evas_Text_Data *o)
 {
    return o->paragraph_direction;
 }
 
+EOLIAN static void
+_evas_text_efl_text_font_font_bitmap_scalable_set(Eo *eo_obj, Evas_Text_Data *o, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
+{
+   if (o->cur.bitmap_scalable == bitmap_scalable) return;
+   o->prev.bitmap_scalable = o->cur.bitmap_scalable;
+   o->cur.bitmap_scalable = bitmap_scalable;
+   _evas_text_font_reload(eo_obj, o);
+}
+
+EOLIAN static Efl_Text_Font_Bitmap_Scalable
+_evas_text_efl_text_font_font_bitmap_scalable_get(const Eo *eo_obj EINA_UNUSED, Evas_Text_Data *o)
+{
+   return o->cur.bitmap_scalable;
+}
+
 #define EVAS_TEXT_EXTRA_OPS \
    EFL_OBJECT_OP_FUNC(efl_dbg_info_get, _evas_text_efl_object_dbg_info_get)
 
