@@ -6,6 +6,7 @@
 #include "evas_font_private.h" /* for Frame-Queuing support */
 
 #include "evas_font_ot.h"
+#include "draw.h"
 
 #ifdef EVAS_CSERVE2
 #include "../cserve2/evas_cs2_private.h"
@@ -24,16 +25,25 @@ evas_common_font_draw_init(void)
 }
 
 static void *
-_evas_font_image_new_from_data(int w, int h, DATA32 *image_data, int alpha, Evas_Colorspace cspace)
+_evas_font_image_new(RGBA_Font_Glyph *fg, int alpha, Evas_Colorspace cspace)
 {
+   DATA32 *image_data;
+   int src_w, src_h;
+
+   if (!fg) return NULL;
+
+   image_data = (DATA32 *)fg->glyph_out->bitmap.buffer;
+   src_w = fg->glyph_out->bitmap.width;
+   src_h = fg->glyph_out->bitmap.rows;
+
 #ifdef EVAS_CSERVE2
    if (evas_cserve2_use_get())
      {
         Evas_Cache2 *cache = evas_common_image_cache2_get();
-        return evas_cache2_image_data(cache, w, h, image_data, alpha, cspace);
+        return evas_cache2_image_data(cache, src_w, src_h, image_data, alpha, cspace);
      }
 #endif
-   return evas_cache_image_data(evas_common_image_cache_get(), w, h, image_data, alpha, cspace);
+   return evas_cache_image_data(evas_common_image_cache_get(), src_w, src_h, image_data, alpha, cspace);
 }
 
 static void
@@ -50,12 +60,15 @@ _evas_font_image_free(void *image)
 }
 
 static void
-_evas_font_image_draw(void *context, void *surface, void *image, int src_x, int src_y, int src_w, int src_h, int dst_x, int dst_y, int dst_w, int dst_h, int smooth)
+_evas_font_image_draw(void *context, void *surface, void *image, RGBA_Font_Glyph *fg, int x, int y, int w, int h, int smooth)
 {
    RGBA_Image *im;
+   int src_w, src_h;
 
-   if (!image) return;
+   if (!image || !fg) return;
    im = image;
+   src_w = fg->glyph_out->bitmap.width;
+   src_h = fg->glyph_out->bitmap.rows;
 
 #ifdef BUILD_PIPE_RENDER
    if ((eina_cpu_count() > 1))
@@ -66,24 +79,24 @@ _evas_font_image_draw(void *context, void *surface, void *image, int src_x, int
 #endif
         evas_common_rgba_image_scalecache_prepare((Image_Entry *)(im),
                                                   surface, context, smooth,
-                                                  src_x, src_y, src_w, src_h,
-                                                  dst_x, dst_y, dst_w, dst_h);
+                                                  0, 0, src_w, src_h,
+                                                  x, y, w, h);
 
         evas_common_pipe_image_draw(im, surface, context, smooth,
-                                    src_x, src_y, src_w, src_h,
-                                    dst_x, dst_y, dst_w, dst_h);
+                                    0, 0, src_w, src_h,
+                                    x, y, w, h);
      }
    else
 #endif
      {
         evas_common_rgba_image_scalecache_prepare
           (&im->cache_entry, surface, context, smooth,
-           src_x, src_y, src_w, src_h,
-           dst_x, dst_y, dst_w, dst_h);
+           0, 0, src_w, src_h,
+           x, y, w, h);
         evas_common_rgba_image_scalecache_do
           (&im->cache_entry, surface, context, smooth,
-           src_x, src_y, src_w, src_h,
-           dst_x, dst_y, dst_w, dst_h);
+           0, 0, src_w, src_h,
+           x, y, w, h);
 
         evas_common_cpu_end_opt();
      }
@@ -111,9 +124,20 @@ evas_common_font_rgba_draw(RGBA_Image *dst, RGBA_Draw_Context *dc, int x, int y,
         int chr_x, chr_y, w, h;
 
         fg = glyph->fg;
+
         w = fg->glyph_out->bitmap.width;
         h = fg->glyph_out->bitmap.rows;
 
+        if (FT_HAS_FIXED_SIZES(fg->fi->src->ft.face))
+          {
+             if ((fg->fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR) &&
+                 FT_HAS_COLOR(fg->fi->src->ft.face))
+               {
+                  w *= fg->fi->scale_factor;
+                  h *= fg->fi->scale_factor;
+               }
+          }
+
         if ((!fg->ext_dat) && (dc->font_ext.func.gl_new))
           {
              /* extension calls */
@@ -132,9 +156,7 @@ evas_common_font_rgba_draw(RGBA_Image *dst, RGBA_Draw_Context *dc, int x, int y,
                }
              else
                {
-                  fg->ext_dat = _evas_font_image_new_from_data
-                    (w, h, (DATA32 *)fg->glyph_out->bitmap.buffer,
-                     EINA_TRUE, EVAS_COLORSPACE_ARGB8888);
+                  fg->ext_dat = _evas_font_image_new(fg, EINA_TRUE, EVAS_COLORSPACE_ARGB8888);
                   fg->ext_dat_free = _evas_font_image_free;
                }
           }
@@ -150,10 +172,11 @@ evas_common_font_rgba_draw(RGBA_Image *dst, RGBA_Draw_Context *dc, int x, int y,
                        if ((fg->ext_dat) && (dc->font_ext.func.gl_draw))
                          dc->font_ext.func.gl_draw(dc->font_ext.data, dst,
                                                    dc, fg,
-                                                   chr_x, y - (chr_y - y));
+                                                   chr_x, y - (chr_y - y), w, h);
                        else
+                         // TODO: scale with evas_font_compress_draw.c...
                          evas_common_font_glyph_draw(fg, dc, dst, im_w,
-                                                     chr_x, y - (chr_y - y),
+                                                     chr_x, y - (chr_y - y), w, h,
                                                      ext_x, ext_y,
                                                      ext_w, ext_h);
                     }
@@ -165,7 +188,7 @@ evas_common_font_rgba_draw(RGBA_Image *dst, RGBA_Draw_Context *dc, int x, int y,
                             chr_x, y - (chr_y - y), w, h, EINA_TRUE);
                        else
                          _evas_font_image_draw
-                           (dc, dst, fg->ext_dat, 0, 0, w, h,
+                           (dc, dst, fg->ext_dat, fg,
                             chr_x, y - (chr_y - y), w, h, EINA_TRUE);
                     }
                }
@@ -485,3 +508,154 @@ evas_common_font_draw_prepare_cutout(Cutout_Rects **reuse, RGBA_Image *dst, RGBA
    return EINA_TRUE;
 }
 
+// this draws a compressed font glyph and decompresses on the fly as it
+// draws, saving memory bandwidth and providing speedups
+EAPI void
+evas_common_font_glyph_draw(RGBA_Font_Glyph *fg,
+                            RGBA_Draw_Context *dc,
+                            RGBA_Image *dst_image, int dst_pitch,
+                            int dx, int dy, int dw, int dh, int cx, int cy, int cw, int ch)
+{
+   RGBA_Font_Glyph_Out *fgo = fg->glyph_out;
+   int x, y, w, h, x1, x2, y1, y2, i, *iptr;
+   DATA32 *dst = dst_image->image.data;
+   DATA32 coltab[16], col;
+   DATA16 mtab[16], v;
+
+   // FIXME: Use dw, dh for scaling glyphs...
+   (void) dw;
+   (void) dh;
+   x = dx;
+   y = dy;
+   w = fgo->bitmap.width; h = fgo->bitmap.rows;
+   // skip if totally clipped out
+   if ((y >= (cy + ch)) || ((y + h) <= cy) ||
+       (x >= (cx + cw)) || ((x + w) <= cx)) return;
+   // figure y1/y2 limit range
+   y1 = 0; y2 = h;
+   if ((y + y1) < cy) y1 = cy - y;
+   if ((y + y2) > (cy + ch)) y2 = cy + ch - y;
+   // figure x1/x2 limit range
+   x1 = 0; x2 = w;
+   if ((x + x1) < cx) x1 = cx - x;
+   if ((x + x2) > (cx + cw)) x2 = cx + cw - x;
+   col = dc->col.col;
+   if (dst_image->cache_entry.space == EVAS_COLORSPACE_GRY8)
+     {
+        // FIXME: Font draw not optimized for Alpha targets! SLOW!
+        // This is not pretty :)
+
+        DATA8 *src8, *dst8;
+        Draw_Func_Alpha func;
+        int row;
+
+        if (EINA_UNLIKELY(x < 0))
+          {
+             x1 += (-x);
+             x = 0;
+             if ((x2 - x1) <= 0) return;
+          }
+        if (EINA_UNLIKELY(y < 0))
+          {
+             y1 += (-y);
+             y = 0;
+             if ((y2 - y1) <= 0) return;
+          }
+
+        dst8 = dst_image->image.data8 + x + (y * dst_pitch);
+        func = efl_draw_alpha_func_get(dc->render_op, EINA_FALSE);
+        src8 = evas_common_font_glyph_uncompress(fg, NULL, NULL);
+        if (!src8) return;
+
+        for (row = y1; row < y2; row++)
+          {
+             DATA8 *d = dst8 + ((row - y1) * dst_pitch);
+             DATA8 *s = src8 + (row * w) + x1;
+             func(d, s, x2 - x1);
+          }
+        free(src8);
+     }
+   else if (dc->clip.mask)
+     {
+        RGBA_Gfx_Func func;
+        DATA8 *src8, *mask;
+        DATA32 *buf, *ptr, *buf_ptr;
+        RGBA_Image *im = dc->clip.mask;
+        int row;
+
+        buf = alloca(sizeof(DATA32) * w * h);
+
+        // Adjust clipping info
+        if (EINA_UNLIKELY((x + x1) < dc->clip.mask_x))
+          x1 = dc->clip.mask_x - x;
+        if (EINA_UNLIKELY((y + y1) < dc->clip.mask_y))
+          y1 = dc->clip.mask_y - y;
+        if (EINA_UNLIKELY((x + x2) > (int)(x + x1 + im->cache_entry.w)))
+          x2 = x1 + im->cache_entry.w;
+        if (EINA_UNLIKELY((y + y2) > (int)(y + y1 + im->cache_entry.h)))
+          y2 = y1 + im->cache_entry.h;
+
+        // Step 1: alpha glyph drawing
+        src8 = evas_common_font_glyph_uncompress(fg, NULL, NULL);
+        if (!src8) return;
+
+        // Step 2: color blending to buffer
+        func = evas_common_gfx_func_composite_mask_color_span_get(col, dst_image->cache_entry.flags.alpha, 1, EVAS_RENDER_COPY);
+        for (row = y1; row < y2; row++)
+          {
+             buf_ptr = buf + (row * w) + x1;
+             DATA8 *s = src8 + (row * w) + x1;
+             func(NULL, s, col, buf_ptr, x2 - x1);
+          }
+        free(src8);
+
+        // Step 3: masking to destination
+        func = evas_common_gfx_func_composite_pixel_mask_span_get(im->cache_entry.flags.alpha, im->cache_entry.flags.alpha_sparse, dst_image->cache_entry.flags.alpha, dst_pitch, dc->render_op);
+        for (row = y1; row < y2; row++)
+          {
+             mask = im->image.data8
+                + (y + row - dc->clip.mask_y) * im->cache_entry.w
+                + (x + x1 - dc->clip.mask_x);
+
+             ptr = dst + (x + x1) + ((y + row) * dst_pitch);
+             buf_ptr = buf + (row * w) + x1;
+             func(buf_ptr, mask, 0, ptr, w);
+          }
+     }
+   else
+     {
+        // build fast multiply + mask color tables to avoid compute. this works
+        // because of our very limited 4bit range of alpha values
+        for (i = 0; i <= 0xf; i++)
+          {
+             v = (i << 4) | i;
+             coltab[i] = MUL_SYM(v, col);
+             mtab[i] = 256 - (coltab[i] >> 24);
+          }
+#ifdef BUILD_MMX
+        if (evas_common_cpu_has_feature(CPU_FEATURE_MMX))
+          {
+#define MMX 1
+#include "evas_font_compress_draw.c"
+#undef MMX
+          }
+        else
+#endif
+
+#ifdef BUILD_NEON
+        if (evas_common_cpu_has_feature(CPU_FEATURE_NEON))
+          {
+#define NEON 1
+#include "evas_font_compress_draw.c"
+#undef NEON
+          }
+        else
+#endif
+
+          // Plain C
+          {
+#include "evas_font_compress_draw.c"
+          }
+     }
+}
+
