@@ -3,9 +3,7 @@
 #endif
 
 #include <assert.h>
-
-#include "evas_common_private.h"
-#include "evas_private.h"
+#include "evas_font_ot.h"
 
 #ifdef USE_HARFBUZZ
 # include <hb.h>
@@ -13,7 +11,7 @@
 
 #include "evas_font_private.h" /* for Frame-Queuing support */
 
-#include <ft2build.h> 
+#include <ft2build.h>
 #include FT_TRUETYPE_TABLES_H /* Freetype2 OS/2 font table. */
 
 #ifdef EVAS_CSERVE2
@@ -24,7 +22,8 @@ extern FT_Library         evas_ft_lib;
 
 static int                font_cache_usage = 0;
 static int                font_cache = 0;
-static int                font_dpi = 75;
+static int                font_dpi_h = 75;
+static int                font_dpi_v = 75;
 
 static Eina_Hash   *fonts_src = NULL;
 static Eina_Hash   *fonts = NULL;
@@ -42,9 +41,16 @@ _evas_font_cache_int_cmp(const RGBA_Font_Int *k1, int k1_length EINA_UNUSED,
    if (k1->src->name == k2->src->name)
      {
         if (k1->size == k2->size)
-           return k1->wanted_rend - k2->wanted_rend;
+          {
+             if (k1->wanted_rend == k2->wanted_rend)
+               return k1->bitmap_scalable - k2->bitmap_scalable;
+             else
+               return k1->wanted_rend - k2->wanted_rend;
+          }
         else
-           return k1->size - k2->size;
+          {
+             return k1->size - k2->size;
+          }
      }
    return strcmp(k1->src->name, k2->src->name);
 }
@@ -57,6 +63,7 @@ _evas_font_cache_int_hash(const RGBA_Font_Int *key, int key_length EINA_UNUSED)
    hash = eina_hash_djb2(key->src->name, eina_stringshare_strlen(key->src->name) + 1);
    hash ^= eina_hash_int32(&key->size, sizeof (int));
    hash ^= eina_hash_int32(&wanted_rend, sizeof (int));
+   hash ^= eina_hash_int32(&key->bitmap_scalable, sizeof (int));
    return hash;
 }
 
@@ -123,15 +130,17 @@ evas_common_font_load_shutdown(void)
 }
 
 EAPI void
-evas_common_font_dpi_set(int dpi)
+evas_common_font_dpi_set(int dpi_h, int dpi_v)
 {
-   font_dpi = dpi;
+   if (dpi_v <= 0) dpi_v = dpi_h;
+   font_dpi_h = dpi_h;
+   font_dpi_v = dpi_v;
 }
 
 EAPI RGBA_Font_Source *
 evas_common_font_source_memory_load(const char *name, const void *data, int data_size)
 {
-   int error; 
+   int error;
    RGBA_Font_Source *fs;
 
    assert(name != NULL);
@@ -207,7 +216,7 @@ evas_common_font_source_reload(RGBA_Font_Source *fs)
   if (fs->data)
     {
       int error;
-      
+
       FTLOCK();
       error = FT_New_Memory_Face(evas_ft_lib, fs->data, fs->data_size, 0, &(fs->ft.face));
       FTUNLOCK();
@@ -305,8 +314,8 @@ _evas_common_font_double_int_cmp(const int *key1, EINA_UNUSED int key1_length,
 static int
 _evas_common_font_double_int_hash(const unsigned int key[2], int key_length)
 {
-   return 
-    eina_hash_int32(&key[0], key_length) ^ 
+   return
+    eina_hash_int32(&key[0], key_length) ^
     eina_hash_int32(&key[1], key_length);
 }
 
@@ -322,22 +331,20 @@ _evas_common_font_int_cache_init(RGBA_Font_Int *fi)
 }
 
 EAPI RGBA_Font_Int *
-evas_common_font_int_memory_load(const char *source, const char *name, int size, const void *data, int data_size, Font_Rend_Flags wanted_rend)
+evas_common_font_int_memory_load(const char *source, const char *name, int size, const void *data, int data_size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font_Int *fi;
-   char *fake_name;
+   char fake_name[PATH_MAX];
 
-   fake_name = evas_file_path_join(source, name);
-   fi = evas_common_font_int_find(fake_name, size, wanted_rend);
+   eina_file_path_join(fake_name, sizeof(fake_name), source, name);
+   fi = evas_common_font_int_find(fake_name, size, wanted_rend, bitmap_scalable);
    if (fi)
      {
-        free(fake_name);
         return fi;
      }
    fi = calloc(1, sizeof(RGBA_Font_Int));
    if (!fi)
      {
-        free(fake_name);
         return NULL;
      }
    fi->src = evas_common_font_source_find(fake_name);
@@ -345,18 +352,18 @@ evas_common_font_int_memory_load(const char *source, const char *name, int size,
     fi->src = evas_common_font_source_memory_load(fake_name, data, data_size);
    if (!fi->src)
      {
-	free(fi);
-        free(fake_name);
-	return NULL;
+        free(fi);
+        return NULL;
      }
    fi->size = size;
+   fi->bitmap_scalable = bitmap_scalable;
    _evas_common_font_int_cache_init(fi);
    fi = evas_common_font_int_load_init(fi);
    evas_common_font_int_load_complete(fi);
 #ifdef EVAS_CSERVE2
    if (evas_cserve2_use_get())
      {
-        fi->cs2_handler = evas_cserve2_font_load(source, name, size, font_dpi,
+        fi->cs2_handler = evas_cserve2_font_load(source, name, size, font_dpi_h,
                                                  wanted_rend);
         if (fi->cs2_handler)
           {
@@ -368,22 +375,32 @@ evas_common_font_int_memory_load(const char *source, const char *name, int size,
           }
      }
 #endif
-   free(fake_name);
    return fi;
 }
 
+static int
+_file_path_is_file_helper(const char *path)
+{
+   struct stat st;
+
+   if (stat(path, &st) == -1) return 0;
+   if (S_ISREG(st.st_mode)) return 1;
+   return 0;
+}
+
 EAPI RGBA_Font_Int *
 evas_common_font_int_load(const char *name, int size,
-                          Font_Rend_Flags wanted_rend)
+                          Font_Rend_Flags wanted_rend,
+						  Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font_Int *fi;
 
-   fi = evas_common_font_int_find(name, size, wanted_rend);
+   fi = evas_common_font_int_find(name, size, wanted_rend, bitmap_scalable);
    if (fi) return fi;
    fi = calloc(1, sizeof(RGBA_Font_Int));
    if (!fi) return NULL;
    fi->src = evas_common_font_source_find(name);
-   if (!fi->src && evas_file_path_is_file(name))
+   if (!fi->src && _file_path_is_file_helper(name))
      fi->src = evas_common_font_source_load(name);
 
    if (!fi->src)
@@ -393,12 +410,13 @@ evas_common_font_int_load(const char *name, int size,
      }
    fi->size = size;
    fi->wanted_rend = wanted_rend;
+   fi->bitmap_scalable = bitmap_scalable;
    _evas_common_font_int_cache_init(fi);
    fi = evas_common_font_int_load_init(fi);
 #ifdef EVAS_CSERVE2
    if (evas_cserve2_use_get())
      {
-        fi->cs2_handler = evas_cserve2_font_load(NULL, name, size, font_dpi,
+        fi->cs2_handler = evas_cserve2_font_load(NULL, name, size, font_dpi_h,
                                                  wanted_rend);
         if (fi->cs2_handler)
           {
@@ -437,7 +455,8 @@ evas_common_font_int_load_complete(RGBA_Font_Int *fi)
 	FT_Activate_Size(fi->ft.size);
      }
    fi->real_size = fi->size * 64;
-   error = FT_Set_Char_Size(fi->src->ft.face, 0, fi->real_size, font_dpi, font_dpi);
+   fi->scale_factor = 1.0;
+   error = FT_Set_Char_Size(fi->src->ft.face, 0, fi->real_size, font_dpi_h, font_dpi_v);
    if (error)
      error = FT_Set_Pixel_Sizes(fi->src->ft.face, 0, fi->real_size);
    FTUNLOCK();
@@ -451,7 +470,7 @@ evas_common_font_int_load_complete(RGBA_Font_Int *fi)
 	for (i = 0; i < fi->src->ft.face->num_fixed_sizes; i++)
 	  {
 	     int s, cd;
-             
+
 	     s = fi->src->ft.face->available_sizes[i].size;
 	     cd = chosen_size - fi->real_size;
 	     if (cd < 0) cd = -cd;
@@ -468,19 +487,35 @@ evas_common_font_int_load_complete(RGBA_Font_Int *fi)
         FTLOCK();
 
         if (FT_HAS_FIXED_SIZES(fi->src->ft.face))
-          error = FT_Select_Size(fi->src->ft.face, strike_index);
+          {
+             error = FT_Select_Size(fi->src->ft.face, strike_index);
+
+             if (!error)
+               {
+                  if (FT_HAS_COLOR(fi->src->ft.face) &&
+                      fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR)
+                    {
+                       if (fi->real_size > 0)
+                         fi->scale_factor = (float)fi->size * 64.0 / (float)fi->real_size;
+                       else
+                         fi->scale_factor = (float)64.0;
+                    }
+               }
+          }
         else
-          error = FT_Set_Pixel_Sizes(fi->src->ft.face, 0, fi->real_size);
+          {
+             error = FT_Set_Pixel_Sizes(fi->src->ft.face, 0, fi->real_size);
+          }
 
         FTUNLOCK();
 	if (error)
 	  {
-             error = FT_Set_Char_Size(fi->src->ft.face, 0, fi->real_size, font_dpi, font_dpi);
+             error = FT_Set_Char_Size(fi->src->ft.face, 0, fi->real_size, font_dpi_h, font_dpi_v);
              if (error)
                {
                   /* hack around broken fonts */
                   fi->real_size = (chosen_size2 / 64) * 60;
-                  error = FT_Set_Char_Size(fi->src->ft.face, 0, fi->real_size, font_dpi, font_dpi);
+                  error = FT_Set_Char_Size(fi->src->ft.face, 0, fi->real_size, font_dpi_h, font_dpi_v);
                   if (error)
                     {
                        /* couldn't choose the size anyway... what now? */
@@ -543,13 +578,13 @@ evas_common_font_int_load_complete(RGBA_Font_Int *fi)
 }
 
 EAPI RGBA_Font *
-evas_common_font_memory_load(const char *source, const char *name, int size, const void *data, int data_size, Font_Rend_Flags wanted_rend)
+evas_common_font_memory_load(const char *source, const char *name, int size, const void *data, int data_size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font *fn;
    RGBA_Font_Int *fi;
 
    fi = evas_common_font_int_memory_load(source, name, size, data, data_size,
-                                         wanted_rend);
+                                         wanted_rend, bitmap_scalable);
    if (!fi) return NULL;
    fn = calloc(1, sizeof(RGBA_Font));
    if (!fn)
@@ -577,12 +612,12 @@ evas_common_font_memory_load(const char *source, const char *name, int size, con
 //   fi->fs
 
 EAPI RGBA_Font *
-evas_common_font_load(const char *name, int size, Font_Rend_Flags wanted_rend)
+evas_common_font_load(const char *name, int size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font *fn;
    RGBA_Font_Int *fi;
 
-   fi = evas_common_font_int_load(name, size, wanted_rend);
+   fi = evas_common_font_int_load(name, size, wanted_rend, bitmap_scalable);
    if (!fi) return NULL;
    /* First font, complete load */
    if (!fi->ft.size)
@@ -619,12 +654,12 @@ evas_common_font_load(const char *name, int size, Font_Rend_Flags wanted_rend)
 }
 
 EAPI RGBA_Font *
-evas_common_font_add(RGBA_Font *fn, const char *name, int size, Font_Rend_Flags wanted_rend)
+evas_common_font_add(RGBA_Font *fn, const char *name, int size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font_Int *fi;
 
    if (!fn) return NULL;
-   fi = evas_common_font_int_load(name, size, wanted_rend);
+   fi = evas_common_font_int_load(name, size, wanted_rend, bitmap_scalable);
    if (fi)
      {
 	fn->fonts = eina_list_append(fn->fonts, fi);
@@ -641,13 +676,13 @@ evas_common_font_add(RGBA_Font *fn, const char *name, int size, Font_Rend_Flags
 }
 
 EAPI RGBA_Font *
-evas_common_font_memory_add(RGBA_Font *fn, const char *source, const char *name, int size, const void *data, int data_size, Font_Rend_Flags wanted_rend)
+evas_common_font_memory_add(RGBA_Font *fn, const char *source, const char *name, int size, const void *data, int data_size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font_Int *fi;
 
    if (!fn)
       return NULL;
-   fi = evas_common_font_int_memory_load(source, name, size, data, data_size, wanted_rend);
+   fi = evas_common_font_int_memory_load(source, name, size, data, data_size, wanted_rend, bitmap_scalable);
    if (fi)
      {
 	fn->fonts = eina_list_append(fn->fonts, fi);
@@ -744,38 +779,38 @@ evas_common_hinting_available(Font_Hint_Flags hinting)
 }
 
 EAPI RGBA_Font *
-evas_common_font_memory_hinting_load(const char *source, const char *name, int size, const void *data, int data_size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend)
+evas_common_font_memory_hinting_load(const char *source, const char *name, int size, const void *data, int data_size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font *fn;
 
-   fn = evas_common_font_memory_load(source, name, size, data, data_size, wanted_rend);
+   fn = evas_common_font_memory_load(source, name, size, data, data_size, wanted_rend, bitmap_scalable);
    if (fn) evas_common_font_hinting_set(fn, hinting);
    return fn;
 }
 
 EAPI RGBA_Font *
-evas_common_font_hinting_load(const char *name, int size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend)
+evas_common_font_hinting_load(const char *name, int size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font *fn;
 
-   fn = evas_common_font_load(name, size, wanted_rend);
+   fn = evas_common_font_load(name, size, wanted_rend, bitmap_scalable);
    if (fn) evas_common_font_hinting_set(fn, hinting);
    return fn;
 }
 
 EAPI RGBA_Font *
-evas_common_font_hinting_add(RGBA_Font *fn, const char *name, int size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend)
+evas_common_font_hinting_add(RGBA_Font *fn, const char *name, int size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
-   fn = evas_common_font_add(fn, name, size, wanted_rend);
+   fn = evas_common_font_add(fn, name, size, wanted_rend, bitmap_scalable);
    if (fn) evas_common_font_hinting_set(fn, hinting);
    return fn;
 }
 
 EAPI RGBA_Font *
-evas_common_font_memory_hinting_add(RGBA_Font *fn, const char *source, const char *name, int size, const void *data, int data_size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend)
+evas_common_font_memory_hinting_add(RGBA_Font *fn, const char *source, const char *name, int size, const void *data, int data_size, Font_Hint_Flags hinting, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    fn = evas_common_font_memory_add(fn, source, name, size, data, data_size,
-                                    wanted_rend);
+                                    wanted_rend, bitmap_scalable);
    if (fn) evas_common_font_hinting_set(fn, hinting);
    return fn;
 }
@@ -822,7 +857,7 @@ void
 evas_common_font_int_promote(RGBA_Font_Int *fi EINA_UNUSED)
 {
   return;
-/* unused - keep for reference  
+/* unused - keep for reference
   if (fonts_use_lru == (Eina_Inlist *)fi) return;
   if (!fi->inuse) return;
   fonts_use_lru = eina_inlist_remove(fonts_use_lru, EINA_INLIST_GET(fi));
@@ -840,7 +875,7 @@ void
 evas_common_font_int_use_trim(void)
 {
   return;
-/* unused - keep for reference  
+/* unused - keep for reference
   Eina_Inlist *l;
 
   if (fonts_use_usage <= (font_cache << 1)) return;
@@ -863,7 +898,7 @@ void
 evas_common_font_int_unload(RGBA_Font_Int *fi EINA_UNUSED)
 {
   return;
-/* unused - keep for reference  
+/* unused - keep for reference
   if (!fi->src->ft.face) return;
   _evas_common_font_int_clear(fi);
   FT_Done_Size(fi->ft.size);
@@ -878,7 +913,7 @@ evas_common_font_int_reload(RGBA_Font_Int *fi)
   if (fi->src->ft.face) return;
   evas_common_font_source_load_complete(fi->src);
   return;
-/* unused - keep for reference  
+/* unused - keep for reference
   evas_common_font_source_reload(fi->src);
   evas_common_font_int_load_complete(fi);
  */
@@ -916,7 +951,7 @@ evas_common_font_flush(void)
    while (font_cache_usage > font_cache)
      {
         int pfont_cache_usage;
-        
+
         pfont_cache_usage = font_cache_usage;
         evas_common_font_flush_last();
         if (pfont_cache_usage == font_cache_usage) break;
@@ -939,7 +974,8 @@ evas_common_font_flush_last(void)
 
 EAPI RGBA_Font_Int *
 evas_common_font_int_find(const char *name, int size,
-                          Font_Rend_Flags wanted_rend)
+                          Font_Rend_Flags wanted_rend,
+						  Efl_Text_Font_Bitmap_Scalable bitmap_scalable)
 {
    RGBA_Font_Int tmp_fi;
    RGBA_Font_Source tmp_fn;
@@ -949,6 +985,7 @@ evas_common_font_int_find(const char *name, int size,
    tmp_fi.src = &tmp_fn;
    tmp_fi.size = size;
    tmp_fi.wanted_rend = wanted_rend;
+   tmp_fi.bitmap_scalable = bitmap_scalable;
    fi = eina_hash_find(fonts, &tmp_fi);
    if (fi)
      {
