@@ -1,13 +1,5 @@
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
-
-#include <assert.h>
-
-#include "evas_common_private.h"
-#include "evas_private.h"
-
 #include "evas_font_private.h"
+#include "evas_font_draw.h"
 
 #ifdef EVAS_CSERVE2
 # include "../cserve2/evas_cs2_private.h"
@@ -25,6 +17,8 @@ LK(lock_font_draw); // for freetype2 API calls
 LK(lock_bidi); // for evas bidi internal usage.
 LK(lock_ot); // for evas bidi internal usage.
 
+int _evas_font_log_dom_global = -1;
+
 EAPI void
 evas_common_font_init(void)
 {
@@ -36,6 +30,12 @@ evas_common_font_init(void)
 #else
    35;
 #endif
+   _evas_font_log_dom_global = eina_log_domain_register
+     ("evas_font_main", EVAS_FONT_DEFAULT_LOG_COLOR);
+   if (_evas_font_log_dom_global < 0)
+     {
+        EINA_LOG_ERR("Can not create a module log domain.");
+     }
 
    initialised++;
    if (initialised != 1) return;
@@ -48,9 +48,12 @@ evas_common_font_init(void)
    s = getenv("EVAS_FONT_DPI");
    if (s)
      {
-        int dpi = atoi(s);
+        int dpi_h = 75, dpi_v = 0;
 
-        if (dpi > 0) evas_common_font_dpi_set(dpi);
+        if (sscanf(s, "%dx%d", &dpi_h, &dpi_v) < 2)
+          dpi_h = dpi_v = atoi(s);
+
+        if (dpi_h > 0) evas_common_font_dpi_set(dpi_h, dpi_v);
      }
    LKI(lock_font_draw);
    LKI(lock_bidi);
@@ -74,6 +77,7 @@ evas_common_font_shutdown(void)
    LKD(lock_font_draw);
    LKD(lock_bidi);
    LKD(lock_ot);
+   eina_log_domain_unregister(_evas_font_log_dom_global);
 }
 
 EAPI void
@@ -115,6 +119,14 @@ evas_common_font_instance_ascent_get(RGBA_Font_Int *fi)
         WRN("NOT SCALABLE!");
      }
    val = (int)fi->src->ft.face->size->metrics.ascender;
+
+   if (FT_HAS_FIXED_SIZES(fi->src->ft.face))
+     {
+        if (FT_HAS_COLOR(fi->src->ft.face) &&
+            fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR)
+          val *= fi->scale_factor;
+     }
+
    return FONT_METRIC_ROUNDUP(val);
 //   printf("%i | %i\n", val, val >> 6);
 //   if (fi->src->ft.face->units_per_EM == 0)
@@ -137,6 +149,14 @@ evas_common_font_instance_descent_get(RGBA_Font_Int *fi)
         fi->src->current_size = fi->size;
      }
    val = -(int)fi->src->ft.face->size->metrics.descender;
+
+   if (FT_HAS_FIXED_SIZES(fi->src->ft.face))
+     {
+        if (FT_HAS_COLOR(fi->src->ft.face) &&
+            fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR)
+          val *= fi->scale_factor;
+     }
+
    return FONT_METRIC_ROUNDUP(val);
 //   if (fi->src->ft.face->units_per_EM == 0)
 //     return val;
@@ -165,6 +185,14 @@ evas_common_font_instance_max_ascent_get(RGBA_Font_Int *fi)
      val = FONT_METRIC_ROUNDUP((int)fi->src->ft.face->size->metrics.ascender);
    else
      val = (int)fi->src->ft.face->bbox.yMax;
+
+   if (FT_HAS_FIXED_SIZES(fi->src->ft.face))
+     {
+        if (FT_HAS_COLOR(fi->src->ft.face) &&
+            fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR)
+          val *= fi->scale_factor;
+     }
+
    if (fi->src->ft.face->units_per_EM == 0)
      return val;
    dv = (fi->src->ft.orig_upem * 2048) / fi->src->ft.face->units_per_EM;
@@ -192,6 +220,14 @@ evas_common_font_instance_max_descent_get(RGBA_Font_Int *fi)
      val = FONT_METRIC_ROUNDUP(-(int)fi->src->ft.face->size->metrics.descender);
    else
      val = -(int)fi->src->ft.face->bbox.yMin;
+
+   if (FT_HAS_FIXED_SIZES(fi->src->ft.face))
+     {
+        if (FT_HAS_COLOR(fi->src->ft.face) &&
+            fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR)
+          val *= fi->scale_factor;
+     }
+
    if (fi->src->ft.face->units_per_EM == 0)
      return val;
    dv = (fi->src->ft.orig_upem * 2048) / fi->src->ft.face->units_per_EM;
@@ -244,6 +280,14 @@ evas_common_font_get_line_advance(RGBA_Font *fn)
         fi->src->current_size = fi->size;
      }
    val = (int)fi->src->ft.face->size->metrics.height;
+
+   if (FT_HAS_FIXED_SIZES(fi->src->ft.face))
+     {
+        if ((fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR) &&
+            FT_HAS_COLOR(fi->src->ft.face))
+          val *= fi->scale_factor;
+     }
+
    if ((fi->src->ft.face->bbox.yMax == 0) &&
        (fi->src->ft.face->bbox.yMin == 0) &&
        (fi->src->ft.face->units_per_EM == 0))
@@ -558,6 +602,19 @@ evas_common_font_int_cache_glyph_get(RGBA_Font_Int *fi, FT_UInt idx)
         fg->width = EVAS_FONT_ROUND_26_6_TO_INT(outbox.xMax - outbox.xMin);
         fg->x_bear = EVAS_FONT_ROUND_26_6_TO_INT(outbox.xMin);
         fg->y_bear = EVAS_FONT_ROUND_26_6_TO_INT(outbox.yMax);
+
+        if (FT_HAS_FIXED_SIZES(fi->src->ft.face))
+          {
+             if (FT_HAS_COLOR(fi->src->ft.face) &&
+                 fi->bitmap_scalable & EFL_TEXT_FONT_BITMAP_SCALABLE_COLOR)
+               {
+                  fg->glyph->advance.x *= fi->scale_factor;
+                  fg->glyph->advance.y *= fi->scale_factor;
+                  fg->width *= fi->scale_factor;
+                  fg->x_bear *= fi->scale_factor;
+                  fg->y_bear *= fi->scale_factor;
+               }
+          }
      }
 
    fg->index = idx;
@@ -625,7 +682,7 @@ evas_common_font_int_cache_glyph_render(RGBA_Font_Glyph *fg)
    fg->glyph_out->bitmap.pitch = fbg->bitmap.pitch;
    fg->glyph_out->bitmap.buffer = fbg->bitmap.buffer;
    fg->glyph_out->bitmap.rle_alloc = EINA_TRUE;
-   
+
    /* This '+ 100' is just an estimation of how much memory freetype will use
     * on it's size. This value is not really used anywhere in code - it's
     * only for statistics. */
@@ -653,7 +710,7 @@ evas_common_font_int_cache_glyph_render(RGBA_Font_Glyph *fg)
         fg->glyph_out->rle = NULL;
         fg->glyph_out->bitmap.rle_alloc = EINA_FALSE;
      }
-   
+
    return EINA_TRUE;
 }
 
@@ -749,11 +806,11 @@ evas_common_get_char_index(RGBA_Font_Int* fi, Eina_Unicode gl)
         // codepoints with a guess that bitmap font is playing the old
         // game of putting line drawing chars in specific ranges
         max = sizeof(mapfix) / (sizeof(mapfix[0]) * 2);
-        i = (min + max) / 2;                                          
+        i = (min + max) / 2;
         for (;;)
           {
              unsigned short v;
-             
+
              v = mapfix[i << 1];
              if (gl == v)
                {
@@ -811,7 +868,7 @@ evas_common_font_glyph_search(RGBA_Font *fn, RGBA_Font_Int **fi_ret, Eina_Unicod
         fi = l->data;
 
 #if 0 /* FIXME: charmap user is disabled and use a deprecated data type. */
-/*        
+/*
 	if (fi->src->charmap) // Charmap loaded, FI/FS blank
 	  {
 	     idx = evas_array_hash_search(fi->src->charmap, gl);
