@@ -17,6 +17,7 @@
 //#include "evas_cs.h"
 
 #ifdef HAVE_VALGRIND
+# include <valgrind.h>
 # include <memcheck.h>
 #endif
 
@@ -115,6 +116,10 @@ _evas_common_rgba_image_surface_size(unsigned int w, unsigned int h,
    int siz, block_size = 8;
    Eina_Bool reset_borders = EINA_TRUE;
 
+#ifdef HAVE_VALGRIND
+   if (RUNNING_ON_VALGRIND) evas_image_no_mmap = 1;
+#endif
+
    if (EINA_UNLIKELY(evas_image_no_mmap == -1))
      {
         const char *s = getenv("EVAS_IMAGE_NO_MMAP");
@@ -1067,18 +1072,6 @@ evas_common_image_get_cache(void)
    return evas_cache_image_get(eci);
 }
 
-EAPI RGBA_Image *
-evas_common_load_image_from_file(const char *file, const char *key,
-                                 Evas_Image_Load_Opts *lo, int *error)
-{
-   if (!file)
-     {
-        *error = EVAS_LOAD_ERROR_GENERIC;
-        return NULL;
-     }
-   return (RGBA_Image *) evas_cache_image_request(eci, file, key, lo, error);
-}
-
 EAPI RGBA_Image *
 evas_common_load_image_from_mmap(Eina_File *f, const char *key,
                                  Evas_Image_Load_Opts *lo, int *error)
