@@ -6,6 +6,7 @@
 
 #include "evas_common_private.h"
 #include "evas_private.h"
+#include "../../static_libs/buildsystem/buildsystem.h"
 
 
 #ifndef EVAS_MODULE_NO_ENGINES
@@ -147,7 +148,6 @@ evas_module_paths_init(void)
      evas_module_paths = _evas_module_append(evas_module_paths, path);
 
    /* 2. PREFIX/lib/evas/modules/ */
-#ifndef _MSC_VER
    path = PACKAGE_LIB_DIR "/evas/modules";
    if (!eina_list_search_unsorted(evas_module_paths, (Eina_Compare_Cb) strcmp, path))
      {
@@ -155,7 +155,6 @@ evas_module_paths_init(void)
         if (path)
           evas_module_paths = _evas_module_append(evas_module_paths, path);
      }
-#endif
 }
 
 #define EVAS_EINA_STATIC_MODULE_DEFINE(Tn, Name) \
@@ -167,17 +166,20 @@ evas_module_paths_init(void)
 
 #if !EVAS_MODULE_NO_ENGINES
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, buffer);
+EVAS_EINA_STATIC_MODULE_DEFINE(engine, drm);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, fb);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, gl_generic);
+EVAS_EINA_STATIC_MODULE_DEFINE(engine, gl_drm);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, gl_x11);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, gl_sdl);
-EVAS_EINA_STATIC_MODULE_DEFINE(engine, psl1ght);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, software_8);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, software_8_x11);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, software_ddraw);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, software_gdi);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, software_generic);
 EVAS_EINA_STATIC_MODULE_DEFINE(engine, software_x11);
+EVAS_EINA_STATIC_MODULE_DEFINE(engine, wayland_shm);
+EVAS_EINA_STATIC_MODULE_DEFINE(engine, wayland_egl);
 #endif
 
 #if !EVAS_MODULE_NO_VG_LOADERS
@@ -208,6 +210,7 @@ EVAS_EINA_STATIC_MODULE_DEFINE(image_loader, tgv);
 
 #if !EVAS_MODULE_NO_VG_SAVERS
 EVAS_EINA_STATIC_MODULE_DEFINE(vg_saver, eet);
+EVAS_EINA_STATIC_MODULE_DEFINE(vg_saver, svg);
 #endif
 
 #if !EVAS_MODULE_NO_IMAGE_SAVERS
@@ -227,21 +230,24 @@ static const struct {
 #ifdef EVAS_STATIC_BUILD_BUFFER
   EVAS_EINA_STATIC_MODULE_USE(engine, buffer),
 #endif
+#ifdef EVAS_STATIC_BUILD_DRM
+  EVAS_EINA_STATIC_MODULE_USE(engine, drm),
+#endif
 #ifdef EVAS_STATIC_BUILD_FB
   EVAS_EINA_STATIC_MODULE_USE(engine, fb),
 #endif
 #ifdef EVAS_STATIC_BUILD_GL_COMMON
   EVAS_EINA_STATIC_MODULE_USE(engine, gl_generic),
 #endif
+#ifdef EVAS_STATIC_BUILD_GL_DRM
+  EVAS_EINA_STATIC_MODULE_USE(engine, gl_drm),
+#endif
 #ifdef EVAS_STATIC_BUILD_GL_X11
   EVAS_EINA_STATIC_MODULE_USE(engine, gl_x11),
 #endif
 #ifdef EVAS_STATIC_BUILD_GL_SDL
   EVAS_EINA_STATIC_MODULE_USE(engine, gl_sdl),
 #endif
-#ifdef EVAS_STATIC_BUILD_PSL1GHT
-  EVAS_EINA_STATIC_MODULE_USE(engine, psl1ght),
-#endif
 #ifdef EVAS_STATIC_BUILD_SOFTWARE_DDRAW
   EVAS_EINA_STATIC_MODULE_USE(engine, software_ddraw),
 #endif
@@ -254,6 +260,12 @@ static const struct {
 #ifdef EVAS_STATIC_BUILD_SOFTWARE_X11
   EVAS_EINA_STATIC_MODULE_USE(engine, software_x11),
 #endif
+#ifdef EVAS_STATIC_BUILD_WAYLAND_EGL
+  EVAS_EINA_STATIC_MODULE_USE(engine, wayland_egl),
+#endif
+#ifdef EVAS_STATIC_BUILD_WAYLAND_SHM
+  EVAS_EINA_STATIC_MODULE_USE(engine, wayland_shm),
+#endif
 #endif
 #if !EVAS_MODULE_NO_VG_LOADERS
 #ifdef EVAS_STATIC_BUILD_VG_SVG
@@ -323,6 +335,9 @@ static const struct {
 #ifdef EVAS_STATIC_BUILD_VG_EET
   EVAS_EINA_STATIC_MODULE_USE(vg_saver, eet),
 #endif
+#ifdef EVAS_STATIC_BUILD_VG_SVG
+  EVAS_EINA_STATIC_MODULE_USE(vg_saver, svg),
+#endif
 #endif
 #if !EVAS_MODULE_NO_IMAGE_SAVERS
 #ifdef EVAS_STATIC_BUILD_EET
@@ -438,8 +453,7 @@ evas_module_engine_list(void)
                     {
                        if (run_in_tree)
                          {
-                            snprintf(buf, sizeof(buf), "%s/engines/%s/.libs",
-                                     s, fname);
+                            bs_mod_dir_get(buf, sizeof(buf), "evas/engines", fname);
                             if (!evas_file_path_exists(buf))
                             buf[0] = '\0';
                          }
@@ -568,8 +582,10 @@ evas_module_find_type(Evas_Module_Type type, const char *name)
           {
              if (run_in_tree)
                {
-                  snprintf(buffer, sizeof(buffer), "%s/%s/%s/.libs/%s",
-                           path, type_str, name, EVAS_MODULE_NAME);
+                  char subsystem[PATH_MAX];
+
+                  snprintf(subsystem, sizeof(subsystem), "evas/%s", type_str);
+                  bs_mod_get(buffer, sizeof(buffer), subsystem, name);
                   if (!evas_file_path_exists(buffer))
                   buffer[0] = '\0';
                }
@@ -645,7 +661,7 @@ evas_module_unload(Evas_Module *em)
    if (!em->definition)
      return;
 
-// for now lets not unload modules - they may still be in use.   
+// for now lets not unload modules - they may still be in use.
 //   em->definition->func.close(em);
 //   em->loaded = 0;
 
@@ -765,7 +781,7 @@ evas_module_shutdown(void)
 }
 
 EAPI int
-_evas_module_engine_inherit(Evas_Func *funcs, char *name)
+_evas_module_engine_inherit(Evas_Func *funcs, char *name, size_t info)
 {
    Evas_Module *em;
 
@@ -778,6 +794,7 @@ _evas_module_engine_inherit(Evas_Func *funcs, char *name)
              evas_module_ref(em);
              evas_module_use(em);
              *funcs = *((Evas_Func *)(em->functions));
+             funcs->info_size = info;
              return 1;
           }
      }
@@ -790,7 +807,7 @@ _evas_module_libdir_get(void)
    if (!pfx) pfx = eina_prefix_new
       (NULL, _evas_module_libdir_get, "EVAS", "evas", "checkme",
        PACKAGE_BIN_DIR, PACKAGE_LIB_DIR, PACKAGE_DATA_DIR, PACKAGE_DATA_DIR);
-   if (!pfx) return NULL;
+   if (!pfx) return "";
    return eina_prefix_lib_get(pfx);
 }
 
