@@ -116,13 +116,13 @@ static void
 _filter_buffer_backing_free(Evas_Filter_Buffer *fb)
 {
    if (!fb || !fb->buffer) return;
-   efl_del(fb->buffer);
+   efl_unref(fb->buffer);
    fb->buffer = NULL;
 }
 
 /** @hidden private render proxy objects */
 void
-evas_filter_context_proxy_render_all(Evas_Filter_Context *ctx, Eo *eo_obj,
+evas_filter_context_proxy_render_all(Evas_Filter_Context *ctx, Eo *eo_obj, void *output,
                                      Eina_Bool do_async)
 {
    Evas_Object_Protected_Data *source;
@@ -152,7 +152,7 @@ evas_filter_context_proxy_render_all(Evas_Filter_Context *ctx, Eo *eo_obj,
                XDBG("Source needs to be rendered: '%s' of type '%s' (%s)",
                    fb->source_name, efl_class_name_get(efl_class_get(fb->source)),
                    source->proxy->redraw ? "redraw" : "no surface");
-               evas_render_proxy_subrender(ctx->evas->evas, fb->source, eo_obj, obj, EINA_FALSE, do_async);
+               evas_render_proxy_subrender(ctx->evas->evas, output, fb->source, eo_obj, obj, EINA_FALSE, do_async);
             }
           if (fb->buffer)
             {
@@ -173,7 +173,7 @@ evas_filter_context_proxy_render_all(Evas_Filter_Context *ctx, Eo *eo_obj,
 }
 
 void
-_evas_filter_context_program_reuse(Evas_Filter_Context *ctx)
+_evas_filter_context_program_reuse(void *engine, void *output, Evas_Filter_Context *ctx)
 {
    Evas_Filter_Buffer *fb;
    Eina_List *li;
@@ -193,11 +193,11 @@ _evas_filter_context_program_reuse(Evas_Filter_Context *ctx)
         surface = evas_ector_buffer_render_image_get(fb->buffer);
         if (!surface) continue;
 
-        dc = ENFN->context_new(ENC);
-        ENFN->context_color_set(ENC, dc, 0, 0, 0, 0);
-        ENFN->context_render_op_set(ENC, dc, EVAS_RENDER_COPY);
-        ENFN->rectangle_draw(ENC, ENDT, dc, surface, 0, 0, fb->w, fb->h, ctx->async);
-        ENFN->context_free(ENC, dc);
+        dc = ENFN->context_new(engine);
+        ENFN->context_color_set(engine, dc, 0, 0, 0, 0);
+        ENFN->context_render_op_set(engine, dc, EVAS_RENDER_COPY);
+        ENFN->rectangle_draw(engine, output, dc, surface, 0, 0, fb->w, fb->h, ctx->async);
+        ENFN->context_free(engine, dc);
         fb->dirty = EINA_FALSE;
 
         evas_ector_buffer_engine_image_release(fb->buffer, surface);
@@ -715,10 +715,10 @@ evas_filter_command_fill_add(Evas_Filter_Context *ctx, void *draw_context,
    cmd = _command_new(ctx, EVAS_FILTER_MODE_FILL, buf, NULL, buf);
    if (!cmd) return NULL;
 
-   ENFN->context_color_get(ENDT, draw_context, &R, &G, &B, &A);
+   ENFN->context_color_get(ENC, draw_context, &R, &G, &B, &A);
    DRAW_COLOR_SET(R, G, B, A);
 
-   ENFN->context_clip_get(ENDT, draw_context, &cx, &cy, &cw, &ch);
+   ENFN->context_clip_get(ENC, draw_context, &cx, &cy, &cw, &ch);
    DRAW_CLIP_SET(cx, cy, cw, ch);
 
    XDBG("Add fill %d with color(%d,%d,%d,%d)", buf->id, R, G, B, A);
@@ -734,7 +734,7 @@ evas_filter_command_blur_add_gl(Evas_Filter_Context *ctx,
                                 Evas_Filter_Buffer *in, Evas_Filter_Buffer *out,
                                 Evas_Filter_Blur_Type type,
                                 int rx, int ry, int ox, int oy, int count,
-                                int R, int G, int B, int A)
+                                int R, int G, int B, int A, Eina_Bool alphaonly)
 {
    Evas_Filter_Command *cmd = NULL;
    Evas_Filter_Buffer *dx_in, *dx_out, *dy_in, *dy_out, *tmp = NULL;
@@ -798,6 +798,7 @@ evas_filter_command_blur_add_gl(Evas_Filter_Context *ctx,
              cmd->draw.scale.pad_y = pad_y;
              cmd->draw.scale.factor_x = down_x;
              cmd->draw.scale.factor_y = down_y;
+             cmd->draw.alphaonly = alphaonly;
              dx_in = tmp;
 
              tmp = evas_filter_temporary_buffer_get(ctx, ww, hh, in->alpha_only, EINA_TRUE);
@@ -827,6 +828,7 @@ evas_filter_command_blur_add_gl(Evas_Filter_Context *ctx,
         cmd->blur.type = type;
         cmd->blur.dx = dx;
         cmd->blur.count = count;
+        cmd->draw.alphaonly = alphaonly;
      }
 
    if (dy)
@@ -837,6 +839,7 @@ evas_filter_command_blur_add_gl(Evas_Filter_Context *ctx,
         cmd->blur.type = type;
         cmd->blur.dy = dy;
         cmd->blur.count = count;
+        cmd->draw.alphaonly = alphaonly;
      }
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(cmd, NULL);
@@ -852,6 +855,7 @@ evas_filter_command_blur_add_gl(Evas_Filter_Context *ctx,
         cmd->draw.scale.pad_y = pad_y;
         cmd->draw.scale.factor_x = down_x;
         cmd->draw.scale.factor_y = down_y;
+        cmd->draw.alphaonly = alphaonly;
      }
 
    cmd->draw.ox = ox;
@@ -886,7 +890,8 @@ _blur_support_gl(Evas_Filter_Context *ctx, Evas_Filter_Buffer *in, Evas_Filter_B
 Evas_Filter_Command *
 evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
                              int inbuf, int outbuf, Evas_Filter_Blur_Type type,
-                             int dx, int dy, int ox, int oy, int count)
+                             int dx, int dy, int ox, int oy, int count,
+                             Eina_Bool alphaonly)
 {
    Evas_Filter_Buffer *in = NULL, *out = NULL, *tmp = NULL, *in_dy = NULL;
    Evas_Filter_Buffer *out_dy = NULL, *out_dx = NULL;
@@ -904,7 +909,7 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
    if (!dx && !dy)
      {
         XDBG("Changing 0px blur into simple blend");
-        return evas_filter_command_blend_add(ctx, drawctx, inbuf, outbuf, ox, oy, EVAS_FILTER_FILL_MODE_NONE);
+        return evas_filter_command_blend_add(ctx, drawctx, inbuf, outbuf, ox, oy, EVAS_FILTER_FILL_MODE_NONE, alphaonly);
      }
 
    in = _filter_buffer_get(ctx, inbuf);
@@ -913,7 +918,7 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
    out = _filter_buffer_get(ctx, outbuf);
    EINA_SAFETY_ON_FALSE_GOTO(out, fail);
 
-   ENFN->context_color_get(ENDT, drawctx, &R, &G, &B, &A);
+   ENFN->context_color_get(ENC, drawctx, &R, &G, &B, &A);
    color = ARGB_JOIN(A, R, G, B);
    if (!color)
      {
@@ -922,7 +927,8 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
      }
 
    if (_blur_support_gl(ctx, in, out))
-     return evas_filter_command_blur_add_gl(ctx, in, out, type, dx, dy, ox, oy, count, R, G, B, A);
+     return evas_filter_command_blur_add_gl(ctx, in, out, type, dx, dy, ox, oy,
+                                            count, R, G, B, A, alphaonly);
 
    // Note (SW engine):
    // The basic blur operation overrides the pixels in the target buffer,
@@ -931,7 +937,7 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
 
    if (in == out) out->dirty = EINA_FALSE;
 
-   render_op = ENFN->context_render_op_get(ENDT, drawctx);
+   render_op = ENFN->context_render_op_get(ENC, drawctx);
    override = (render_op == EVAS_RENDER_COPY);
 
    switch (type)
@@ -977,12 +983,13 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
                 else
                   type = EVAS_FILTER_BLUR_BOX;
 
-                if (dy) ENFN->context_color_set(ENDT, drawctx, 255, 255, 255, 255);
+                if (dy) ENFN->context_color_set(ENC, drawctx, 255, 255, 255, 255);
                 cmd = evas_filter_command_blur_add(ctx, drawctx, inbuf, tmp_out,
-                                                   type, dx, 0, tmp_ox, tmp_oy, 0);
+                                                   type, dx, 0, tmp_ox, tmp_oy, 0,
+                                                   alphaonly);
                 if (!cmd) goto fail;
                 cmd->blur.auto_count = EINA_TRUE;
-                if (dy) ENFN->context_color_set(ENDT, drawctx, R, G, B, A);
+                if (dy) ENFN->context_color_set(ENC, drawctx, R, G, B, A);
              }
 
            // Y box blur
@@ -994,11 +1001,12 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
                   type = EVAS_FILTER_BLUR_BOX;
 
                 if (dx && (inbuf == outbuf))
-                  ENFN->context_render_op_set(ENDT, drawctx, EVAS_RENDER_COPY);
+                  ENFN->context_render_op_set(ENC, drawctx, EVAS_RENDER_COPY);
                 cmd = evas_filter_command_blur_add(ctx, drawctx, tmp_in, outbuf,
-                                                   type, 0, dy, ox, oy, 0);
+                                                   type, 0, dy, ox, oy, 0,
+                                                   alphaonly);
                 if (dx && (inbuf == outbuf))
-                  ENFN->context_render_op_set(ENDT, drawctx, render_op);
+                  ENFN->context_render_op_set(ENC, drawctx, render_op);
                 if (!cmd) goto fail;
                 cmd->blur.auto_count = EINA_TRUE;
              }
@@ -1145,7 +1153,8 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
         XDBG("Add extra blend %d -> %d", blendbuf->id, out->id);
         blendcmd = evas_filter_command_blend_add(ctx, drawctx,
                                                  blendbuf->id, out->id, ox, oy,
-                                                 EVAS_FILTER_FILL_MODE_NONE);
+                                                 EVAS_FILTER_FILL_MODE_NONE,
+                                                 alphaonly);
         if (!blendcmd) goto fail;
         ox = oy = 0;
      }
@@ -1154,13 +1163,14 @@ evas_filter_command_blur_add(Evas_Filter_Context *ctx, void *drawctx,
         Evas_Filter_Command *copycmd;
 
         XDBG("Add extra copy %d -> %d: offset: %d,%d", copybuf->id, out->id, ox, oy);
-        ENFN->context_color_set(ENDT, drawctx, 255, 255, 255, 255);
-        ENFN->context_render_op_set(ENDT, drawctx, EVAS_RENDER_COPY);
+        ENFN->context_color_set(ENC, drawctx, 255, 255, 255, 255);
+        ENFN->context_render_op_set(ENC, drawctx, EVAS_RENDER_COPY);
         copycmd = evas_filter_command_blend_add(ctx, drawctx,
                                                 copybuf->id, out->id, ox, oy,
-                                                EVAS_FILTER_FILL_MODE_NONE);
-        ENFN->context_color_set(ENDT, drawctx, R, G, B, A);
-        ENFN->context_render_op_set(ENDT, drawctx, render_op);
+                                                EVAS_FILTER_FILL_MODE_NONE,
+                                                alphaonly);
+        ENFN->context_color_set(ENC, drawctx, R, G, B, A);
+        ENFN->context_render_op_set(ENC, drawctx, render_op);
         if (!copycmd) goto fail;
         ox = oy = 0;
      }
@@ -1178,7 +1188,8 @@ fail:
 Evas_Filter_Command *
 evas_filter_command_blend_add(Evas_Filter_Context *ctx, void *drawctx,
                               int inbuf, int outbuf, int ox, int oy,
-                              Evas_Filter_Fill_Mode fillmode)
+                              Evas_Filter_Fill_Mode fillmode,
+                              Eina_Bool alphaonly)
 {
    Evas_Filter_Command *cmd;
    Evas_Filter_Buffer *in, *out;
@@ -1210,21 +1221,22 @@ evas_filter_command_blend_add(Evas_Filter_Context *ctx, void *drawctx,
    cmd = _command_new(ctx, EVAS_FILTER_MODE_BLEND, in, NULL, out);
    if (!cmd) return NULL;
 
-   if (ENFN->context_render_op_get(ENDT, drawctx) == EVAS_RENDER_COPY)
+   if (ENFN->context_render_op_get(ENC, drawctx) == EVAS_RENDER_COPY)
      copy = EINA_TRUE;
    else
      copy = EINA_FALSE;
 
-   ENFN->context_color_get(ENDT, drawctx, &R, &G, &B, &A);
+   ENFN->context_color_get(ENC, drawctx, &R, &G, &B, &A);
    DRAW_COLOR_SET(R, G, B, A);
    DRAW_FILL_SET(fillmode);
    cmd->draw.ox = ox;
    cmd->draw.oy = oy;
    cmd->draw.rop = copy ? EFL_GFX_RENDER_OP_COPY : EFL_GFX_RENDER_OP_BLEND;
+   cmd->draw.alphaonly = alphaonly;
    cmd->draw.clip_use =
-         ENFN->context_clip_get(ENDT, drawctx,
-                                &cmd->draw.clip.x, &cmd->draw.clip.y,
-                                &cmd->draw.clip.w, &cmd->draw.clip.h);
+         !!ENFN->context_clip_get(ENC, drawctx,
+                                  &cmd->draw.clip.x, &cmd->draw.clip.y,
+                                  &cmd->draw.clip.w, &cmd->draw.clip.h);
 
    XDBG("Add %s %d -> %d: offset %d,%d, color: %d,%d,%d,%d",
         copy ? "copy" : "blend", in->id, out->id, ox, oy, R, G, B, A);
@@ -1238,7 +1250,8 @@ evas_filter_command_blend_add(Evas_Filter_Context *ctx, void *drawctx,
 
 Evas_Filter_Command *
 evas_filter_command_grow_add(Evas_Filter_Context *ctx, void *draw_context,
-                             int inbuf, int outbuf, int radius, Eina_Bool smooth)
+                             int inbuf, int outbuf, int radius, Eina_Bool smooth,
+                             Eina_Bool alphaonly)
 {
    Evas_Filter_Command *blurcmd, *threshcmd, *blendcmd;
    Evas_Filter_Buffer *tmp = NULL, *in, *out;
@@ -1251,7 +1264,8 @@ evas_filter_command_grow_add(Evas_Filter_Context *ctx, void *draw_context,
    if (!radius)
      {
         XDBG("Changing 0px grow into simple blend");
-        return evas_filter_command_blend_add(ctx, draw_context, inbuf, outbuf, 0, 0, EVAS_FILTER_FILL_MODE_NONE);
+        return evas_filter_command_blend_add(ctx, draw_context, inbuf, outbuf, 0, 0,
+                                             EVAS_FILTER_FILL_MODE_NONE, alphaonly);
      }
 
    in = _filter_buffer_get(ctx, inbuf);
@@ -1271,7 +1285,8 @@ evas_filter_command_grow_add(Evas_Filter_Context *ctx, void *draw_context,
 
    blurcmd = evas_filter_command_blur_add(ctx, draw_context, inbuf, growbuf,
                                           EVAS_FILTER_BLUR_DEFAULT,
-                                          abs(radius), abs(radius), 0, 0, 0);
+                                          abs(radius), abs(radius), 0, 0, 0,
+                                          alphaonly);
    if (!blurcmd) return NULL;
 
    if (diam > 255) diam = 255;
@@ -1309,7 +1324,8 @@ evas_filter_command_grow_add(Evas_Filter_Context *ctx, void *draw_context,
      {
         blendcmd = evas_filter_command_blend_add(ctx, draw_context, tmp->id,
                                                  outbuf, 0, 0,
-                                                 EVAS_FILTER_FILL_MODE_NONE);
+                                                 EVAS_FILTER_FILL_MODE_NONE,
+                                                 alphaonly);
         if (!blendcmd)
           {
              _command_del(ctx, threshcmd);
@@ -1375,6 +1391,7 @@ evas_filter_command_displacement_map_add(Evas_Filter_Context *ctx,
 {
    Evas_Filter_Buffer *in, *out, *map, *tmp = NULL, *disp_out;
    Evas_Filter_Command *cmd = NULL;
+   Eina_Bool alphaonly = EINA_FALSE;
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(ctx, NULL);
    EINA_SAFETY_ON_FALSE_RETURN_VAL(intensity >= 0, NULL);
@@ -1409,7 +1426,7 @@ evas_filter_command_displacement_map_add(Evas_Filter_Context *ctx,
    DRAW_FILL_SET(fillmode);
    cmd->displacement.flags = flags & EVAS_FILTER_DISPLACE_BITMASK;
    cmd->displacement.intensity = intensity;
-   cmd->draw.rop = _evas_to_gfx_render_op(ENFN->context_render_op_get(ENDT, draw_context));
+   cmd->draw.rop = _evas_to_gfx_render_op(ENFN->context_render_op_get(ENC, draw_context));
 
    if (tmp)
      {
@@ -1417,7 +1434,8 @@ evas_filter_command_displacement_map_add(Evas_Filter_Context *ctx,
 
         fillcmd = evas_filter_command_blend_add(ctx, draw_context, disp_out->id,
                                                 out->id, 0, 0,
-                                                EVAS_FILTER_FILL_MODE_NONE);
+                                                EVAS_FILTER_FILL_MODE_NONE,
+                                                alphaonly);
         if (!fillcmd) goto fail;
      }
 
@@ -1442,8 +1460,8 @@ evas_filter_command_mask_add(Evas_Filter_Context *ctx, void *draw_context,
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(ctx, NULL);
 
-   render_op = _evas_to_gfx_render_op(ENFN->context_render_op_get(ENDT, draw_context));
-   ENFN->context_color_get(ENDT, draw_context, &R, &G, &B, &A);
+   render_op = _evas_to_gfx_render_op(ENFN->context_render_op_get(ENC, draw_context));
+   ENFN->context_color_get(ENC, draw_context, &R, &G, &B, &A);
 
    in = _filter_buffer_get(ctx, inbuf);
    out = _filter_buffer_get(ctx, outbuf);
@@ -1566,15 +1584,15 @@ evas_filter_target_set(Evas_Filter_Context *ctx, void *draw_context,
    ctx->target.x = x;
    ctx->target.y = y;
    ctx->target.clip_use = ENFN->context_clip_get
-         (ENDT, draw_context, &ctx->target.cx, &ctx->target.cy,
+         (ENC, draw_context, &ctx->target.cx, &ctx->target.cy,
           &ctx->target.cw, &ctx->target.ch);
    ctx->target.color_use = ENFN->context_multiplier_get
-         (ENDT, draw_context, &ctx->target.r, &ctx->target.g,
+         (ENC, draw_context, &ctx->target.r, &ctx->target.g,
           &ctx->target.b, &ctx->target.a);
    if (ctx->target.r == 255 && ctx->target.g == 255 &&
        ctx->target.b == 255 && ctx->target.a == 255)
      ctx->target.color_use = EINA_FALSE;
-   ctx->target.rop = ENFN->context_render_op_get(ENDT, draw_context);
+   ctx->target.rop = ENFN->context_render_op_get(ENC, draw_context);
 
    _free(ctx->target.map);
    if (!map) ctx->target.map = NULL;
@@ -1586,7 +1604,7 @@ evas_filter_target_set(Evas_Filter_Context *ctx, void *draw_context,
      }
 
    ENFN->context_clip_image_get
-      (ENDT, draw_context, &mask, &ctx->target.mask_x, &ctx->target.mask_y);
+      (ENC, draw_context, &mask, &ctx->target.mask_x, &ctx->target.mask_y);
    if (ctx->target.mask)
      ctx->evas->engine.func->image_free(_evas_engine_context(ctx->evas), ctx->target.mask);
    ctx->target.mask = mask; // FIXME: why no ref???
@@ -1595,14 +1613,14 @@ evas_filter_target_set(Evas_Filter_Context *ctx, void *draw_context,
 }
 
 static Eina_Bool
-_filter_target_render(Evas_Filter_Context *ctx)
+_filter_target_render(void *engine, void *output, Evas_Filter_Context *ctx)
 {
    Evas_Filter_Buffer *src;
    void *drawctx, *image = NULL, *surface;
 
    EINA_SAFETY_ON_NULL_RETURN_VAL(ctx->target.surface, EINA_FALSE);
 
-   drawctx = ENFN->context_new(ENC);
+   drawctx = ENFN->context_new(engine);
    surface = ctx->target.surface;
 
    src = _filter_buffer_get(ctx, EVAS_FILTER_BUFFER_OUTPUT_ID);
@@ -1615,48 +1633,48 @@ _filter_target_render(Evas_Filter_Context *ctx)
 
    if (ctx->target.clip_use)
      {
-        ENFN->context_clip_set(ENC, drawctx, ctx->target.cx, ctx->target.cy,
+        ENFN->context_clip_set(engine, drawctx, ctx->target.cx, ctx->target.cy,
                                ctx->target.cw, ctx->target.ch);
      }
 
    if (ctx->target.color_use)
      {
-        ENFN->context_multiplier_set(ENC, drawctx,
+        ENFN->context_multiplier_set(engine, drawctx,
                                      ctx->target.r, ctx->target.g,
                                      ctx->target.b, ctx->target.a);
      }
 
    if (ctx->target.mask)
      {
-        ENFN->context_clip_image_set(ENC, drawctx, ctx->target.mask,
+        ENFN->context_clip_image_set(engine, drawctx, ctx->target.mask,
                                      ctx->target.mask_x, ctx->target.mask_y,
                                      ctx->evas, EINA_FALSE);
      }
 
-   ENFN->context_render_op_set(ENC, drawctx, ctx->target.rop);
+   ENFN->context_render_op_set(engine, drawctx, ctx->target.rop);
    if (ctx->target.map)
      {
-        ENFN->image_map_draw(ENC, ENDT, drawctx, surface, image,
+        ENFN->image_map_draw(engine, output, drawctx, surface, image,
                              ctx->target.map, EINA_TRUE, 0, EINA_FALSE);
      }
    else
      {
-        ENFN->image_draw(ENC, ENDT, drawctx, surface, image,
+        ENFN->image_draw(engine, output, drawctx, surface, image,
                          0, 0, src->w, src->h,
                          ctx->target.x, ctx->target.y, src->w, src->h,
                          EINA_TRUE, EINA_FALSE);
      }
 
-   ENFN->context_free(ENC, drawctx);
+   ENFN->context_free(engine, drawctx);
    evas_ector_buffer_engine_image_release(src->buffer, image);
 
-   ENFN->image_free(ENC, surface);
+   ENFN->image_free(engine, surface);
    ctx->target.surface = NULL;
 
    return EINA_TRUE;
 
 fail:
-   ENFN->image_free(ENC, surface);
+   ENFN->image_free(engine, surface);
    ctx->target.surface = NULL;
 
    ERR("Failed to render filter to target canvas!");
@@ -1814,7 +1832,7 @@ _filter_command_run(Evas_Filter_Command *cmd)
 }
 
 static Eina_Bool
-_filter_chain_run(Evas_Filter_Context *ctx)
+_filter_chain_run(void *engine, void *output, Evas_Filter_Context *ctx)
 {
    Evas_Filter_Command *cmd;
    Eina_Bool ok = EINA_FALSE;
@@ -1831,7 +1849,7 @@ _filter_chain_run(Evas_Filter_Context *ctx)
           }
      }
 
-   ok = _filter_target_render(ctx);
+   ok = _filter_target_render(engine, output, ctx);
 
 end:
    ctx->running = EINA_FALSE;
@@ -1841,10 +1859,21 @@ end:
    return ok;
 }
 
+typedef struct _Filter_Thread_Data Filter_Thread_Data;
+struct _Filter_Thread_Data
+{
+   void *engine;
+   void *output;
+   Evas_Filter_Context *ctx;
+};
+
 static void
 _filter_thread_run_cb(void *data)
 {
-   _filter_chain_run(data);
+   Filter_Thread_Data *ftd = data;
+
+   _filter_chain_run(ftd->engine, ftd->output, ftd->ctx);
+   _free(ftd);
 }
 
 static void
@@ -1897,7 +1926,7 @@ _filter_obscured_region_calc(Evas_Filter_Context *ctx)
 }
 
 Eina_Bool
-evas_filter_context_run(Evas_Filter_Context *ctx)
+evas_filter_context_run(void *engine, void *output, Evas_Filter_Context *ctx)
 {
    evas_filter_context_ref(ctx);
    _filter_obscured_region_calc(ctx);
@@ -1906,11 +1935,18 @@ evas_filter_context_run(Evas_Filter_Context *ctx)
    ctx->running = EINA_TRUE;
    if (ctx->async)
      {
-        evas_thread_queue_flush(_filter_thread_run_cb, ctx);
+        Filter_Thread_Data *ftd;
+
+        ftd = calloc(1, sizeof(*ftd));
+        ftd->engine = engine;
+        ftd->output = output;
+        ftd->ctx = ctx;
+
+        evas_thread_queue_flush(_filter_thread_run_cb, ftd);
         return EINA_TRUE;
      }
 
-   return _filter_chain_run(ctx);
+   return _filter_chain_run(engine, output, ctx);
 }
 
 
