@@ -14,26 +14,24 @@
 
 #include "../file/evas_module.h"
 #include "../file/evas_path.h"
-#include "../common/evas_text_utils.h"
-#include "../common/language/evas_bidi_utils.h"
-#include "../common/language/evas_language_utils.h"
 
 #include "evas_3d_utils.h"
 
+
 #ifdef EAPI
 # undef EAPI
 #endif
 
 #ifdef _WIN32
-# ifdef EFL_EVAS_BUILD
+# ifdef EFL_BUILD
 #  ifdef DLL_EXPORT
 #   define EAPI __declspec(dllexport)
 #  else
 #   define EAPI
-#  endif /* ! DLL_EXPORT */
+#  endif
 # else
 #  define EAPI __declspec(dllimport)
-# endif /* ! EFL_EVAS_BUILD */
+# endif
 #else
 # ifdef __GNUC__
 #  if __GNUC__ >= 4
@@ -44,13 +42,13 @@
 # else
 #  define EAPI
 # endif
-#endif /* ! _WIN32 */
+#endif
 
 /* save typing */
 #define ENFN obj->layer->evas->engine.func
-#define ENDT _evas_default_output_get(obj->layer->evas)
 #define ENC  _evas_engine_context(obj->layer->evas)
 
+#include "canvas/evas_canvas.eo.h"
 #include "canvas/evas_text.eo.h"
 #include "canvas/evas_textgrid.eo.h"
 #include "canvas/evas_line.eo.h"
@@ -66,10 +64,6 @@ typedef struct _Evas_Aspect                 Evas_Aspect;
 typedef struct _Evas_Border                 Evas_Border;
 typedef struct _Evas_Double_Pair            Evas_Double_Pair;
 typedef struct _Evas_Size_Hints             Evas_Size_Hints;
-typedef struct _Evas_Font_Dir               Evas_Font_Dir;
-typedef struct _Evas_Font                   Evas_Font;
-typedef struct _Evas_Font_Alias             Evas_Font_Alias;
-typedef struct _Evas_Font_Description       Evas_Font_Description;
 typedef struct _Evas_Data_Node              Evas_Data_Node;
 typedef struct _Evas_Func                   Evas_Func;
 typedef struct _Evas_Image_Save_Func        Evas_Image_Save_Func;
@@ -143,6 +137,8 @@ typedef struct _Evas_Canvas3D_Mesh_Eet         Evas_Canvas3D_Mesh_Eet;
 typedef struct _Evas_Canvas3D_Header_Eet       Evas_Canvas3D_Header_Eet;
 typedef struct _Evas_Canvas3D_File_Eet         Evas_Canvas3D_File_Eet;
 
+typedef struct _Vg_File_Data                   Vg_File_Data;
+
 struct _Evas_Canvas3D_Vec2_Eet
 {
    float x;
@@ -434,6 +430,9 @@ struct _Evas_Canvas3D_Texture
    /* Engine-side object. */
    void             *engine_data;
 
+   Eina_File        *f;
+   const char       *key;
+
    /*Use atlases, @EINA_TRUE by default*/
    Eina_Bool        atlas_enable :1;
 };
@@ -500,64 +499,6 @@ struct _Evas_Canvas3D_Pick_Data
    Evas_Real         s, t;
 };
 
-enum _Evas_Font_Style
-{
-   EVAS_FONT_STYLE_SLANT,
-   EVAS_FONT_STYLE_WEIGHT,
-   EVAS_FONT_STYLE_WIDTH
-};
-
-enum _Evas_Font_Slant
-{
-   EVAS_FONT_SLANT_NORMAL,
-   EVAS_FONT_SLANT_OBLIQUE,
-   EVAS_FONT_SLANT_ITALIC
-};
-
-enum _Evas_Font_Weight
-{
-   EVAS_FONT_WEIGHT_NORMAL,
-   EVAS_FONT_WEIGHT_THIN,
-   EVAS_FONT_WEIGHT_ULTRALIGHT,
-   EVAS_FONT_WEIGHT_EXTRALIGHT,
-   EVAS_FONT_WEIGHT_LIGHT,
-   EVAS_FONT_WEIGHT_BOOK,
-   EVAS_FONT_WEIGHT_MEDIUM,
-   EVAS_FONT_WEIGHT_SEMIBOLD,
-   EVAS_FONT_WEIGHT_BOLD,
-   EVAS_FONT_WEIGHT_ULTRABOLD,
-   EVAS_FONT_WEIGHT_EXTRABOLD,
-   EVAS_FONT_WEIGHT_BLACK,
-   EVAS_FONT_WEIGHT_EXTRABLACK
-};
-
-enum _Evas_Font_Width
-{
-   EVAS_FONT_WIDTH_NORMAL,
-   EVAS_FONT_WIDTH_ULTRACONDENSED,
-   EVAS_FONT_WIDTH_EXTRACONDENSED,
-   EVAS_FONT_WIDTH_CONDENSED,
-   EVAS_FONT_WIDTH_SEMICONDENSED,
-   EVAS_FONT_WIDTH_SEMIEXPANDED,
-   EVAS_FONT_WIDTH_EXPANDED,
-   EVAS_FONT_WIDTH_EXTRAEXPANDED,
-   EVAS_FONT_WIDTH_ULTRAEXPANDED
-};
-
-enum _Evas_Font_Spacing
-{
-   EVAS_FONT_SPACING_PROPORTIONAL,
-   EVAS_FONT_SPACING_DUAL,
-   EVAS_FONT_SPACING_MONO,
-   EVAS_FONT_SPACING_CHARCELL
-};
-
-typedef enum _Evas_Font_Style               Evas_Font_Style;
-typedef enum _Evas_Font_Slant               Evas_Font_Slant;
-typedef enum _Evas_Font_Weight              Evas_Font_Weight;
-typedef enum _Evas_Font_Width               Evas_Font_Width;
-typedef enum _Evas_Font_Spacing             Evas_Font_Spacing;
-
 /* General types - used for script type chceking */
 #define OPAQUE_TYPE(type) struct __##type { int a; }; \
    typedef struct __##type type
@@ -627,7 +568,7 @@ MAGIC_CHECK_FAILED(o, t, m)
 #define EVAS_OBJECT_LEGACY_API(_eo, ...) \
    do { Evas_Object_Protected_Data *_o = efl_data_scope_get(_eo, EFL_CANVAS_OBJECT_CLASS); \
       if (EINA_UNLIKELY(!_o)) return __VA_ARGS__; \
-      if (EINA_UNLIKELY(!_o->legacy)) { \
+      if (EINA_UNLIKELY(!_o->legacy.ctor)) { \
          char buf[1024]; snprintf(buf, sizeof(buf), "Calling legacy API on EO object '%s' is not permitted!", efl_class_name_get(_o->object)); \
          EINA_SAFETY_ERROR(buf); \
    } } while (0)
@@ -638,13 +579,6 @@ MAGIC_CHECK_FAILED(o, t, m)
    if (!_e) return __VA_ARGS__
 
 #define EVAS_OBJECT_IMAGE_FREE_FILE_AND_KEY(cur, prev)                  \
-  if (cur->u.file && !cur->mmaped_source)				\
-    {                                                                   \
-       eina_stringshare_del(cur->u.file);				\
-       if (prev->u.file == cur->u.file)					\
-         prev->u.file = NULL;						\
-       cur->u.file = NULL;						\
-    }                                                                   \
   if (cur->key)                                                         \
     {                                                                   \
        eina_stringshare_del(cur->key);                                  \
@@ -652,11 +586,6 @@ MAGIC_CHECK_FAILED(o, t, m)
          prev->key = NULL;                                              \
        cur->key = NULL;                                                 \
     }                                                                   \
-  if (prev->u.file && !prev->mmaped_source)				\
-    {                                                                   \
-       eina_stringshare_del(prev->u.file);				\
-       prev->u.file = NULL;						\
-    }                                                                   \
   if (prev->key)                                                        \
     {                                                                   \
        eina_stringshare_del(prev->key);                                 \
@@ -819,7 +748,7 @@ struct _Evas_Post_Callback
 typedef struct
 {
 #ifdef INLINE_ACTIVE_GEOM
-   Evas_Coord_Rectangle        rect;
+   Eina_Rectangle        rect;
 #endif
    Evas_Object_Protected_Data *obj;
 } Evas_Active_Entry;
@@ -872,7 +801,7 @@ struct _Evas_Public_Data
    struct {
       int            w, h;
       DATA32         render_method;
-      unsigned char  changed : 1;
+      Eina_Bool      legacy : 1;
    } output;
 
    struct
@@ -893,7 +822,6 @@ struct _Evas_Public_Data
 
    int               output_validity;
 
-   int               walking_list;
    Evas_Event_Flags  default_event_flags;
 
    struct {
@@ -902,7 +830,6 @@ struct _Evas_Public_Data
    } engine;
 
    struct {
-      Eina_List *updates;
       Eina_Spinlock lock;
    } render;
 
@@ -919,6 +846,7 @@ struct _Evas_Public_Data
    Eina_Array     image_unref_queue;
    Eina_Array     glyph_unref_queue;
    Eina_Array     texts_unref_queue;
+   Eina_List     *finalize_objects;
 
    struct {
       Evas_Post_Render_Job *jobs;
@@ -932,6 +860,7 @@ struct _Evas_Public_Data
    Eina_List     *post_events; // free me on evas_free
 
    Eina_Inlist    *callbacks;
+   Eina_Inlist    *deferred_callbacks;
 
    int            delete_grabs;
    int            walking_grabs;
@@ -944,6 +873,7 @@ struct _Evas_Public_Data
    int            in_smart_calc;
    int            smart_calc_count;
 
+   Eo            *gesture_manager;
    Eo            *pending_default_focus_obj;
    Eina_Hash     *focused_objects; //Key - seat; value - the focused object
    Eina_List     *focused_by; //Which seat has the canvas focus
@@ -962,6 +892,8 @@ struct _Evas_Public_Data
    Eina_List     *devices;
    Eina_Array    *cur_device;
 
+   void          *backend;
+   Ector_Surface *ector;
    Eina_List     *outputs;
 
    Evas_Device   *default_seat;
@@ -975,7 +907,6 @@ struct _Evas_Public_Data
    Eina_Bool      is_frozen : 1;
    Eina_Bool      rendering : 1;
    Eina_Bool      render2 : 1;
-   Eina_Bool      common_init : 1;
    Eina_Bool      inside_post_render : 1;
    Eina_Bool      devices_modified : 1;
 };
@@ -1004,7 +935,7 @@ struct _Evas_Size
 struct _Evas_Aspect
 {
    Evas_Aspect_Control mode;
-   Evas_Size size;
+   Eina_Size2D size;
 };
 
 struct _Evas_Border
@@ -1019,7 +950,8 @@ struct _Evas_Double_Pair
 
 struct _Evas_Size_Hints
 {
-   Evas_Size min, max, user_min, request;
+   Evas_Size request;
+   Eina_Size2D min, user_min, max;
    Evas_Aspect aspect;
    Evas_Double_Pair align, weight;
    Evas_Border padding;
@@ -1037,7 +969,7 @@ struct _Evas_Map
 {
    DATA32                magic;
    int                   count; // num of points
-   Evas_Coord_Rectangle  normal_geometry; // bounding box of map geom actually
+   Eina_Rectangle        normal_geometry; // bounding box of map geom actually
 //   void                 *surface; // surface holding map if needed
 //   int                   surface_w, surface_h; // current surface w & h alloc
    double                mx, my; // mouse x, y after conversion to map space
@@ -1119,7 +1051,7 @@ struct _Evas_Object_Protected_State
 {
    Evas_Object_Protected_Data *clipper;
 
-   Evas_Coord_Rectangle  geometry;
+   Eina_Rectangle        geometry;
    struct {
       struct {
          Evas_Coord      x, y, w, h;
@@ -1198,6 +1130,8 @@ struct _Evas_Object_Protected_Data
    // Pointer to the Evas_Object itself
    Evas_Object                *object;
 
+   Evas_Object                *anim_player;
+
    Evas_Size_Hints            *size_hints;
 
    int                         last_mouse_down_counter;
@@ -1217,6 +1151,8 @@ struct _Evas_Object_Protected_Data
    unsigned char               no_change_render;
    unsigned char               delete_me;
 
+   Eina_Inlist                *event_anims; //List of Efl_Animation
+
    Eina_Bool                   render_pre : 1;
    Eina_Bool                   rect_del : 1;
 
@@ -1249,8 +1185,6 @@ struct _Evas_Object_Protected_Data
    Eina_Bool                   child_has_map : 1;
    Eina_Bool                   efl_del_called : 1;
    Eina_Bool                   no_render : 1; // since 1.15
-   Eina_Bool                   legacy : 1; // used legacy constructor
-   Eina_Bool                   clean_layer : 1; // destructor option
 
    Eina_Bool                   snapshot_needs_redraw : 1;
    Eina_Bool                   snapshot_no_obscure : 1;
@@ -1258,6 +1192,14 @@ struct _Evas_Object_Protected_Data
    Eina_Bool                   gfx_map_has : 1;
    Eina_Bool                   gfx_map_update : 1;
 
+   struct {
+      Eina_Bool                ctor : 1; // used legacy constructor
+      Eina_Bool                visible_set : 1; // visibility manually set
+      Eina_Bool                weight_set : 1; // weight manually set
+      Eina_Bool                align_set : 1; // align manually set
+      Eina_Bool                finalized : 1; // object fully constructed
+   } legacy;
+
    struct  {
       Eina_Bool                pass_events : 1;
       Eina_Bool                pass_events_valid : 1;
@@ -1268,6 +1210,7 @@ struct _Evas_Object_Protected_Data
    } parent_cache;
 
    Eina_Bool                   events_filter_enabled : 1;
+   Eina_Bool                   is_pointer_inside_legacy : 1;
 };
 
 struct _Evas_Data_Node
@@ -1276,60 +1219,23 @@ struct _Evas_Data_Node
    void *data;
 };
 
-struct _Evas_Font_Dir
-{
-   Eina_Hash *lookup;
-   Eina_List *fonts;
-   Eina_List *aliases;
-   DATA64     dir_mod_time;
-   DATA64     fonts_dir_mod_time;
-   DATA64     fonts_alias_mod_time;
-};
-
-struct _Evas_Font
-{
-   struct {
-      const char *prop[14];
-   } x;
-   struct {
-      const char *name;
-   } simple;
-   const char *path;
-   char     type;
-};
-
-struct _Evas_Font_Alias
-{
-   const char *alias;
-   Evas_Font  *fn;
-};
-
-struct _Evas_Font_Description
-{
-   int ref;
-   Eina_Stringshare *name;
-   Eina_Stringshare *fallbacks;
-   Eina_Stringshare *lang;
-   Eina_Stringshare *style;
-
-   Evas_Font_Slant slant;
-   Evas_Font_Weight weight;
-   Evas_Font_Width width;
-   Evas_Font_Spacing spacing;
-
-   Eina_Bool is_new : 1;
-};
-
 struct _Efl_Canvas_Output
 {
    Eo *canvas;
 
-   Ector_Surface *ector;
+   Evas_Engine_Info *info;
+   void *output;
 
-   void *info, *output;
-   Evas_Coord x, y, w, h;
+   Eina_List *planes;
+   Eina_List *updates;
+
+   Eina_Rectangle geometry;
 
    int info_magic;
+
+   unsigned short lock;
+
+   Eina_Bool changed : 1;
 };
 
 struct _Evas_Object_Func
@@ -1361,8 +1267,6 @@ struct _Evas_Object_Func
 
    void (*coords_recalc) (Evas_Object *obj, Evas_Object_Protected_Data *pd, void *type_private_data);
 
-   void (*scale_update) (Evas_Object *obj, Evas_Object_Protected_Data *pd, void *type_private_data);
-
    int (*has_opaque_rect) (Evas_Object *obj, Evas_Object_Protected_Data *pd, void *type_private_data);
    int (*get_opaque_rect) (Evas_Object *obj, Evas_Object_Protected_Data *pd, void *type_private_data,
                            Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
@@ -1385,16 +1289,19 @@ struct _Evas_Object_Func
 
 struct _Evas_Func
 {
-   void *(*info)                           (Evas *e);
-   void (*info_free)                       (Evas *e, void *info);
-   void *(*setup)                          (void *engine, void *info, unsigned int w, unsigned int h);
-   int  (*update)                          (void *engine, void *data, void *info, unsigned int w, unsigned int h);
+   void *(*engine_new)                     (void);
+   void (*engine_free)                     (void *engine);
 
+   void (*output_info_setup)               (void *info);
+   void *(*output_setup)                   (void *engine, void *info, unsigned int w, unsigned int h);
+   int  (*output_update)                   (void *engine, void *data, void *info, unsigned int w, unsigned int h);
    void (*output_free)                     (void *engine, void *data);
    void (*output_resize)                   (void *engine, void *data, int w, int h);
-   void (*output_tile_size_set)            (void *engine, void *data, int w, int h);
-   void (*output_redraws_rect_add)         (void *engine, void *data, int x, int y, int w, int h);
-   void (*output_redraws_rect_del)         (void *engine, void *data, int x, int y, int w, int h);
+
+   /* The redraws are automatically propagated on all output */
+   void (*output_redraws_rect_add)         (void *engine, int x, int y, int w, int h);
+   void (*output_redraws_rect_del)         (void *engine, int x, int y, int w, int h);
+
    void (*output_redraws_clear)            (void *engine, void *data);
    void *(*output_redraws_next_update_get) (void *engine, void *data, int *x, int *y, int *w, int *h, int *cx, int *cy, int *cw, int *ch);
    void (*output_redraws_next_update_push) (void *engine, void *data, void *surface, int x, int y, int w, int h, Evas_Render_Mode render_mode);
@@ -1436,7 +1343,6 @@ struct _Evas_Func
    void *(*polygon_points_clear)           (void *engine, void *polygon);
    void (*polygon_draw)                    (void *engine, void *data, void *context, void *surface, void *polygon, int x, int y, Eina_Bool do_async);
 
-   void *(*image_load)                     (void *engine, const char *file, const char *key, int *error, Evas_Image_Load_Opts *lo);
    void *(*image_mmap)                     (void *engine, Eina_File *f, const char *key, int *error, Evas_Image_Load_Opts *lo);
    void *(*image_new_from_data)            (void *engine, int w, int h, DATA32 *image_data, int alpha, Evas_Colorspace cspace);
    void *(*image_new_from_copied_data)     (void *engine, int w, int h, DATA32 *image_data, int alpha, Evas_Colorspace cspace);
@@ -1472,7 +1378,6 @@ struct _Evas_Func
    void (*image_prepare)                   (void *engine, void *image);
 
    void *(*image_surface_noscale_new)      (void *engine, int w, int h, int alpha);
-   void (*image_surface_noscale_region_get)(void *engine, void *image, int *x, int *y, int *w, int *h);
 
    int (*image_native_init)                (void *engine, Evas_Native_Surface_Type type);
    void (*image_native_shutdown)           (void *engine, Evas_Native_Surface_Type type);
@@ -1486,10 +1391,10 @@ struct _Evas_Func
    void *(*image_plane_assign)             (void *data, void *image, int x, int y);
    void (*image_plane_release)             (void *data, void *image, void *plane);
 
-   Evas_Font_Set *(*font_load)             (void *engine, const char *name, int size, Font_Rend_Flags wanted_rend);
-   Evas_Font_Set *(*font_memory_load)      (void *engine, const char *source, const char *name, int size, const void *fdata, int fdata_size, Font_Rend_Flags wanted_rend);
-   Evas_Font_Set *(*font_add)              (void *engine, Evas_Font_Set *font, const char *name, int size, Font_Rend_Flags wanted_rend);
-   Evas_Font_Set *(*font_memory_add)       (void *engine, Evas_Font_Set *font, const char *source, const char *name, int size, const void *fdata, int fdata_size, Font_Rend_Flags wanted_rend);
+   Evas_Font_Set *(*font_load)             (void *engine, const char *name, int size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable);
+   Evas_Font_Set *(*font_memory_load)      (void *engine, const char *source, const char *name, int size, const void *fdata, int fdata_size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable);
+   Evas_Font_Set *(*font_add)              (void *engine, Evas_Font_Set *font, const char *name, int size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable);
+   Evas_Font_Set *(*font_memory_add)       (void *engine, Evas_Font_Set *font, const char *source, const char *name, int size, const void *fdata, int fdata_size, Font_Rend_Flags wanted_rend, Efl_Text_Font_Bitmap_Scalable bitmap_scalable);
    void (*font_free)                       (void *engine, Evas_Font_Set *font);
    int  (*font_ascent_get)                 (void *engine, Evas_Font_Set *font);
    int  (*font_descent_get)                (void *engine, Evas_Font_Set *font);
@@ -1521,12 +1426,13 @@ struct _Evas_Func
    void *(*image_scaled_update)            (void *engine, void *scaled, void *image, int dst_w, int dst_h, Eina_Bool smooth, Evas_Colorspace cspace);
 
    void (*image_content_hint_set)          (void *engine, void *surface, int hint);
-   int  (*image_content_hint_get)          (void *engine, void *surface);
    int  (*font_pen_coords_get)             (void *engine, Evas_Font_Set *font, const Evas_Text_Props *intl_props, int pos, int *cpen_x, int *cy, int *cadv, int *ch);
    Eina_Bool (*font_text_props_info_create) (void *engine, Evas_Font_Instance *fi, const Eina_Unicode *text, Evas_Text_Props *intl_props, const Evas_BiDi_Paragraph_Props *par_props, size_t pos, size_t len, Evas_Text_Props_Mode mode, const char *lang);
    int  (*font_right_inset_get)            (void *engine, Evas_Font_Set *font, const Evas_Text_Props *text_props);
 
    /* EFL-GL Glue Layer */
+   Eina_Bool (*gl_supports_evas_gl)      (void *engine);
+   void *(*gl_output_set)                (void *engine, void *output);
    void *(*gl_surface_create)            (void *engine, void *config, int w, int h);
    void *(*gl_pbuffer_surface_create)    (void *engine, void *config, int w, int h, int const *attrib_list);
    int  (*gl_surface_destroy)            (void *engine, void *surface);
@@ -1547,11 +1453,11 @@ struct _Evas_Func
    void *(*gl_current_surface_get)       (void *engine);
    int  (*gl_rotation_angle_get)         (void *engine);
    Eina_Bool (*gl_surface_query)         (void *engine, void *surface, int attr, void *value);
-   Eina_Bool (*gl_surface_direct_renderable_get) (void *engine, Evas_Native_Surface *ns, Eina_Bool *override, void *surface);
+   Eina_Bool (*gl_surface_direct_renderable_get) (void *engine, void *output, Evas_Native_Surface *ns, Eina_Bool *override, void *surface);
    void (*gl_image_direct_set)           (void *engine, void *image, Eina_Bool direct);
    int  (*gl_image_direct_get)           (void *engine, void *image);
-   void (*gl_get_pixels_pre)             (void *engine);
-   void (*gl_get_pixels_post)            (void *engine);
+   void (*gl_get_pixels_pre)             (void *engine, void *output);
+   void (*gl_get_pixels_post)            (void *engine, void *output);
 
    int  (*image_load_error_get)          (void *engine, void *image);
    int  (*font_run_end_get)              (void *engine, Evas_Font_Set *font, Evas_Font_Instance **script_fi, Evas_Font_Instance **cur_fi, Evas_Script_Type script, const Eina_Unicode *text, int run_len);
@@ -1597,18 +1503,24 @@ struct _Evas_Func
    void  (*texture_image_set)            (void *engine, void *texture, void *image);
    void *(*texture_image_get)            (void *engine, void *texture);
 
-   Ector_Surface *(*ector_create)        (void *engine, void *output);
+   Ector_Surface *(*ector_create)        (void *engine);
    void  (*ector_destroy)                (void *engine, Ector_Surface *surface);
    Ector_Buffer *(*ector_buffer_wrap)    (void *engine, Evas *e, void *engine_image);
    Ector_Buffer *(*ector_buffer_new)     (void *engine, Evas *e, int width, int height, Efl_Gfx_Colorspace cspace, Ector_Buffer_Flag flags);
-   void  (*ector_begin)                  (void *engine, void *context, Ector_Surface *ector, void *surface, void *engine_data, int x, int y, Eina_Bool do_async);
-   void  (*ector_renderer_draw)          (void *engine, void *data, void *context, void *surface, void *engine_data, Ector_Renderer *r, Eina_Array *clips, Eina_Bool do_async);
-   void  (*ector_end)                    (void *engine, void *context, Ector_Surface *ector, void *surface, void *engine_data, Eina_Bool do_async);
-   void* (*ector_new)                    (void *engine, void *context, Ector_Surface *ector, void *surface);
-   void  (*ector_free)                   (void *engine_data);
+   void  (*ector_begin)                  (void *engine, void *output, void *context, void *surface, Ector_Surface *ector, int x, int y, Eina_Bool do_async);
+   void  (*ector_renderer_draw)          (void *engine, void *output, void *context, void *surface, Ector_Renderer *r, Eina_Array *clips, Eina_Bool do_async);
+   void  (*ector_end)                    (void *engine, void *output, void *context, void *surface, Ector_Surface *ector, Eina_Bool do_async);
+
+   void *(*ector_surface_create)         (void *engine, int w, int h, int *error);
+   void  (*ector_surface_destroy)        (void *engine, void *surface);
+   void  (*ector_surface_cache_set)      (void *engine, void *key, void *surface);
+   void *(*ector_surface_cache_get)      (void *engine, void *key);
+   void  (*ector_surface_cache_drop)     (void *engine, void *key);
 
    Evas_Filter_Support (*gfx_filter_supports) (void *engine, Evas_Filter_Command *cmd);
    Eina_Bool (*gfx_filter_process)       (void *engine, Evas_Filter_Command *cmd);
+
+   unsigned int info_size;
 };
 
 struct _Evas_Image_Save_Func
@@ -1616,14 +1528,21 @@ struct _Evas_Image_Save_Func
   int (*image_save) (RGBA_Image *im, const char *file, const char *key, int quality, int compress, const char *encoding);
 };
 
+struct _Vg_File_Data
+{
+   Eina_Rectangle  view_box;
+   Efl_VG         *root;
+   Eina_Bool       preserve_aspect;
+};
+
 struct _Evas_Vg_Load_Func
 {
-  void     *(*file_data) (Eina_File *f, Eina_Stringshare *key, int *error);
+   Vg_File_Data *(*file_data) (const char *file, const char *key, int *error);
 };
 
 struct _Evas_Vg_Save_Func
 {
-  int (*vg_save) (void *vg, const char *file, const char *key, int compress);
+   int (*vg_save) (Vg_File_Data *vg, const char *file, const char *key, int compress);
 };
 
 #ifdef __cplusplus
@@ -1634,7 +1553,7 @@ Evas_Object *evas_object_new(Evas *e);
 void evas_object_change_reset(Evas_Object_Protected_Data *obj);
 void evas_object_clip_recalc_do(Evas_Object_Protected_Data *obj, Evas_Object_Protected_Data *clipper);
 void evas_object_cur_prev(Evas_Object_Protected_Data *obj);
-void evas_object_free(Evas_Object *obj, Eina_Bool clean_layer);
+void evas_object_free(Evas_Object_Protected_Data *obj, Eina_Bool clean_layer);
 void evas_object_update_bounding_box(Evas_Object *obj, Evas_Object_Protected_Data *pd, Evas_Smart_Data *s);
 void evas_object_inject(Evas_Object *obj, Evas_Object_Protected_Data *pd, Evas *e);
 void evas_object_release(Evas_Object *obj, Evas_Object_Protected_Data *pd, int clean_layer);
@@ -1680,7 +1599,7 @@ void evas_debug_generic(const char *str);
 const char *evas_debug_magic_string_get(DATA32 magic);
 void evas_render_update_del(Evas_Public_Data *e, int x, int y, int w, int h);
 void evas_render_object_render_cache_free(Evas_Object *eo_obj, void *data);
-   
+
 void evas_object_smart_use(Evas_Smart *s);
 void evas_object_smart_unuse(Evas_Smart *s);
 void evas_smart_cb_descriptions_fix(Evas_Smart_Cb_Description_Array *a) EINA_ARG_NONNULL(1);
@@ -1695,12 +1614,10 @@ Evas_Object *_evas_object_image_video_parent_get(Evas_Object *obj);
 void _evas_object_image_video_overlay_show(Evas_Object *obj);
 void _evas_object_image_video_overlay_hide(Evas_Object *obj);
 void _evas_object_image_video_overlay_do(Evas_Object *obj);
-Eina_Bool _evas_object_image_can_use_plane(Evas_Object_Protected_Data *obj);
-void _evas_object_image_plane_release(Evas_Object *eo_obj, Evas_Object_Protected_Data *obj);
+Eina_Bool _evas_object_image_can_use_plane(Evas_Object_Protected_Data *obj, Efl_Canvas_Output *output);
+void _evas_object_image_plane_release(Evas_Object *eo_obj, Evas_Object_Protected_Data *obj, Efl_Canvas_Output *output);
 void _evas_object_image_free(Evas_Object *obj);
-void evas_object_smart_bounding_box_get(Evas_Object_Protected_Data *obj,
-                                        Evas_Coord_Rectangle *cur_bounding_box,
-                                        Evas_Coord_Rectangle *prev_bounding_box);
+void evas_object_smart_bounding_box_get(Evas_Object_Protected_Data *obj, Eina_Rectangle *cur_bounding_box, Eina_Rectangle *prev_bounding_box);
 void evas_object_smart_del(Evas_Object *obj);
 void evas_object_smart_cleanup(Evas_Object *obj);
 void evas_object_smart_member_raise(Evas_Object *member);
@@ -1715,6 +1632,8 @@ const Eina_List *evas_object_event_grabber_members_list(const Eo *eo_obj);
 
 const Eina_Inlist *evas_object_smart_members_get_direct(const Evas_Object *obj);
 void _efl_canvas_group_group_members_all_del(Evas_Object *eo_obj);
+void _evas_object_smart_clipped_init(Evas_Object *eo_obj);
+void evas_object_smart_clipped_smart_move(Evas_Object *eo_obj, Evas_Coord x, Evas_Coord y);
 void _evas_object_smart_clipped_smart_move_internal(Evas_Object *eo_obj, Evas_Coord x, Evas_Coord y);
 void evas_call_smarts_calculate(Evas *e);
 void evas_object_smart_bounding_box_update(Evas_Object_Protected_Data *obj);
@@ -1730,35 +1649,18 @@ void evas_object_event_callback_all_del(Evas_Object *obj);
 void evas_object_event_callback_cleanup(Evas_Object *obj);
 void evas_event_callback_all_del(Evas *e);
 void evas_event_callback_cleanup(Evas *e);
-void evas_object_inform_call_show(Evas_Object *obj);
-void evas_object_inform_call_hide(Evas_Object *obj);
+void evas_object_inform_call_show(Evas_Object *obj, Evas_Object_Protected_Data *pd);
+void evas_object_inform_call_hide(Evas_Object *obj, Evas_Object_Protected_Data *pd);
 void evas_object_inform_call_move(Evas_Object *obj, Evas_Object_Protected_Data *pd);
-void evas_object_inform_call_resize(Evas_Object *obj);
-void evas_object_inform_call_restack(Evas_Object *obj);
-void evas_object_inform_call_changed_size_hints(Evas_Object *obj);
+void evas_object_inform_call_resize(Evas_Object *obj, Evas_Object_Protected_Data *pd);
+void evas_object_inform_call_restack(Evas_Object *obj, Evas_Object_Protected_Data *pd);
+void evas_object_inform_call_changed_size_hints(Evas_Object *obj, Evas_Object_Protected_Data *pd);
 void evas_object_inform_call_image_preloaded(Evas_Object *obj);
 void evas_object_inform_call_image_unloaded(Evas_Object *obj);
 void evas_object_inform_call_image_resize(Evas_Object *obj);
 void evas_object_intercept_cleanup(Evas_Object *obj);
 void evas_object_grabs_cleanup(Evas_Object *obj, Evas_Object_Protected_Data *pd);
 void evas_key_grab_free(Evas_Object *obj, Evas_Object_Protected_Data *pd, const char *keyname, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
-void evas_font_dir_cache_free(void);
-const char *evas_font_dir_cache_find(char *dir, char *font);
-Eina_List *evas_font_dir_available_list(const Evas* evas);
-void evas_font_dir_available_list_free(Eina_List *available);
-void evas_font_free(Evas *evas, void *font);
-void evas_fonts_zero_free(Evas *evas);
-void evas_fonts_zero_pressure(Evas *evas);
-void evas_font_name_parse(Evas_Font_Description *fdesc, const char *name);
-int evas_font_style_find(const char *start, const char *end, Evas_Font_Style style);
-Evas_Font_Description *evas_font_desc_new(void);
-Evas_Font_Description *evas_font_desc_dup(const Evas_Font_Description *fdesc);
-void evas_font_desc_unref(Evas_Font_Description *fdesc);
-int evas_font_desc_cmp(const Evas_Font_Description *a, const Evas_Font_Description *b);
-Evas_Font_Description *evas_font_desc_ref(Evas_Font_Description *fdesc);
-const char *evas_font_lang_normalize(const char *lang);
-void * evas_font_load(Evas *evas, Evas_Font_Description *fdesc, const char *source, Evas_Font_Size size);
-void evas_font_load_hinting_set(Evas *evas, void *font, int hinting);
 void evas_object_smart_member_cache_invalidate(Evas_Object *obj, Eina_Bool pass_events, Eina_Bool freeze_events, Eina_Bool sourve_invisible);
 void evas_text_style_pad_get(Evas_Text_Style_Type style, int *l, int *r, int *t, int *b);
 void _evas_object_text_rehint(Evas_Object *obj);
@@ -1785,90 +1687,9 @@ void _efl_canvas_object_clip_prev_reset(Evas_Object_Protected_Data *obj, Eina_Bo
 
 Eina_Bool _efl_canvas_object_clip_set_block(Eo *eo_obj, Evas_Object_Protected_Data *obj, Evas_Object *eo_clip, Evas_Object_Protected_Data *clip);
 Eina_Bool _efl_canvas_object_clip_unset_block(Eo *eo_obj, Evas_Object_Protected_Data *obj);
-Eina_Bool _efl_canvas_object_efl_gfx_size_set_block(Eo *eo_obj, Evas_Object_Protected_Data *obj, Evas_Coord w, Evas_Coord h, Eina_Bool internal);
+Eina_Bool _efl_canvas_object_efl_gfx_entity_size_set_block(Eo *eo_obj, Evas_Object_Protected_Data *obj, Evas_Coord w, Evas_Coord h, Eina_Bool internal);
 
-void _canvas_event_default_flags_set(Eo *e, void *_pd, va_list *list);
-void _canvas_event_default_flags_get(Eo *e, void *_pd, va_list *list);
-void _canvas_event_freeze(Eo *e, void *_pd, va_list *list);
-void _canvas_event_thaw(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_mouse_down(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_mouse_up(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_mouse_cancel(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_mouse_wheel(Eo *e, void *_pd, va_list *list);
-void _canvas_event_input_mouse_move(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_mouse_move(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_mouse_in(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_mouse_out(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_multi_down(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_multi_up(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_multi_move(Eo *e, void *_pd, va_list *list);
-void _canvas_event_input_multi_down(Eo *e, void *_pd, va_list *list);
-void _canvas_event_input_multi_up(Eo *e, void *_pd, va_list *list);
-void _canvas_event_input_multi_move(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_key_down(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_key_up(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_key_down_with_keycode(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_key_up_with_keycode(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_hold(Eo *e, void *_pd, va_list *list);
-void _canvas_event_feed_axis_update(Eo *e, void *_pd, va_list *list);
-void _canvas_event_refeed_event(Eo *e, void *_pd, va_list *list);
-void _canvas_event_down_count_get(Eo *e, void *_pd, va_list *list);
-void _canvas_tree_objects_at_xy_get(Eo *e, void *_pd, va_list *list);
-void _canvas_focus_get(Eo *e, void *_pd, va_list *list);
-void _canvas_font_path_clear(Eo *e, void *_pd, va_list *list);
-void _canvas_font_path_append(Eo *e, void *_pd, va_list *list);
-void _canvas_font_path_prepend(Eo *e, void *_pd, va_list *list);
-void _canvas_font_path_list(Eo *e, void *_pd, va_list *list);
-void _canvas_font_hinting_set(Eo *e, void *_pd, va_list *list);
-void _canvas_font_hinting_get(Eo *e, void *_pd, va_list *list);
-void _canvas_font_hinting_can_hint(Eo *e, void *_pd, va_list *list);
-void _canvas_font_cache_flush(Eo *e, void *_pd, va_list *list);
-void _canvas_font_cache_set(Eo *e, void *_pd, va_list *list);
-void _canvas_font_cache_get(Eo *e, void *_pd, va_list *list);
-void _canvas_font_available_list(Eo *e, void *_pd, va_list *list);
-void _evas_focus_device_del_cb(void *data, const Efl_Event *ev);
-
-void _canvas_key_modifier_get(Eo *e, void *_pd, va_list *list);
-void _canvas_key_lock_get(Eo *e, void *_pd, va_list *list);
-void _canvas_key_modifier_add(Eo *e, void *_pd, va_list *list);
-void _canvas_key_modifier_del(Eo *e, void *_pd, va_list *list);
-void _canvas_key_lock_add(Eo *e, void *_pd, va_list *list);
-void _canvas_key_lock_del(Eo *e, void *_pd, va_list *list);
-void _canvas_key_modifier_on(Eo *e, void *_pd, va_list *list);
-void _canvas_key_modifier_off(Eo *e, void *_pd, va_list *list);
-void _canvas_key_lock_on(Eo *e, void *_pd, va_list *list);
-void _canvas_key_lock_off(Eo *e, void *_pd, va_list *list);
-void _canvas_key_modifier_mask_get(Eo *e, void *_pd, va_list *list);
-
-void _canvas_damage_rectangle_add(Eo *obj, void *_pd, va_list *list);
-void _canvas_obscured_rectangle_add(Eo *obj, void *_pd, va_list *list);
-void _canvas_obscured_clear(Eo *obj, void *_pd, va_list *list);
-void _canvas_render_async(Eo *obj, void *_pd, va_list *list);
-void _canvas_render_updates(Eo *obj, void *_pd, va_list *list);
-void _canvas_render(Eo *e, void *_pd, va_list *list);
-void _canvas_norender(Eo *e, void *_pd, va_list *list);
-void _canvas_render_idle_flush(Eo *e, void *_pd, va_list *list);
-void _canvas_sync(Eo *obj, void *_pd, va_list *list);
-void _canvas_render_dump(Eo *obj, void *_pd, va_list *list);
-
-void _canvas_object_bottom_get(Eo *e, void *_pd, va_list *list);
-void _canvas_object_top_get(Eo *e, void *_pd, va_list *list);
-
-void _canvas_image_cache_flush(Eo *e, void *_pd, va_list *list);
-void _canvas_image_cache_reload(Eo *e, void *_pd, va_list *list);
-void _canvas_image_cache_set(Eo *e, void *_pd, va_list *list);
-void _canvas_image_cache_get(Eo *e, void *_pd, va_list *list);
-void _canvas_image_max_size_get(Eo *e, void *_pd, va_list *list);
-
-void _canvas_object_name_find(Eo *e, void *_pd, va_list *list);
-
-void _canvas_object_top_at_xy_get(Eo *e, void *_pd, va_list *list);
-void _canvas_object_top_in_rectangle_get(Eo *e, void *_pd, va_list *list);
-void _canvas_objects_at_xy_get(Eo *e, void *_pd, va_list *list);
-void _canvas_objects_in_rectangle_get(Eo *obj, void *_pd, va_list *list);
-
-void _canvas_smart_objects_calculate(Eo *e, void *_pd, va_list *list);
-void _canvas_smart_objects_calculate_count_get(Eo *e, void *_pd, va_list *list);
+void _evas_focus_device_invalidate_cb(void *data, const Efl_Event *ev);
 
 /* Node functions. */
 void evas_canvas3d_node_traverse(Evas_Canvas3D_Node *from, Evas_Canvas3D_Node *to, Evas_Canvas3D_Node_Traverse_Type type, Eina_Bool skip, Evas_Canvas3D_Node_Func func, void *data);
@@ -1935,7 +1756,7 @@ void _efl_gfx_map_shutdown(void);
 void _efl_gfx_map_update(Eo *eo_obj);
 
 /* Ector */
-Ector_Surface *evas_ector_get(Evas_Public_Data *evas, void *output);
+Ector_Surface *evas_ector_get(Evas_Public_Data *evas);
 
 /* Temporary save/load functions */
 void evas_common_load_model_from_file(Evas_Canvas3D_Mesh *model, const char *file);
@@ -2027,7 +1848,7 @@ EAPI void evas_module_task_register(Eina_Bool (*cancelled)(void *data), void *da
 EAPI void evas_module_task_unregister(void);
 
 // expose for use in engines
-EAPI int _evas_module_engine_inherit(Evas_Func *funcs, char *name);
+EAPI int _evas_module_engine_inherit(Evas_Func *funcs, char *name, size_t info);
 EAPI const char *_evas_module_libdir_get(void);
 const char *_evas_module_datadir_get(void);
 EAPI Eina_List *_evas_canvas_image_data_unset(Evas *eo_e);
@@ -2035,14 +1856,14 @@ EAPI void _evas_canvas_image_data_regenerate(Eina_List *list);
 
 Eina_Bool evas_render_mapped(Evas_Public_Data *e, Evas_Object *obj,
                              Evas_Object_Protected_Data *source_pd,
-                             void *context, void *surface, int off_x, int off_y,
+                             void *context, void *output, void *surface,
+                             int off_x, int off_y,
                              int mapped, int ecx, int ecy, int ecw, int ech,
                              Evas_Proxy_Render_Data *proxy_render_data,
                              int level, Eina_Bool do_async);
 void evas_render_invalidate(Evas *e);
 void evas_render_object_recalc(Evas_Object_Protected_Data *obj);
-void evas_render_proxy_subrender(Evas *eo_e, Evas_Object *eo_source, Evas_Object *eo_proxy, Evas_Object_Protected_Data *proxy_obj, Eina_Bool source_clip, Eina_Bool do_async);
-void evas_render_mask_subrender(Evas_Public_Data *e, Evas_Object_Protected_Data *mask, Evas_Object_Protected_Data *prev_mask, int level, Eina_Bool do_async);
+void evas_render_proxy_subrender(Evas *eo_e, void *output, Evas_Object *eo_source, Evas_Object *eo_proxy, Evas_Object_Protected_Data *proxy_obj, Eina_Bool source_clip, Eina_Bool do_async);
 
 Eina_Bool evas_map_inside_get(const Evas_Map *m, Evas_Coord x, Evas_Coord y);
 Eina_Bool evas_map_coords_get(const Evas_Map *m, double x, double y, double *mx, double *my, int grab);
@@ -2060,6 +1881,9 @@ void _evas_device_cleanup(Evas *e);
 Evas_Device *_evas_device_top_get(const Evas *e);
 
 /* legacy/eo events */
+Efl_Input_Event *efl_input_event_instance_get(Eo *klass, Eo *owner);
+void efl_input_event_instance_clean(Eo *klass);
+
 void *efl_input_pointer_legacy_info_fill(Evas *eo_evas, Efl_Input_Key *eo_ev, Evas_Callback_Type type, Evas_Event_Flags **pflags);
 void *efl_input_key_legacy_info_fill(Efl_Input_Key *evt, Evas_Event_Flags **pflags);
 void *efl_input_hold_legacy_info_fill(Efl_Input_Hold *evt, Evas_Event_Flags **pflags);
@@ -2081,6 +1905,19 @@ Eina_List *_evas_pointer_list_in_rect_get(Evas_Public_Data *edata,
                                          Evas_Object_Protected_Data *obj_data,
                                          int w, int h);
 
+void efl_canvas_output_info_get(Evas_Public_Data *e, Efl_Canvas_Output *output);
+
+// Gesture Manager
+void _efl_canvas_gesture_manager_filter_event(Eo *gesture_manager, Eo *target, void *event);
+void _efl_canvas_gesture_manager_callback_del_hook(Eo *gesture_manager, Eo *target, const Efl_Event_Description *type);
+void _efl_canvas_gesture_manager_callback_add_hook(Eo *gesture_manager, Eo *target, const Efl_Event_Description *type);
+
+//evas focus functions
+void evas_focus_init(void);
+void evas_focus_shutdown(void);
+
+void _deferred_callbacks_process(Evas *eo_e, Evas_Public_Data *e);
+
 extern Eina_Cow *evas_object_proxy_cow;
 extern Eina_Cow *evas_object_map_cow;
 extern Eina_Cow *evas_object_state_cow;
@@ -2190,5 +2027,9 @@ _gfx_to_evas_render_op(Efl_Gfx_Render_Op rop)
 #ifdef __cplusplus
 }
 #endif
+
+#undef EAPI
+#define EAPI
+
 #endif
 
