@@ -1,11 +1,15 @@
 #ifndef __EVIL_MACRO_H__
 #define __EVIL_MACRO_H__
 
+#if _WIN32_WINNT < 0x0600
+# error Windows XP not supported anymore
+#endif
+
 #ifdef EAPI
 # undef EAPI
 #endif
 
-#ifdef EFL_EVIL_BUILD
+#ifdef EFL_BUILD
 # ifdef DLL_EXPORT
 #  define EAPI __declspec(dllexport)
 # else
