@@ -48,21 +48,22 @@
 
 typedef struct _Ecore_Evas_Engine_Drm_Data
 {
-   int fd;
    int cw, ch;
    int clockid;
    int x, y, w, h;
    int depth, bpp;
    unsigned int format;
    double offset;
+   double tick_job_timestamp;
    Ecore_Drm2_Context ctx;
    Ecore_Fd_Handler *hdlr;
    Ecore_Drm2_Device *dev;
    Ecore_Drm2_Output *output;
    Evas_Device *seat;
-   Eina_Bool pending : 1;
    Eina_Bool ticking : 1;
    Eina_Bool once : 1;
+   Ecore_Job *tick_job;
+   Ecore_Job *focus_job;
 } Ecore_Evas_Engine_Drm_Data;
 
 static int _drm_init_count = 0;
@@ -153,15 +154,8 @@ _ecore_evas_drm_init(Ecore_Evas *ee, Ecore_Evas_Engine_Drm_Data *edata, const ch
    /* NB: fallback to seat0 if env var is not set */
    if (!device) device = "seat0";
 
-   edata->dev = ecore_drm2_device_find(device, 0);
+   edata->dev = ecore_drm2_device_open(device, 0);
    if (!edata->dev)
-     {
-        ERR("Failed to create device");
-        goto dev_err;
-     }
-
-   edata->fd = ecore_drm2_device_open(edata->dev);
-   if (edata->fd < 0)
      {
         ERR("Failed to open device");
         goto open_err;
@@ -183,8 +177,10 @@ _ecore_evas_drm_init(Ecore_Evas *ee, Ecore_Evas_Engine_Drm_Data *edata, const ch
    ecore_event_evas_init();
    if (!handlers)
      {
-        handlers = eina_list_append(handlers,
-          ecore_event_handler_add(ELPUT_EVENT_DEVICE_CHANGE, _drm_device_change, NULL));
+        handlers =
+          eina_list_append(handlers,
+                           ecore_event_handler_add(ELPUT_EVENT_DEVICE_CHANGE,
+                                                   _drm_device_change, NULL));
      }
 
    return _drm_init_count;
@@ -192,8 +188,6 @@ _ecore_evas_drm_init(Ecore_Evas *ee, Ecore_Evas_Engine_Drm_Data *edata, const ch
 output_err:
    ecore_drm2_device_close(edata->dev);
 open_err:
-   ecore_drm2_device_free(edata->dev);
-dev_err:
    ecore_drm2_shutdown();
 init_err:
    return --_drm_init_count;
@@ -205,9 +199,13 @@ _ecore_evas_drm_shutdown(Ecore_Evas_Engine_Drm_Data *edata)
    Ecore_Event_Handler *h;
    if (--_drm_init_count != 0) return _drm_init_count;
 
+   if (edata->focus_job)
+     {
+        ecore_job_del(edata->focus_job);
+        edata->focus_job = NULL;
+     }
    ecore_drm2_outputs_destroy(edata->dev);
    ecore_drm2_device_close(edata->dev);
-   ecore_drm2_device_free(edata->dev);
    ecore_drm2_shutdown();
    ecore_event_evas_shutdown();
    EINA_LIST_FREE(handlers, h)
@@ -230,17 +228,115 @@ _drm_free(Ecore_Evas *ee)
 }
 
 static void
-_drm_rotation_do(Ecore_Evas *ee, int rotation, int resize EINA_UNUSED)
+_drm_rotation_do(Ecore_Evas *ee, int rotation, int resize)
 {
    Evas_Engine_Info_Drm *einfo;
+   Ecore_Evas_Engine_Drm_Data *edata;
+   Eina_Bool use_hw = EINA_FALSE;
+   int diff, rotations = 0, orient = 0;
 
    if (ee->rotation == rotation) return;
-   ee->rotation = rotation;
+
    einfo = (Evas_Engine_Info_Drm *)evas_engine_info_get(ee->evas);
    if (!einfo) return;
+
+   edata = ee->engine.data;
+
+   rotations = ecore_drm2_output_supported_rotations_get(edata->output);
+   if (rotations >= 0)
+     {
+        if (rotations & ECORE_DRM2_ROTATION_NORMAL)
+          {
+             if (rotation == 0)
+               {
+                  use_hw = EINA_TRUE;
+                  orient = ECORE_DRM2_ROTATION_NORMAL;
+               }
+          }
+
+        if (rotations & ECORE_DRM2_ROTATION_90)
+          {
+             if (rotation == 90)
+               {
+                  use_hw = EINA_TRUE;
+                  orient = ECORE_DRM2_ROTATION_90;
+               }
+          }
+
+        if (rotations & ECORE_DRM2_ROTATION_180)
+          {
+             if (rotation == 180)
+               {
+                  use_hw = EINA_TRUE;
+                  orient = ECORE_DRM2_ROTATION_180;
+               }
+          }
+
+        if (rotations & ECORE_DRM2_ROTATION_270)
+          {
+             if (rotation == 270)
+               {
+                  use_hw = EINA_TRUE;
+                  orient = ECORE_DRM2_ROTATION_270;
+               }
+          }
+     }
+
+   if (use_hw)
+     {
+        ecore_drm2_output_rotation_set(edata->output, orient);
+        ee->rotation = rotation;
+        return;
+     }
+
    einfo->info.rotation = rotation;
    if (!evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo))
      ERR("evas_engine_info_set() for engine '%s' failed", ee->driver);
+
+   diff = ee->rotation - rotation;
+   if (diff < 0) diff = -diff;
+
+   if (diff != 180)
+     {
+        if (!resize)
+          {
+             int ww, hh;
+
+             if (ECORE_EVAS_PORTRAIT(ee))
+               evas_damage_rectangle_add(ee->evas, 0, 0, ee->req.w, ee->req.h);
+             else
+               evas_damage_rectangle_add(ee->evas, 0, 0, ee->req.h, ee->req.w);
+
+             ww = ee->h;
+             hh = ee->w;
+             ee->w = ww;
+             ee->h = hh;
+             ee->req.w = ww;
+             ee->req.h = hh;
+          }
+        else
+          {
+             if ((rotation == 0) || (rotation == 180))
+               {
+                  evas_output_size_set(ee->evas, ee->w, ee->h);
+                  evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h);
+               }
+             else
+               {
+                  evas_output_size_set(ee->evas, ee->h, ee->w);
+                  evas_output_viewport_set(ee->evas, 0, 0, ee->h, ee->w);
+               }
+          }
+     }
+
+   ee->rotation = rotation;
+
+   if (ee->func.fn_resize) ee->func.fn_resize(ee);
+
+   if (ECORE_EVAS_PORTRAIT(ee))
+     evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h);
+   else
+     evas_damage_rectangle_add(ee->evas, 0, 0, ee->h, ee->w);
 }
 
 static void
@@ -261,7 +357,7 @@ _drm_screen_geometry_get(const Ecore_Evas *ee, int *x, int *y, int *w, int *h)
    Ecore_Evas_Engine_Drm_Data *edata;
 
    edata = ee->engine.data;
-   ecore_drm2_output_geometry_get(edata->output, x, y, w, h);
+   ecore_drm2_output_info_get(edata->output, x, y, w, h, NULL);
 }
 
 static void
@@ -292,6 +388,17 @@ _drm_pointer_warp(const Ecore_Evas *ee, Evas_Coord x, Evas_Coord y)
    return EINA_TRUE;
 }
 
+static void
+_drm_show_focus_job(void *data)
+{
+   Ecore_Evas *ee = data;
+   Ecore_Evas_Engine_Drm_Data *edata;
+
+   _ecore_evas_focus_device_set(ee, NULL, EINA_TRUE);
+   edata = ee->engine.data;
+   edata->focus_job = NULL;
+}
+
 static void
 _drm_show(Ecore_Evas *ee)
 {
@@ -316,14 +423,10 @@ _drm_show(Ecore_Evas *ee)
    if (ee->visible) return;
 
    ee->visible = 1;
-   if (ee->prop.fullscreen)
-     {
-        evas_focus_in(ee->evas);
-        if (ee->func.fn_focus_in) ee->func.fn_focus_in(ee);
-     }
    if (ee->func.fn_show) ee->func.fn_show(ee);
 
    edata = ee->engine.data;
+   edata->focus_job = ecore_job_add(_drm_show_focus_job, ee);
    /* HACK: sometimes we still have an animator ticking when we vc switch
     * so for now we just fire off a flip here to kick it when we come back.
     * This is just papering over a bug for now until I have time to track
@@ -505,7 +608,7 @@ _drm_fullscreen_set(Ecore_Evas *ee, Eina_Bool on)
         edata->w = ee->w;
         edata->h = ee->h;
 
-        ecore_drm2_output_geometry_get(edata->output, NULL, NULL, &ow, &oh);
+        ecore_drm2_output_info_get(edata->output, NULL, NULL, &ow, &oh, NULL);
         if ((ow == 0) || (oh == 0))
           {
              ow = ee->w;
@@ -601,7 +704,7 @@ _cb_drm_event(void *data, Ecore_Fd_Handler *hdlr EINA_UNUSED)
 
    ee = data;
    edata = ee->engine.data;
-   ret = ecore_drm2_event_handle(edata->fd, &edata->ctx);
+   ret = ecore_drm2_event_handle(edata->dev, &edata->ctx);
    if (ret)
      {
         WRN("drmHandleEvent failed to read an event");
@@ -623,20 +726,19 @@ _cb_pageflip(int fd EINA_UNUSED, unsigned int frame EINA_UNUSED, unsigned int se
 
    ret = ecore_drm2_fb_flip_complete(edata->output);
 
-   edata->pending = EINA_FALSE;
-
    if (edata->ticking)
      {
+        int x, y, w, h;
         double t = (double)sec + ((double)usec / 1000000);
 
+        ecore_drm2_output_info_get(edata->output, &x, &y, &w, &h, NULL);
+
         if (!edata->once) t = ecore_time_get();
-        ecore_evas_animator_tick(ee, NULL, t - edata->offset);
+        ecore_evas_animator_tick(ee, &(Eina_Rectangle){x, y, w, h},
+                                 t - edata->offset);
      }
    else if (ret)
-     {
-        edata->pending = EINA_TRUE;
-        ecore_drm2_fb_flip(NULL, edata->output);
-     }
+     ecore_drm2_fb_flip(NULL, edata->output);
 }
 
 static void
@@ -647,11 +749,25 @@ _drm_evas_changed(Ecore_Evas *ee, Eina_Bool changed)
    if (changed) return;
 
    edata = ee->engine.data;
-   if (edata->ticking && !edata->pending)
-     {
-        edata->pending = EINA_TRUE;
-        ecore_drm2_fb_flip(NULL, edata->output);
-     }
+   if (edata->ticking && !ecore_drm2_output_pending_get(edata->output))
+     ecore_drm2_fb_flip(NULL, edata->output);
+}
+
+static void
+_tick_job(void *data)
+{
+   Ecore_Evas_Engine_Drm_Data *edata;
+   Ecore_Evas *ee;
+   int x, y, w, h;
+
+   ee = data;
+   edata = ee->engine.data;
+   edata->tick_job = NULL;
+
+   ecore_drm2_output_info_get(edata->output, &x, &y, &w, &h, NULL);
+
+   ecore_evas_animator_tick(ee, &(Eina_Rectangle){x, y, w, h},
+                            edata->tick_job_timestamp - edata->offset);
 }
 
 static void
@@ -666,7 +782,6 @@ _drm_animator_register(Ecore_Evas *ee)
      ERR("Attempt to schedule tick for manually rendered canvas");
 
    edata = ee->engine.data;
-   edata->ticking = EINA_TRUE;
 
    /* Some graphics stacks appear to lie about their clock sources
     * so attempt to measure the difference between our clock and the
@@ -694,11 +809,29 @@ _drm_animator_register(Ecore_Evas *ee)
           }
      }
 
-   if (!edata->pending && !ee->in_async_render)
+   if (ee->animator_ticked || ee->animator_ran)
      {
-        edata->pending = EINA_TRUE;
-        ecore_drm2_fb_flip(NULL, edata->output);
+        edata->ticking = EINA_TRUE;
+        return;
      }
+
+   if (edata->tick_job) ERR("Double animator register");
+   else
+   if (!edata->ticking &&
+       !(ecore_drm2_output_pending_get(edata->output) || ee->in_async_render))
+     {
+        r = ecore_drm2_output_blanktime_get(edata->output, 0, &sec, &usec);
+        if (r)
+          {
+             edata->tick_job_timestamp = (double)sec
+                                       + ((double)usec / 1000000);
+             edata->tick_job = ecore_job_add(_tick_job, ee);
+          }
+        else
+          ecore_drm2_fb_flip(NULL, edata->output);
+     }
+
+   edata->ticking = EINA_TRUE;
 }
 
 static void
@@ -708,6 +841,12 @@ _drm_animator_unregister(Ecore_Evas *ee)
 
    edata = ee->engine.data;
    edata->ticking = EINA_FALSE;
+   if (edata->tick_job)
+     {
+        ERR("Animator unregister before first tick");
+        ecore_job_del(edata->tick_job);
+        edata->tick_job = NULL;
+     }
 }
 
 static double
@@ -888,11 +1027,13 @@ _ecore_evas_new_internal(const char *device, int x, int y, int w, int h, Eina_Bo
    if (getenv("ECORE_EVAS_FORCE_SYNC_RENDER"))
      ee->can_async_render = 0;
 
-   ee->evas = evas_new();
-   evas_data_attach_set(ee->evas, ee);
+   if (!ecore_evas_evas_new(ee, w, h))
+     {
+        ERR("Can not create a Canvas.");
+        goto eng_err;
+     }
+
    evas_output_method_set(ee->evas, method);
-   evas_output_size_set(ee->evas, w, h);
-   evas_output_viewport_set(ee->evas, 0, 0, w, h);
 
    if (ee->can_async_render)
      evas_event_callback_add(ee->evas, EVAS_CALLBACK_RENDER_POST,
@@ -911,7 +1052,7 @@ _ecore_evas_new_internal(const char *device, int x, int y, int w, int h, Eina_Bo
         if ((num) && (!atoi(num)))
           einfo->info.vsync = EINA_FALSE;
 
-        einfo->info.fd = edata->fd;
+        einfo->info.dev = edata->dev;
         einfo->info.bpp = edata->bpp;
         einfo->info.depth = edata->depth;
         einfo->info.format = edata->format;
@@ -929,7 +1070,7 @@ _ecore_evas_new_internal(const char *device, int x, int y, int w, int h, Eina_Bo
      {
         Evas_Engine_Info_Drm *einfo = tinfo;
 
-        einfo->info.fd = edata->fd;
+        einfo->info.dev = edata->dev;
         einfo->info.bpp = edata->bpp;
         einfo->info.depth = edata->depth;
         einfo->info.format = edata->format;
@@ -947,15 +1088,9 @@ _ecore_evas_new_internal(const char *device, int x, int y, int w, int h, Eina_Bo
 
    ecore_evas_data_set(ee, "device", edata->dev);
 
-   _ecore_evas_register(ee);
-   ecore_event_window_register(ee->prop.window, ee, ee->evas,
-                               (Ecore_Event_Mouse_Move_Cb)_ecore_evas_mouse_move_process,
-                               (Ecore_Event_Multi_Move_Cb)_ecore_evas_mouse_multi_move_process,
-                               (Ecore_Event_Multi_Down_Cb)_ecore_evas_mouse_multi_down_process,
-                               (Ecore_Event_Multi_Up_Cb)_ecore_evas_mouse_multi_up_process);
-   _ecore_event_window_direct_cb_set(ee->prop.window, _ecore_evas_input_direct_cb);
+   ecore_evas_done(ee, EINA_FALSE);
 
-   ecore_drm2_output_crtc_size_get(edata->output, &mw, &mh);
+   ecore_drm2_output_info_get(edata->output, NULL, NULL, &mw, &mh, NULL);
 
    ecore_drm2_device_calibrate(edata->dev, mw, mh);
    ecore_drm2_device_pointer_max_set(edata->dev, mw, mh);
@@ -966,7 +1101,8 @@ _ecore_evas_new_internal(const char *device, int x, int y, int w, int h, Eina_Bo
    edata->ctx.page_flip_handler = _cb_pageflip;
 
    edata->hdlr =
-     ecore_main_fd_handler_add(edata->fd, ECORE_FD_READ, _cb_drm_event, ee,
+     ecore_main_fd_handler_add(ecore_drm2_device_fd_get(edata->dev),
+                               ECORE_FD_READ, _cb_drm_event, ee,
                                NULL, NULL);
 
    canvases = eina_list_append(canvases, ee);
