@@ -518,6 +518,7 @@ text_input_preedit_styling(void *data,
 {
    WaylandIMContext *imcontext = (WaylandIMContext *)data;
    Ecore_IMF_Preedit_Attr *attr = calloc(1, sizeof(*attr));
+   if (!attr) return;
 
    switch (style)
      {
@@ -633,8 +634,8 @@ text_input_keysym(void *data,
    strcpy((char *)e->key, key);
    strcpy((char *)e->string, string);
 
-   e->window = ecore_wl2_window_id_get(imcontext->window);
-   e->event_window = ecore_wl2_window_id_get(imcontext->window);
+   e->window = (Ecore_Window)imcontext->window;
+   e->event_window = (Ecore_Window)imcontext->window;
    e->timestamp = time;
 
    e->modifiers = 0;
@@ -761,6 +762,8 @@ wayland_im_context_del(Ecore_IMF_Context *ctx)
 
    EINA_LOG_DOM_INFO(_ecore_imf_wayland_log_dom, "context_del");
 
+   _clear_hide_timer();
+
    if (imcontext->language)
      {
         free(imcontext->language);
@@ -864,8 +867,11 @@ wayland_im_context_preedit_string_with_attributes_get(Ecore_IMF_Context *ctx,
         EINA_LIST_FOREACH(imcontext->preedit_attrs, l, a)
           {
              attr = malloc(sizeof(*attr));
-             attr = memcpy(attr, a, sizeof(*attr));
-             *attrs = eina_list_append(*attrs, attr);
+             if (attr)
+               {
+                  attr = memcpy(attr, a, sizeof(*attr));
+                  *attrs = eina_list_append(*attrs, attr);
+               }
           }
      }
 
@@ -900,8 +906,7 @@ wayland_im_context_client_window_set(Ecore_IMF_Context *ctx, void *window)
 
    if (window != NULL)
      {
-        imcontext->window =
-          ecore_wl2_display_window_find(ewd, (Ecore_Window)window);
+        imcontext->window = window;
      }
 }
 
@@ -1101,9 +1106,11 @@ WaylandIMContext *
 wayland_im_context_new(struct zwp_text_input_manager_v1 *text_input_manager)
 {
    WaylandIMContext *context = calloc(1, sizeof(WaylandIMContext));
-
-   EINA_LOG_DOM_INFO(_ecore_imf_wayland_log_dom, "new context created");
-   context->text_input_manager = text_input_manager;
+   if (context)
+     {
+        EINA_LOG_DOM_INFO(_ecore_imf_wayland_log_dom, "new context created");
+        context->text_input_manager = text_input_manager;
+     }
 
    return context;
 }
