@@ -2,7 +2,11 @@
 # include "elementary_config.h"
 #endif
 
-#include <Elementary.h>
+#include "Elementary.h"
+
+#define ELEMENTARY_BUILD
+#undef ELM_MODULE_HELPER_H
+#include "elm_module_helper.h"
 
 // module api funcs needed
 EAPI int
