@@ -79,15 +79,15 @@ typedef Eina_Bool (*evas_gl_make_current_cb)(void *engine_data, void *doit);
 #endif
 
 #ifdef _WIN32
-# ifdef EFL_EVAS_BUILD
+# ifdef EFL_BUILD
 #  ifdef DLL_EXPORT
 #   define EAPI __declspec(dllexport)
 #  else
 #   define EAPI
-#  endif /* ! DLL_EXPORT */
+#  endif
 # else
 #  define EAPI __declspec(dllimport)
-# endif /* ! EFL_EVAS_BUILD */
+# endif
 #else
 # ifdef __GNUC__
 #  if __GNUC__ >= 4
@@ -98,7 +98,7 @@ typedef Eina_Bool (*evas_gl_make_current_cb)(void *engine_data, void *doit);
 # else
 #  define EAPI
 # endif
-#endif /* ! _WIN32 */
+#endif
 
 #define PROGRAM_HITCOUNT_MAX 0x1000000
 
@@ -563,9 +563,10 @@ EAPI void         evas_gl_preload_render_lock(evas_gl_make_current_cb make_curre
 EAPI void         evas_gl_preload_render_unlock(evas_gl_make_current_cb make_current, void *engine_data);
 EAPI void         evas_gl_preload_render_relax(evas_gl_make_current_cb make_current, void *engine_data);
 EAPI void         evas_gl_symbols(void *(*GetProcAddress)(const char *name), const char *extsn);
+EAPI Eina_Bool    evas_gl_extension_string_check(const char *ext, const char *exts);
 
-EAPI void         evas_gl_common_error_set(void *data, int error_enum);
-EAPI int          evas_gl_common_error_get(void *data);
+EAPI void         evas_gl_common_error_set(int error_enum);
+EAPI int          evas_gl_common_error_get(void);
 EAPI void        *evas_gl_common_current_context_get(void);
 
 typedef int (*Evas_GL_Preload)(void);
@@ -577,6 +578,7 @@ typedef Evas_Engine_GL_Context *(*Evas_GL_Common_Context_New)(void);
 typedef void (*Evas_GL_Common_Context_Resize_Call)(Evas_Engine_GL_Context *gc, int w, int h, int rot);
 typedef int (*Evas_GL_Common_Buffer_Dump_Call)(Evas_Engine_GL_Context *gc,const char* dname, const char* fname, int frame, const char* suffix);
 typedef void (*Evas_Gl_Symbols)(void *(*GetProcAddress)(const char *sym), const char *extsn);
+typedef Eina_Bool (*Evas_Gl_Extension_String_Check)(const char *exts, const char *ext);
 
 EAPI void __evas_gl_err(int err, const char *file, const char *func, int line, const char *op);
 
@@ -606,7 +608,7 @@ void              evas_gl_common_context_image_push(Evas_Engine_GL_Context *gc,
                                                     Evas_GL_Texture *mtex, int mx, int my, int mw, int mh,
                                                     Eina_Bool mask_smooth, Eina_Bool mask_color,
                                                     int r, int g, int b, int a,
-                                                    Eina_Bool smooth, Eina_Bool tex_only);
+                                                    Eina_Bool smooth, Eina_Bool tex_only, Eina_Bool alphaonly);
 void              evas_gl_common_context_font_push(Evas_Engine_GL_Context *gc,
                                                    Evas_GL_Texture *tex,
                                                    double sx, double sy, double sw, double sh,
@@ -667,13 +669,16 @@ void             evas_gl_common_context_image_map_push(Evas_Engine_GL_Context *g
                                                        Evas_Colorspace cspace);
 
 // Gfx Filters
+void              evas_gl_common_filter_blend_push(Evas_Engine_GL_Context *gc, Evas_GL_Texture *tex,
+                                                   double sx, double sy, double sw, double sh, double dx,
+                                                   double dy, double dw, double dh, Eina_Bool alphaonly);
 void              evas_gl_common_filter_displace_push(Evas_Engine_GL_Context *gc, Evas_GL_Texture *tex, Evas_GL_Texture *map_tex,
                                                       int x, int y, int w, int h, double dx, double dy, Eina_Bool nearest);
 void              evas_gl_common_filter_curve_push(Evas_Engine_GL_Context *gc, Evas_GL_Texture *tex,
                                                    int x, int y, int w, int h, const uint8_t *points, int channel);
 void              evas_gl_common_filter_blur_push(Evas_Engine_GL_Context *gc, Evas_GL_Texture *tex, double sx, double sy, double sw, double sh,
                                                   double dx, double dy, double dw, double dh, const double * const values, const double * const offsets, int count, double radius,
-                                                  Eina_Bool horiz);
+                                                  Eina_Bool horiz, Eina_Bool alphaonly);
 
 int               evas_gl_common_shader_program_init(Evas_GL_Shared *shared);
 void              evas_gl_common_shader_program_shutdown(Evas_GL_Shared *shared);
@@ -687,6 +692,7 @@ Evas_GL_Program  *evas_gl_common_shader_program_get(Evas_Engine_GL_Context *gc,
                                                     Evas_GL_Texture *tex, Eina_Bool tex_only,
                                                     Evas_GL_Texture *mtex, Eina_Bool mask_smooth,
                                                     Eina_Bool mask_color, int mw, int mh,
+                                                    Eina_Bool alphaonly,
                                                     Shader_Sampling *psam, int *pnomul,
                                                     Shader_Sampling *pmasksam);
 void              evas_gl_common_shader_textures_bind(Evas_GL_Program *p);
@@ -725,7 +731,6 @@ void              evas_gl_common_texture_rgb_a_pair_update(Evas_GL_Texture *tex,
 Evas_Colorspace   evas_gl_common_gl_format_to_colorspace(GLuint f);
 
 void              evas_gl_common_image_alloc_ensure(Evas_GL_Image *im);
-Evas_GL_Image    *evas_gl_common_image_load(Evas_Engine_GL_Context *gc, const char *file, const char *key, Evas_Image_Load_Opts *lo, int *error);
 Evas_GL_Image    *evas_gl_common_image_mmap(Evas_Engine_GL_Context *gc, Eina_File *f, const char *key, Evas_Image_Load_Opts *lo, int *error);
 Evas_GL_Image    *evas_gl_common_image_new_from_copied_data(Evas_Engine_GL_Context *gc, unsigned int w, unsigned int h, DATA32 *data, int alpha, Evas_Colorspace cspace);
 Evas_GL_Image    *evas_gl_common_image_new(Evas_Engine_GL_Context *gc, unsigned int w, unsigned int h, int alpha, Evas_Colorspace cspace);
@@ -748,7 +753,7 @@ Evas_GL_Image    *evas_gl_common_image_virtual_scaled_get(Evas_GL_Image *scaled,
 
 void             *evas_gl_font_texture_new(void *gc, RGBA_Font_Glyph *fg);
 void              evas_gl_font_texture_free(void *);
-void              evas_gl_font_texture_draw(void *gc, void *surface, void *dc, RGBA_Font_Glyph *fg, int x, int y);
+void              evas_gl_font_texture_draw(void *gc, void *surface, void *dc, RGBA_Font_Glyph *fg, int x, int y, int w, int h);
 void             *evas_gl_font_image_new(void *gc, RGBA_Font_Glyph *fg, int alpha, Evas_Colorspace cspace);
 void              evas_gl_font_image_free(void *im);
 void              evas_gl_font_image_draw(void *gc, void *im, int dx, int dy, int dw, int dh, int smooth);
@@ -858,16 +863,15 @@ __evas_gl_errdyn(int err, const char *file, const char *func, int line, const ch
    if (!sym) sym = dlsym(RTLD_DEFAULT, "__evas_gl_err");
    sym(err, file, func, line, op);
 }
-# define GLERRV(op) \
-  { \
+# define GLERRV(op) do { \
       int __gl_err = glGetError(); \
       if (__gl_err != GL_NO_ERROR) \
         __evas_gl_errdyn(__gl_err, __FILE__, __FUNCTION__, __LINE__, op); \
-   }
+   } while (0)
 /* Redefine common gl funcs */
 # ifndef GL_ERRORS_NODEF
 #  ifndef GL_ERRORS_TRACE
-#   define GL_ERROR_TRACE(f, _args, ...) do { f(__VA_ARGS__); GLERRV(#f); } while(0)
+#   define GL_ERROR_TRACE(f, _args, ...) do { GLERRV("Uncaught error before this point:"); f(__VA_ARGS__); GLERRV(#f); } while(0)
 #   define GL_ERROR_TRACE_RET(t, f, _args, ...) ({ t _r = f(__VA_ARGS__); GLERRV(#f); _r; })
 #  else
 #   define GL_ERROR_TRACE(f, _args, ...) do { DBG("%s(%s);", #f, _args); f(__VA_ARGS__); GLERRV(#f); } while(0)
@@ -904,6 +908,7 @@ __evas_gl_errdyn(int err, const char *file, const char *func, int line, const ch
 #  define glTexParameterf(...) GL_ERROR_TRACE(glTexParameterf, #__VA_ARGS__, __VA_ARGS__)
 #  define glTexParameteri(...) GL_ERROR_TRACE(glTexParameteri, #__VA_ARGS__, __VA_ARGS__)
 #  define glTexSubImage2D(...) GL_ERROR_TRACE(glTexSubImage2D, #__VA_ARGS__, __VA_ARGS__)
+#  define glTexImage2D(...) GL_ERROR_TRACE(glTexImage2D, #__VA_ARGS__, __VA_ARGS__)
 #  define glUniform1f(...) GL_ERROR_TRACE(glUniform1f, #__VA_ARGS__, __VA_ARGS__)
 #  define glUniform1i(...) GL_ERROR_TRACE(glUniform1i, #__VA_ARGS__, __VA_ARGS__)
 #  define glUniform2fv(...) GL_ERROR_TRACE(glUniform2fv, #__VA_ARGS__, __VA_ARGS__)
