@@ -243,7 +243,7 @@ evas_gl_common_image_new_from_rgbaimage(Evas_Engine_GL_Context *gc, RGBA_Image *
        ((int)im_im->cache_entry.h > gc->shared->info.max_texture_size))
      {
         evas_cache_image_drop(&(im_im->cache_entry));
-        *error = EVAS_LOAD_ERROR_RESOURCE_ALLOCATION_FAILED;
+        if (error) *error = EVAS_LOAD_ERROR_RESOURCE_ALLOCATION_FAILED;
         return NULL;
      }
     */
@@ -259,7 +259,7 @@ evas_gl_common_image_new_from_rgbaimage(Evas_Engine_GL_Context *gc, RGBA_Image *
              gc->shared->images = eina_list_remove_list(gc->shared->images, l);
              gc->shared->images = eina_list_prepend(gc->shared->images, im);
              evas_gl_common_image_ref(im);
-             *error = EVAS_LOAD_ERROR_NONE;
+             if (error) *error = EVAS_LOAD_ERROR_NONE;
              return im;
           }
      }
@@ -273,7 +273,7 @@ evas_gl_common_image_new_from_rgbaimage(Evas_Engine_GL_Context *gc, RGBA_Image *
         else
 #endif
           evas_cache_image_drop(&(im_im->cache_entry));
-        *error = EVAS_LOAD_ERROR_RESOURCE_ALLOCATION_FAILED;
+        if (error) *error = EVAS_LOAD_ERROR_RESOURCE_ALLOCATION_FAILED;
         return NULL;
      }
    if (im_im->cache_entry.cspaces)
@@ -320,37 +320,6 @@ found_cspace:
    return im;
 }
 
-Evas_GL_Image *
-evas_gl_common_image_load(Evas_Engine_GL_Context *gc, const char *file, const char *key, Evas_Image_Load_Opts *lo, int *error)
-{
-   RGBA_Image *im_im;
-
-#ifdef EVAS_CSERVE2
-   if (evas_cserve2_use_get())
-     {
-        im_im = (RGBA_Image *) evas_cache2_image_open
-          (evas_common_image_cache2_get(), file, key, lo, error);
-        if (im_im)
-          {
-             *error = evas_cache2_image_open_wait(&im_im->cache_entry);
-             if ((*error != EVAS_LOAD_ERROR_NONE)
-                 && im_im->cache_entry.animated.animated)
-               {
-                  evas_cache2_image_close(&im_im->cache_entry);
-                  im_im = NULL;
-               }
-             else
-               return evas_gl_common_image_new_from_rgbaimage(gc, im_im, lo, error);
-          }
-     }
-#endif
-
-   im_im = evas_common_load_image_from_file(file, key, lo, error);
-   if (!im_im) return NULL;
-
-   return evas_gl_common_image_new_from_rgbaimage(gc, im_im, lo, error);
-}
-
 Evas_GL_Image *
 evas_gl_common_image_mmap(Evas_Engine_GL_Context *gc, Eina_File *f, const char *key, Evas_Image_Load_Opts *lo, int *error)
 {
@@ -766,6 +735,8 @@ evas_gl_common_image_cache_flush(Evas_Engine_GL_Context *gc)
 EAPI void
 evas_gl_common_image_free(Evas_GL_Image *im)
 {
+   if (!im) return;
+
    im->references--;
    if (im->references > 0) return;
 
@@ -774,12 +745,14 @@ evas_gl_common_image_free(Evas_GL_Image *im)
 
    if (im->fglyph)
      {
-        im->gc->font_glyph_images = eina_list_remove(im->gc->font_glyph_images, im);
+        if (im->gc)
+          im->gc->font_glyph_images = eina_list_remove(im->gc->font_glyph_images, im);
         im->fglyph->ext_dat = NULL;
         im->fglyph->ext_dat_free = NULL;
      }
 
-   evas_gl_common_context_flush(im->gc);
+   if (im->gc)
+     evas_gl_common_context_flush(im->gc);
 
    evas_gl_common_image_preload_unwatch(im);
 
@@ -794,7 +767,7 @@ evas_gl_common_image_free(Evas_GL_Image *im)
 
    if (im->cs.data)
      {
-	if (!im->cs.no_free) free(im->cs.data);
+        if (!im->cs.no_free) free(im->cs.data);
      }
    if (im->cached)
      {
@@ -885,7 +858,6 @@ evas_gl_common_image_update(Evas_Engine_GL_Context *gc, Evas_GL_Image *im)
    Image_Entry *ie;
    if (!im->im) return;
 
-   // alloc ensure can change im->im, so only get the local variable later.
    ie = &im->im->cache_entry;
    if (!im->tex)
      {
@@ -894,6 +866,8 @@ evas_gl_common_image_update(Evas_Engine_GL_Context *gc, Evas_GL_Image *im)
         im->h = ie->h;
      }
    evas_gl_common_image_alloc_ensure(im);
+   // alloc ensure can change im->im, so only get the local variable later.
+   ie = &im->im->cache_entry;
 /*
    if ((im->cs.space == EVAS_COLORSPACE_YCBCR422P601_PL) ||
        (im->cs.space == EVAS_COLORSPACE_YCBCR422P709_PL))
@@ -1349,7 +1323,7 @@ _evas_gl_common_image_push(Evas_Engine_GL_Context *gc, Evas_GL_Image *im,
                                             dx, dy, dw, dh,
                                             mtex, mx, my, mw, mh, mask_smooth, mask_color,
                                             r, g, b, a,
-                                            smooth, im->tex_only);
+                                            smooth, im->tex_only, EINA_FALSE);
         return;
      }
 
@@ -1405,11 +1379,14 @@ _evas_gl_common_image_push(Evas_Engine_GL_Context *gc, Evas_GL_Image *im,
                                        nx, ny, nw, nh,
                                        mtex, mx, my, mw, mh, mask_smooth, mask_color,
                                        r, g, b, a,
-                                       smooth, im->tex_only);
+                                       smooth, im->tex_only, EINA_FALSE);
 }
 
 void
-evas_gl_common_image_draw(Evas_Engine_GL_Context *gc, Evas_GL_Image *im, int sx, int sy, int sw, int sh, int dx, int dy, int dw, int dh, int smooth)
+evas_gl_common_image_draw(Evas_Engine_GL_Context *gc, Evas_GL_Image *im,
+                          int sx, int sy, int sw, int sh,
+                          int dx, int dy, int dw, int dh,
+                          int smooth)
 {
    RGBA_Draw_Context *dc;
    int r, g, b, a;
@@ -1429,9 +1406,9 @@ evas_gl_common_image_draw(Evas_Engine_GL_Context *gc, Evas_GL_Image *im, int sx,
    if (dc->mul.use)
      {
 	a = (dc->mul.col >> 24) & 0xff;
-	r = (dc->mul.col >> 16) & 0xff;
-	g = (dc->mul.col >> 8 ) & 0xff;
-	b = (dc->mul.col      ) & 0xff;
+        r = (dc->mul.col >> 16) & 0xff;
+        g = (dc->mul.col >> 8 ) & 0xff;
+        b = (dc->mul.col      ) & 0xff;
      }
    else
      {
