@@ -29,11 +29,14 @@ struct scanout_handle
 /* external variables */
 int _evas_engine_gl_drm_log_dom = -1;
 int _extn_have_buffer_age = 1;
+int _extn_have_context_priority = 0;
 
 /* local variables */
 static Eina_Bool initted = EINA_FALSE;
 static Eina_Bool dmabuf_present = EINA_FALSE;
 static int gl_wins = 0;
+static struct gbm_device *gbm_dev = NULL;
+static int gbm_dev_refs = 0;
 
 /* local function prototype types */
 typedef void (*glsym_func_void)();
@@ -55,6 +58,7 @@ Evas_GL_Preload glsym_evas_gl_preload_shutdown = NULL;
 EVGL_Engine_Call glsym_evgl_engine_shutdown = NULL;
 EVGL_Current_Native_Context_Get_Call glsym_evgl_current_native_context_get = NULL;
 Evas_Gl_Symbols glsym_evas_gl_symbols = NULL;
+Evas_Gl_Extension_String_Check _ckext = NULL;
 
 Evas_GL_Common_Context_New glsym_evas_gl_common_context_new = NULL;
 Evas_GL_Common_Context_Call glsym_evas_gl_common_context_flush = NULL;
@@ -122,14 +126,25 @@ static const EVGL_Interface evgl_funcs =
 Eina_Bool
 eng_gbm_init(Evas_Engine_Info_GL_Drm *info)
 {
+   int fd;
    if (!info) return EINA_FALSE;
 
-   if (!(info->info.gbm = gbm_create_device(info->info.fd)))
+   if (gbm_dev)
+     {
+        info->info.gbm = gbm_dev;
+        gbm_dev_refs++;
+        return EINA_TRUE;
+     }
+
+   fd = ecore_drm2_device_fd_get(info->info.dev);
+   if (!(info->info.gbm = gbm_create_device(fd)))
      {
         ERR("Coult not create gbm device");
         return EINA_FALSE;
      }
 
+   gbm_dev = info->info.gbm;
+   gbm_dev_refs = 1;
    return EINA_TRUE;
 }
 
@@ -140,8 +155,13 @@ eng_gbm_shutdown(Evas_Engine_Info_GL_Drm *info)
 
    if (info->info.gbm)
      {
-        gbm_device_destroy(info->info.gbm);
+        gbm_dev_refs--;
         info->info.gbm = NULL;
+        if (!gbm_dev_refs)
+          {
+             gbm_device_destroy(gbm_dev);
+             gbm_dev = NULL;
+          }
      }
 
    return EINA_TRUE;
@@ -150,6 +170,7 @@ eng_gbm_shutdown(Evas_Engine_Info_GL_Drm *info)
 static void
 symbols(void)
 {
+   Evas_Gl_Extension_String_Check glsym_evas_gl_extension_string_check = NULL;
    static Eina_Bool done = EINA_FALSE;
 
    if (done) return;
@@ -184,15 +205,18 @@ symbols(void)
    LINK2GENERIC(eglGetProcAddress);
    LINK2GENERIC(evas_gl_common_eglCreateImage);
    LINK2GENERIC(evas_gl_common_eglDestroyImage);
+   LINK2GENERIC(evas_gl_extension_string_check);
+
+   _ckext = glsym_evas_gl_extension_string_check;
 
    done = EINA_TRUE;
 }
 
 void
-eng_gl_symbols(EGLDisplay edsp)
+eng_egl_symbols(EGLDisplay edsp)
 {
    static Eina_Bool done = EINA_FALSE;
-   const char *exts = NULL;
+   const char *exts;
 
    if (done) return;
 
@@ -200,7 +224,6 @@ eng_gl_symbols(EGLDisplay edsp)
    if (!dst) dst = (typ)glsym_eglGetProcAddress(sym);
 
    exts = eglQueryString(edsp, EGL_EXTENSIONS);
-   glsym_evas_gl_symbols(glsym_eglGetProcAddress, exts);
 
    FINDSYM(glsym_glEGLImageTargetTexture2DOES,
            "glEGLImageTargetTexture2DOES", glsym_func_void);
@@ -218,6 +241,9 @@ eng_gl_symbols(EGLDisplay edsp)
    FINDSYM(glsym_eglQueryWaylandBufferWL, "eglQueryWaylandBufferWL",
            glsym_func_uint);
 
+   if (evas_gl_extension_string_check(exts, "EGL_IMG_context_priority"))
+     _extn_have_context_priority = 1;
+
    done = EINA_TRUE;
 }
 
@@ -241,15 +267,15 @@ gl_extn_veto(Render_Engine *re)
              glsym_eglSwapBuffersWithDamage = NULL;
              glsym_eglSetDamageRegionKHR = NULL;
           }
-        if (!strstr(str, "EGL_EXT_buffer_age"))
+        if (!_ckext(str, "EGL_EXT_buffer_age"))
           _extn_have_buffer_age = 0;
 
-        if (!strstr(str, "EGL_KHR_partial_update"))
+        if (!_ckext(str, "EGL_KHR_partial_update"))
           glsym_eglSetDamageRegionKHR = NULL;
 
-        if (!strstr(str, "EGL_EXT_swap_buffers_with_damage"))
+        if (!_ckext(str, "EGL_EXT_swap_buffers_with_damage"))
           glsym_eglSwapBuffersWithDamage = NULL;
-        if (strstr(str, "EGL_EXT_image_dma_buf_import"))
+        if (_ckext(str, "EGL_EXT_image_dma_buf_import"))
           dmabuf_present = EINA_TRUE;
      }
    else
@@ -600,7 +626,7 @@ _re_winfree(Render_Engine *re)
 }
 
 static Ecore_Drm2_Fb *
-drm_import_simple_dmabuf(int fd, struct dmabuf_attributes *attributes)
+drm_import_simple_dmabuf(Ecore_Drm2_Device *dev, struct dmabuf_attributes *attributes)
 {
    unsigned int stride[4] = { 0 };
    int dmabuf_fd[4] = { 0 };
@@ -612,7 +638,7 @@ drm_import_simple_dmabuf(int fd, struct dmabuf_attributes *attributes)
         dmabuf_fd[i] = attributes->fd[i];
      }
 
-   return ecore_drm2_fb_dmabuf_import(fd, attributes->width,
+   return ecore_drm2_fb_dmabuf_import(dev, attributes->width,
                                       attributes->height, 32, 32,
                                       attributes->format, stride,
                                       dmabuf_fd, attributes->n_planes);
@@ -805,7 +831,7 @@ eng_image_plane_assign(void *data, void *image, int x, int y)
     * sticking to this one for now */
    if (n->ns.type != EVAS_NATIVE_SURFACE_WL_DMABUF) return NULL;
 
-   fb = drm_import_simple_dmabuf(re->fd, &n->ns_data.wl_surface_dmabuf.attr);
+   fb = drm_import_simple_dmabuf(re->dev, &n->ns_data.wl_surface_dmabuf.attr);
 
    if (!fb) return NULL;
 
@@ -889,61 +915,23 @@ _native_cb_free(void *image)
 }
 
 /* engine specific override functions */
-static void *
-eng_info(Evas *eo_e EINA_UNUSED)
-{
-   Evas_Engine_Info_GL_Drm *info;
-
-   /* try to allocate space for our engine info */
-   if (!(info = calloc(1, sizeof(Evas_Engine_Info_GL_Drm))))
-     return NULL;
-
-   info->magic.magic = rand();
-   info->render_mode = EVAS_RENDER_MODE_BLOCKING;
-
-   return info;
-}
-
 static void
-eng_info_free(Evas *eo_e EINA_UNUSED, void *in)
+eng_output_info_setup(void *info)
 {
-   Evas_Engine_Info_GL_Drm *info;
+   Evas_Engine_Info_GL_Drm *einfo = info;
 
-   if ((info = (Evas_Engine_Info_GL_Drm *)in))
-     free(info);
-}
-
-static Render_Engine_Merge_Mode
-_eng_merge_mode_get(void)
-{
-   Render_Engine_Merge_Mode merge_mode = MERGE_SMART;
-   const char *s;
-
-   s = getenv("EVAS_GL_PARTIAL_MERGE");
-   if (s)
-     {
-        if ((!strcmp(s, "bounding")) || (!strcmp(s, "b")))
-          merge_mode = MERGE_BOUNDING;
-        else if ((!strcmp(s, "full")) || (!strcmp(s, "f")))
-          merge_mode = MERGE_FULL;
-        else if ((!strcmp(s, "smart")) || (!strcmp(s, "s")))
-          merge_mode = MERGE_SMART;
-     }
-
-   return merge_mode;
+   einfo->render_mode = EVAS_RENDER_MODE_BLOCKING;
 }
 
 static void *
-eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
+eng_output_setup(void *engine, void *in, unsigned int w, unsigned int h)
 {
    Evas_Engine_Info_GL_Drm *info = in;
    Render_Engine *re = NULL;
    Outbuf *ob;
-   Render_Engine_Swap_Mode swap_mode;
-   Render_Engine_Merge_Mode merge_mode;
+   Render_Output_Swap_Mode swap_mode;
 
    swap_mode = evas_render_engine_gl_swap_mode_get(info->info.swap_mode);
-   merge_mode = _eng_merge_mode_get();
 
    if (!initted)
      {
@@ -958,7 +946,7 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
         return NULL;
      }
 
-   re->fd = info->info.fd;
+   re->dev = info->info.dev;
 
    /* try to create new outbuf */
    ob = evas_outbuf_new(info, w, h, swap_mode);
@@ -969,7 +957,7 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
         return NULL;
      }
 
-   if (!evas_render_engine_gl_generic_init(&re->generic, ob,
+   if (!evas_render_engine_gl_generic_init(engine, &re->generic, ob,
                                            evas_outbuf_buffer_state_get,
                                            evas_outbuf_rot_get,
                                            evas_outbuf_reconfigure,
@@ -977,7 +965,7 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
                                            evas_outbuf_damage_region_set,
                                            evas_outbuf_update_region_new,
                                            evas_outbuf_update_region_push,
-                                           evas_outbuf_update_region_free,
+                                           NULL,
                                            NULL,
                                            evas_outbuf_flush,
                                            NULL,
@@ -998,7 +986,7 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
 
    gl_wins++;
 
-   evas_render_engine_software_generic_merge_mode_set(&re->generic.software, merge_mode);
+   evas_render_engine_software_generic_merge_mode_set(&re->generic.software);
 
    if (!initted)
      {
@@ -1006,23 +994,13 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
         initted = EINA_TRUE;
      }
 
-   if (re->generic.software.tb)
-     evas_common_tilebuf_free(re->generic.software.tb);
-   re->generic.software.tb = evas_common_tilebuf_new(w, h);
-   if (re->generic.software.tb)
-     evas_common_tilebuf_set_tile_size(re->generic.software.tb,
-                                       TILESIZE, TILESIZE);
-
-   if (re->generic.software.tb)
-     evas_render_engine_software_generic_tile_strict_set(&re->generic.software, EINA_TRUE);
-
    evas_outbuf_use(eng_get_ob(re));
 
    return re;
 }
 
 static int
-eng_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w, unsigned int h)
+eng_output_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w, unsigned int h)
 {
    Evas_Engine_Info_GL_Drm *info = (Evas_Engine_Info_GL_Drm *)in;
    Render_Engine *re = data;
@@ -1033,7 +1011,7 @@ eng_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w, unsig
             (info->info.destination_alpha != eng_get_ob(re)->destination_alpha))
           {
              Outbuf *ob, *ob_old;
-             Render_Engine_Swap_Mode swap_mode = MODE_AUTO;
+             Render_Output_Swap_Mode swap_mode = MODE_AUTO;
 
              ob_old = re->generic.software.ob;
              re->generic.software.ob = NULL;
@@ -1068,23 +1046,13 @@ eng_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w, unsig
           }
      }
 
-   if (re->generic.software.tb)
-     evas_common_tilebuf_free(re->generic.software.tb);
-   re->generic.software.tb = evas_common_tilebuf_new(w, h);
-   if (re->generic.software.tb)
-     evas_common_tilebuf_set_tile_size(re->generic.software.tb,
-                                       TILESIZE, TILESIZE);
-
-   if (re->generic.software.tb)
-     evas_render_engine_software_generic_tile_strict_set(&re->generic.software, EINA_TRUE);
-
    evas_outbuf_use(eng_get_ob(re));
 
    return 1;
 }
 
 static void
-eng_output_free(void *engine EINA_UNUSED, void *data)
+eng_output_free(void *engine, void *data)
 {
    Render_Engine *re;
 
@@ -1099,7 +1067,7 @@ eng_output_free(void *engine EINA_UNUSED, void *data)
 
         info = eng_get_ob(re)->info;
         /* NB: evas_render_engine_software_generic_clean() frees ob */
-        evas_render_engine_software_generic_clean(&re->generic.software);
+        evas_render_engine_software_generic_clean(engine, &re->generic.software);
 
         eng_gbm_shutdown(info);
         gl_wins--;
@@ -1126,13 +1094,14 @@ eng_canvas_alpha_get(void *data)
 }
 
 static void
-eng_output_dump(void *engine EINA_UNUSED, void *data)
+eng_output_dump(void *engine, void *data)
 {
    Render_Engine *re;
+   Render_Engine_GL_Generic *e = engine;
 
    re = (Render_Engine *)data;
    if (!re) return;
-
+   generic_cache_dump(e->software.surface_cache);
    evas_common_image_image_all_unload();
    evas_common_font_font_all_unload();
    glsym_evas_gl_common_image_all_unload(eng_get_ob(re)->gl_context);
@@ -1170,7 +1139,6 @@ eng_image_native_shutdown(void *engine EINA_UNUSED, Evas_Native_Surface_Type typ
 static void *
 eng_image_native_set(void *engine, void *image, void *native)
 {
-   Render_Engine *re;
    Outbuf *ob;
    Native *n;
    Evas_Native_Surface *ns;
@@ -1179,10 +1147,7 @@ eng_image_native_set(void *engine, void *image, void *native)
    uint32_t texid;
    void *wlid, *wl_buf = NULL;
 
-   re = (Render_Engine *)engine;
-   if (!re) return NULL;
-
-   ob = eng_get_ob(re);
+   ob = gl_generic_any_output_get(engine);
    if (!ob) return NULL;
 
    ns = native;
@@ -1258,19 +1223,14 @@ eng_image_native_set(void *engine, void *image, void *native)
           }
      }
 
-   if ((!ns) && (!img->native.data)) return img;
-
    evas_outbuf_use(ob);
 
-   if (img->native.data)
+   if (!ns)
      {
-        if (img->native.func.free)
-          img->native.func.free(img);
-        glsym_evas_gl_common_image_native_disable(img);
+        glsym_evas_gl_common_image_free(img);
+        return NULL;
      }
 
-   if (!ns) return img;
-
    if (ns->type == EVAS_NATIVE_SURFACE_WL_DMABUF)
      {
         wlid = wl_buf;
@@ -1485,7 +1445,7 @@ module_open(Evas_Module *em)
    if (!em) return 0;
 
    /* get whatever engine module we inherit from */
-   if (!_evas_module_engine_inherit(&pfunc, "gl_generic")) return 0;
+   if (!_evas_module_engine_inherit(&pfunc, "gl_generic", sizeof (Evas_Engine_Info_GL_Drm))) return 0;
 
    /* try to create eina logging domain */
    if (_evas_engine_gl_drm_log_dom < 0)
@@ -1507,18 +1467,18 @@ module_open(Evas_Module *em)
    func = pfunc;
 
    /* now to override methods */
-   EVAS_API_OVERRIDE(info, &func, eng_);
-   EVAS_API_OVERRIDE(info_free, &func, eng_);
-   EVAS_API_OVERRIDE(setup, &func, eng_);
-   EVAS_API_OVERRIDE(update, &func, eng_);
-   EVAS_API_OVERRIDE(canvas_alpha_get, &func, eng_);
-   EVAS_API_OVERRIDE(output_free, &func, eng_);
-   EVAS_API_OVERRIDE(output_dump, &func, eng_);
-   EVAS_API_OVERRIDE(image_native_set, &func, eng_);
-   EVAS_API_OVERRIDE(image_native_init, &func, eng_);
-   EVAS_API_OVERRIDE(image_native_shutdown, &func, eng_);
-   EVAS_API_OVERRIDE(image_plane_assign, &func, eng_);
-   EVAS_API_OVERRIDE(image_plane_release, &func, eng_);
+#define ORD(f) EVAS_API_OVERRIDE(f, &func, eng_)
+   ORD(output_info_setup);
+   ORD(output_setup);
+   ORD(output_update);
+   ORD(canvas_alpha_get);
+   ORD(output_free);
+   ORD(output_dump);
+   ORD(image_native_set);
+   ORD(image_native_init);
+   ORD(image_native_shutdown);
+   ORD(image_plane_assign);
+   ORD(image_plane_release);
 
    /* Mesa's EGL driver loads wayland egl by default. (called by eglGetProcaddr() )
     * implicit env set (EGL_PLATFORM=drm) prevent that. */
