@@ -54,6 +54,7 @@ _evas_outbuf_release_fb(Ecore_Drm2_Fb *fb, Ecore_Drm2_Fb_Status status, void *da
 
    ob = data;
    bo = ecore_drm2_fb_bo_get(fb);
+   if ((!ob->surface) || (!bo)) return;
    gbm_surface_release_buffer(ob->surface, bo);
 }
 
@@ -75,7 +76,7 @@ _evas_outbuf_fb_get(Outbuf *ob, struct gbm_bo *bo)
    /* fb->size = fb->stride * fb->h; */
 
    fb =
-     ecore_drm2_fb_gbm_create(ob->fd, w, h, ob->depth, ob->bpp,
+     ecore_drm2_fb_gbm_create(ob->dev, w, h, ob->depth, ob->bpp,
                               format, hdl, stride, bo);
    if (!fb)
      {
@@ -111,35 +112,6 @@ _evas_outbuf_buffer_swap(Outbuf *ob)
         else ecore_drm2_plane_fb_set(ob->priv.plane, fb);
 
         ecore_drm2_fb_flip(fb, ob->priv.output);
-
-        /* Ecore_Drm2_Plane *plane; */
-
-        /* plane = ecore_drm2_plane_find(ob->priv.output, fb, ob->format); */
-        /* if (plane) */
-        /*   { */
-        /*      int ret; */
-        /*      drmVBlank vbl = */
-        /*        { */
-        /*           .request.type = DRM_VBLANK_RELATIVE | DRM_VBLANK_EVENT, */
-        /*           .request.sequence = 1, */
-        /*        }; */
-
-        /*      vbl.request.type |= ecore_drm2_output_vblank_get(ob->priv.output); */
-        /*      vbl.request.signal = (unsigned long)ob; */
-
-        /*      ecore_drm2_fb_dirty(fb, rects, count); */
-
-        /*      if (!ecore_drm2_plane_fb_set(plane, fb)) */
-        /*        { */
-        /*           ERR("Failed to set FB on Plane"); */
-        /*           return; */
-        /*        } */
-
-        /*      ret = drmWaitVBlank(ob->fd, &vbl); */
-        /*      if (ret) return; */
-        /*   } */
-        /* else */
-        /*   WRN("NO PLANE FOUND"); */
      }
    else
      WRN("Could not get FBO from Bo");
@@ -172,15 +144,21 @@ static Eina_Bool
 _evas_outbuf_init(void)
 {
    static int _init = 0;
+
    if (_init) return EINA_TRUE;
 #ifdef EGL_MESA_platform_gbm
-   /* FIXME: Pretty sure we should be checking if EGL_EXT_platform_base
-    * exists before looking these up and trusting them?
-    */
-   dlsym_eglGetPlatformDisplayEXT = (PFNEGLGETPLATFORMDISPLAYEXTPROC)
-         eglGetProcAddress("eglGetPlatformDisplayEXT");
-   dlsym_eglCreatePlatformWindowSurfaceEXT = (PFNEGLCREATEPLATFORMWINDOWSURFACEEXTPROC)
-         eglGetProcAddress("eglCreatePlatformWindowSurfaceEXT");
+   {
+     const char *exts;
+
+     exts = eglQueryString(NULL, EGL_EXTENSIONS);
+     if (_ckext(exts, "EGL_EXT_platform_base"))
+       {
+          dlsym_eglGetPlatformDisplayEXT = (PFNEGLGETPLATFORMDISPLAYEXTPROC)
+                eglGetProcAddress("eglGetPlatformDisplayEXT");
+          dlsym_eglCreatePlatformWindowSurfaceEXT = (PFNEGLCREATEPLATFORMWINDOWSURFACEEXTPROC)
+                eglGetProcAddress("eglCreatePlatformWindowSurfaceEXT");
+       }
+   }
 #endif
    _init = 1;
    return EINA_TRUE;
@@ -189,9 +167,10 @@ _evas_outbuf_init(void)
 static Eina_Bool
 _evas_outbuf_egl_setup(Outbuf *ob)
 {
-   int ctx_attr[3];
+   const char *exts;
+   int ctx_attr[5];
    int cfg_attr[40];
-   int maj = 0, min = 0, n = 0, i = 0;
+   int maj = 0, min = 0, n = 0, i = 0, cn = 0;
    EGLint ncfg = 0;
    EGLConfig *cfgs;
    const GLubyte *vendor, *renderer, *version, *glslversion;
@@ -204,9 +183,15 @@ _evas_outbuf_egl_setup(Outbuf *ob)
      }
 
    /* setup gbm egl surface */
-   ctx_attr[0] = EGL_CONTEXT_CLIENT_VERSION;
-   ctx_attr[1] = 2;
-   ctx_attr[2] = EGL_NONE;
+   ctx_attr[cn++] = EGL_CONTEXT_CLIENT_VERSION;
+   ctx_attr[cn++] = 2;
+
+   if (_extn_have_context_priority)
+     {
+        ctx_attr[cn++] = EGL_CONTEXT_PRIORITY_LEVEL_IMG;
+        ctx_attr[cn++] = EGL_CONTEXT_PRIORITY_HIGH_IMG;
+     }
+   ctx_attr[cn++] = EGL_NONE;
 
    cfg_attr[n++] = EGL_RENDERABLE_TYPE;
    cfg_attr[n++] = EGL_OPENGL_ES2_BIT;
@@ -254,6 +239,8 @@ _evas_outbuf_egl_setup(Outbuf *ob)
         return EINA_FALSE;
      }
 
+   eng_egl_symbols(ob->egl.disp);
+
    if (!eglGetConfigs(ob->egl.disp, NULL, 0, &ncfg) || (ncfg == 0))
      {
         ERR("eglGetConfigs() fail. code=%#x", eglGetError());
@@ -327,6 +314,9 @@ _evas_outbuf_egl_setup(Outbuf *ob)
         goto err;
      }
 
+   exts = eglQueryString(ob->egl.disp, EGL_EXTENSIONS);
+   glsym_evas_gl_symbols(glsym_eglGetProcAddress, exts);
+
    vendor = glGetString(GL_VENDOR);
    renderer = glGetString(GL_RENDERER);
    version = glGetString(GL_VERSION);
@@ -362,8 +352,6 @@ _evas_outbuf_egl_setup(Outbuf *ob)
         goto err;
      }
 
-   eng_gl_symbols(ob->egl.disp);
-
    ob->gl_context = glsym_evas_gl_common_context_new();
    if (!ob->gl_context) goto err;
 
@@ -387,7 +375,7 @@ err:
 }
 
 Outbuf *
-evas_outbuf_new(Evas_Engine_Info_GL_Drm *info, int w, int h, Render_Engine_Swap_Mode swap_mode)
+evas_outbuf_new(Evas_Engine_Info_GL_Drm *info, int w, int h, Render_Output_Swap_Mode swap_mode)
 {
    Outbuf *ob;
 
@@ -407,7 +395,7 @@ evas_outbuf_new(Evas_Engine_Info_GL_Drm *info, int w, int h, Render_Engine_Swap_
    /* ob->vsync = info->info.vsync; */
    ob->swap_mode = swap_mode;
 
-   ob->fd = info->info.fd;
+   ob->dev = info->info.dev;
    ob->bpp = info->info.bpp;
    ob->format = info->info.format;
    ob->priv.output = info->info.output;
@@ -570,7 +558,7 @@ evas_outbuf_reconfigure(Outbuf *ob, int w, int h, int rot, Outbuf_Depth depth)
    glsym_evas_gl_common_context_resize(ob->gl_context, w, h, rot);
 }
 
-Render_Engine_Swap_Mode
+Render_Output_Swap_Mode
 evas_outbuf_buffer_state_get(Outbuf *ob)
 {
    /* check for valid output buffer */
@@ -580,7 +568,7 @@ evas_outbuf_buffer_state_get(Outbuf *ob)
 
    if (ob->swap_mode == MODE_AUTO && _extn_have_buffer_age)
      {
-        Render_Engine_Swap_Mode swap_mode;
+        Render_Output_Swap_Mode swap_mode;
         EGLint age = 0;
 
         eina_evlog("+gl_query_surf_swap_mode", ob, 0.0, NULL);
@@ -724,12 +712,6 @@ evas_outbuf_update_region_push(Outbuf *ob, RGBA_Image *update EINA_UNUSED, int x
    glsym_evas_gl_common_context_flush(ob->gl_context);
 }
 
-void
-evas_outbuf_update_region_free(Outbuf *ob EINA_UNUSED, RGBA_Image *update EINA_UNUSED)
-{
-   /* Nothing to do here as we don't really create an image per area */
-}
-
 void
 evas_outbuf_flush(Outbuf *ob, Tilebuf_Rect *surface_damage, Tilebuf_Rect *buffer_damage EINA_UNUSED, Evas_Render_Mode render_mode)
 {
