@@ -10,10 +10,12 @@ static Eina_TLS _context_key = 0;
 typedef void (*glsym_func_void) ();
 glsym_func_void glsym_evas_gl_common_context_restore_set = NULL;
 
+Eina_Bool gles3_supported = EINA_FALSE;
+
 #ifdef GL_GLES
 typedef EGLContext GLContext;
 typedef EGLConfig GLConfig;
-static int gles3_supported = -1;
+static Eina_Bool gles3_probed = EINA_FALSE;
 #else
 // FIXME: this will only work for 1 display connection (glx land can have > 1)
 typedef GLXContext GLContext;
@@ -184,7 +186,7 @@ eng_window_new(Evas_Engine_Info_GL_X11 *info,
                int      indirect EINA_UNUSED,
                int      alpha,
                int      rot,
-               Render_Engine_Swap_Mode swap_mode,
+               Render_Output_Swap_Mode swap_mode,
                int depth_bits,
                int stencil_bits,
                int msaa_bits)
@@ -239,7 +241,6 @@ eng_window_new(Evas_Engine_Info_GL_X11 *info,
 
 // EGL / GLES
 #ifdef GL_GLES
-   gw->gles3 = gles3_supported;
    gw->egl_disp = _x11_eglGetDisplay(gw->disp);
    if (!gw->egl_disp)
      {
@@ -277,7 +278,7 @@ eng_window_new(Evas_Engine_Info_GL_X11 *info,
 
 try_gles2:
    context_attrs[0] = EGL_CONTEXT_CLIENT_VERSION;
-   context_attrs[1] = gw->gles3 ? 3 : 2;
+   context_attrs[1] = gles3_supported ? 3 : 2;
    context_attrs[2] = EGL_NONE;
 
    context = _tls_context_get();
@@ -286,11 +287,11 @@ try_gles2:
    if (gw->egl_context == EGL_NO_CONTEXT)
      {
         ERR("eglCreateContext() fail. code=%#x", eglGetError());
-        if (gw->gles3)
+        if (gles3_supported)
           {
              /* Note: this shouldn't happen */
              ERR("Trying again with an Open GL ES 2 context (fallback).");
-             gw->gles3 = EINA_FALSE;
+             gles3_supported = EINA_FALSE;
              goto try_gles2;
           }
         eng_window_free(gw);
@@ -344,6 +345,13 @@ try_gles2:
         eng_window_free(gw);
         return NULL;
      }
+   // nvidia drivers in egl/gles mode dont need re-creating of the
+   // eglimage ... and doign so is super slow on them, so avoid the
+   // multi buffer path - as it's only for nvidia and this fixes
+   // the performance regression there, it's fairly safe to do
+   // as it's not universal across all drivers.
+   if (strstr((const char *)vendor, "NVIDIA"))
+     gw->detected.no_multi_buffer_native = 1;
 
    eglGetConfigAttrib(gw->egl_disp, gw->egl_config, EGL_DEPTH_SIZE, &val);
    gw->detected.depth_buffer_size = val;
@@ -873,9 +881,9 @@ eng_best_visual_get(Evas_Engine_Info_GL_X11 *einfo)
      }
 
    /* detect GLES 3.x support */
-   if (gles3_supported == -1)
+   if (gles3_probed == EINA_FALSE)
      {
-        gles3_supported = EINA_FALSE;
+        gles3_probed = EINA_TRUE;
         eglexts = eglQueryString(egl_disp, EGL_EXTENSIONS);
         if (eglexts && strstr(eglexts, "EGL_KHR_create_context"))
           {
@@ -1299,7 +1307,7 @@ eng_gl_context_new(Outbuf *win)
    if (!ctx) return NULL;
 
 #if GL_GLES
-   if (win->gles3)
+   if (gles3_supported)
      context_attrs[1] = 3;
    ctx->context = eglCreateContext(win->egl_disp, win->egl_config,
                                    win->egl_context, context_attrs);
@@ -1358,7 +1366,7 @@ eng_gl_context_use(Context_3D *ctx)
 #else
    if (!__glXMakeContextCurrent(ctx->display, ctx->glxwin, ctx->context))
      {
-        ERR("glXMakeContextCurrent(%p, %p, %p, %p) faild.",
+        ERR("glXMakeContextCurrent(%p, %p, %p, %p) failed.",
             (void *)ctx->display, (void *)ctx->glxwin,
             (void *)ctx->win, (void *)ctx->context);
      }
@@ -1381,12 +1389,12 @@ eng_outbuf_get_rot(Outbuf *ob)
    return ob->rot;
 }
 
-Render_Engine_Swap_Mode
+Render_Output_Swap_Mode
 eng_outbuf_swap_mode(Outbuf *ob)
 {
    if (ob->swap_mode == MODE_AUTO && extn_have_buffer_age)
      {
-        Render_Engine_Swap_Mode swap_mode;
+        Render_Output_Swap_Mode swap_mode;
         eina_evlog("+gl_query_surf_swap_mode", ob, 0.0, NULL);
 #ifdef GL_GLES
         EGLint age = 0;
@@ -1552,13 +1560,6 @@ eng_outbuf_push_updated_region(Outbuf *ob, RGBA_Image *update EINA_UNUSED,
    glsym_evas_gl_common_context_flush(ob->gl_context);
 }
 
-void
-eng_outbuf_push_free_region_for_update(Outbuf *ob EINA_UNUSED,
-                                       RGBA_Image *update EINA_UNUSED)
-{
-   /* Nothing to do here as we don't really create an image per area */
-}
-
 void
 eng_outbuf_flush(Outbuf *ob, Tilebuf_Rect *surface_damage EINA_UNUSED, Tilebuf_Rect *buffer_damage, Evas_Render_Mode render_mode)
 {
