@@ -24,8 +24,8 @@
 #include <Ecore.h>
 #include <Eina.h>
 
-Evas_Native_Tbm_Surface_Image_Set_Call glsym__evas_native_tbm_surface_image_set = NULL;
-Evas_Native_Tbm_Surface_Stride_Get_Call glsym__evas_native_tbm_surface_stride_get = NULL;
+static Evas_Native_Tbm_Surface_Image_Set_Call glsym__evas_native_tbm_surface_image_set = NULL;
+static Evas_Native_Tbm_Surface_Stride_Get_Call glsym__evas_native_tbm_surface_stride_get = NULL;
 int _evas_engine_soft_x11_log_dom = -1;
 
 /* function tables - filled in later (func and parent func) */
@@ -36,7 +36,7 @@ typedef struct _Render_Engine Render_Engine;
 
 struct _Render_Engine
 {
-   Render_Engine_Software_Generic generic;
+   Render_Output_Software_Generic generic;
    Eina_Bool                      (*outbuf_alpha_get)(Outbuf *ob);
 
    struct
@@ -64,15 +64,13 @@ _output_egl_shutdown(Render_Engine *re)
 }
 
 static void *
-_output_xlib_setup(int w, int h, int rot, Display *disp, Drawable draw,
+_output_xlib_setup(void *engine, int w, int h, int rot, Display *disp, Drawable draw,
                    Visual *vis, Colormap cmap, int depth, int debug,
                    int grayscale, int max_colors, Pixmap mask,
                    int shape_dither, int destination_alpha)
 {
    Render_Engine *re;
    Outbuf *ob;
-   Render_Engine_Merge_Mode merge_mode = MERGE_SMART;
-   const char *s;
 
    if (!(re = calloc(1, sizeof(Render_Engine)))) return NULL;
 
@@ -98,14 +96,14 @@ _output_xlib_setup(int w, int h, int rot, Display *disp, Drawable draw,
 //   re->ob->onebuf = 1;
 
    evas_software_xlib_outbuf_debug_set(ob, debug);
-   if (!evas_render_engine_software_generic_init(&re->generic, ob, NULL,
+   if (!evas_render_engine_software_generic_init(engine, &re->generic, ob, NULL,
                                                  evas_software_xlib_outbuf_get_rot,
                                                  evas_software_xlib_outbuf_reconfigure,
                                                  NULL,
                                                  NULL,
                                                  evas_software_xlib_outbuf_new_region_for_update,
                                                  evas_software_xlib_outbuf_push_updated_region,
-                                                 evas_software_xlib_outbuf_free_region_for_update,
+                                                 NULL,
                                                  evas_software_xlib_outbuf_idle_flush,
                                                  evas_software_xlib_outbuf_flush,
                                                  NULL,
@@ -113,20 +111,7 @@ _output_xlib_setup(int w, int h, int rot, Display *disp, Drawable draw,
                                                  w, h))
      goto on_error;
 
-   if ((s = getenv("EVAS_SOFTWARE_PARTIAL_MERGE")))
-     {
-        if ((!strcmp(s, "bounding")) ||
-            (!strcmp(s, "b")))
-          merge_mode = MERGE_BOUNDING;
-        else if ((!strcmp(s, "full")) ||
-                 (!strcmp(s, "f")))
-          merge_mode = MERGE_FULL;
-        else if ((!strcmp(s, "smart")) ||
-                 (!strcmp(s, "s")))
-          merge_mode = MERGE_SMART;
-     }
-
-   evas_render_engine_software_generic_merge_mode_set(&re->generic, merge_mode);
+   evas_render_engine_software_generic_merge_mode_set(&re->generic);
 
    return re;
 
@@ -137,7 +122,7 @@ on_error:
 }
 
 static void *
-_output_swapbuf_setup(int w, int h, int rot, Display *disp, Drawable draw,
+_output_swapbuf_setup(void *engine, int w, int h, int rot, Display *disp, Drawable draw,
                       Visual *vis, Colormap cmap, int depth,
                       int debug EINA_UNUSED,
                       int grayscale, int max_colors, Pixmap mask,
@@ -159,7 +144,7 @@ _output_swapbuf_setup(int w, int h, int rot, Display *disp, Drawable draw,
                                         destination_alpha);
    if (!ob) goto on_error;
 
-   if (!evas_render_engine_software_generic_init(&re->generic, ob,
+   if (!evas_render_engine_software_generic_init(engine, &re->generic, ob,
                                                  evas_software_xlib_swapbuf_buffer_state_get,
                                                  evas_software_xlib_swapbuf_get_rot,
                                                  evas_software_xlib_swapbuf_reconfigure,
@@ -167,7 +152,7 @@ _output_swapbuf_setup(int w, int h, int rot, Display *disp, Drawable draw,
                                                  NULL,
                                                  evas_software_xlib_swapbuf_new_region_for_update,
                                                  evas_software_xlib_swapbuf_push_updated_region,
-                                                 evas_software_xlib_swapbuf_free_region_for_update,
+                                                 NULL,
                                                  evas_software_xlib_swapbuf_idle_flush,
                                                  evas_software_xlib_swapbuf_flush,
                                                  NULL,
@@ -231,36 +216,22 @@ _symbols(void)
 }
 
 /* engine api this module provides */
-static void *
-eng_info(Evas *eo_e EINA_UNUSED)
-{
-   Evas_Engine_Info_Software_X11 *info;
-
-   if (!(info = calloc(1, sizeof(Evas_Engine_Info_Software_X11))))
-     return NULL;
-
-   info->magic.magic = rand();
-   info->info.debug = 0;
-   info->info.alloc_grayscale = 0;
-   info->info.alloc_colors_max = 216;
-   info->func.best_visual_get = _best_visual_get;
-   info->func.best_colormap_get = _best_colormap_get;
-   info->func.best_depth_get = _best_depth_get;
-   info->render_mode = EVAS_RENDER_MODE_BLOCKING;
-   return info;
-}
-
 static void
-eng_info_free(Evas *eo_e EINA_UNUSED, void *info)
+eng_output_info_setup(void *info)
 {
-   Evas_Engine_Info_Software_X11 *in;
+   Evas_Engine_Info_Software_X11 *einfo = info;
 
-   in = (Evas_Engine_Info_Software_X11 *)info;
-   free(in);
+   einfo->info.debug = 0;
+   einfo->info.alloc_grayscale = 0;
+   einfo->info.alloc_colors_max = 216;
+   einfo->func.best_visual_get = _best_visual_get;
+   einfo->func.best_colormap_get = _best_colormap_get;
+   einfo->func.best_depth_get = _best_depth_get;
+   einfo->render_mode = EVAS_RENDER_MODE_BLOCKING;
 }
 
 static void *
-eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
+eng_output_setup(void *engine, void *in, unsigned int w, unsigned int h)
 {
    Evas_Engine_Info_Software_X11 *info = in;
    Render_Engine *re = NULL;
@@ -281,7 +252,7 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
      }
 
    if (try_swapbuf)
-     re = _output_swapbuf_setup(w, h,
+     re = _output_swapbuf_setup(engine, w, h,
                                 info->info.rotation, info->info.connection,
                                 info->info.drawable, info->info.visual,
                                 info->info.colormap,
@@ -293,7 +264,7 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
    if (re) re->outbuf_alpha_get = evas_software_xlib_swapbuf_alpha_get;
    else
      {
-        re = _output_xlib_setup(w, h,
+        re = _output_xlib_setup(engine, w, h,
                                 info->info.rotation, info->info.connection,
                                 info->info.drawable, info->info.visual,
                                 info->info.colormap,
@@ -311,7 +282,7 @@ eng_setup(void *engine EINA_UNUSED, void *in, unsigned int w, unsigned int h)
 }
 
 static int
-eng_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w, unsigned int h)
+eng_output_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w, unsigned int h)
 {
    Evas_Engine_Info_Software_X11 *info = in;
    Render_Engine *re = data;
@@ -370,14 +341,14 @@ eng_update(void *engine EINA_UNUSED, void *data, void *in, unsigned int w, unsig
 }
 
 static void
-eng_output_free(void *engine EINA_UNUSED, void *data)
+eng_output_free(void *engine, void *data)
 {
    Render_Engine *re;
 
    if ((re = (Render_Engine *)data))
      {
         _outbufs = eina_list_remove(_outbufs, re->generic.ob);
-        evas_render_engine_software_generic_clean(&re->generic);
+        evas_render_engine_software_generic_clean(engine, &re->generic);
         _output_egl_shutdown(re);
         free(re);
      }
@@ -574,7 +545,7 @@ module_open(Evas_Module *em)
    if (!em) return 0;
 
    /* get whatever engine module we inherit from */
-   if (!_evas_module_engine_inherit(&pfunc, "software_generic")) return 0;
+   if (!_evas_module_engine_inherit(&pfunc, "software_generic", sizeof (Evas_Engine_Info_Software_X11))) return 0;
 
    _evas_engine_soft_x11_log_dom =
      eina_log_domain_register("evas-software_x11", EVAS_DEFAULT_LOG_COLOR);
@@ -590,10 +561,9 @@ module_open(Evas_Module *em)
 
    /* now to override methods */
 #define ORD(f) EVAS_API_OVERRIDE(f, &func, eng_)
-   ORD(info);
-   ORD(info_free);
-   ORD(setup);
-   ORD(update);
+   ORD(output_info_setup);
+   ORD(output_setup);
+   ORD(output_update);
    ORD(canvas_alpha_get);
    ORD(output_free);
    ORD(image_native_init);
