@@ -317,12 +317,6 @@ evas_software_xlib_swapbuf_new_region_for_update(Outbuf *buf, int x, int y, int
    return NULL;
 }
 
-void
-evas_software_xlib_swapbuf_free_region_for_update(Outbuf *buf EINA_UNUSED, RGBA_Image *update EINA_UNUSED)
-{
-   /* no need to do anything - they are cleaned up on flush */
-}
-
 void
 evas_software_xlib_swapbuf_flush(Outbuf *buf, Tilebuf_Rect *surface_damage EINA_UNUSED, Tilebuf_Rect *buffer_damage EINA_UNUSED, Evas_Render_Mode render_mode)
 {
@@ -602,12 +596,10 @@ evas_software_xlib_swapbuf_alpha_get(Outbuf *buf)
    return buf->priv.destination_alpha;
 }
 
-Render_Engine_Swap_Mode
+Render_Output_Swap_Mode
 evas_software_xlib_swapbuf_buffer_state_get(Outbuf *buf)
 {
-   Render_Engine_Swap_Mode mode;
    if (!buf->priv.swapper) return MODE_FULL;
-   mode = evas_xlib_swapper_buffer_state_get(buf->priv.swapper);
-   return mode;
+   return evas_xlib_swapper_buffer_state_get(buf->priv.swapper);
 }
 
