@@ -1,6 +1,8 @@
 #ifndef _EVAS_ENGINE_WAYLAND_COMMON_H
 # define _EVAS_ENGINE_WAYLAND_COMMON_H
 
+#include "Ecore_Wl2.h"
+
 typedef struct _Evas_Engine_Info_Wayland Evas_Engine_Info_Wayland;
 
 struct _Evas_Engine_Info_Wayland
@@ -12,13 +14,8 @@ struct _Evas_Engine_Info_Wayland
    /* engine specific data & parameters it needs to set up */
    struct
      {
-        /* the wayland shm object used to create new shm pool */
-        struct wl_shm *wl_shm;
-        struct zwp_linux_dmabuf_v1 *wl_dmabuf;
-        struct wl_display *wl_display;
-        struct wl_surface *wl_surface;
-        int depth, rotation, edges;
-        int compositor_version;
+        Ecore_Wl2_Window *wl2_win;
+        int depth, rotation;
         Eina_Bool destination_alpha : 1;
         Eina_Bool hidden : 1;
      } info;
