@@ -28,7 +28,7 @@
 typedef struct _Render_Engine Render_Engine;
 struct _Render_Engine
 {
-   Render_Engine_GL_Generic generic;
+   Render_Output_GL_Generic generic;
 };
 
 /* local function prototypes */
@@ -279,11 +279,13 @@ evgl_eng_native_window_create(void *data)
    Render_Engine *re;
    Outbuf *ob;
    struct wl_egl_window *win;
+   struct wl_surface *wls;
 
    if (!(re = (Render_Engine *)data)) return NULL;
    if (!(ob = eng_get_ob(re))) return NULL;
 
-   if (!(win = wl_egl_window_create(ob->info->info.wl_surface, 1, 1)))
+   wls = ecore_wl2_window_surface_get(ob->info->info.wl2_win);
+   if (!(win = wl_egl_window_create(wls, 1, 1)))
      {
         ERR("Could not create wl_egl window");
         return NULL;
@@ -500,34 +502,18 @@ static const EVGL_Interface evgl_funcs =
 };
 
 /* engine functions */
-static void *
-eng_info(Evas *evas EINA_UNUSED)
-{
-   Evas_Engine_Info_Wayland *info;
-
-   /* try to allocate space for our engine info */
-   if (!(info = calloc(1, sizeof(Evas_Engine_Info_Wayland))))
-     return NULL;
-
-   info->magic.magic = rand();
-   info->render_mode = EVAS_RENDER_MODE_BLOCKING;
-
-   return info;
-}
-
 static void
-eng_info_free(Evas *evas EINA_UNUSED, void *info)
+eng_output_info_setup(void *info)
 {
-   Evas_Engine_Info_Wayland *inf;
+   Evas_Engine_Info_Wayland *in = info;
 
-   if ((inf = (Evas_Engine_Info_Wayland *)info))
-     free(inf);
+   in->render_mode = EVAS_RENDER_MODE_BLOCKING;
 }
 
-static Render_Engine_Swap_Mode
+static Render_Output_Swap_Mode
 _eng_swap_mode_get(void)
 {
-   Render_Engine_Swap_Mode swap_mode = MODE_FULL;
+   Render_Output_Swap_Mode swap_mode = MODE_FULL;
    const char *s;
 
    if ((s = getenv("EVAS_GL_SWAP_MODE")))
@@ -559,36 +545,15 @@ _eng_swap_mode_get(void)
    return swap_mode;
 }
 
-static Render_Engine_Merge_Mode
-_eng_merge_mode_get(void)
-{
-   Render_Engine_Merge_Mode merge = MERGE_SMART;
-   const char *s;
-
-   if ((s = getenv("EVAS_GL_PARTIAL_MERGE")))
-     {
-        if ((!strcmp(s, "bounding")) || (!strcmp(s, "b")))
-          merge = MERGE_BOUNDING;
-        else if ((!strcmp(s, "full")) || (!strcmp(s, "f")))
-          merge = MERGE_FULL;
-        else if ((!strcmp(s, "smart")) || (!strcmp(s, "s")))
-          merge = MERGE_SMART;
-     }
-
-   return merge;
-}
-
 static void *
-eng_setup(void *engine EINA_UNUSED, void *info, unsigned int w, unsigned int h)
+eng_output_setup(void *engine, void *info, unsigned int w, unsigned int h)
 {
    Evas_Engine_Info_Wayland *inf = info;
    Render_Engine *re;
    Outbuf *ob;
-   Render_Engine_Swap_Mode swap_mode;
-   Render_Engine_Merge_Mode merge;
+   Render_Output_Swap_Mode swap_mode;
 
    swap_mode = _eng_swap_mode_get();
-   merge = _eng_merge_mode_get();
 
    /* FIXME: Remove this line as soon as eglGetDisplay() autodetection
     * gets fixed. Currently it is incorrectly detecting wl_display and
@@ -611,7 +576,7 @@ eng_setup(void *engine EINA_UNUSED, void *info, unsigned int w, unsigned int h)
    ob = eng_window_new(inf, w, h, swap_mode);
    if (!ob) goto ob_err;
 
-   if (!evas_render_engine_gl_generic_init(&re->generic, ob,
+   if (!evas_render_engine_gl_generic_init(engine, &re->generic, ob,
                                            eng_outbuf_swap_mode_get,
                                            eng_outbuf_rotation_get,
                                            eng_outbuf_reconfigure,
@@ -619,7 +584,7 @@ eng_setup(void *engine EINA_UNUSED, void *info, unsigned int w, unsigned int h)
                                            eng_outbuf_damage_region_set,
                                            eng_outbuf_update_region_new,
                                            eng_outbuf_update_region_push,
-                                           eng_outbuf_update_region_free,
+                                           NULL,
                                            NULL,
                                            eng_outbuf_flush,
                                            NULL,
@@ -638,7 +603,7 @@ eng_setup(void *engine EINA_UNUSED, void *info, unsigned int w, unsigned int h)
 
    gl_wins++;
 
-   evas_render_engine_software_generic_merge_mode_set(&re->generic.software, merge);
+   evas_render_engine_software_generic_merge_mode_set(&re->generic.software);
 
    if (!initted)
      {
@@ -646,18 +611,6 @@ eng_setup(void *engine EINA_UNUSED, void *info, unsigned int w, unsigned int h)
         initted = EINA_TRUE;
      }
 
-   if (re->generic.software.tb)
-     evas_common_tilebuf_free(re->generic.software.tb);
-   re->generic.software.tb = evas_common_tilebuf_new(w, h);
-
-   if (re->generic.software.tb)
-     {
-        evas_common_tilebuf_set_tile_size(re->generic.software.tb,
-                                          TILESIZE, TILESIZE);
-        evas_render_engine_software_generic_tile_strict_set
-          (&re->generic.software, EINA_TRUE);
-     }
-
    eng_window_use(eng_get_ob(re));
 
    return re;
@@ -668,16 +621,17 @@ ob_err:
 }
 
 static int
-eng_update(void *engine EINA_UNUSED, void *data, void *info, unsigned int w, unsigned int h)
+eng_output_update(void *engine EINA_UNUSED, void *data, void *info, unsigned int w, unsigned int h)
 {
    Evas_Engine_Info_Wayland *inf = info;
+   struct wl_surface *wls;
    Render_Engine *re = data;
    Outbuf *ob;
 
    ob = eng_get_ob(re);
    if (!ob)
      {
-        Render_Engine_Swap_Mode swap_mode = MODE_AUTO;
+        Render_Output_Swap_Mode swap_mode = MODE_AUTO;
 
         swap_mode = _eng_swap_mode_get();
         ob = eng_window_new(inf, w, h, swap_mode);
@@ -689,13 +643,14 @@ eng_update(void *engine EINA_UNUSED, void *data, void *info, unsigned int w, uns
         return 1;
      }
 
-   if (!inf->info.wl_surface && (ob->egl_surface != EGL_NO_SURFACE))
+   wls = ecore_wl2_window_surface_get(inf->info.wl2_win);
+   if (!wls && (ob->egl_surface != EGL_NO_SURFACE))
      {
         eglDestroySurface(ob->egl_disp, ob->egl_surface);
         eglMakeCurrent(ob->egl_disp, EGL_NO_SURFACE, EGL_NO_SURFACE,
                        EGL_NO_CONTEXT);
         ob->egl_surface = EGL_NO_SURFACE;
-        ob->surface = NULL;
+        ob->wl2_win = NULL;
         evas_render_engine_software_generic_update(&re->generic.software,
                                                    NULL, w, h);
         return 1;
@@ -703,9 +658,11 @@ eng_update(void *engine EINA_UNUSED, void *data, void *info, unsigned int w, uns
 
    if (ob)
      {
+        Ecore_Wl2_Display *ewd;
         ob->info = inf;
-        if ((ob->info->info.wl_display != ob->disp) ||
-            (ob->info->info.wl_surface != ob->surface) ||
+        ewd = ecore_wl2_window_display_get(ob->info->info.wl2_win);
+        if ((ewd != ob->wl2_disp) ||
+            (ob->info->info.wl2_win != ob->wl2_win) ||
             /* FIXME: comment out below line.
              * since there is no place set the info->info.win for now,
              * it causes renew the window unnecessarily.
@@ -714,10 +671,10 @@ eng_update(void *engine EINA_UNUSED, void *data, void *info, unsigned int w, uns
             (ob->info->info.depth != ob->depth) ||
             (ob->info->info.destination_alpha != ob->alpha))
           {
-             Render_Engine_Swap_Mode swap_mode = MODE_AUTO;
+             Render_Output_Swap_Mode swap_mode = MODE_AUTO;
 
              gl_wins--;
-             if (!ob->info->info.wl_display)
+             if (!ewd)
                {
                   eng_window_free(ob);
                   re->generic.software.ob = NULL;
@@ -730,8 +687,6 @@ eng_update(void *engine EINA_UNUSED, void *data, void *info, unsigned int w, uns
 
              eng_window_use(ob);
 
-             evas_render_engine_software_generic_update(&re->generic.software,
-                                                        ob, w, h);
              gl_wins++;
           }
         else if ((ob->w != (int)w) || (ob->h != (int)h) ||
@@ -744,18 +699,8 @@ eng_update(void *engine EINA_UNUSED, void *data, void *info, unsigned int w, uns
 
    if (!eng_get_ob(re)) goto ob_err;
 
-   if (re->generic.software.tb)
-     evas_common_tilebuf_free(re->generic.software.tb);
-   re->generic.software.tb = evas_common_tilebuf_new(w, h);
-
-   if (re->generic.software.tb)
-     {
-        evas_common_tilebuf_set_tile_size(re->generic.software.tb,
-                                          TILESIZE, TILESIZE);
-        evas_render_engine_software_generic_tile_strict_set
-          (&re->generic.software, EINA_TRUE);
-     }
-
+   evas_render_engine_software_generic_update(&re->generic.software,
+                                              ob, w, h);
    eng_window_use(eng_get_ob(re));
 
    return 1;
@@ -776,7 +721,7 @@ eng_canvas_alpha_get(void *engine)
 }
 
 static void
-eng_output_free(void *engine EINA_UNUSED, void *data)
+eng_output_free(void *engine, void *data)
 {
    Render_Engine *re;
 
@@ -786,7 +731,7 @@ eng_output_free(void *engine EINA_UNUSED, void *data)
 
         if (gl_wins == 1) glsym_evgl_engine_shutdown(re);
 
-        evas_render_engine_software_generic_clean(&re->generic.software);
+        evas_render_engine_software_generic_clean(engine, &re->generic.software);
 
         gl_wins--;
 
@@ -805,9 +750,10 @@ eng_output_dump(void *engine EINA_UNUSED, void *data)
 {
    Outbuf *ob;
    Render_Engine *re;
+   Render_Engine_GL_Generic *e = engine;
 
    if (!(re = (Render_Engine *)data)) return;
-
+   generic_cache_dump(e->software.surface_cache);
    evas_common_image_image_all_unload();
    evas_common_font_font_all_unload();
    ob = eng_get_ob(re);
@@ -1058,7 +1004,6 @@ eng_image_native_shutdown(void *engine EINA_UNUSED, Evas_Native_Surface_Type typ
 static void *
 eng_image_native_set(void *engine, void *image, void *native)
 {
-   Render_Engine *re;
    Outbuf *ob;
    Native *n;
    Evas_Native_Surface *ns;
@@ -1068,8 +1013,8 @@ eng_image_native_set(void *engine, void *image, void *native)
    void *buffer = NULL;
    void *wlid, *wl_buf = NULL;
 
-   if (!(re = (Render_Engine *)engine)) return NULL;
-   if (!(ob = eng_get_ob(re))) return NULL;
+   ob = gl_generic_any_output_get(engine);
+   if (!ob) return NULL;
 
    ns = native;
 
@@ -1138,18 +1083,14 @@ eng_image_native_set(void *engine, void *image, void *native)
          }
      }
 
-   if ((!ns) && (!img->native.data)) return img;
-
    eng_window_use(ob);
 
-   if (img->native.data)
+   if (!ns)
      {
-        if (img->native.func.free)
-          img->native.func.free(img);
-        glsym_evas_gl_common_image_native_disable(img);
+        glsym_evas_gl_common_image_free(img);
+        return NULL;
      }
 
-   if (!ns) return img;
 
    if (ns->type == EVAS_NATIVE_SURFACE_WL)
      {
@@ -1430,7 +1371,7 @@ module_open(Evas_Module *em)
    if (!em) return 0;
 
    /* get whatever engine module we inherit from */
-   if (!_evas_module_engine_inherit(&pfunc, "gl_generic")) return 0;
+   if (!_evas_module_engine_inherit(&pfunc, "gl_generic", sizeof (Evas_Engine_Info_Wayland))) return 0;
 
    /* setup logging domain */
    if (_evas_engine_wl_egl_log_dom < 0)
@@ -1450,10 +1391,9 @@ module_open(Evas_Module *em)
 
 #define ORD(f) EVAS_API_OVERRIDE(f, &func, eng_)
 
-   ORD(info);
-   ORD(info_free);
-   ORD(setup);
-   ORD(update);
+   ORD(output_info_setup);
+   ORD(output_setup);
+   ORD(output_update);
    ORD(canvas_alpha_get);
 
    ORD(output_free);
