@@ -4,7 +4,7 @@
 
 #include <stdio.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
