@@ -19,7 +19,7 @@
 # include <netinet/in.h>
 #endif
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
