@@ -6,7 +6,7 @@
 #include <sys/types.h>
 #include <fcntl.h>
 
-#ifdef HAVE_EVIL
+#ifdef _WIN32
 # include <Evil.h>
 #endif
 
