@@ -22,8 +22,8 @@ M.nspace_to_path = function(ns)
     return ns:gsub(":", path_sep):gsub(rep_sep, path_sep):lower()
 end
 
-M.make_page = function(path)
-    return M.path_join(doc_root, "auto", path .. ".txt")
+M.make_page = function(path, ext)
+    return M.path_join(doc_root, path .. "." .. ext)
 end
 
 M.get_root_ns = function()
@@ -31,7 +31,7 @@ M.get_root_ns = function()
 end
 
 M.mkdir_r = function(dirn)
-    assert(cutil.file_mkpath(M.path_join(doc_root, "auto", dirn)))
+    assert(cutil.file_mkpath(M.path_join(doc_root, dirn)))
 end
 
 M.mkdir_p = function(path)
@@ -39,7 +39,7 @@ M.mkdir_p = function(path)
 end
 
 M.rm_root = function()
-    cutil.file_rmrf(M.path_join(doc_root, "auto"))
+    cutil.file_rmrf(doc_root)
 end
 
 M.init = function(root, rns)
