@@ -210,7 +210,13 @@ static void set_wordbreaks(
                 posLast = posCur;
                 break;
             }
-            /* Fall off */
+#ifndef __has_attribute
+# define __has_attribute(x) 0
+#endif
+#if __has_attribute(fallthrough)
+           __attribute__((fallthrough));
+#endif
+           /* Fall off */
 
         case WBP_Newline:
             /* WB3a,3b */
@@ -323,7 +329,13 @@ static void set_wordbreaks(
                 wbcSeqStart = wbcCur;
                 posLast = posCur;
             }
-            /* No break on purpose */
+#ifndef __has_attribute
+# define __has_attribute(x) 0
+#endif
+#if __has_attribute(fallthrough)
+           __attribute__((fallthrough));
+#endif
+           /* No break on purpose */
         case WBP_MidNumLet:
             if (((wbcLast == WBP_ALetter) ||
                         (wbcLast == WBP_Hebrew_Letter)) || /* WB6,7 */
