@@ -14,8 +14,8 @@
 
 /////////////////timeout function
 
-#define TEST_TIMEOUT_SEC 10
-#define TEST_OPERATION_DELAY 0.5
+#define TEST_TIMEOUT_SEC 1
+#define TEST_OPERATION_DELAY 0.05
 
 static Ecore_Timer *test_timeout_timer;
 
@@ -106,14 +106,16 @@ static Eina_Bool _modify_attrib_file(void *data)
 
 static Eina_Bool _check_event_path(void *data, void *event)
 {
-   ck_assert_str_eq((const char*)data, ((Eio_Monitor_Event*)event)->filename);
+   const char *f = ((Eio_Monitor_Event*)event)->filename;
+    /* ignore directory creation events */
+   if (ecore_file_is_dir(f)) return ECORE_CALLBACK_RENEW;
+   ck_assert_str_eq((const char*)data, f);
    return EINA_TRUE;
 }
 
 static Eina_Tmpstr *_common_init()
 {
    Eina_Tmpstr *dirname;
-   fail_if(eio_init() != 1);
    ecore_file_init();
 
    //test timeout
@@ -127,36 +129,31 @@ static void _common_shutdown(Eina_Tmpstr *dirname)
 {
    _delete_directory((void*)dirname);
    ecore_file_shutdown();
-   fail_if(eio_shutdown() != 0);
    eina_tmpstr_del(dirname);
+   _cancel_timeout();
 }
 
 /////// tests monitoring a directory
 
-START_TEST(eio_test_monitor_add_and_remove)
+EFL_START_TEST(eio_test_monitor_add_and_remove)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
    Eio_Monitor *monitor;
 
-   filename = eina_stringshare_printf("%s/eio_test_monitor_directory_file_created_notify", dirname);
+   filename = eina_stringshare_printf("%s/eio_test_monitor_add_and_remove", dirname);
    _create_directory((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    monitor = eio_monitor_add(filename);
 
-   usleep(500000);
-
    eio_monitor_del(monitor);
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eio_test_monitor_add_remove_add)
+EFL_START_TEST(eio_test_monitor_add_remove_add)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -166,23 +163,18 @@ START_TEST(eio_test_monitor_add_remove_add)
    filename = eina_stringshare_printf("%s/eio_test_monitor_add_remove_add", dirname);
    _create_directory((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    monitor1 = eio_monitor_add(filename);
    eio_monitor_del(monitor1);
 
-   usleep(500000);
-
    monitor2 = eio_monitor_add(filename);
    eio_monitor_del(monitor2);
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eio_test_monitor_add_add_remove_remove)
+EFL_START_TEST(eio_test_monitor_add_add_remove_remove)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename1;
@@ -195,19 +187,16 @@ START_TEST(eio_test_monitor_add_add_remove_remove)
    _create_directory((void*)filename1);
    _create_directory((void*)filename2);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    monitor1 = eio_monitor_add(filename1);
    monitor2 = eio_monitor_add(filename2);
-   usleep(500000);
+
    eio_monitor_del(monitor2);
    eio_monitor_del(monitor1);
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _file_created_cb(void *data, int type, void *event)
 {
@@ -220,16 +209,13 @@ static void _file_created_cb(void *data, int type, void *event)
 }
 
 
-START_TEST(eio_test_monitor_directory_file_created_notify)
+EFL_START_TEST(eio_test_monitor_directory_file_created_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
 
    filename = eina_stringshare_printf("%s/eio_test_monitor_directory_file_created_notify", dirname);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_FILE_CREATED, (Ecore_Event_Handler_Cb)_file_created_cb, filename);
@@ -240,7 +226,7 @@ START_TEST(eio_test_monitor_directory_file_created_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 struct {
    Eina_Stringshare *s;
@@ -276,7 +262,7 @@ _multi_file_created_cb(void *data EINA_UNUSED, int type, void *event)
    ecore_main_loop_quit();
 }
 
-START_TEST(eio_test_monitor_directory_multi_file_created_notify)
+EFL_START_TEST(eio_test_monitor_directory_multi_file_created_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
 
@@ -284,9 +270,6 @@ START_TEST(eio_test_monitor_directory_multi_file_created_notify)
    multi_files[1].s = eina_stringshare_printf("%s/eio_test_monitor_directory_m2file_created_notify", dirname);
    multi_files[2].s = eina_stringshare_printf("%s/eio_test_monitor_directory_m3file_created_notify", dirname);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_FILE_CREATED, (Ecore_Event_Handler_Cb)_multi_file_created_cb, NULL);
@@ -299,7 +282,7 @@ START_TEST(eio_test_monitor_directory_multi_file_created_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _file_deleted_cb(void *data, int type, void *event)
 {
@@ -311,7 +294,7 @@ static void _file_deleted_cb(void *data, int type, void *event)
      }
 }
 
-START_TEST(eio_test_monitor_directory_file_deleted_notify)
+EFL_START_TEST(eio_test_monitor_directory_file_deleted_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -319,9 +302,6 @@ START_TEST(eio_test_monitor_directory_file_deleted_notify)
    filename = eina_stringshare_printf("%s/eio_test_monitor_directory_file_deleted_notify", dirname);
    _create_file((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_FILE_DELETED, (Ecore_Event_Handler_Cb)_file_deleted_cb, filename);
@@ -332,7 +312,7 @@ START_TEST(eio_test_monitor_directory_file_deleted_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _file_modified_cb(void *data, int type, void *event)
 {
@@ -344,7 +324,7 @@ static void _file_modified_cb(void *data, int type, void *event)
      }
 }
 
-START_TEST(eio_test_monitor_directory_file_modified_notify)
+EFL_START_TEST(eio_test_monitor_directory_file_modified_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -352,9 +332,6 @@ START_TEST(eio_test_monitor_directory_file_modified_notify)
    filename = eina_stringshare_printf("%s/eio_test_monitor_directory_file_modified_notify", dirname);
    _create_file((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_FILE_MODIFIED, (Ecore_Event_Handler_Cb)_file_modified_cb, filename);
@@ -366,7 +343,7 @@ START_TEST(eio_test_monitor_directory_file_modified_notify)
    //cleanup
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _file_closed_cb(void *data, int type, void *event)
 {
@@ -378,27 +355,30 @@ static void _file_closed_cb(void *data, int type, void *event)
      }
 }
 
-START_TEST(eio_test_monitor_directory_file_closed_notify)
+EFL_START_TEST(eio_test_monitor_directory_file_closed_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
+   Eio_Monitor *monitor;
 
    filename = eina_stringshare_printf("%s/eio_test_monitor_directory_file_closed_notify", dirname);
    _create_file((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
-   eio_monitor_add(dirname);
-   ecore_event_handler_add(EIO_MONITOR_FILE_CLOSED, (Ecore_Event_Handler_Cb)_file_closed_cb, filename);
-   ecore_timer_add(TEST_OPERATION_DELAY, _modify_file, filename);
+   monitor = eio_monitor_add(dirname);
+   if (eio_monitor_fallback_check(monitor))
+     printf("skipping %s: using fallback monitoring\n", "eio_test_monitor_directory_file_closed_notify");
+   else
+     {
+        ecore_event_handler_add(EIO_MONITOR_FILE_CLOSED, (Ecore_Event_Handler_Cb)_file_closed_cb, filename);
+        ecore_timer_add(TEST_OPERATION_DELAY, _modify_file, filename);
 
-   ecore_main_loop_begin();
+        ecore_main_loop_begin();
+     }
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _directory_created_cb(void *data, int type, void *event)
 {
@@ -410,16 +390,13 @@ static void _directory_created_cb(void *data, int type, void *event)
      }
 }
 
-START_TEST(eio_test_monitor_directory_directory_created_notify)
+EFL_START_TEST(eio_test_monitor_directory_directory_created_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
 
    filename = eina_stringshare_printf("%s/eio_test_monitor_directory_directory_created_notify", dirname);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_DIRECTORY_CREATED, (Ecore_Event_Handler_Cb)_directory_created_cb, filename);
@@ -430,7 +407,7 @@ START_TEST(eio_test_monitor_directory_directory_created_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _directory_deleted_cb(void *data, int type, void *event)
 {
@@ -442,7 +419,7 @@ static void _directory_deleted_cb(void *data, int type, void *event)
      }
 }
 
-START_TEST(eio_test_monitor_directory_directory_deleted_notify)
+EFL_START_TEST(eio_test_monitor_directory_directory_deleted_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -450,9 +427,6 @@ START_TEST(eio_test_monitor_directory_directory_deleted_notify)
    filename = eina_stringshare_printf("%s/eio_test_monitor_directory_directory_deleted_notify", dirname);
    _create_directory((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_DIRECTORY_DELETED, (Ecore_Event_Handler_Cb)_directory_deleted_cb, filename);
@@ -463,7 +437,7 @@ START_TEST(eio_test_monitor_directory_directory_deleted_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _directory_modified_cb(void *data, int type, void *event)
 {
@@ -476,7 +450,7 @@ static void _directory_modified_cb(void *data, int type, void *event)
 }
 
 
-START_TEST(eio_test_monitor_directory_directory_modified_notify)
+EFL_START_TEST(eio_test_monitor_directory_directory_modified_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -484,9 +458,6 @@ START_TEST(eio_test_monitor_directory_directory_modified_notify)
    filename = eina_stringshare_printf("%s/eio_test_monitor_directory_directory_modified_notify", dirname);
    _create_directory((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_DIRECTORY_MODIFIED, (Ecore_Event_Handler_Cb)_directory_modified_cb, filename);
@@ -497,7 +468,7 @@ START_TEST(eio_test_monitor_directory_directory_modified_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 
 static void _directory_self_deleted_cb(void *data, int type, void *event)
@@ -511,13 +482,10 @@ static void _directory_self_deleted_cb(void *data, int type, void *event)
 }
 
 
-START_TEST(eio_test_monitor_directory_directory_self_deleted_notify)
+EFL_START_TEST(eio_test_monitor_directory_directory_self_deleted_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    ecore_event_handler_add(EIO_MONITOR_SELF_DELETED, (Ecore_Event_Handler_Cb)_directory_self_deleted_cb, dirname);
@@ -528,11 +496,11 @@ START_TEST(eio_test_monitor_directory_directory_self_deleted_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 //////// test monitoring a single file
 
-START_TEST(eio_test_monitor_file_file_modified_notify)
+EFL_START_TEST(eio_test_monitor_file_file_modified_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -540,9 +508,6 @@ START_TEST(eio_test_monitor_file_file_modified_notify)
    filename = eina_stringshare_printf("%s/filecreated", dirname);
    _create_file((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor file
    eio_monitor_add(filename);
    ecore_event_handler_add(EIO_MONITOR_FILE_MODIFIED, (Ecore_Event_Handler_Cb)_file_modified_cb, filename);
@@ -554,9 +519,9 @@ START_TEST(eio_test_monitor_file_file_modified_notify)
    //cleanup
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eio_test_monitor_file_file_attrib_modified_notify)
+EFL_START_TEST(eio_test_monitor_file_file_attrib_modified_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -564,9 +529,6 @@ START_TEST(eio_test_monitor_file_file_attrib_modified_notify)
    filename = eina_stringshare_printf("%s/eio_test_monitor_file_file_attrib_modified_notify", dirname);
    _create_file((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor file
    eio_monitor_add(filename);
    ecore_event_handler_add(EIO_MONITOR_FILE_MODIFIED, (Ecore_Event_Handler_Cb)_file_modified_cb, filename);
@@ -577,32 +539,35 @@ START_TEST(eio_test_monitor_file_file_attrib_modified_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 
-START_TEST(eio_test_monitor_file_file_closed_notify)
+EFL_START_TEST(eio_test_monitor_file_file_closed_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
+   Eio_Monitor *monitor;
 
    filename = eina_stringshare_printf("%s/eio_test_monitor_file_file_closed_notify", dirname);
    _create_file((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor file
-   eio_monitor_add(dirname);
-   ecore_event_handler_add(EIO_MONITOR_FILE_CLOSED, (Ecore_Event_Handler_Cb)_file_closed_cb, filename);
-   ecore_timer_add(TEST_OPERATION_DELAY, _modify_file, filename);
+   monitor = eio_monitor_add(dirname);
+   if (eio_monitor_fallback_check(monitor))
+     printf("skipping %s: using fallback monitoring\n", "eio_test_monitor_file_file_closed_notify");
+   else
+     {
+        ecore_event_handler_add(EIO_MONITOR_FILE_CLOSED, (Ecore_Event_Handler_Cb)_file_closed_cb, filename);
+        ecore_timer_add(TEST_OPERATION_DELAY, _modify_file, filename);
 
-   ecore_main_loop_begin();
+        ecore_main_loop_begin();
+     }
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eio_test_monitor_file_file_self_deleted_notify)
+EFL_START_TEST(eio_test_monitor_file_file_self_deleted_notify)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -610,9 +575,6 @@ START_TEST(eio_test_monitor_file_file_self_deleted_notify)
    filename = eina_stringshare_printf("%s/eio_test_monitor_file_file_self_deleted_notify", dirname);
    _create_file((void*)filename);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor file
    eio_monitor_add(filename);
    ecore_event_handler_add(EIO_MONITOR_SELF_DELETED, (Ecore_Event_Handler_Cb)_directory_self_deleted_cb, filename);
@@ -623,9 +585,9 @@ START_TEST(eio_test_monitor_file_file_self_deleted_notify)
 
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eio_test_monitor_two_monitors_one_event)
+EFL_START_TEST(eio_test_monitor_two_monitors_one_event)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Tmpstr *dirname2;
@@ -635,9 +597,6 @@ START_TEST(eio_test_monitor_two_monitors_one_event)
    eina_file_mkdtemp("checkFileCreationXXXXXX", &dirname2);
    filename = eina_stringshare_printf("%s/eio_test_monitor_two_monitors_one_event", dirname);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    eio_monitor_add(dirname);
    eio_monitor_add(dirname2);
@@ -650,10 +609,10 @@ START_TEST(eio_test_monitor_two_monitors_one_event)
    _delete_directory((void*)dirname2);
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 
-START_TEST(eio_test_monitor_two_monitors_one_removed_one_event)
+EFL_START_TEST(eio_test_monitor_two_monitors_one_removed_one_event)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Tmpstr *dirname2;
@@ -665,9 +624,6 @@ START_TEST(eio_test_monitor_two_monitors_one_removed_one_event)
    eina_file_mkdtemp("checkFileCreationXXXXXX", &dirname2);
    filename = eina_stringshare_printf("%s/eio_test_monitor_two_monitors_one_removed", dirname);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    monitor = eio_monitor_add(dirname2);
    eio_monitor_add(dirname);
@@ -681,14 +637,14 @@ START_TEST(eio_test_monitor_two_monitors_one_removed_one_event)
    _delete_directory((void*)dirname2);
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 static void _unexpected_event_cb(void *data EINA_UNUSED, int type EINA_UNUSED, void *event EINA_UNUSED)
 {
    ck_abort_msg("unexpected event");
 }
 
-START_TEST(eio_test_monitor_two_monitors_one_removed_no_event)
+EFL_START_TEST(eio_test_monitor_two_monitors_one_removed_no_event)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Tmpstr *dirname2;
@@ -700,9 +656,6 @@ START_TEST(eio_test_monitor_two_monitors_one_removed_no_event)
    eina_file_mkdtemp("checkFileCreationXXXXXX", &dirname2);
    filename = eina_stringshare_printf("%s/eio_test_monitor_two_monitors_one_removed", dirname);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor directory
    monitor = eio_monitor_add(dirname);
    eio_monitor_add(dirname2);
@@ -710,16 +663,16 @@ START_TEST(eio_test_monitor_two_monitors_one_removed_no_event)
    ecore_event_handler_add(EIO_MONITOR_FILE_CREATED, (Ecore_Event_Handler_Cb)_unexpected_event_cb, filename);
 
    ecore_timer_add(TEST_OPERATION_DELAY, _create_file, filename);
-   ecore_timer_add(TEST_TIMEOUT_SEC - 1, _test_timeout_expected, NULL);
+   ecore_timer_add(0.2, _test_timeout_expected, NULL);
 
    ecore_main_loop_begin();
 
    _delete_directory((void*)dirname2);
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST(eio_test_monitor_two_files_in_same_directory)
+EFL_START_TEST(eio_test_monitor_two_files_in_same_directory)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -730,9 +683,6 @@ START_TEST(eio_test_monitor_two_files_in_same_directory)
    _create_file((void*)filename);
    _create_file((void*)filename2);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor file
    eio_monitor_add(filename);
    eio_monitor_add(filename2);
@@ -745,10 +695,10 @@ START_TEST(eio_test_monitor_two_files_in_same_directory)
    //cleanup
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 
-START_TEST(eio_test_monitor_two_files_in_same_directory_one_removed)
+EFL_START_TEST(eio_test_monitor_two_files_in_same_directory_one_removed)
 {
    Eina_Tmpstr *dirname = _common_init();
    Eina_Stringshare *filename;
@@ -760,9 +710,6 @@ START_TEST(eio_test_monitor_two_files_in_same_directory_one_removed)
    _create_file((void*)filename);
    _create_file((void*)filename2);
 
-   //sleep to avoid catching event generated by above manipulations
-   usleep(500000);
-
    //monitor file
    monitor = eio_monitor_add(filename);
    eio_monitor_add(filename2);
@@ -771,14 +718,14 @@ START_TEST(eio_test_monitor_two_files_in_same_directory_one_removed)
    ecore_event_handler_add(EIO_MONITOR_FILE_MODIFIED, (Ecore_Event_Handler_Cb)_unexpected_event_cb, filename);
 
    ecore_timer_add(TEST_OPERATION_DELAY, _modify_file, filename);
-   ecore_timer_add(TEST_TIMEOUT_SEC - 1, _test_timeout_expected, NULL);
+   ecore_timer_add(0.2, _test_timeout_expected, NULL);
 
    ecore_main_loop_begin();
 
    //cleanup
    _common_shutdown(dirname);
 }
-END_TEST
+EFL_END_TEST
 
 
 void eio_test_monitor(TCase *tc)
