@@ -3,9 +3,9 @@
 
 #include <Eldbus.h>
 
-#define FAKE_SERVER_BUS "org.Enlightenment"
-#define FAKE_SERVER_PATH "/org/enlightenment"
-#define FAKE_SERVER_INTERFACE "org.enlightenment.FakeServer"
+#define FAKE_SERVER_BUS "org.Eldbus.Test"
+#define FAKE_SERVER_PATH "/org/eldbus"
+#define FAKE_SERVER_INTERFACE "org.Eldbus.FakeServer"
 #define FAKE_SERVER_READONLY_PROPERTY "r"
 #define FAKE_SERVER_WRITEONLY_PROPERTY "w"
 #define FAKE_SERVER_READWRITE_PROPERTY "rw"
@@ -23,7 +23,7 @@ struct _Fake_Server_Data
    int pong_response;
 };
 
-Eldbus_Service_Interface *fake_server_start(Fake_Server_Data *data);
+Eldbus_Service_Interface *fake_server_start(Fake_Server_Data *data, const char *name);
 void fake_server_stop(Eldbus_Service_Interface *interface);
 
 #endif
