@@ -10,27 +10,17 @@
 
 #include "eldbus_cxx_suite.h"
 
-START_TEST(eldbus_cxx_session_connection)
+EFL_START_TEST(eldbus_cxx_session_connection)
 {
   efl::ecore::ecore_init ecore_init;
   efl::eldbus::eldbus_init init;
 
   efl::eldbus::connection c(efl::eldbus::session);
 }
-END_TEST
-
-START_TEST(eldbus_cxx_system_connection)
-{
-  efl::ecore::ecore_init ecore_init;
-  efl::eldbus::eldbus_init init;
-
-  efl::eldbus::connection c(efl::eldbus::system);
-}
-END_TEST
+EFL_END_TEST
 
 void
 eldbus_test_connection(TCase* tc)
 {
   tcase_add_test(tc, eldbus_cxx_session_connection);
-  tcase_add_test(tc, eldbus_cxx_system_connection);
 }
