@@ -7,11 +7,12 @@
 #include "elm_suite.h"
 #include "Elementary.h"
 
-START_TEST (elm_code_file_memory_lines)
+EFL_START_TEST (elm_code_file_memory_lines)
 {
    Elm_Code *code;
 
-   elm_init(1, NULL);
+   char *args[] = { "exe" };
+   elm_init(1, args);
    code = elm_code_create();
    ck_assert_uint_eq(0, elm_code_file_lines_get(code->file));
 
@@ -21,15 +22,16 @@ START_TEST (elm_code_file_memory_lines)
    elm_code_free(code);
    elm_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST (elm_code_file_memory_tokens)
+EFL_START_TEST (elm_code_file_memory_tokens)
 {
    Elm_Code_File *file;
    Elm_Code_Line *line;
    Elm_Code *code;
 
-   elm_init(1, NULL);
+   char *args[] = { "exe" };
+   elm_init(1, args);
    code = elm_code_create();
    file = code->file;
    elm_code_file_line_append(file, "a line", 6, NULL);
@@ -40,7 +42,7 @@ START_TEST (elm_code_file_memory_tokens)
    elm_code_free(code);
    elm_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
 void elm_code_file_test_memory(TCase *tc)
 {
