@@ -2,17 +2,36 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_BETA
 #include <Elementary.h>
 #include "elm_suite.h"
 
-START_TEST (elm_colorselector_palette)
+EFL_START_TEST (elm_colorselector_legacy_type_check)
+{
+   Evas_Object *win, *colorselector;
+   const char *type;
+
+   win = win_add(NULL, "colorselector", ELM_WIN_BASIC);
+
+   colorselector = elm_colorselector_add(win);
+
+   type = elm_object_widget_type_get(colorselector);
+   ck_assert(type != NULL);
+   ck_assert(!strcmp(type, "Elm_Colorselector"));
+
+   type = evas_object_type_get(colorselector);
+   ck_assert(type != NULL);
+   ck_assert(!strcmp(type, "elm_colorselector"));
+
+}
+EFL_END_TEST
+
+EFL_START_TEST (elm_colorselector_palette)
 {
    Evas_Object *win, *c;
    unsigned int palette_cnt;
 
-   elm_init(1, NULL);
-   win = elm_win_add(NULL, "check", ELM_WIN_BASIC);
+   win = win_add(NULL, "check", ELM_WIN_BASIC);
 
    c = elm_colorselector_add(win);
    /* Get the count of default palettes */
@@ -29,29 +48,27 @@ START_TEST (elm_colorselector_palette)
    ck_assert(eina_list_count(elm_colorselector_palette_items_get(c)) == palette_cnt);
    evas_object_del(c);
 
-   elm_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST (elm_atspi_role_get)
+EFL_START_TEST (elm_atspi_role_get)
 {
    Evas_Object *win, *c;
-   Elm_Atspi_Role role;
+   Efl_Access_Role role;
 
-   elm_init(1, NULL);
-   win = elm_win_add(NULL, "colorselector", ELM_WIN_BASIC);
+   win = win_add(NULL, "colorselector", ELM_WIN_BASIC);
 
    c = elm_colorselector_add(win);
-   role = elm_interface_atspi_accessible_role_get(c);
+   role = efl_access_object_role_get(c);
 
-   ck_assert(role == ELM_ATSPI_ROLE_COLOR_CHOOSER);
+   ck_assert(role == EFL_ACCESS_ROLE_COLOR_CHOOSER);
 
-   elm_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
 void elm_test_colorselector(TCase *tc)
 {
+   tcase_add_test(tc, elm_colorselector_legacy_type_check);
    tcase_add_test(tc, elm_colorselector_palette);
    tcase_add_test(tc, elm_atspi_role_get);
 }
