@@ -2,36 +2,52 @@
 # include "elementary_config.h"
 #endif
 
-#define ELM_INTERFACE_ATSPI_ACCESSIBLE_PROTECTED
+#define EFL_ACCESS_OBJECT_BETA
 #include <Elementary.h>
 #include "elm_suite.h"
 
-
-START_TEST (elm_atspi_role_get)
+EFL_START_TEST (elm_photocam_legacy_type_check)
 {
    Evas_Object *win, *photocam;
-   Elm_Atspi_Role role;
+   const char *type;
 
-   elm_init(1, NULL);
-   win = elm_win_add(NULL, "photocam", ELM_WIN_BASIC);
+   win = win_add(NULL, "photocam", ELM_WIN_BASIC);
 
    photocam = elm_photocam_add(win);
-   role = elm_interface_atspi_accessible_role_get(photocam);
 
-   ck_assert(role == ELM_ATSPI_ROLE_IMAGE);
+   type = elm_object_widget_type_get(photocam);
+   ck_assert(type != NULL);
+   ck_assert(!strcmp(type, "Elm_Photocam"));
+
+   type = evas_object_type_get(photocam);
+   ck_assert(type != NULL);
+   ck_assert(!strcmp(type, "elm_photocam"));
 
-   elm_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
-START_TEST (efl_ui_image_zoomable_icon)
+EFL_START_TEST (elm_atspi_role_get)
+{
+   Evas_Object *win, *photocam;
+   Efl_Access_Role role;
+
+   win = win_add(NULL, "photocam", ELM_WIN_BASIC);
+
+   photocam = elm_photocam_add(win);
+   role = efl_access_object_role_get(photocam);
+
+   ck_assert(role == EFL_ACCESS_ROLE_IMAGE);
+
+}
+EFL_END_TEST
+
+EFL_START_TEST (efl_ui_image_zoomable_icon)
 {
    Evas_Object *win, *img_zoomable;
    Eina_Bool ok;
    const char *icon_name;
 
-   elm_init(1, NULL);
-   win = elm_win_add(NULL, "photocam", ELM_WIN_BASIC);
+   win = win_add(NULL, "photocam", ELM_WIN_BASIC);
 
    img_zoomable = efl_add(EFL_UI_IMAGE_ZOOMABLE_CLASS, win);
    evas_object_show(img_zoomable);
@@ -46,12 +62,12 @@ START_TEST (efl_ui_image_zoomable_icon)
    icon_name = efl_ui_image_icon_get(img_zoomable);
    ck_assert(icon_name == NULL);
 
-   elm_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
 void elm_test_photocam(TCase *tc)
 {
+   tcase_add_test(tc, elm_photocam_legacy_type_check);
    tcase_add_test(tc, elm_atspi_role_get);
    tcase_add_test(tc, efl_ui_image_zoomable_icon);
 }
