@@ -76,7 +76,7 @@ static const char  *theme_file = NULL;
 static void
 bg_resize(Evas_Coord w, Evas_Coord h)
 {
-   efl_gfx_size_set(o_bg, w, h);
+   efl_gfx_entity_size_set(o_bg, EINA_SIZE2D(w,  h));
 }
 
 static void
@@ -111,12 +111,12 @@ main_delete_request(Ecore_Evas *ee EINA_UNUSED)
 static void
 bg_setup(void)
 {
-   o_bg = efl_add(EDJE_OBJECT_CLASS, evas);
+   o_bg = efl_add(EFL_CANVAS_LAYOUT_CLASS, evas);
    efl_file_set(o_bg, theme_file, "background");
-   efl_gfx_position_set(o_bg, 0, 0);
-   efl_gfx_size_set(o_bg, startw, starth);
+   efl_gfx_entity_position_set(o_bg, EINA_POSITION2D(0, 0));
+   efl_gfx_entity_size_set(o_bg, EINA_SIZE2D(startw,  starth));
    efl_gfx_stack_layer_set(o_bg, -999);
-   efl_gfx_visible_set(o_bg, EINA_TRUE);
+   efl_gfx_entity_visible_set(o_bg, EINA_TRUE);
    evas_object_focus_set(o_bg, EINA_TRUE);
    efl_event_callback_add(o_bg, EFL_EVENT_KEY_DOWN, bg_key_down, NULL);
 }
@@ -354,7 +354,7 @@ video_obj_frame_resize_cb(void *data, const Efl_Event *event)
    evas_object_size_hint_min_set(event->object, iw, ih);
    edje_object_part_swallow(oe, "video_swallow", event->object);
    edje_object_size_min_calc(oe, &w, &h);
-   efl_gfx_size_set(oe, w, h);
+   efl_gfx_entity_size_set(oe, EINA_SIZE2D(w,  h));
    evas_object_size_hint_min_set(event->object, 0, 0);
    edje_object_part_swallow(oe, "video_swallow", event->object);
 }
@@ -434,7 +434,7 @@ video_obj_signal_play_cb(void *data, Evas_Object *o, const char *emission EINA_U
 {
    Evas_Object *ov = data;
    emotion_object_play_set(ov, EINA_TRUE);
-   edje_obj_signal_emit(o, "video_state", "play");
+   efl_layout_signal_emit(o, "video_state", "play");
 }
 
 static void
@@ -442,7 +442,7 @@ video_obj_signal_pause_cb(void *data, Evas_Object *o, const char *emission EINA_
 {
    Evas_Object *ov = data;
    emotion_object_play_set(ov, EINA_FALSE);
-   edje_obj_signal_emit(o, "video_state", "pause");
+   efl_layout_signal_emit(o, "video_state", "pause");
 }
 
 static void
@@ -451,7 +451,7 @@ video_obj_signal_stop_cb(void *data, Evas_Object *o, const char *emission EINA_U
    Evas_Object *ov = data;
    emotion_object_play_set(ov, EINA_FALSE);
    emotion_object_position_set(ov, 0.0);
-   edje_obj_signal_emit(o, "video_state", "stop");
+   efl_layout_signal_emit(o, "video_state", "stop");
 }
 
 static void
@@ -503,7 +503,7 @@ video_obj_signal_frame_move_start_cb(void *data EINA_UNUSED, Evas_Object *o, con
    fd = efl_key_data_get(o, "frame_data");
    if (!fd) return;
    fd->moving = 1;
-   evas_canvas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
+   evas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
    fd->x = x;
    fd->y = y;
    efl_gfx_stack_raise(o);
@@ -528,7 +528,7 @@ video_obj_signal_frame_resize_start_cb(void *data EINA_UNUSED, Evas_Object *o, c
    fd = efl_key_data_get(o, "frame_data");
    if (!fd) return;
    fd->resizing = 1;
-   evas_canvas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
+   evas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
    fd->x = x;
    fd->y = y;
    efl_gfx_stack_raise(o);
@@ -553,21 +553,25 @@ video_obj_signal_frame_move_cb(void *data EINA_UNUSED, Evas_Object *o, const cha
    if (!fd) return;
    if (fd->moving)
      {
-        Evas_Coord x, y, ox, oy;
+        Evas_Coord x, y;
+        Eina_Position2D pos;
 
-        evas_canvas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
-        efl_gfx_position_get(o, &ox, &oy);
-        efl_gfx_position_set(o, ox + (x - fd->x), oy + (y - fd->y));
+        evas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
+        pos = efl_gfx_entity_position_get(o);
+        pos.x += (x - fd->x);
+        pos.y += (y - fd->y);
+        efl_gfx_entity_position_set(o, pos);
         fd->x = x;
         fd->y = y;
      }
    else if (fd->resizing)
      {
-        Evas_Coord x, y, ow, oh;
+        Evas_Coord x, y;
+        Eina_Size2D sz;
 
-        evas_canvas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
-        efl_gfx_size_get(o, &ow, &oh);
-        evas_object_resize(o, ow + (x - fd->x), oh + (y - fd->y));
+        evas_pointer_canvas_xy_get(evas_object_evas_get(o), &x, &y);
+        sz = efl_gfx_entity_size_get(o);
+        evas_object_resize(o, sz.w + (x - fd->x), sz.h + (y - fd->y));
         fd->x = x;
         fd->y = y;
      }
@@ -617,36 +621,36 @@ init_video_object(const char *module_filename, const char *filename)
    fd = calloc(1, sizeof(Frame_Data));
    if (!fd) exit(1);
 
-   oe = efl_add(EDJE_OBJECT_CLASS, evas);
+   oe = efl_add(EFL_CANVAS_LAYOUT_CLASS, evas);
    efl_event_callback_add(oe, EFL_EVENT_DEL, _oe_free_cb, fd);
    efl_key_data_set(oe, "frame_data", fd);
    efl_file_set(oe, theme_file, reflex ? "video_controller/reflex" : "video_controller");
    edje_object_part_swallow(oe, "video_swallow", o);
 
    offset = 20 * (eina_list_count(video_objs) - 1);
-   efl_gfx_position_set(oe, offset, offset);
+   efl_gfx_entity_position_set(oe, EINA_POSITION2D(offset, offset));
    edje_object_size_min_calc(oe, &w, &h);
-   efl_gfx_size_set(oe, w, h);
+   efl_gfx_entity_size_set(oe, EINA_SIZE2D(w,  h));
 
    efl_event_callback_array_add(o, emotion_object_test_callbacks(), oe);
 
-   edje_obj_signal_callback_add(oe, "video_control", "play", video_obj_signal_play_cb, o);
-   edje_obj_signal_callback_add(oe, "video_control", "pause", video_obj_signal_pause_cb, o);
-   edje_obj_signal_callback_add(oe, "video_control", "stop", video_obj_signal_stop_cb, o);
-   edje_obj_signal_callback_add(oe, "drag", "video_progress", video_obj_signal_jump_cb, o);
-   edje_obj_signal_callback_add(oe, "drag", "video_alpha", video_obj_signal_alpha_cb, o);
-   edje_obj_signal_callback_add(oe, "drag", "video_volume", video_obj_signal_vol_cb, o);
-   edje_obj_signal_callback_add(oe, "frame_move", "start", video_obj_signal_frame_move_start_cb, oe);
-   edje_obj_signal_callback_add(oe, "frame_move", "stop", video_obj_signal_frame_move_stop_cb, oe);
-   edje_obj_signal_callback_add(oe, "frame_resize", "start", video_obj_signal_frame_resize_start_cb, oe);
-   edje_obj_signal_callback_add(oe, "frame_resize", "stop", video_obj_signal_frame_resize_stop_cb, oe);
-   edje_obj_signal_callback_add(oe, "mouse, move", "*", video_obj_signal_frame_move_cb, oe);
+   efl_layout_signal_callback_add(oe, "video_control", "play", video_obj_signal_play_cb, o);
+   efl_layout_signal_callback_add(oe, "video_control", "pause", video_obj_signal_pause_cb, o);
+   efl_layout_signal_callback_add(oe, "video_control", "stop", video_obj_signal_stop_cb, o);
+   efl_layout_signal_callback_add(oe, "drag", "video_progress", video_obj_signal_jump_cb, o);
+   efl_layout_signal_callback_add(oe, "drag", "video_alpha", video_obj_signal_alpha_cb, o);
+   efl_layout_signal_callback_add(oe, "drag", "video_volume", video_obj_signal_vol_cb, o);
+   efl_layout_signal_callback_add(oe, "frame_move", "start", video_obj_signal_frame_move_start_cb, oe);
+   efl_layout_signal_callback_add(oe, "frame_move", "stop", video_obj_signal_frame_move_stop_cb, oe);
+   efl_layout_signal_callback_add(oe, "frame_resize", "start", video_obj_signal_frame_resize_start_cb, oe);
+   efl_layout_signal_callback_add(oe, "frame_resize", "stop", video_obj_signal_frame_resize_stop_cb, oe);
+   efl_layout_signal_callback_add(oe, "mouse, move", "*", video_obj_signal_frame_move_cb, oe);
    efl_ui_drag_value_set(efl_part(oe, "video_alpha"), 0.0, 1.0);
    efl_text_set(efl_part(oe, "video_alpha_txt"), "alpha 255");
    efl_ui_drag_value_set(efl_part(oe, "video_volume"), 0.0, 0.5);
    efl_text_set(efl_part(oe, "video_volume_txt"), "vol 0.50");
-   edje_obj_signal_emit(oe, "video_state", "play");
-   efl_gfx_visible_set(oe, EINA_TRUE);
+   efl_layout_signal_emit(oe, "video_state", "play");
+   efl_gfx_entity_visible_set(oe, EINA_TRUE);
 }
 
 int
