@@ -2,7 +2,7 @@
 #define _EO_SUITE_H
 
 #include <check.h>
-
+#include "../../efl_check.h"
 void eo_test_init(TCase *tc);
 void eo_test_general(TCase *tc);
 void eo_test_class_errors(TCase *tc);
@@ -11,5 +11,5 @@ void eo_test_call_errors(TCase *tc);
 void eo_test_value(TCase *tc);
 void eo_test_threaded_calls(TCase *tc);
 void eo_test_event(TCase *tc);
-
+void eo_test_lifecycle(TCase *tc);
 #endif /* _EO_SUITE_H */
