@@ -1,5 +1,5 @@
-#ifndef _EOLIAN_CLASS_SIMPLE_H_
-#define _EOLIAN_CLASS_SIMPLE_H_
+#ifndef _EOLIAN_CLASS_SIMPLE_EO_H_
+#define _EOLIAN_CLASS_SIMPLE_EO_H_
 
 #ifndef _CLASS_SIMPLE_EO_CLASS_TYPE
 #define _CLASS_SIMPLE_EO_CLASS_TYPE
@@ -47,6 +47,7 @@ EWAPI const Efl_Class *class_simple_class_get(void);
  *
  * comment a.set
  *
+ * @param[in] obj The object.
  * @param[in] value Value description
  *
  * @return comment for property set return
@@ -60,6 +61,8 @@ EOAPI Eina_Bool efl_canvas_object_simple_a_set(Eo *obj, int value);
 /**
  * @brief Common desc for a
  *
+ * @param[in] obj The object.
+ *
  * @return Value description
  *
  * @ingroup Class_Simple
@@ -73,6 +76,7 @@ EOAPI void efl_canvas_object_simple_b_set(Eo *obj);
 /**
  * @brief comment foo
  *
+ * @param[in] obj The object.
  * @param[in] a a
  * @param[in,out] b
  * @param[out] c
