@@ -1,5 +1,5 @@
-#ifndef _EOLIAN_CLASS_SIMPLE_LEGACY_H_
-#define _EOLIAN_CLASS_SIMPLE_LEGACY_H_
+#ifndef _EOLIAN_CLASS_SIMPLE_EO_LEGACY_H_
+#define _EOLIAN_CLASS_SIMPLE_EO_LEGACY_H_
 
 #ifndef _CLASS_SIMPLE_EO_CLASS_TYPE
 #define _CLASS_SIMPLE_EO_CLASS_TYPE
