@@ -8,13 +8,25 @@
 
 #include "eolian_suite.h"
 #include "../efl_check.h"
+#include <Eolian.h>
 
 static const Efl_Test_Case etc[] = {
   { "Eolian Parsing", eolian_parsing_test},
+  { "Eolian Static Analysis", eolian_static_test},
   { "Eolian Generation", eolian_generation_test},
   { NULL, NULL }
 };
 
+SUITE_INIT(eolian)
+{
+   ck_assert_int_eq(eolian_init(), 1);
+}
+
+SUITE_SHUTDOWN(eolian)
+{
+   ck_assert_int_eq(eolian_shutdown(), 0);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -30,7 +42,7 @@ main(int argc, char **argv)
 #endif
 
    failed_count = _efl_suite_build_and_run(argc - 1, (const char **)argv + 1,
-                                           "Eolian", etc);
+                                           "Eolian", etc, SUITE_INIT_FN(eolian), SUITE_SHUTDOWN_FN(eolian));
 
    return (failed_count == 0) ? 0 : 255;
 }
