@@ -2,8 +2,9 @@
 #define _EOLIAN_SUITE_H
 
 #include <check.h>
-
+#include "../efl_check.h"
 void eolian_parsing_test(TCase *tc);
+void eolian_static_test(TCase *tc);
 void eolian_generation_test(TCase *tc);
 
 #endif /* _EOLIAN_SUITE_H */
