@@ -13,6 +13,7 @@ static const Efl_Test_Case etc[] = {
   { "Eolian-Cxx Inheritance", eolian_cxx_test_inheritance },
   { "Eolian-Cxx Binding", eolian_cxx_test_binding },
   { "Eolian-Cxx Cyclic", eolian_cxx_test_cyclic },
+  { "Eolian-Cxx Documentation", eolian_cxx_test_documentation },
   { NULL, NULL }
 };
 
@@ -27,7 +28,7 @@ main(int argc, char* argv[])
    putenv(const_cast<char*>("EFL_RUN_IN_TREE=1"));
 
    failed_count = _efl_suite_build_and_run(argc - 1, (const char **)argv + 1,
-                                           "Eolian C++", etc);
+                                           "Eolian C++", etc, NULL, NULL);
 
    return (failed_count == 0) ? 0 : 255;
 }
