@@ -3,12 +3,14 @@
 #endif
 
 #include <Evas.h>
+#include <Ecore_Evas.h>
 
 #include "evas_suite.h"
 #include "../efl_check.h"
 
 static const Efl_Test_Case etc[] = {
   { "Evas", evas_test_init },
+  { "Evas New", evas_test_new },
   { "Object", evas_test_object },
   { "Object Textblock", evas_test_textblock },
   { "Object Text", evas_test_text },
@@ -16,7 +18,11 @@ static const Efl_Test_Case etc[] = {
   { "Render Engines", evas_test_render_engines },
   { "Filters", evas_test_filters },
   { "Images", evas_test_image_object },
+  { "Images", evas_test_image_object2 },
   { "Meshes", evas_test_mesh },
+  { "Meshes", evas_test_mesh1 },
+  { "Meshes", evas_test_mesh2 },
+  { "Meshes", evas_test_mesh3 },
   { "Masking", evas_test_mask },
   { "Evas GL", evas_test_evasgl },
   { "Object Smart", evas_test_object_smart },
@@ -24,6 +30,18 @@ static const Efl_Test_Case etc[] = {
   { NULL, NULL }
 };
 
+SUITE_INIT(evas)
+{
+   ck_assert_int_eq(evas_init(), 1);
+   ck_assert_int_eq(ecore_evas_init(), 1);
+}
+
+SUITE_SHUTDOWN(evas)
+{
+   ck_assert_int_eq(ecore_evas_shutdown(), 0);
+   ck_assert_int_eq(evas_shutdown(), 0);
+}
+
 int
 main(int argc, char **argv)
 {
@@ -36,12 +54,8 @@ main(int argc, char **argv)
    putenv("EFL_RUN_IN_TREE=1");
 #endif
 
-   evas_init();
-
    failed_count = _efl_suite_build_and_run(argc - 1, (const char **)argv + 1,
-                                           "Evas", etc);
-
-   evas_shutdown();
+                                           "Evas", etc, SUITE_INIT_FN(evas), SUITE_SHUTDOWN_FN(evas));
 
    return (failed_count == 0) ? 0 : 255;
 }
