@@ -9,7 +9,7 @@
 #include "evas_suite.h"
 #include "evas_tests_helpers.h"
 
-START_TEST(evas_object_various)
+EFL_START_TEST(evas_object_various)
 {
    Evas *evas = EVAS_TEST_INIT_EVAS();
 
@@ -20,16 +20,15 @@ START_TEST(evas_object_various)
    evas_object_unref(obj);
 
    evas = EVAS_TEST_INIT_EVAS();
+   obj = evas_object_rectangle_add(evas);
    efl_ref(obj);
    evas_free(evas);
    efl_unref(obj);
 
 
    /* Twice because EVAS_TEST_INIT_EVAS inits it twice. */
-   evas_shutdown();
-   evas_shutdown();
 }
-END_TEST
+EFL_END_TEST
 
 void evas_test_object(TCase *tc)
 {
